@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.expressions;
 
+import java.util.Locale;
 import org.apache.iceberg.Accessor;
 import org.apache.iceberg.StructLike;
 import org.apache.iceberg.types.Type;
@@ -27,10 +27,12 @@ import org.apache.iceberg.types.Types;
 public class BoundReference<T> implements BoundTerm<T>, Reference<T> {
   private final Types.NestedField field;
   private final Accessor<StructLike> accessor;
+  private final String name;
 
-  BoundReference(Types.NestedField field, Accessor<StructLike> accessor) {
+  BoundReference(Types.NestedField field, Accessor<StructLike> accessor, String name) {
     this.field = field;
     this.accessor = accessor;
+    this.name = name;
   }
 
   @Override
@@ -53,14 +55,24 @@ public class BoundReference<T> implements BoundTerm<T>, Reference<T> {
     return field.type();
   }
 
+  @Override
+  public boolean producesNull() {
+    return field.isOptional();
+  }
+
+  @Override
+  public String name() {
+    return name;
+  }
+
   @Override
   public boolean isEquivalentTo(BoundTerm<?> other) {
     if (other instanceof BoundReference) {
       Types.NestedField otherField = ((BoundReference<?>) other).field();
       // equivalence only depends on the field ID, type, and optional. name and accessor are ignored
-      return field.fieldId() == otherField.fieldId() &&
-          field.type().equals(otherField.type()) &&
-          field.isOptional() == otherField.isOptional();
+      return field.fieldId() == otherField.fieldId()
+          && field.type().equals(otherField.type())
+          && field.isOptional() == otherField.isOptional();
     }
 
     return other.isEquivalentTo(this);
@@ -76,6 +88,7 @@ public class BoundReference<T> implements BoundTerm<T>, Reference<T> {
 
   @Override
   public String toString() {
-    return String.format("ref(id=%d, accessor-type=%s)", field.fieldId(), accessor.type());
+    return String.format(
+        Locale.ROOT, "ref(id=%d, accessor-type=%s)", field.fieldId(), accessor.type());
   }
 }
