@@ -21,9 +21,11 @@ package org.apache.iceberg.types;
 import java.nio.ByteBuffer;
 import java.util.Comparator;
 import java.util.List;
+import java.util.Map;
 import java.util.function.IntFunction;
 import org.apache.iceberg.StructLike;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
+import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.util.UnicodeUtil;
 
 public class Comparators {
@@ -56,6 +58,10 @@ public class Comparators {
     return new ListComparator<>(list);
   }
 
+  public static <K, V> Comparator<Map<K, V>> forType(Types.MapType mapType) {
+    return new MapComparator<>(mapType);
+  }
+
   @SuppressWarnings("unchecked")
   public static <T> Comparator<T> forType(Type.PrimitiveType type) {
     Comparator<?> cmp = COMPARATORS.get(type);
@@ -78,6 +84,8 @@ public class Comparators {
       return (Comparator<T>) forType(type.asStructType());
     } else if (type.isListType()) {
       return (Comparator<T>) forType(type.asListType());
+    } else if (type.isMapType()) {
+      return (Comparator<T>) forType(type.asMapType());
     }
 
     throw new UnsupportedOperationException("Cannot determine comparator for type: " + type);
@@ -149,6 +157,51 @@ public class Comparators {
     }
   }
 
+  private static class MapComparator<K, V> implements Comparator<Map<K, V>> {
+    private final Comparator<K> keyComparator;
+    private final Comparator<V> valueComparator;
+    private final Comparator<List<K>> keyListComparator;
+
+    private MapComparator(Types.MapType mapType) {
+      this.keyComparator = internal(mapType.keyType());
+      this.valueComparator =
+          mapType.isValueOptional()
+              ? Comparators.<V>nullsFirst().thenComparing(internal(mapType.valueType()))
+              : internal(mapType.valueType());
+      this.keyListComparator =
+          internal(Types.ListType.ofRequired(mapType.keyId(), mapType.keyType()));
+    }
+
+    @Override
+    public int compare(Map<K, V> o1, Map<K, V> o2) {
+      if (o1 == o2) {
+        return 0;
+      }
+
+      List<K> keys1 = Lists.newArrayList(o1.keySet());
+      List<K> keys2 = Lists.newArrayList(o2.keySet());
+      keys1.sort(keyComparator);
+      keys2.sort(keyComparator);
+
+      int cmp = keyListComparator.compare(keys1, keys2);
+      if (cmp != 0) {
+        return cmp;
+      }
+
+      for (K key : keys1) {
+        V value1 = o1.get(key);
+        V value2 = o2.get(key);
+
+        cmp = valueComparator.compare(value1, value2);
+        if (cmp != 0) {
+          return cmp;
+        }
+      }
+
+      return 0;
+    }
+  }
+
   public static Comparator<ByteBuffer> unsignedBytes() {
     return UnsignedByteBufComparator.INSTANCE;
   }
