@@ -35,4 +35,23 @@ public interface VariantArray extends VariantValue {
   default VariantArray asArray() {
     return this;
   }
+
+  static String asString(VariantArray arr) {
+    StringBuilder builder = new StringBuilder();
+
+    builder.append("VariantArray([");
+    boolean first = true;
+    for (int i = 0; i < arr.numElements(); i++) {
+      if (first) {
+        first = false;
+      } else {
+        builder.append(", ");
+      }
+
+      builder.append(arr.get(i));
+    }
+    builder.append("])");
+
+    return builder.toString();
+  }
 }
