@@ -18,15 +18,12 @@
  */
 package org.apache.iceberg.view;
 
-import org.immutables.value.Value;
-
 /**
  * View history entry.
  *
  * <p>An entry contains a change to the view state. At the given timestamp, the current version was
  * set to the given version ID.
  */
-@Value.Immutable
 public interface ViewHistoryEntry {
   /** Return the timestamp in milliseconds of the change */
   long timestampMillis();
