@@ -27,7 +27,10 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.nio.ByteBuffer;
 import java.util.Map;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.types.Type;
+import org.apache.iceberg.types.Types;
 import org.junit.jupiter.api.Test;
 
 public class TestMetricsSerialization {
@@ -88,7 +91,9 @@ public class TestMetricsSerialization {
     Map<Integer, ByteBuffer> byteMap2 = Maps.newHashMap();
     byteMap1.put(3, ByteBuffer.wrap(new byte[] {1, 2}));
 
-    return new Metrics(0L, longMap1, longMap2, longMap3, null, byteMap1, byteMap2);
+    Map<Integer, Type> originalTypes =
+        ImmutableMap.of(1, Types.IntegerType.get(), 2, Types.IntegerType.get());
+    return new Metrics(0L, longMap1, longMap2, longMap3, null, byteMap1, byteMap2, originalTypes);
   }
 
   private static Metrics generateMetricsWithNulls() {
@@ -100,7 +105,8 @@ public class TestMetricsSerialization {
     byteMap.put(null, ByteBuffer.wrap(new byte[] {1, 2, 3}));
     byteMap.put(4, null);
 
-    return new Metrics(null, null, longMap, longMap, null, null, byteMap);
+    Map<Integer, Type> originalTypes = ImmutableMap.of(4, Types.IntegerType.get());
+    return new Metrics(null, null, longMap, longMap, null, null, byteMap, originalTypes);
   }
 
   private static void assertEquals(Metrics expected, Metrics actual) {
@@ -111,6 +117,8 @@ public class TestMetricsSerialization {
 
     assertEquals(expected.lowerBounds(), actual.lowerBounds());
     assertEquals(expected.upperBounds(), actual.upperBounds());
+    // originalTypes isn't serialized
+    assertThat(actual.originalTypes()).isNull();
   }
 
   private static void assertEquals(
