@@ -27,9 +27,12 @@ import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import java.util.List;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
+import org.apache.iceberg.expressions.Literal;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
+import org.apache.iceberg.types.EdgeAlgorithm;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
+import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.Arguments;
 import org.junit.jupiter.params.provider.FieldSource;
@@ -42,7 +45,10 @@ public class TestSchema {
           Types.TimestampNanoType.withoutZone(),
           Types.TimestampNanoType.withZone(),
           Types.VariantType.get(),
-          Types.UnknownType.get());
+          Types.GeometryType.crs84(),
+          Types.GeometryType.of("srid:3857"),
+          Types.GeographyType.crs84(),
+          Types.GeographyType.of("srid:4269", EdgeAlgorithm.KARNEY));
 
   private static final Schema INITIAL_DEFAULT_SCHEMA =
       new Schema(
@@ -50,8 +56,8 @@ public class TestSchema {
           Types.NestedField.required("has_default")
               .withId(2)
               .ofType(Types.StringType.get())
-              .withInitialDefault("--")
-              .withWriteDefault("--")
+              .withInitialDefault(Literal.of("--"))
+              .withWriteDefault(Literal.of("--"))
               .build());
 
   private static final Schema WRITE_DEFAULT_SCHEMA =
@@ -60,7 +66,7 @@ public class TestSchema {
           Types.NestedField.required("has_default")
               .withId(2)
               .ofType(Types.StringType.get())
-              .withWriteDefault("--")
+              .withWriteDefault(Literal.of("--"))
               .build());
 
   private Schema generateTypeSchema(Type type) {
@@ -122,6 +128,56 @@ public class TestSchema {
                     .mapToObj(supportedVersion -> Arguments.of(type, supportedVersion)));
   }
 
+  @Test
+  public void testUnknownSupport() {
+    // this needs a different schema because it cannot be used in required fields
+    Schema schemaWithUnknown =
+        new Schema(
+            Types.NestedField.required(1, "id", Types.LongType.get()),
+            Types.NestedField.optional(2, "top", Types.UnknownType.get()),
+            Types.NestedField.optional(
+                3, "arr", Types.ListType.ofOptional(4, Types.UnknownType.get())),
+            Types.NestedField.required(
+                5,
+                "struct",
+                Types.StructType.of(
+                    Types.NestedField.optional(6, "inner_op", Types.UnknownType.get()),
+                    Types.NestedField.optional(
+                        7,
+                        "inner_map",
+                        Types.MapType.ofOptional(
+                            8, 9, Types.StringType.get(), Types.UnknownType.get())),
+                    Types.NestedField.optional(
+                        10,
+                        "struct_arr",
+                        Types.StructType.of(
+                            Types.NestedField.optional(11, "deep", Types.UnknownType.get()))))));
+
+    assertThatThrownBy(() -> Schema.checkCompatibility(schemaWithUnknown, 2))
+        .isInstanceOf(IllegalStateException.class)
+        .hasMessage(
+            "Invalid schema for v%s:\n"
+                + "- Invalid type for top: %s is not supported until v%s\n"
+                + "- Invalid type for arr.element: %s is not supported until v%s\n"
+                + "- Invalid type for struct.inner_op: %s is not supported until v%s\n"
+                + "- Invalid type for struct.inner_map.value: %s is not supported until v%s\n"
+                + "- Invalid type for struct.struct_arr.deep: %s is not supported until v%s",
+            2,
+            Types.UnknownType.get(),
+            MIN_FORMAT_VERSIONS.get(Type.TypeID.UNKNOWN),
+            Types.UnknownType.get(),
+            MIN_FORMAT_VERSIONS.get(Type.TypeID.UNKNOWN),
+            Types.UnknownType.get(),
+            MIN_FORMAT_VERSIONS.get(Type.TypeID.UNKNOWN),
+            Types.UnknownType.get(),
+            MIN_FORMAT_VERSIONS.get(Type.TypeID.UNKNOWN),
+            Types.UnknownType.get(),
+            MIN_FORMAT_VERSIONS.get(Type.TypeID.UNKNOWN));
+
+    assertThatCode(() -> Schema.checkCompatibility(schemaWithUnknown, 3))
+        .doesNotThrowAnyException();
+  }
+
   @ParameterizedTest
   @MethodSource("supportedTypes")
   public void testTypeSupported(Type type, int supportedVersion) {
