@@ -38,6 +38,7 @@ import software.amazon.awssdk.awscore.client.builder.AwsClientBuilder;
 import software.amazon.awssdk.core.client.config.ClientOverrideConfiguration;
 import software.amazon.awssdk.core.retry.RetryMode;
 import software.amazon.awssdk.regions.Region;
+import software.amazon.awssdk.services.s3.LegacyMd5Plugin;
 import software.amazon.awssdk.services.s3.S3CrtAsyncClientBuilder;
 
 public class AwsClientProperties implements Serializable {
@@ -82,11 +83,20 @@ public class AwsClientProperties implements Serializable {
   /** Controls whether vended credentials should be refreshed or not. Defaults to true. */
   public static final String REFRESH_CREDENTIALS_ENABLED = "client.refresh-credentials-enabled";
 
+  /**
+   * Controls whether legacy MD5 plugin should be added or not. Defaults to false. AWS SDK version
+   * 2.30.0 introduced integrity protections that are not backward compatible. Enable this property
+   * only when you need to access older S3-compatible object storages that depend on the legacy MD5
+   * checksum.
+   */
+  public static final String LEGACY_MD5_PLUGIN_ENABLED = "client.legacy-md5-plugin-enabled";
+
   private String clientRegion;
   private final String clientCredentialsProvider;
   private final Map<String, String> clientCredentialsProviderProperties;
   private final String refreshCredentialsEndpoint;
   private final boolean refreshCredentialsEnabled;
+  private final boolean legacyMd5pluginEnabled;
   private final Map<String, String> allProperties;
 
   public AwsClientProperties() {
@@ -95,6 +105,7 @@ public class AwsClientProperties implements Serializable {
     this.clientCredentialsProviderProperties = null;
     this.refreshCredentialsEndpoint = null;
     this.refreshCredentialsEnabled = true;
+    this.legacyMd5pluginEnabled = false;
     this.allProperties = null;
   }
 
@@ -109,6 +120,8 @@ public class AwsClientProperties implements Serializable {
             properties.get(CatalogProperties.URI), properties.get(REFRESH_CREDENTIALS_ENDPOINT));
     this.refreshCredentialsEnabled =
         PropertyUtil.propertyAsBoolean(properties, REFRESH_CREDENTIALS_ENABLED, true);
+    this.legacyMd5pluginEnabled =
+        PropertyUtil.propertyAsBoolean(properties, LEGACY_MD5_PLUGIN_ENABLED, false);
   }
 
   public String clientRegion() {
@@ -128,7 +141,8 @@ public class AwsClientProperties implements Serializable {
    *     S3Client.builder().applyMutation(awsClientProperties::applyClientRegionConfiguration)
    * </pre>
    */
-  public <T extends AwsClientBuilder> void applyClientRegionConfiguration(T builder) {
+  public <BuilderT extends AwsClientBuilder<BuilderT, ClientT>, ClientT>
+      void applyClientRegionConfiguration(BuilderT builder) {
     if (clientRegion != null) {
       builder.region(Region.of(clientRegion));
     }
@@ -158,7 +172,8 @@ public class AwsClientProperties implements Serializable {
    *     DynamoDbClient.builder().applyMutation(awsClientProperties::applyClientCredentialConfigurations)
    * </pre>
    */
-  public <T extends AwsClientBuilder> void applyClientCredentialConfigurations(T builder) {
+  public <BuilderT extends AwsClientBuilder<BuilderT, ClientT>, ClientT>
+      void applyClientCredentialConfigurations(BuilderT builder) {
     if (!Strings.isNullOrEmpty(this.clientCredentialsProvider)) {
       builder.credentialsProvider(credentialsProvider(this.clientCredentialsProvider));
     }
@@ -231,7 +246,8 @@ public class AwsClientProperties implements Serializable {
    *   KmsClient.builder().applyMutation(awsClientProperties::applyRetryConfigurations)
    * </pre>
    */
-  public <T extends AwsClientBuilder> void applyRetryConfigurations(T builder) {
+  public <BuilderT extends AwsClientBuilder<BuilderT, ClientT>, ClientT>
+      void applyRetryConfigurations(BuilderT builder) {
     ClientOverrideConfiguration.Builder configBuilder =
         null != builder.overrideConfiguration()
             ? builder.overrideConfiguration().toBuilder()
@@ -240,6 +256,22 @@ public class AwsClientProperties implements Serializable {
     builder.overrideConfiguration(configBuilder.retryStrategy(RetryMode.ADAPTIVE_V2).build());
   }
 
+  /**
+   * Add a legacy md5 plugin if it is enabled.
+   *
+   * <p>Sample usage:
+   *
+   * <pre>
+   *     S3Client.builder().applyMutation(awsClientProperties::applyLegacyMd5Plugin)
+   * </pre>
+   */
+  public <BuilderT extends AwsClientBuilder<BuilderT, ClientT>, ClientT> void applyLegacyMd5Plugin(
+      BuilderT builder) {
+    if (legacyMd5pluginEnabled) {
+      builder.addPlugin(LegacyMd5Plugin.create());
+    }
+  }
+
   private AwsCredentialsProvider credentialsProvider(String credentialsProviderClass) {
     Class<?> providerClass;
     try {
