@@ -18,9 +18,9 @@
  */
 package org.apache.iceberg.aws.s3;
 
-import org.apache.iceberg.aws.AwsProperties;
 import org.apache.iceberg.metrics.MetricsContext;
 import software.amazon.awssdk.http.HttpStatusCode;
+import software.amazon.awssdk.services.s3.S3AsyncClient;
 import software.amazon.awssdk.services.s3.S3Client;
 import software.amazon.awssdk.services.s3.model.HeadObjectRequest;
 import software.amazon.awssdk.services.s3.model.HeadObjectResponse;
@@ -28,15 +28,22 @@ import software.amazon.awssdk.services.s3.model.S3Exception;
 
 abstract class BaseS3File {
   private final S3Client client;
+  private final S3AsyncClient asyncClient;
   private final S3URI uri;
-  private final AwsProperties awsProperties;
+  private final S3FileIOProperties s3FileIOProperties;
   private HeadObjectResponse metadata;
   private final MetricsContext metrics;
 
-  BaseS3File(S3Client client, S3URI uri, AwsProperties awsProperties, MetricsContext metrics) {
+  BaseS3File(
+      S3Client client,
+      S3AsyncClient asyncClient,
+      S3URI uri,
+      S3FileIOProperties s3FileIOProperties,
+      MetricsContext metrics) {
     this.client = client;
+    this.asyncClient = asyncClient;
     this.uri = uri;
-    this.awsProperties = awsProperties;
+    this.s3FileIOProperties = s3FileIOProperties;
     this.metrics = metrics;
   }
 
@@ -48,12 +55,16 @@ abstract class BaseS3File {
     return client;
   }
 
+  S3AsyncClient asyncClient() {
+    return asyncClient;
+  }
+
   S3URI uri() {
     return uri;
   }
 
-  public AwsProperties awsProperties() {
-    return awsProperties;
+  public S3FileIOProperties s3FileIOProperties() {
+    return s3FileIOProperties;
   }
 
   protected MetricsContext metrics() {
@@ -81,7 +92,7 @@ abstract class BaseS3File {
     if (metadata == null) {
       HeadObjectRequest.Builder requestBuilder =
           HeadObjectRequest.builder().bucket(uri().bucket()).key(uri().key());
-      S3RequestUtil.configureEncryption(awsProperties, requestBuilder);
+      S3RequestUtil.configureEncryption(s3FileIOProperties, requestBuilder);
       metadata = client().headObject(requestBuilder.build());
     }
 
