@@ -30,7 +30,6 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.stream.Collectors;
-import org.apache.iceberg.aws.AwsClientFactory;
 import org.apache.iceberg.aws.S3FileIOAwsClientFactories;
 import org.apache.iceberg.common.DynConstructors;
 import org.apache.iceberg.io.BulkDeletionFailureException;
@@ -43,6 +42,7 @@ import org.apache.iceberg.io.StorageCredential;
 import org.apache.iceberg.io.SupportsRecoveryOperations;
 import org.apache.iceberg.io.SupportsStorageCredentials;
 import org.apache.iceberg.metrics.MetricsContext;
+import org.apache.iceberg.relocated.com.google.common.annotations.VisibleForTesting;
 import org.apache.iceberg.relocated.com.google.common.base.Joiner;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
@@ -93,19 +93,19 @@ public class S3FileIO
   private static final Logger LOG = LoggerFactory.getLogger(S3FileIO.class);
   private static final String DEFAULT_METRICS_IMPL =
       "org.apache.iceberg.hadoop.HadoopMetricsContext";
+  private static final String ROOT_PREFIX = "s3";
   private static volatile ExecutorService executorService;
 
   private String credential = null;
   private SerializableSupplier<S3Client> s3;
   private SerializableSupplier<S3AsyncClient> s3Async;
-  private S3FileIOProperties s3FileIOProperties;
   private SerializableMap<String, String> properties = null;
-  private transient volatile S3Client client;
-  private transient volatile S3AsyncClient asyncClient;
   private MetricsContext metrics = MetricsContext.nullMetrics();
   private final AtomicBoolean isResourceClosed = new AtomicBoolean(false);
   private transient StackTraceElement[] createStack;
-  private List<StorageCredential> storageCredentials = ImmutableList.of();
+  // use modifiable collection for Kryo serde
+  private List<StorageCredential> storageCredentials = Lists.newArrayList();
+  private transient volatile Map<String, PrefixedS3Client> clientByPrefix;
 
   /**
    * No-arg constructor to load the FileIO dynamically.
@@ -144,7 +144,10 @@ public class S3FileIO
    *
    * @param s3 s3 supplier
    * @param s3FileIOProperties S3 FileIO properties
+   * @deprecated since 1.10.0, will be removed in 1.11.0; use {@link
+   *     S3FileIO#S3FileIO(SerializableSupplier)} with {@link S3FileIO#initialize(Map)} instead
    */
+  @Deprecated
   public S3FileIO(SerializableSupplier<S3Client> s3, S3FileIOProperties s3FileIOProperties) {
     this(s3, null, s3FileIOProperties);
   }
@@ -157,47 +160,43 @@ public class S3FileIO
    * @param s3 s3 supplier
    * @param s3Async s3Async supplier
    * @param s3FileIOProperties S3 FileIO properties
+   * @deprecated since 1.10.0, will be removed in 1.11.0; use {@link
+   *     S3FileIO#S3FileIO(SerializableSupplier, SerializableSupplier)} with {@link
+   *     S3FileIO#initialize(Map)} instead
    */
+  @Deprecated
   public S3FileIO(
       SerializableSupplier<S3Client> s3,
       SerializableSupplier<S3AsyncClient> s3Async,
       S3FileIOProperties s3FileIOProperties) {
     this.s3 = s3;
     this.s3Async = s3Async;
-    this.s3FileIOProperties = s3FileIOProperties;
     this.createStack = Thread.currentThread().getStackTrace();
+    this.properties = SerializableMap.copyOf(s3FileIOProperties.properties());
   }
 
   @Override
   public InputFile newInputFile(String path) {
-    if (shouldUseAsyncClient()) {
-      return S3InputFile.fromLocation(path, client(), asyncClient(), s3FileIOProperties, metrics);
-    }
-    return S3InputFile.fromLocation(path, client(), s3FileIOProperties, metrics);
+    return S3InputFile.fromLocation(path, clientForStoragePath(path), metrics);
   }
 
   @Override
   public InputFile newInputFile(String path, long length) {
-    if (shouldUseAsyncClient()) {
-      return S3InputFile.fromLocation(
-          path, length, client(), asyncClient(), s3FileIOProperties, metrics);
-    }
-    return S3InputFile.fromLocation(path, length, client(), s3FileIOProperties, metrics);
+    return S3InputFile.fromLocation(path, length, clientForStoragePath(path), metrics);
   }
 
   @Override
   public OutputFile newOutputFile(String path) {
-    if (shouldUseAsyncClient()) {
-      return S3OutputFile.fromLocation(path, client(), asyncClient(), s3FileIOProperties, metrics);
-    }
-    return S3OutputFile.fromLocation(path, client(), s3FileIOProperties, metrics);
+    return S3OutputFile.fromLocation(path, clientForStoragePath(path), metrics);
   }
 
   @Override
   public void deleteFile(String path) {
+    PrefixedS3Client client = clientForStoragePath(path);
+    S3FileIOProperties s3FileIOProperties = client.s3FileIOProperties();
     if (s3FileIOProperties.deleteTags() != null && !s3FileIOProperties.deleteTags().isEmpty()) {
       try {
-        tagFileToDelete(path, s3FileIOProperties.deleteTags());
+        tagFileToDelete(client, path, s3FileIOProperties.deleteTags());
       } catch (S3Exception e) {
         LOG.warn("Failed to add delete tags: {} to {}", s3FileIOProperties.deleteTags(), path, e);
       }
@@ -211,7 +210,7 @@ public class S3FileIO
     DeleteObjectRequest deleteRequest =
         DeleteObjectRequest.builder().bucket(location.bucket()).key(location.key()).build();
 
-    client().deleteObject(deleteRequest);
+    client.s3().deleteObject(deleteRequest);
   }
 
   @Override
@@ -229,6 +228,7 @@ public class S3FileIO
    */
   @Override
   public void deleteFiles(Iterable<String> paths) throws BulkDeletionFailureException {
+    S3FileIOProperties s3FileIOProperties = clientForStoragePath(ROOT_PREFIX).s3FileIOProperties();
     if (s3FileIOProperties.deleteTags() != null && !s3FileIOProperties.deleteTags().isEmpty()) {
       Tasks.foreach(paths)
           .noRetry()
@@ -241,7 +241,10 @@ public class S3FileIO
                       s3FileIOProperties.deleteTags(),
                       path,
                       exc))
-          .run(path -> tagFileToDelete(path, s3FileIOProperties.deleteTags()));
+          .run(
+              path ->
+                  tagFileToDelete(
+                      clientForStoragePath(path), path, s3FileIOProperties.deleteTags()));
     }
 
     if (s3FileIOProperties.isDeleteEnabled()) {
@@ -249,14 +252,15 @@ public class S3FileIO
           Multimaps.newSetMultimap(Maps.newHashMap(), Sets::newHashSet);
       List<Future<List<String>>> deletionTasks = Lists.newArrayList();
       for (String path : paths) {
-        S3URI location = new S3URI(path, s3FileIOProperties.bucketToAccessPointMapping());
+        PrefixedS3Client client = clientForStoragePath(path);
+        S3URI location = new S3URI(path, client.s3FileIOProperties().bucketToAccessPointMapping());
         String bucket = location.bucket();
         String objectKey = location.key();
         bucketToObjects.get(bucket).add(objectKey);
-        if (bucketToObjects.get(bucket).size() == s3FileIOProperties.deleteBatchSize()) {
+        if (bucketToObjects.get(bucket).size() == client.s3FileIOProperties().deleteBatchSize()) {
           Set<String> keys = Sets.newHashSet(bucketToObjects.get(bucket));
           Future<List<String>> deletionTask =
-              executorService().submit(() -> deleteBatch(bucket, keys));
+              executorService().submit(() -> deleteBatch(client, bucket, keys));
           deletionTasks.add(deletionTask);
           bucketToObjects.removeAll(bucket);
         }
@@ -268,7 +272,8 @@ public class S3FileIO
         String bucket = bucketToObjectsEntry.getKey();
         Collection<String> keys = bucketToObjectsEntry.getValue();
         Future<List<String>> deletionTask =
-            executorService().submit(() -> deleteBatch(bucket, keys));
+            executorService()
+                .submit(() -> deleteBatch(clientForStoragePath("s3://" + bucket), bucket, keys));
         deletionTasks.add(deletionTask);
       }
 
@@ -294,14 +299,15 @@ public class S3FileIO
     }
   }
 
-  private void tagFileToDelete(String path, Set<Tag> deleteTags) throws S3Exception {
-    S3URI location = new S3URI(path, s3FileIOProperties.bucketToAccessPointMapping());
+  private void tagFileToDelete(PrefixedS3Client client, String path, Set<Tag> deleteTags)
+      throws S3Exception {
+    S3URI location = new S3URI(path, client.s3FileIOProperties().bucketToAccessPointMapping());
     String bucket = location.bucket();
     String objectKey = location.key();
     GetObjectTaggingRequest getObjectTaggingRequest =
         GetObjectTaggingRequest.builder().bucket(bucket).key(objectKey).build();
     GetObjectTaggingResponse getObjectTaggingResponse =
-        client().getObjectTagging(getObjectTaggingRequest);
+        client.s3().getObjectTagging(getObjectTaggingRequest);
     // Get existing tags, if any and then add the delete tags
     Set<Tag> tags = Sets.newHashSet();
     if (getObjectTaggingResponse.hasTagSet()) {
@@ -315,10 +321,11 @@ public class S3FileIO
             .key(objectKey)
             .tagging(Tagging.builder().tagSet(tags).build())
             .build();
-    client().putObjectTagging(putObjectTaggingRequest);
+    client.s3().putObjectTagging(putObjectTaggingRequest);
   }
 
-  private List<String> deleteBatch(String bucket, Collection<String> keysToDelete) {
+  private List<String> deleteBatch(
+      PrefixedS3Client client, String bucket, Collection<String> keysToDelete) {
     List<ObjectIdentifier> objectIds =
         keysToDelete.stream()
             .map(key -> ObjectIdentifier.builder().key(key).build())
@@ -330,7 +337,7 @@ public class S3FileIO
             .build();
     List<String> failures = Lists.newArrayList();
     try {
-      DeleteObjectsResponse response = client().deleteObjects(request);
+      DeleteObjectsResponse response = client.s3().deleteObjects(request);
       if (response.hasErrors()) {
         failures.addAll(
             response.errors().stream()
@@ -349,9 +356,11 @@ public class S3FileIO
 
   @Override
   public Iterable<FileInfo> listPrefix(String prefix) {
-    S3URI uri = new S3URI(prefix, s3FileIOProperties.bucketToAccessPointMapping());
+    PrefixedS3Client client = clientForStoragePath(prefix);
+
+    S3URI uri = new S3URI(prefix, client.s3FileIOProperties().bucketToAccessPointMapping());
     if (uri.useS3DirectoryBucket()
-        && s3FileIOProperties.isS3DirectoryBucketListPrefixAsDirectory()) {
+        && client.s3FileIOProperties().isS3DirectoryBucketListPrefixAsDirectory()) {
       uri = uri.toDirectoryPath();
     }
 
@@ -360,7 +369,7 @@ public class S3FileIO
         ListObjectsV2Request.builder().bucket(s3uri.bucket()).prefix(s3uri.key()).build();
 
     return () ->
-        client().listObjectsV2Paginator(request).stream()
+        client.s3().listObjectsV2Paginator(request).stream()
             .flatMap(r -> r.contents().stream())
             .map(
                 o ->
@@ -385,29 +394,72 @@ public class S3FileIO
   }
 
   public S3Client client() {
-    if (client == null) {
-      synchronized (this) {
-        if (client == null) {
-          client = s3.get();
-        }
-      }
-    }
-    return client;
+    return client(ROOT_PREFIX);
+  }
+
+  @SuppressWarnings("resource")
+  public S3Client client(String storagePath) {
+    return clientForStoragePath(storagePath).s3();
   }
 
   public S3AsyncClient asyncClient() {
-    if (asyncClient == null) {
+    return asyncClient(ROOT_PREFIX);
+  }
+
+  @SuppressWarnings("resource")
+  public S3AsyncClient asyncClient(String storagePath) {
+    return clientForStoragePath(storagePath).s3Async();
+  }
+
+  @VisibleForTesting
+  PrefixedS3Client clientForStoragePath(String storagePath) {
+    PrefixedS3Client client;
+    String matchingPrefix = ROOT_PREFIX;
+
+    for (String storagePrefix : clientByPrefix().keySet()) {
+      if (storagePath.startsWith(storagePrefix)
+          && storagePrefix.length() > matchingPrefix.length()) {
+        matchingPrefix = storagePrefix;
+      }
+    }
+
+    client = clientByPrefix().getOrDefault(matchingPrefix, null);
+
+    Preconditions.checkState(
+        null != client, "[BUG] S3 client for storage path not available: %s", storagePath);
+    return client;
+  }
+
+  private Map<String, PrefixedS3Client> clientByPrefix() {
+    if (null == clientByPrefix) {
       synchronized (this) {
-        if (asyncClient == null) {
-          asyncClient = s3Async.get();
+        if (null == clientByPrefix) {
+          Map<String, PrefixedS3Client> localClientByPrefix = Maps.newHashMap();
+
+          localClientByPrefix.put(
+              ROOT_PREFIX, new PrefixedS3Client(ROOT_PREFIX, properties, s3, s3Async));
+          storageCredentials.stream()
+              .filter(c -> c.prefix().startsWith(ROOT_PREFIX))
+              .collect(Collectors.toList())
+              .forEach(
+                  storageCredential -> {
+                    Map<String, String> propertiesWithCredentials =
+                        ImmutableMap.<String, String>builder()
+                            .putAll(properties)
+                            .putAll(storageCredential.config())
+                            .buildKeepingLast();
+
+                    localClientByPrefix.put(
+                        storageCredential.prefix(),
+                        new PrefixedS3Client(
+                            storageCredential.prefix(), propertiesWithCredentials, s3, s3Async));
+                  });
+          this.clientByPrefix = localClientByPrefix;
         }
       }
     }
-    return asyncClient;
-  }
 
-  private boolean shouldUseAsyncClient() {
-    return s3FileIOProperties.isS3AnalyticsAcceleratorEnabled();
+    return clientByPrefix;
   }
 
   private ExecutorService executorService() {
@@ -416,7 +468,8 @@ public class S3FileIO
         if (executorService == null) {
           executorService =
               ThreadPools.newExitingWorkerPool(
-                  "iceberg-s3fileio-delete", s3FileIOProperties.deleteThreads());
+                  "iceberg-s3fileio-delete",
+                  clientForStoragePath(ROOT_PREFIX).s3FileIOProperties().deleteThreads());
         }
       }
     }
@@ -432,44 +485,17 @@ public class S3FileIO
   @Override
   public void initialize(Map<String, String> props) {
     this.properties = SerializableMap.copyOf(props);
-    Map<String, String> propertiesWithCredentials =
-        ImmutableMap.<String, String>builder()
-            .putAll(properties)
-            .putAll(storageCredentialConfig())
-            .buildKeepingLast();
 
-    this.s3FileIOProperties = new S3FileIOProperties(propertiesWithCredentials);
     this.createStack =
-        PropertyUtil.propertyAsBoolean(props, "init-creation-stacktrace", true)
+        PropertyUtil.propertyAsBoolean(properties, "init-creation-stacktrace", true)
             ? Thread.currentThread().getStackTrace()
             : null;
 
-    // Do not override s3 client if it was provided
     if (s3 == null) {
-      Object clientFactory = S3FileIOAwsClientFactories.initialize(props);
-      if (clientFactory instanceof S3FileIOAwsClientFactory) {
-        this.s3 = ((S3FileIOAwsClientFactory) clientFactory)::s3;
-      }
-      if (clientFactory instanceof AwsClientFactory) {
-        this.s3 = ((AwsClientFactory) clientFactory)::s3;
-      }
+      Object clientFactory = S3FileIOAwsClientFactories.initialize(properties);
       if (clientFactory instanceof CredentialSupplier) {
         this.credential = ((CredentialSupplier) clientFactory).getCredential();
       }
-      if (s3FileIOProperties.isPreloadClientEnabled()) {
-        client();
-      }
-    }
-
-    // Do not override s3Async client if it was provided
-    if (s3Async == null) {
-      Object clientFactory = S3FileIOAwsClientFactories.initialize(props);
-      if (clientFactory instanceof S3FileIOAwsClientFactory) {
-        this.s3Async = ((S3FileIOAwsClientFactory) clientFactory)::s3Async;
-      }
-      if (clientFactory instanceof AwsClientFactory) {
-        this.s3Async = ((AwsClientFactory) clientFactory)::s3Async;
-      }
     }
 
     initMetrics(properties);
@@ -483,7 +509,7 @@ public class S3FileIO
           DynConstructors.builder(MetricsContext.class)
               .hiddenImpl(DEFAULT_METRICS_IMPL, String.class)
               .buildChecked();
-      MetricsContext context = ctor.newInstance("s3");
+      MetricsContext context = ctor.newInstance(ROOT_PREFIX);
       context.initialize(props);
       this.metrics = context;
     } catch (NoClassDefFoundError | NoSuchMethodException | ClassCastException e) {
@@ -496,13 +522,9 @@ public class S3FileIO
   public void close() {
     // handles concurrent calls to close()
     if (isResourceClosed.compareAndSet(false, true)) {
-      if (client != null) {
-        client.close();
-      }
-      if (asyncClient != null) {
-        // cleanup usage in analytics accelerator if any
-        AnalyticsAcceleratorUtil.cleanupCache(asyncClient, s3FileIOProperties);
-        asyncClient.close();
+      if (clientByPrefix != null) {
+        clientByPrefix.values().forEach(PrefixedS3Client::close);
+        this.clientByPrefix = null;
       }
     }
   }
@@ -524,9 +546,11 @@ public class S3FileIO
 
   @Override
   public boolean recoverFile(String path) {
-    S3URI location = new S3URI(path, s3FileIOProperties.bucketToAccessPointMapping());
+    PrefixedS3Client client = clientForStoragePath(path);
+    S3URI location = new S3URI(path, client.s3FileIOProperties().bucketToAccessPointMapping());
     ListObjectVersionsIterable response =
-        client()
+        client
+            .s3()
             .listObjectVersionsPaginator(
                 builder -> builder.bucket(location.bucket()).prefix(location.key()));
 
@@ -535,10 +559,12 @@ public class S3FileIO
     Optional<ObjectVersion> recoverVersion =
         response.versions().stream().max(Comparator.comparing(ObjectVersion::lastModified));
 
-    return recoverVersion.map(version -> recoverObject(version, location.bucket())).orElse(false);
+    return recoverVersion
+        .map(version -> recoverObject(client, version, location.bucket()))
+        .orElse(false);
   }
 
-  private boolean recoverObject(ObjectVersion version, String bucket) {
+  private boolean recoverObject(PrefixedS3Client client, ObjectVersion version, String bucket) {
     if (version.isLatest()) {
       return true;
     }
@@ -547,7 +573,8 @@ public class S3FileIO
     try {
       // Perform a copy instead of deleting the delete marker
       // so that recovery does not rely on delete permissions
-      client()
+      client
+          .s3()
           .copyObject(
               builder ->
                   builder
@@ -575,16 +602,4 @@ public class S3FileIO
   public List<StorageCredential> credentials() {
     return ImmutableList.copyOf(storageCredentials);
   }
-
-  private Map<String, String> storageCredentialConfig() {
-    List<StorageCredential> s3Credentials =
-        storageCredentials.stream()
-            .filter(c -> c.prefix().startsWith("s3"))
-            .collect(Collectors.toList());
-
-    Preconditions.checkState(
-        s3Credentials.size() <= 1, "Invalid S3 Credentials: only one S3 credential should exist");
-
-    return s3Credentials.isEmpty() ? Map.of() : s3Credentials.get(0).config();
-  }
 }
