@@ -26,8 +26,6 @@ import java.util.Map;
 import java.util.Set;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
-import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.util.JsonUtil;
 import org.apache.iceberg.view.ViewVersionParser;
 
@@ -61,6 +59,8 @@ public class MetadataUpdateParser {
   static final String REMOVE_PARTITION_STATISTICS = "remove-partition-statistics";
   static final String REMOVE_PARTITION_SPECS = "remove-partition-specs";
   static final String REMOVE_SCHEMAS = "remove-schemas";
+  static final String ADD_ENCRYPTION_KEY = "add-encryption-key";
+  static final String REMOVE_ENCRYPTION_KEY = "remove-encryption-key";
 
   // AssignUUID
   private static final String UUID = "uuid";
@@ -134,6 +134,12 @@ public class MetadataUpdateParser {
   // RemoveSchemas
   private static final String SCHEMA_IDS = "schema-ids";
 
+  // AddEncryptionKey
+  private static final String ENCRYPTION_KEY = "encryption-key";
+
+  // RemoveEncryptionKey
+  private static final String KEY_ID = "key-id";
+
   private static final Map<Class<? extends MetadataUpdate>, String> ACTIONS =
       ImmutableMap.<Class<? extends MetadataUpdate>, String>builder()
           .put(MetadataUpdate.AssignUUID.class, ASSIGN_UUID)
@@ -149,7 +155,6 @@ public class MetadataUpdateParser {
           .put(MetadataUpdate.SetPartitionStatistics.class, SET_PARTITION_STATISTICS)
           .put(MetadataUpdate.RemovePartitionStatistics.class, REMOVE_PARTITION_STATISTICS)
           .put(MetadataUpdate.AddSnapshot.class, ADD_SNAPSHOT)
-          .put(MetadataUpdate.RemoveSnapshot.class, REMOVE_SNAPSHOTS)
           .put(MetadataUpdate.RemoveSnapshots.class, REMOVE_SNAPSHOTS)
           .put(MetadataUpdate.RemoveSnapshotRef.class, REMOVE_SNAPSHOT_REF)
           .put(MetadataUpdate.SetSnapshotRef.class, SET_SNAPSHOT_REF)
@@ -160,6 +165,8 @@ public class MetadataUpdateParser {
           .put(MetadataUpdate.SetCurrentViewVersion.class, SET_CURRENT_VIEW_VERSION)
           .put(MetadataUpdate.RemovePartitionSpecs.class, REMOVE_PARTITION_SPECS)
           .put(MetadataUpdate.RemoveSchemas.class, REMOVE_SCHEMAS)
+          .put(MetadataUpdate.AddEncryptionKey.class, ADD_ENCRYPTION_KEY)
+          .put(MetadataUpdate.RemoveEncryptionKey.class, REMOVE_ENCRYPTION_KEY)
           .buildOrThrow();
 
   public static String toJson(MetadataUpdate metadataUpdate) {
@@ -228,14 +235,7 @@ public class MetadataUpdateParser {
         writeAddSnapshot((MetadataUpdate.AddSnapshot) metadataUpdate, generator);
         break;
       case REMOVE_SNAPSHOTS:
-        MetadataUpdate.RemoveSnapshots removeSnapshots;
-        if (metadataUpdate instanceof MetadataUpdate.RemoveSnapshot) {
-          Long snapshotId = ((MetadataUpdate.RemoveSnapshot) metadataUpdate).snapshotId();
-          removeSnapshots = new MetadataUpdate.RemoveSnapshots(ImmutableSet.of(snapshotId));
-        } else {
-          removeSnapshots = (MetadataUpdate.RemoveSnapshots) metadataUpdate;
-        }
-        writeRemoveSnapshots(removeSnapshots, generator);
+        writeRemoveSnapshots((MetadataUpdate.RemoveSnapshots) metadataUpdate, generator);
         break;
       case REMOVE_SNAPSHOT_REF:
         writeRemoveSnapshotRef((MetadataUpdate.RemoveSnapshotRef) metadataUpdate, generator);
@@ -265,6 +265,12 @@ public class MetadataUpdateParser {
       case REMOVE_SCHEMAS:
         writeRemoveSchemas((MetadataUpdate.RemoveSchemas) metadataUpdate, generator);
         break;
+      case ADD_ENCRYPTION_KEY:
+        writeAddEncryptionKey((MetadataUpdate.AddEncryptionKey) metadataUpdate, generator);
+        break;
+      case REMOVE_ENCRYPTION_KEY:
+        writeRemoveEncryptionKey((MetadataUpdate.RemoveEncryptionKey) metadataUpdate, generator);
+        break;
       default:
         throw new IllegalArgumentException(
             String.format(
@@ -340,6 +346,10 @@ public class MetadataUpdateParser {
         return readRemovePartitionSpecs(jsonNode);
       case REMOVE_SCHEMAS:
         return readRemoveSchemas(jsonNode);
+      case ADD_ENCRYPTION_KEY:
+        return readAddEncryptionKey(jsonNode);
+      case REMOVE_ENCRYPTION_KEY:
+        return readRemoveEncryptionKey(jsonNode);
       default:
         throw new UnsupportedOperationException(
             String.format("Cannot convert metadata update action to json: %s", action));
@@ -483,6 +493,17 @@ public class MetadataUpdateParser {
     JsonUtil.writeIntegerArray(SCHEMA_IDS, metadataUpdate.schemaIds(), gen);
   }
 
+  private static void writeAddEncryptionKey(
+      MetadataUpdate.AddEncryptionKey update, JsonGenerator gen) throws IOException {
+    gen.writeFieldName(ENCRYPTION_KEY);
+    EncryptedKeyParser.toJson(update.key(), gen);
+  }
+
+  private static void writeRemoveEncryptionKey(
+      MetadataUpdate.RemoveEncryptionKey update, JsonGenerator gen) throws IOException {
+    gen.writeStringField(KEY_ID, update.keyId());
+  }
+
   private static MetadataUpdate readAssignUUID(JsonNode node) {
     String uuid = JsonUtil.getString(UUID, node);
     return new MetadataUpdate.AssignUUID(uuid);
@@ -560,14 +581,7 @@ public class MetadataUpdateParser {
         snapshotIds != null,
         "Invalid set of snapshot ids to remove: must be non-null",
         snapshotIds);
-    MetadataUpdate metadataUpdate;
-    if (snapshotIds.size() == 1) {
-      Long snapshotId = Iterables.getOnlyElement(snapshotIds);
-      metadataUpdate = new MetadataUpdate.RemoveSnapshot(snapshotId);
-    } else {
-      metadataUpdate = new MetadataUpdate.RemoveSnapshots(snapshotIds);
-    }
-    return metadataUpdate;
+    return new MetadataUpdate.RemoveSnapshots(snapshotIds);
   }
 
   private static MetadataUpdate readSetSnapshotRef(JsonNode node) {
@@ -639,4 +653,18 @@ public class MetadataUpdateParser {
   private static MetadataUpdate readRemoveSchemas(JsonNode node) {
     return new MetadataUpdate.RemoveSchemas(JsonUtil.getIntegerSet(SCHEMA_IDS, node));
   }
+
+  private static MetadataUpdate readAddEncryptionKey(JsonNode node) {
+    JsonNode keyNode = node.get(ENCRYPTION_KEY);
+    Preconditions.checkArgument(
+        keyNode != null && keyNode.isObject(),
+        "Invalid encryption key, must be non-null object: %s",
+        keyNode);
+    return new MetadataUpdate.AddEncryptionKey(EncryptedKeyParser.fromJson(keyNode));
+  }
+
+  private static MetadataUpdate readRemoveEncryptionKey(JsonNode node) {
+    String keyId = JsonUtil.getString(KEY_ID, node);
+    return new MetadataUpdate.RemoveEncryptionKey(keyId);
+  }
 }
