@@ -82,7 +82,7 @@ class ReachableFileCleanup extends FileCleanupStrategy {
 
     deleteFiles(manifestListsToDelete, "manifest list");
 
-    if (!beforeExpiration.statisticsFiles().isEmpty()) {
+    if (hasAnyStatisticsFiles(beforeExpiration)) {
       deleteFiles(
           expiredStatisticsFilesLocations(beforeExpiration, afterExpiration), "statistics files");
     }
