@@ -16,15 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg;
 
 import java.util.UUID;
 
 public final class SnapshotIdGeneratorUtil {
 
-  private SnapshotIdGeneratorUtil() {
-  }
+  private SnapshotIdGeneratorUtil() {}
 
   /**
    * Create a new ID for a Snapshot
