@@ -20,6 +20,7 @@ package org.apache.iceberg;
 
 import java.util.Collection;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ExecutorService;
 import javax.annotation.Nullable;
 import org.apache.iceberg.expressions.Expression;
@@ -59,6 +60,9 @@ abstract class TableScanContext {
     return false;
   }
 
+  @Nullable
+  public abstract Set<Integer> columnsToKeepStats();
+
   @Nullable
   public abstract Collection<String> selectedColumns();
 
@@ -125,6 +129,16 @@ abstract class TableScanContext {
         .build();
   }
 
+  TableScanContext columnsToKeepStats(Set<Integer> columnsToKeepStats) {
+    Preconditions.checkState(
+        returnColumnStats(),
+        "Cannot select columns to keep stats when column stats are not returned");
+    return ImmutableTableScanContext.builder()
+        .from(this)
+        .columnsToKeepStats(columnsToKeepStats)
+        .build();
+  }
+
   TableScanContext selectColumns(Collection<String> columns) {
     Preconditions.checkState(
         projectedSchema() == null, "Cannot select columns when projection schema is set");
