@@ -46,6 +46,7 @@ import org.apache.avro.io.Encoder;
 import org.apache.avro.specific.SpecificData;
 import org.apache.iceberg.FieldMetrics;
 import org.apache.iceberg.FileFormat;
+import org.apache.iceberg.InternalData;
 import org.apache.iceberg.MetricsConfig;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.SchemaParser;
@@ -85,11 +86,17 @@ public class Avro {
 
   static {
     LogicalTypes.register(LogicalMap.NAME, schema -> LogicalMap.get());
+    LogicalTypes.register(VariantLogicalType.NAME, schema -> VariantLogicalType.get());
     DEFAULT_MODEL.addLogicalTypeConversion(new Conversions.DecimalConversion());
     DEFAULT_MODEL.addLogicalTypeConversion(new UUIDConversion());
+    DEFAULT_MODEL.addLogicalTypeConversion(new VariantConversion());
   }
 
   public static WriteBuilder write(OutputFile file) {
+    if (file instanceof EncryptedOutputFile) {
+      return write((EncryptedOutputFile) file);
+    }
+
     return new WriteBuilder(file);
   }
 
@@ -97,7 +104,7 @@ public class Avro {
     return new WriteBuilder(file.encryptingOutputFile());
   }
 
-  public static class WriteBuilder {
+  public static class WriteBuilder implements InternalData.WriteBuilder {
     private final OutputFile file;
     private final Map<String, String> config = Maps.newHashMap();
     private final Map<String, String> metadata = Maps.newLinkedHashMap();
@@ -119,11 +126,13 @@ public class Avro {
       return this;
     }
 
+    @Override
     public WriteBuilder schema(org.apache.iceberg.Schema newSchema) {
       this.schema = newSchema;
       return this;
     }
 
+    @Override
     public WriteBuilder named(String newName) {
       this.name = newName;
       return this;
@@ -134,6 +143,7 @@ public class Avro {
       return this;
     }
 
+    @Override
     public WriteBuilder set(String property, String value) {
       config.put(property, value);
       return this;
@@ -144,11 +154,13 @@ public class Avro {
       return this;
     }
 
+    @Override
     public WriteBuilder meta(String property, String value) {
       metadata.put(property, value);
       return this;
     }
 
+    @Override
     public WriteBuilder meta(Map<String, String> properties) {
       metadata.putAll(properties);
       return this;
@@ -159,6 +171,7 @@ public class Avro {
       return this;
     }
 
+    @Override
     public WriteBuilder overwrite() {
       return overwrite(true);
     }
@@ -175,6 +188,7 @@ public class Avro {
       return this;
     }
 
+    @Override
     public <D> FileAppender<D> build() throws IOException {
       Preconditions.checkNotNull(schema, "Schema is required");
       Preconditions.checkNotNull(name, "Table name is required and cannot be null");
@@ -615,9 +629,11 @@ public class Avro {
     return new ReadBuilder(file);
   }
 
-  public static class ReadBuilder {
+  public static class ReadBuilder implements InternalData.ReadBuilder {
     private final InputFile file;
     private final Map<String, String> renames = Maps.newLinkedHashMap();
+    private final Map<Integer, Class<? extends StructLike>> typeMap = Maps.newHashMap();
+    private Class<? extends StructLike> rootType = null;
     private ClassLoader loader = Thread.currentThread().getContextClassLoader();
     private NameMapping nameMapping;
     private boolean reuseContainers = false;
@@ -675,17 +691,20 @@ public class Avro {
      * @param newLength the length of the range this read should scan
      * @return this builder for method chaining
      */
+    @Override
     public ReadBuilder split(long newStart, long newLength) {
       this.start = newStart;
       this.length = newLength;
       return this;
     }
 
+    @Override
     public ReadBuilder project(org.apache.iceberg.Schema projectedSchema) {
       this.schema = projectedSchema;
       return this;
     }
 
+    @Override
     public ReadBuilder reuseContainers() {
       this.reuseContainers = true;
       return this;
@@ -701,6 +720,19 @@ public class Avro {
       return this;
     }
 
+    @Override
+    public InternalData.ReadBuilder setRootType(Class<? extends StructLike> rootClass) {
+      this.rootType = rootClass;
+      return this;
+    }
+
+    @Override
+    public InternalData.ReadBuilder setCustomType(
+        int fieldId, Class<? extends StructLike> structClass) {
+      typeMap.put(fieldId, structClass);
+      return this;
+    }
+
     public ReadBuilder withNameMapping(NameMapping newNameMapping) {
       this.nameMapping = newNameMapping;
       return this;
@@ -711,6 +743,7 @@ public class Avro {
       return this;
     }
 
+    @Override
     @SuppressWarnings("unchecked")
     public <D> AvroIterable<D> build() {
       Preconditions.checkNotNull(schema, "Schema is required");
@@ -737,6 +770,10 @@ public class Avro {
         ((SupportsCustomRecords) reader).setRenames(renames);
       }
 
+      if (reader instanceof SupportsCustomTypes) {
+        ((SupportsCustomTypes) reader).setCustomTypes(rootType, typeMap);
+      }
+
       return new AvroIterable<>(
           file, new NameMappingDatumReader<>(nameMapping, reader), start, length, reuseContainers);
     }
