@@ -57,5 +57,9 @@ public class EncryptedFiles {
         encryptedOutputFile, BaseEncryptionKeyMetadata.fromByteArray(keyMetadata));
   }
 
+  public static EncryptedOutputFile plainAsEncryptedOutput(OutputFile encryptingOutputFile) {
+    return new BaseEncryptedOutputFile(encryptingOutputFile, EncryptionKeyMetadata.EMPTY);
+  }
+
   private EncryptedFiles() {}
 }
