@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.io;
 
 import java.io.IOException;
@@ -40,13 +39,24 @@ public class DataWriter<T> implements FileWriter<T, DataWriteResult> {
   private final SortOrder sortOrder;
   private DataFile dataFile = null;
 
-  public DataWriter(FileAppender<T> appender, FileFormat format, String location,
-                    PartitionSpec spec, StructLike partition, EncryptionKeyMetadata keyMetadata) {
+  public DataWriter(
+      FileAppender<T> appender,
+      FileFormat format,
+      String location,
+      PartitionSpec spec,
+      StructLike partition,
+      EncryptionKeyMetadata keyMetadata) {
     this(appender, format, location, spec, partition, keyMetadata, null);
   }
 
-  public DataWriter(FileAppender<T> appender, FileFormat format, String location,
-                    PartitionSpec spec, StructLike partition, EncryptionKeyMetadata keyMetadata, SortOrder sortOrder) {
+  public DataWriter(
+      FileAppender<T> appender,
+      FileFormat format,
+      String location,
+      PartitionSpec spec,
+      StructLike partition,
+      EncryptionKeyMetadata keyMetadata,
+      SortOrder sortOrder) {
     this.appender = appender;
     this.format = format;
     this.location = location;
@@ -61,16 +71,6 @@ public class DataWriter<T> implements FileWriter<T, DataWriteResult> {
     appender.add(row);
   }
 
-  /**
-   * Writes a data record.
-   *
-   * @deprecated since 0.13.0, will be removed in 0.14.0; use {@link #write(Object)} instead.
-   */
-  @Deprecated
-  public void add(T row) {
-    write(row);
-  }
-
   @Override
   public long length() {
     return appender.length();
@@ -80,16 +80,17 @@ public class DataWriter<T> implements FileWriter<T, DataWriteResult> {
   public void close() throws IOException {
     if (dataFile == null) {
       appender.close();
-      this.dataFile = DataFiles.builder(spec)
-          .withFormat(format)
-          .withPath(location)
-          .withPartition(partition)
-          .withEncryptionKeyMetadata(keyMetadata)
-          .withFileSizeInBytes(appender.length())
-          .withMetrics(appender.metrics())
-          .withSplitOffsets(appender.splitOffsets())
-          .withSortOrder(sortOrder)
-          .build();
+      this.dataFile =
+          DataFiles.builder(spec)
+              .withFormat(format)
+              .withPath(location)
+              .withPartition(partition)
+              .withEncryptionKeyMetadata(keyMetadata)
+              .withFileSizeInBytes(appender.length())
+              .withMetrics(appender.metrics())
+              .withSplitOffsets(appender.splitOffsets())
+              .withSortOrder(sortOrder)
+              .build();
     }
   }
 
