@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.io;
 
 import java.io.IOException;
@@ -55,11 +54,12 @@ class SortedPosDeleteWriter<T> implements FileWriter<PositionDelete<T>, DeleteWr
   private boolean closed = false;
   private Throwable failure;
 
-  SortedPosDeleteWriter(FileAppenderFactory<T> appenderFactory,
-                        OutputFileFactory fileFactory,
-                        FileFormat format,
-                        StructLike partition,
-                        long recordsNumThreshold) {
+  SortedPosDeleteWriter(
+      FileAppenderFactory<T> appenderFactory,
+      OutputFileFactory fileFactory,
+      FileFormat format,
+      StructLike partition,
+      long recordsNumThreshold) {
     this.appenderFactory = appenderFactory;
     this.fileFactory = fileFactory;
     this.format = format;
@@ -67,10 +67,11 @@ class SortedPosDeleteWriter<T> implements FileWriter<PositionDelete<T>, DeleteWr
     this.recordsNumThreshold = recordsNumThreshold;
   }
 
-  SortedPosDeleteWriter(FileAppenderFactory<T> appenderFactory,
-                        OutputFileFactory fileFactory,
-                        FileFormat format,
-                        StructLike partition) {
+  SortedPosDeleteWriter(
+      FileAppenderFactory<T> appenderFactory,
+      OutputFileFactory fileFactory,
+      FileFormat format,
+      StructLike partition) {
     this(appenderFactory, fileFactory, format, partition, DEFAULT_RECORDS_NUM_THRESHOLD);
   }
 
@@ -82,7 +83,8 @@ class SortedPosDeleteWriter<T> implements FileWriter<PositionDelete<T>, DeleteWr
 
   @Override
   public long length() {
-    throw new UnsupportedOperationException(this.getClass().getName() + " does not implement length");
+    throw new UnsupportedOperationException(
+        this.getClass().getName() + " does not implement length");
   }
 
   @Override
@@ -104,7 +106,8 @@ class SortedPosDeleteWriter<T> implements FileWriter<PositionDelete<T>, DeleteWr
 
     records += 1;
 
-    // TODO Flush buffer based on the policy that checking whether whole heap memory size exceed the threshold.
+    // TODO Flush buffer based on the policy that checking whether whole heap memory size exceed the
+    // threshold.
     if (records >= recordsNumThreshold) {
       flushDeletes();
     }
@@ -149,7 +152,9 @@ class SortedPosDeleteWriter<T> implements FileWriter<PositionDelete<T>, DeleteWr
       outputFile = fileFactory.newOutputFile(partition);
     }
 
-    PositionDeleteWriter<T> writer = appenderFactory.newPosDeleteWriter(outputFile, format, partition);
+    PositionDeleteWriter<T> writer =
+        appenderFactory.newPosDeleteWriter(outputFile, format, partition);
+    PositionDelete<T> posDelete = PositionDelete.create();
     try (PositionDeleteWriter<T> closeableWriter = writer) {
       // Sort all the paths.
       List<CharSequence> paths = Lists.newArrayListWithCapacity(posDeletes.keySet().size());
@@ -163,13 +168,14 @@ class SortedPosDeleteWriter<T> implements FileWriter<PositionDelete<T>, DeleteWr
         List<PosRow<T>> positions = posDeletes.get(wrapper.set(path));
         positions.sort(Comparator.comparingLong(PosRow::pos));
 
-        positions.forEach(posRow -> closeableWriter.delete(path, posRow.pos(), posRow.row()));
+        positions.forEach(
+            posRow -> closeableWriter.write(posDelete.set(path, posRow.pos(), posRow.row())));
       }
     } catch (IOException e) {
       setFailure(e);
       throw new UncheckedIOException(
-          "Failed to write the sorted path/pos pairs to pos-delete file: " +
-              outputFile.encryptingOutputFile().location(),
+          "Failed to write the sorted path/pos pairs to pos-delete file: "
+              + outputFile.encryptingOutputFile().location(),
           e);
     }
 
