@@ -36,6 +36,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.function.Consumer;
 import java.util.function.Function;
+import java.util.function.Predicate;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 import org.apache.iceberg.CatalogProperties;
@@ -156,48 +157,62 @@ public class JdbcCatalog extends BaseMetastoreViewCatalog
     closeableGroup.setSuppressCloseFailure(true);
   }
 
+  private void atomicCreateTable(String tableName, String sqlCommand, String reason)
+      throws SQLException, InterruptedException {
+    connections.run(
+        conn -> {
+          DatabaseMetaData dbMeta = conn.getMetaData();
+
+          // check the existence of a table name
+          Predicate<String> tableTest =
+              name -> {
+                try {
+                  ResultSet result =
+                      dbMeta.getTables(
+                          null /* catalog name */,
+                          null /* schemaPattern */,
+                          name /* tableNamePattern */,
+                          null /* types */);
+                  return result.next();
+                } catch (SQLException e) {
+                  return false;
+                }
+              };
+
+          // some databases force table name to upper case -- check that last.
+          Predicate<String> tableExists =
+              name -> tableTest.test(name) || tableTest.test(name.toUpperCase(Locale.ROOT));
+
+          if (tableExists.test(tableName)) {
+            return true;
+          }
+
+          LOG.debug("Creating table {} {}", tableName, reason);
+          try {
+            conn.prepareStatement(sqlCommand).execute();
+            return true;
+          } catch (SQLException e) {
+            // see if table was created by another thread or process.
+            if (tableExists.test(tableName)) {
+              return true;
+            }
+            throw e;
+          }
+        });
+  }
+
   private void initializeCatalogTables() {
     LOG.trace("Creating database tables (if missing) to store iceberg catalog");
+
     try {
-      connections.run(
-          conn -> {
-            DatabaseMetaData dbMeta = conn.getMetaData();
-            ResultSet tableExists =
-                dbMeta.getTables(
-                    null /* catalog name */,
-                    null /* schemaPattern */,
-                    JdbcUtil.CATALOG_TABLE_VIEW_NAME /* tableNamePattern */,
-                    null /* types */);
-            if (tableExists.next()) {
-              return true;
-            }
-
-            LOG.debug(
-                "Creating table {} to store iceberg catalog tables",
-                JdbcUtil.CATALOG_TABLE_VIEW_NAME);
-            return conn.prepareStatement(JdbcUtil.V0_CREATE_CATALOG_SQL).execute();
-          });
-
-      connections.run(
-          conn -> {
-            DatabaseMetaData dbMeta = conn.getMetaData();
-            ResultSet tableExists =
-                dbMeta.getTables(
-                    null /* catalog name */,
-                    null /* schemaPattern */,
-                    JdbcUtil.NAMESPACE_PROPERTIES_TABLE_NAME /* tableNamePattern */,
-                    null /* types */);
-
-            if (tableExists.next()) {
-              return true;
-            }
-
-            LOG.debug(
-                "Creating table {} to store iceberg catalog namespace properties",
-                JdbcUtil.NAMESPACE_PROPERTIES_TABLE_NAME);
-            return conn.prepareStatement(JdbcUtil.CREATE_NAMESPACE_PROPERTIES_TABLE_SQL).execute();
-          });
-
+      atomicCreateTable(
+          JdbcUtil.CATALOG_TABLE_VIEW_NAME,
+          JdbcUtil.V0_CREATE_CATALOG_SQL,
+          "to store iceberg catalog tables");
+      atomicCreateTable(
+          JdbcUtil.NAMESPACE_PROPERTIES_TABLE_NAME,
+          JdbcUtil.CREATE_NAMESPACE_PROPERTIES_TABLE_SQL,
+          "to store iceberg catalog namespace properties");
     } catch (SQLTimeoutException e) {
       throw new UncheckedSQLException(e, "Cannot initialize JDBC catalog: Query timed out");
     } catch (SQLTransientConnectionException | SQLNonTransientConnectionException e) {
