@@ -23,10 +23,16 @@ import java.util.List;
 import java.util.Map;
 import org.apache.iceberg.relocated.com.google.common.base.Joiner;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 
 /** Represents a mapping from external schema names to Iceberg type IDs. */
 public class NameMapping implements Serializable {
   private static final Joiner DOT = Joiner.on('.');
+  private static final NameMapping EMPTY = NameMapping.of();
+
+  public static NameMapping empty() {
+    return EMPTY;
+  }
 
   public static NameMapping of(MappedField... fields) {
     return new NameMapping(MappedFields.of(ImmutableList.copyOf(fields)));
@@ -62,6 +68,14 @@ public class NameMapping implements Serializable {
     return lazyFieldsByName().get(DOT.join(names));
   }
 
+  public MappedField find(Iterable<String> names) {
+    return lazyFieldsByName().get(DOT.join(names));
+  }
+
+  public MappedField find(Iterable<String> names, String name) {
+    return lazyFieldsByName().get(DOT.join(Iterables.concat(names, ImmutableList.of(name))));
+  }
+
   public MappedFields asMappedFields() {
     return mapping;
   }
