@@ -44,6 +44,7 @@ public class PuffinWriter implements FileAppender<Blob> {
   // Must not be modified
   private static final byte[] MAGIC = PuffinFormat.getMagic();
 
+  private final OutputFile outputFile;
   private final PositionOutputStream outputStream;
   private final Map<String, String> properties;
   private final PuffinCompressionCodec footerCompression;
@@ -63,6 +64,7 @@ public class PuffinWriter implements FileAppender<Blob> {
     Preconditions.checkNotNull(outputFile, "outputFile is null");
     Preconditions.checkNotNull(properties, "properties is null");
     Preconditions.checkNotNull(defaultBlobCompression, "defaultBlobCompression is null");
+    this.outputFile = outputFile;
     this.outputStream = outputFile.create();
     this.properties = ImmutableMap.copyOf(properties);
     this.footerCompression =
@@ -70,8 +72,16 @@ public class PuffinWriter implements FileAppender<Blob> {
     this.defaultBlobCompression = defaultBlobCompression;
   }
 
+  public String location() {
+    return outputFile.location();
+  }
+
   @Override
   public void add(Blob blob) {
+    write(blob);
+  }
+
+  public BlobMetadata write(Blob blob) {
     Preconditions.checkNotNull(blob, "blob is null");
     checkNotFinished();
     try {
@@ -82,7 +92,7 @@ public class PuffinWriter implements FileAppender<Blob> {
       ByteBuffer rawData = PuffinFormat.compress(codec, blob.blobData());
       int length = rawData.remaining();
       IOUtil.writeFully(outputStream, rawData);
-      writtenBlobsMetadata.add(
+      BlobMetadata blobMetadata =
           new BlobMetadata(
               blob.type(),
               blob.inputFields(),
@@ -91,7 +101,9 @@ public class PuffinWriter implements FileAppender<Blob> {
               fileOffset,
               length,
               codec.codecName(),
-              blob.properties()));
+              blob.properties());
+      writtenBlobsMetadata.add(blobMetadata);
+      return blobMetadata;
     } catch (IOException e) {
       throw new UncheckedIOException(e);
     }
