@@ -111,7 +111,8 @@ public class CatalogHandlers {
   }
 
   private static <T> Pair<List<T>, String> paginate(List<T> list, String pageToken, int pageSize) {
-    int pageStart = INITIAL_PAGE_TOKEN.equals(pageToken) ? 0 : Integer.parseInt(pageToken);
+    boolean isFirstPage = pageToken == null || pageToken.equals(INITIAL_PAGE_TOKEN);
+    int pageStart = isFirstPage ? 0 : Integer.parseInt(pageToken);
     if (pageStart >= list.size()) {
       return Pair.of(Collections.emptyList(), null);
     }
