@@ -38,6 +38,7 @@ import org.apache.hc.core5.http.HttpResponse;
 import org.apache.hc.core5.http.HttpStatus;
 import org.apache.hc.core5.http.Method;
 import org.apache.hc.core5.http.protocol.HttpContext;
+import org.apache.hc.core5.http.protocol.HttpCoreContext;
 import org.apache.hc.core5.util.TimeValue;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
@@ -60,7 +61,17 @@ import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
  *
  * <ul>
  *   <li>SC_TOO_MANY_REQUESTS (429)
+ * </ul>
+ *
+ * The following retriable HTTP status codes are defined for idempotent requests:
+ *
+ * <ul>
+ *   <li>SC_TOO_MANY_REQUESTS (429)
  *   <li>SC_SERVICE_UNAVAILABLE (503)
+ *   <li>SC_INTERNAL_SERVER_ERROR (500)
+ *   <li>SC_BAD_GATEWAY (502)
+ *   <li>SC_GATEWAY_TIMEOUT (504)
+ *   <li>SC_REQUEST_TIMEOUT (408)
  * </ul>
  *
  * Most code and behavior is taken from {@link
@@ -71,13 +82,21 @@ class ExponentialHttpRequestRetryStrategy implements HttpRequestRetryStrategy {
   private final int maxRetries;
   private final Set<Class<? extends IOException>> nonRetriableExceptions;
   private final Set<Integer> retriableCodes;
+  private final Set<Integer> idempotentRetriableCodes;
 
   ExponentialHttpRequestRetryStrategy(int maximumRetries) {
     Preconditions.checkArgument(
         maximumRetries > 0, "Cannot set retries to %s, the value must be positive", maximumRetries);
     this.maxRetries = maximumRetries;
-    this.retriableCodes =
-        ImmutableSet.of(HttpStatus.SC_TOO_MANY_REQUESTS, HttpStatus.SC_SERVICE_UNAVAILABLE);
+    this.retriableCodes = ImmutableSet.of(HttpStatus.SC_TOO_MANY_REQUESTS);
+    this.idempotentRetriableCodes =
+        ImmutableSet.of(
+            HttpStatus.SC_TOO_MANY_REQUESTS,
+            HttpStatus.SC_SERVICE_UNAVAILABLE,
+            HttpStatus.SC_INTERNAL_SERVER_ERROR,
+            HttpStatus.SC_BAD_GATEWAY,
+            HttpStatus.SC_GATEWAY_TIMEOUT,
+            HttpStatus.SC_REQUEST_TIMEOUT);
     this.nonRetriableExceptions =
         ImmutableSet.of(
             InterruptedIOException.class,
@@ -117,7 +136,23 @@ class ExponentialHttpRequestRetryStrategy implements HttpRequestRetryStrategy {
 
   @Override
   public boolean retryRequest(HttpResponse response, int execCount, HttpContext context) {
-    return execCount <= maxRetries && retriableCodes.contains(response.getCode());
+    HttpRequest request =
+        context instanceof HttpCoreContext ? ((HttpCoreContext) context).getRequest() : null;
+
+    boolean is503Retryable =
+        response.getCode() == HttpStatus.SC_SERVICE_UNAVAILABLE
+            && response.getFirstHeader(HttpHeaders.RETRY_AFTER) != null;
+
+    // A retry is permitted if all the following conditions are met:
+    // 1. The maximum retry count has not been exceeded.
+    // 2. The response code is considered retryable, for one of the following reasons:
+    //    - It's in a predefined list of retriable codes.
+    //    - The request is idempotent, and the response code indicates a retry is safe.
+    //    - The response code is '503 Service Unavailable' and includes a 'Retry-After' header.
+    return execCount <= maxRetries
+        && (retriableCodes.contains(response.getCode())
+            || shouldRetryIdempotent(request, response.getCode())
+            || is503Retryable);
   }
 
   @Override
@@ -148,4 +183,14 @@ class ExponentialHttpRequestRetryStrategy implements HttpRequestRetryStrategy {
 
     return TimeValue.ofMilliseconds(delayMillis + jitter);
   }
+
+  private boolean shouldRetryIdempotent(HttpRequest request, int responseCode) {
+    if (request == null) {
+      return false;
+    }
+
+    // Check if the request is idempotent
+    return Method.isIdempotent(request.getMethod())
+        && idempotentRetriableCodes.contains(responseCode);
+  }
 }
