@@ -70,7 +70,7 @@ public class OAuth2Manager extends RefreshingAuthManager {
 
   @Override
   public OAuth2Util.AuthSession initSession(RESTClient initClient, Map<String, String> properties) {
-    warnIfDeprecatedTokenEndpointUsed(properties);
+    warnIfOAuthServerUriNotSet(properties);
     AuthConfig config =
         ImmutableAuthConfig.builder()
             .from(AuthConfig.fromProperties(properties))
@@ -154,6 +154,38 @@ public class OAuth2Manager extends RefreshingAuthManager {
         (OAuth2Util.AuthSession) parent);
   }
 
+  @Override
+  public AuthSession tableSession(RESTClient sharedClient, Map<String, String> properties) {
+    AuthConfig config = AuthConfig.fromProperties(properties);
+    Map<String, String> headers = OAuth2Util.authHeaders(config.token());
+    OAuth2Util.AuthSession parent = new OAuth2Util.AuthSession(headers, config);
+
+    keepRefreshed(config.keepRefreshed());
+
+    // Important: this method is invoked from standalone components; we must not assume that
+    // the refresh client and session cache have been initialized, because catalogSession()
+    // won't be called.
+    if (refreshClient == null) {
+      refreshClient = sharedClient.withAuthSession(parent);
+    }
+
+    if (sessionCache == null) {
+      sessionCache = newSessionCache(name, properties);
+    }
+
+    if (config.token() != null) {
+      return sessionCache.cachedSession(
+          config.token(), k -> newSessionFromAccessToken(config.token(), properties, parent));
+    }
+
+    if (config.credential() != null && !config.credential().isEmpty()) {
+      return sessionCache.cachedSession(
+          config.credential(), k -> newSessionFromTokenResponse(config, parent));
+    }
+
+    return parent;
+  }
+
   @Override
   public void close() {
     try {
@@ -226,8 +258,22 @@ public class OAuth2Manager extends RefreshingAuthManager {
         refreshClient, refreshExecutor(), token, tokenType, parent);
   }
 
-  private static void warnIfDeprecatedTokenEndpointUsed(Map<String, String> properties) {
-    if (usesDeprecatedTokenEndpoint(properties)) {
+  protected OAuth2Util.AuthSession newSessionFromTokenResponse(
+      AuthConfig config, OAuth2Util.AuthSession parent) {
+    OAuthTokenResponse response =
+        OAuth2Util.fetchToken(
+            refreshClient,
+            Map.of(),
+            config.credential(),
+            config.scope(),
+            config.oauth2ServerUri(),
+            config.optionalOAuthParams());
+    return OAuth2Util.AuthSession.fromTokenResponse(
+        refreshClient, refreshExecutor(), response, System.currentTimeMillis(), parent);
+  }
+
+  private static void warnIfOAuthServerUriNotSet(Map<String, String> properties) {
+    if (!properties.containsKey(OAuth2Properties.OAUTH2_SERVER_URI)) {
       String credential = properties.get(OAuth2Properties.CREDENTIAL);
       String initToken = properties.get(OAuth2Properties.TOKEN);
       boolean hasCredential = credential != null && !credential.isEmpty();
@@ -235,7 +281,7 @@ public class OAuth2Manager extends RefreshingAuthManager {
       if (hasInitToken || hasCredential) {
         LOG.warn(
             "Iceberg REST client is missing the OAuth2 server URI configuration and defaults to {}/{}. "
-                + "This automatic fallback will be removed in a future Iceberg release."
+                + "This automatic fallback will be removed in a future Iceberg release. "
                 + "It is recommended to configure the OAuth2 endpoint using the '{}' property to be prepared. "
                 + "This warning will disappear if the OAuth2 endpoint is explicitly configured. "
                 + "See https://github.com/apache/iceberg/issues/10537",
@@ -246,16 +292,6 @@ public class OAuth2Manager extends RefreshingAuthManager {
     }
   }
 
-  private static boolean usesDeprecatedTokenEndpoint(Map<String, String> properties) {
-    if (properties.containsKey(OAuth2Properties.OAUTH2_SERVER_URI)) {
-      String oauth2ServerUri = properties.get(OAuth2Properties.OAUTH2_SERVER_URI);
-      boolean relativePath = !oauth2ServerUri.startsWith("http");
-      boolean sameHost = oauth2ServerUri.startsWith(properties.get(CatalogProperties.URI));
-      return relativePath || sameHost;
-    }
-    return true;
-  }
-
   private static Duration sessionTimeout(Map<String, String> props) {
     return Duration.ofMillis(
         PropertyUtil.propertyAsLong(
