@@ -201,6 +201,14 @@ public class JsonUtil {
         BaseEncoding.base16().decode(pNode.textValue().toUpperCase(Locale.ROOT)));
   }
 
+  public static Map<String, String> getStringMapOrNull(String property, JsonNode node) {
+    if (!node.has(property)) {
+      return null;
+    }
+
+    return getStringMap(property, node);
+  }
+
   public static Map<String, String> getStringMap(String property, JsonNode node) {
     Preconditions.checkArgument(node.has(property), "Cannot parse missing map: %s", property);
     JsonNode pNode = node.get(property);
@@ -356,6 +364,46 @@ public class JsonUtil {
     writeLongFieldIf(value != null, key, value, generator);
   }
 
+  public static void writeStringFieldIfPresent(String key, String value, JsonGenerator generator)
+      throws IOException {
+    writeStringFieldIf(value != null, key, value, generator);
+  }
+
+  private static void writeStringFieldIf(
+      boolean condition, String key, String value, JsonGenerator generator) throws IOException {
+    if (condition) {
+      generator.writeStringField(key, value);
+    }
+  }
+
+  public static <T> List<T> getObjectListOrNull(
+      String property, JsonNode node, FromJson<T> fromJson) {
+    if (!node.has(property)) {
+      return null;
+    }
+
+    return getObjectList(property, node, fromJson);
+  }
+
+  public static <T> List<T> getObjectList(String property, JsonNode node, FromJson<T> fromJson) {
+    Preconditions.checkArgument(node.has(property), "Cannot parse missing list: %s", property);
+    Iterator<T> iter =
+        new JsonArrayIterator<>(property, node) {
+          @Override
+          T convert(JsonNode element) {
+            return fromJson.parse(element);
+          }
+
+          @Override
+          void validate(JsonNode element) {
+            Preconditions.checkArgument(
+                element.isObject(), "Cannot parse object from non-object value: %s", element);
+          }
+        };
+
+    return ImmutableList.copyOf(iter);
+  }
+
   abstract static class JsonArrayIterator<T> implements Iterator<T> {
 
     private final Iterator<JsonNode> elements;
