@@ -31,6 +31,7 @@ import org.apache.iceberg.SnapshotRef;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableMetadata;
 import org.apache.iceberg.exceptions.ValidationException;
+import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
@@ -281,6 +282,11 @@ public class SnapshotUtil {
     return Iterables.transform(snapshots, Snapshot::snapshotId);
   }
 
+  /**
+   * @deprecated will be removed in 2.0.0, use {@link #newFilesBetween(Long, long, Function,
+   *     FileIO)} instead.
+   */
+  @Deprecated
   public static List<DataFile> newFiles(
       Long baseSnapshotId, long latestSnapshotId, Function<Long, Snapshot> lookup, FileIO io) {
     List<DataFile> newFiles = Lists.newArrayList();
@@ -303,6 +309,34 @@ public class SnapshotUtil {
     return newFiles;
   }
 
+  public static CloseableIterable<DataFile> newFilesBetween(
+      Long startSnapshotId, long endSnapshotId, Function<Long, Snapshot> lookup, FileIO io) {
+
+    List<Snapshot> snapshots = Lists.newArrayList();
+    Snapshot lastSnapshot = null;
+    for (Snapshot currentSnapshot : ancestorsOf(endSnapshotId, lookup)) {
+      lastSnapshot = currentSnapshot;
+      if (Objects.equals(currentSnapshot.snapshotId(), startSnapshotId)) {
+        break;
+      }
+
+      snapshots.add(currentSnapshot);
+    }
+
+    if (lastSnapshot != null) {
+      ValidationException.check(
+          Objects.equals(lastSnapshot.snapshotId(), startSnapshotId)
+              || Objects.equals(lastSnapshot.parentId(), startSnapshotId),
+          "Cannot determine history between read snapshot %s and the last known ancestor %s",
+          startSnapshotId,
+          lastSnapshot.snapshotId());
+    }
+
+    return new ParallelIterable<>(
+        Iterables.transform(snapshots, snapshot -> snapshot.addedDataFiles(io)),
+        ThreadPools.getWorkerPool());
+  }
+
   /**
    * Traverses the history of the table's current snapshot and finds the snapshot with the given
    * snapshot id as its parent.
