@@ -18,12 +18,14 @@
  */
 package org.apache.iceberg.util;
 
+import java.time.Duration;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
 import org.apache.iceberg.SystemConfigs;
 import org.apache.iceberg.relocated.com.google.common.util.concurrent.MoreExecutors;
 import org.apache.iceberg.relocated.com.google.common.util.concurrent.ThreadFactoryBuilder;
@@ -51,6 +53,9 @@ public class ThreadPools {
   private static final ExecutorService DELETE_WORKER_POOL =
       newExitingWorkerPool("iceberg-delete-worker-pool", DELETE_WORKER_THREAD_POOL_SIZE);
 
+  public static final int AUTH_REFRESH_THREAD_POOL_SIZE =
+      SystemConfigs.AUTH_REFRESH_THREAD_POOL_SIZE.value();
+
   /**
    * Return an {@link ExecutorService} that uses the "worker" thread-pool.
    *
@@ -82,6 +87,20 @@ public class ThreadPools {
     return DELETE_WORKER_POOL;
   }
 
+  /**
+   * A shared {@link ScheduledExecutorService} that REST catalogs can use for refreshing their
+   * authentication data.
+   */
+  public static ScheduledExecutorService authRefreshPool() {
+    return AuthRefreshPoolHolder.INSTANCE;
+  }
+
+  private static class AuthRefreshPoolHolder {
+    private static final ScheduledExecutorService INSTANCE =
+        ThreadPools.newExitingScheduledPool(
+            "auth-session-refresh", AUTH_REFRESH_THREAD_POOL_SIZE, Duration.ZERO);
+  }
+
   /**
    * Creates a fixed-size thread pool that uses daemon threads. The pool is wrapped with {@link
    * MoreExecutors#getExitingExecutorService(ThreadPoolExecutor)}, which registers a shutdown hook
@@ -152,6 +171,23 @@ public class ThreadPools {
     return new ScheduledThreadPoolExecutor(poolSize, newDaemonThreadFactory(namePrefix));
   }
 
+  /**
+   * Create a new {@link ScheduledExecutorService} with the given name and pool size.
+   *
+   * <p>Threads used by this service will be daemon threads.
+   *
+   * <p>The service registers a shutdown hook to ensure that it terminates when the JVM exits. This
+   * is suitable for long-lived thread pools that should be automatically cleaned up on JVM
+   * shutdown.
+   */
+  public static ScheduledExecutorService newExitingScheduledPool(
+      String namePrefix, int poolSize, Duration terminationTimeout) {
+    return MoreExecutors.getExitingScheduledExecutorService(
+        (ScheduledThreadPoolExecutor) newScheduledPool(namePrefix, poolSize),
+        terminationTimeout.toMillis(),
+        TimeUnit.MILLISECONDS);
+  }
+
   private static ThreadFactory newDaemonThreadFactory(String namePrefix) {
     return new ThreadFactoryBuilder().setDaemon(true).setNameFormat(namePrefix + "-%d").build();
   }
