@@ -22,7 +22,9 @@ import java.math.BigDecimal;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
 import java.nio.charset.StandardCharsets;
+import java.util.UUID;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
+import org.apache.iceberg.util.UUIDUtil;
 
 class PrimitiveWrapper<T> implements VariantPrimitive<T> {
   private static final byte NULL_HEADER = VariantUtil.primitiveHeader(Primitives.TYPE_NULL);
@@ -45,6 +47,13 @@ class PrimitiveWrapper<T> implements VariantPrimitive<T> {
       VariantUtil.primitiveHeader(Primitives.TYPE_DECIMAL16);
   private static final byte BINARY_HEADER = VariantUtil.primitiveHeader(Primitives.TYPE_BINARY);
   private static final byte STRING_HEADER = VariantUtil.primitiveHeader(Primitives.TYPE_STRING);
+  private static final byte TIME_HEADER = VariantUtil.primitiveHeader(Primitives.TYPE_TIME);
+  private static final byte TIMESTAMPTZ_NANOS_HEADER =
+      VariantUtil.primitiveHeader(Primitives.TYPE_TIMESTAMPTZ_NANOS);
+  private static final byte TIMESTAMPNTZ_NANOS_HEADER =
+      VariantUtil.primitiveHeader(Primitives.TYPE_TIMESTAMPNTZ_NANOS);
+  private static final byte UUID_HEADER = VariantUtil.primitiveHeader(Primitives.TYPE_UUID);
+  private static final int MAX_SHORT_STRING_LENGTH = 63;
 
   private final PhysicalType type;
   private final T value;
@@ -90,6 +99,9 @@ class PrimitiveWrapper<T> implements VariantPrimitive<T> {
       case DOUBLE:
       case TIMESTAMPTZ:
       case TIMESTAMPNTZ:
+      case TIMESTAMPTZ_NANOS:
+      case TIMESTAMPNTZ_NANOS:
+      case TIME:
         return 9; // 1 header + 8 value
       case DECIMAL4:
         return 6; // 1 header + 1 scale + 4 unscaled value
@@ -103,8 +115,12 @@ class PrimitiveWrapper<T> implements VariantPrimitive<T> {
         if (null == buffer) {
           this.buffer = ByteBuffer.wrap(((String) value).getBytes(StandardCharsets.UTF_8));
         }
-
+        if (buffer.remaining() <= MAX_SHORT_STRING_LENGTH) {
+          return 1 + buffer.remaining(); // 1 header + value length
+        }
         return 5 + buffer.remaining(); // 1 header + 4 length + value length
+      case UUID:
+        return 1 + 16; // 1 header + 16 length
     }
 
     throw new UnsupportedOperationException("Unsupported primitive type: " + type());
@@ -195,15 +211,36 @@ class PrimitiveWrapper<T> implements VariantPrimitive<T> {
         VariantUtil.writeBufferAbsolute(outBuffer, offset + 5, binary);
         return 5 + binary.remaining();
       case STRING:
-        // TODO: use short string when possible
         if (null == buffer) {
           this.buffer = ByteBuffer.wrap(((String) value).getBytes(StandardCharsets.UTF_8));
         }
-
-        outBuffer.put(offset, STRING_HEADER);
-        outBuffer.putInt(offset + 1, buffer.remaining());
-        VariantUtil.writeBufferAbsolute(outBuffer, offset + 5, buffer);
-        return 5 + buffer.remaining();
+        if (buffer.remaining() <= MAX_SHORT_STRING_LENGTH) {
+          outBuffer.put(offset, VariantUtil.shortStringHeader(buffer.remaining()));
+          VariantUtil.writeBufferAbsolute(outBuffer, offset + 1, buffer);
+          return 1 + buffer.remaining();
+        } else {
+          outBuffer.put(offset, STRING_HEADER);
+          outBuffer.putInt(offset + 1, buffer.remaining());
+          VariantUtil.writeBufferAbsolute(outBuffer, offset + 5, buffer);
+          return 5 + buffer.remaining();
+        }
+      case TIME:
+        outBuffer.put(offset, TIME_HEADER);
+        outBuffer.putLong(offset + 1, (Long) value);
+        return 9;
+      case TIMESTAMPTZ_NANOS:
+        outBuffer.put(offset, TIMESTAMPTZ_NANOS_HEADER);
+        outBuffer.putLong(offset + 1, (Long) value);
+        return 9;
+      case TIMESTAMPNTZ_NANOS:
+        outBuffer.put(offset, TIMESTAMPNTZ_NANOS_HEADER);
+        outBuffer.putLong(offset + 1, (Long) value);
+        return 9;
+      case UUID:
+        outBuffer.put(offset, UUID_HEADER);
+        VariantUtil.writeBufferAbsolute(
+            outBuffer, offset + 1, UUIDUtil.convertToByteBuffer((UUID) value));
+        return 17;
     }
 
     throw new UnsupportedOperationException("Unsupported primitive type: " + type());
