@@ -18,6 +18,7 @@
  */
 package org.apache.iceberg.view;
 
+import java.util.Locale;
 import java.util.UUID;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.Function;
@@ -102,6 +103,7 @@ public abstract class BaseViewOperations extends BaseMetastoreOperations impleme
   }
 
   @Override
+  @SuppressWarnings("ImmutablesReferenceEquality")
   public void commit(ViewMetadata base, ViewMetadata metadata) {
     // if the metadata is already out of date, reject it
     if (base != current()) {
@@ -156,13 +158,20 @@ public abstract class BaseViewOperations extends BaseMetastoreOperations impleme
                 ViewProperties.METADATA_COMPRESSION, ViewProperties.METADATA_COMPRESSION_DEFAULT);
     String fileExtension = TableMetadataParser.getFileExtension(codecName);
     return metadataFileLocation(
-        metadata, String.format("%05d-%s%s", newVersion, UUID.randomUUID(), fileExtension));
+        metadata,
+        String.format(Locale.ROOT, "%05d-%s%s", newVersion, UUID.randomUUID(), fileExtension));
   }
 
   private String metadataFileLocation(ViewMetadata metadata, String filename) {
-    return String.format(
-        "%s/%s/%s",
-        LocationUtil.stripTrailingSlash(metadata.location()), METADATA_FOLDER_NAME, filename);
+    String metadataLocation = metadata.properties().get(ViewProperties.WRITE_METADATA_LOCATION);
+
+    if (metadataLocation != null) {
+      return String.format("%s/%s", LocationUtil.stripTrailingSlash(metadataLocation), filename);
+    } else {
+      return String.format(
+          "%s/%s/%s",
+          LocationUtil.stripTrailingSlash(metadata.location()), METADATA_FOLDER_NAME, filename);
+    }
   }
 
   protected void refreshFromMetadataLocation(String newLocation) {
