@@ -39,7 +39,6 @@ public class TestBaseIncrementalAppendScan
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_B).commit();
-    long snapshotBId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_C).commit();
     long snapshotCId = table.currentSnapshot().snapshotId();
 
@@ -67,13 +66,13 @@ public class TestBaseIncrementalAppendScan
     table.manageSnapshots().createTag(tagSnapshotAName, snapshotAId).commit();
 
     String tagSnapshotBName = "t2";
-    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_B).commit();
+    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_C).commit();
     long snapshotBId = table.currentSnapshot().snapshotId();
     table.manageSnapshots().createTag(tagSnapshotBName, snapshotBId).commit();
-    table.newFastAppend().appendFile(FILE_C).appendFile(FILE_C).commit();
+    table.newFastAppend().appendFile(FILE_D).appendFile(FILE_A2).commit();
 
     /*
-              files:FILE_A         files:FILE_B FILE_B       files:FILE_C FILE_C
+              files:FILE_A         files:FILE_B FILE_C       files:FILE_D FILE_A2
      ---- snapshotAId(tag:t1) ---- snapshotMainB(tag:t2) ----  currentSnapshot
     */
     IncrementalAppendScan scan = newScan().fromSnapshotInclusive(tagSnapshotAName);
@@ -111,11 +110,11 @@ public class TestBaseIncrementalAppendScan
     table.manageSnapshots().createTag(tagSnapshotAName, snapshotAId).commit();
 
     String tagName2 = "t2";
-    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_B).commit();
+    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_C).commit();
     long snapshotMainBId = table.currentSnapshot().snapshotId();
     table.manageSnapshots().createTag(tagName2, snapshotMainBId).commit();
 
-    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_B).commit();
+    table.newFastAppend().appendFile(FILE_D).appendFile(FILE_A2).commit();
 
     table.newFastAppend().appendFile(FILE_C).toBranch(branchName).commit();
     long snapshotBranchBId = table.snapshot(branchName).snapshotId();
@@ -125,7 +124,7 @@ public class TestBaseIncrementalAppendScan
 
     /*
 
-            files:FILE_A         files:FILE_B FILE_B       files:FILE_B FILE_B
+            files:FILE_A         files:FILE_B FILE_C       files:FILE_D FILE_A2
      ---- snapshotA(tag:t1) ---- snapshotMainB(tag:t2) ----  currentSnapshot
                         \
                          \
@@ -175,21 +174,21 @@ public class TestBaseIncrementalAppendScan
     table.newFastAppend().appendFile(FILE_A).commit();
     long snapshotAId = table.currentSnapshot().snapshotId();
 
-    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_B).commit();
+    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_C).commit();
     long snapshotMainBId = table.currentSnapshot().snapshotId();
 
     String branchName = "b1";
     table.manageSnapshots().createBranch(branchName, snapshotAId).commit();
-    table.newFastAppend().appendFile(FILE_C).toBranch(branchName).commit();
+    table.newFastAppend().appendFile(FILE_D).toBranch(branchName).commit();
     long snapshotBranchBId = table.snapshot(branchName).snapshotId();
 
     /*
 
-          files:FILE_A            files:FILE_B FILE_B
+          files:FILE_A            files:FILE_B FILE_C
           ---- snapshotA  ------ snapshotMainB
                         \
                          \
-                          \files:FILE_C
+                          \files:FILE_D
                           snapshotBranchB(branch:b1)
     */
     assertThatThrownBy(
@@ -221,7 +220,6 @@ public class TestBaseIncrementalAppendScan
     table.newFastAppend().appendFile(FILE_B).commit();
     long snapshotBId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_C).commit();
-    long snapshotCId = table.currentSnapshot().snapshotId();
 
     IncrementalAppendScan scan = newScan().fromSnapshotExclusive(snapshotAId);
     assertThat(scan.planFiles()).hasSize(2);
@@ -240,7 +238,6 @@ public class TestBaseIncrementalAppendScan
     table.newFastAppend().appendFile(FILE_B).commit();
     long snapshotBId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_C).commit();
-    long snapshotCId = table.currentSnapshot().snapshotId();
     table.expireSnapshots().expireOlderThan(expireTimestampSnapshotA).commit();
 
     IncrementalAppendScan scan = newScan().fromSnapshotExclusive(snapshotAId);
@@ -267,13 +264,13 @@ public class TestBaseIncrementalAppendScan
     table.manageSnapshots().createTag(tagSnapshotAName, snapshotAId).commit();
 
     String tagSnapshotBName = "t2";
-    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_B).commit();
+    table.newFastAppend().appendFile(FILE_B).appendFile(FILE_C).commit();
     long snapshotBId = table.currentSnapshot().snapshotId();
     table.manageSnapshots().createTag(tagSnapshotBName, snapshotBId).commit();
-    table.newFastAppend().appendFile(FILE_C).appendFile(FILE_C).commit();
+    table.newFastAppend().appendFile(FILE_D).appendFile(FILE_A2).commit();
 
     /*
-              files:FILE_A         files:FILE_B FILE_B       files:FILE_C FILE_C
+              files:FILE_A         files:FILE_B FILE_C       files:FILE_D FILE_A2
      ---- snapshotAId(tag:t1) ---- snapshotMainB(tag:t2) ----  currentSnapshot
     */
     IncrementalAppendScan scan = newScan().fromSnapshotExclusive(tagSnapshotAName);
@@ -299,11 +296,9 @@ public class TestBaseIncrementalAppendScan
   @TestTemplate
   public void testToSnapshot() {
     table.newFastAppend().appendFile(FILE_A).commit();
-    long snapshotAId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_B).commit();
     long snapshotBId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_C).commit();
-    long snapshotCId = table.currentSnapshot().snapshotId();
 
     IncrementalAppendScan scan = newScan().toSnapshot(snapshotBId);
     assertThat(scan.planFiles()).hasSize(2);
@@ -312,7 +307,6 @@ public class TestBaseIncrementalAppendScan
   @TestTemplate
   public void testToSnapshotWithTag() {
     table.newFastAppend().appendFile(FILE_A).commit();
-    long snapshotAId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_B).commit();
     long snapshotBId = table.currentSnapshot().snapshotId();
 
@@ -368,7 +362,6 @@ public class TestBaseIncrementalAppendScan
   @TestTemplate
   public void testMultipleRootSnapshots() throws Exception {
     table.newFastAppend().appendFile(FILE_A).commit();
-    long snapshotAId = table.currentSnapshot().snapshotId();
     long expireTimestampSnapshotA =
         TestHelpers.waitUntilAfter(table.currentSnapshot().timestampMillis());
 
@@ -378,7 +371,6 @@ public class TestBaseIncrementalAppendScan
     appendFiles.commit();
 
     table.newFastAppend().appendFile(FILE_C).commit();
-    long snapshotCId = table.currentSnapshot().snapshotId();
     table.newFastAppend().appendFile(FILE_D).commit();
     long snapshotDId = table.currentSnapshot().snapshotId();
 
