@@ -32,10 +32,12 @@ import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.IOException;
-import java.util.Arrays;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 import org.apache.iceberg.ManifestEntry.Status;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Expression;
@@ -57,11 +59,9 @@ public class TestRowDelta extends TestBase {
 
   @Parameters(name = "formatVersion = {0}, branch = {1}")
   protected static List<Object> parameters() {
-    return Arrays.asList(
-        new Object[] {2, "main"},
-        new Object[] {2, "testBranch"},
-        new Object[] {3, "main"},
-        new Object[] {3, "testBranch"});
+    return TestHelpers.V2_AND_ABOVE.stream()
+        .flatMap(v -> Stream.of(new Object[] {v, "main"}, new Object[] {v, "testBranch"}))
+        .collect(Collectors.toList());
   }
 
   @TestTemplate
@@ -77,7 +77,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testAddDeleteFile() {
+  public void testAddRemoveRows() {
     SnapshotUpdate<?> rowDelta =
         table.newRowDelta().addRows(FILE_A).addDeletes(fileADeletes()).addDeletes(fileBDeletes());
 
@@ -289,6 +289,147 @@ public class TestRowDelta extends TestBase {
         statuses(Status.ADDED));
   }
 
+  @TestTemplate
+  public void testFileDeleteAndRowDelete() {
+    commit(table, table.newAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
+    long initialCommit = latestSnapshot(table, branch).snapshotId();
+
+    commit(
+        table,
+        table
+            .newRowDelta()
+            .addDeletes(fileADeletes())
+            .addRows(FILE_A2)
+            .removeRows(FILE_B)
+            .validateFromSnapshot(initialCommit)
+            .validateDataFilesExist(ImmutableList.of(FILE_A.location())),
+        branch);
+
+    Snapshot snap = latestSnapshot(table, branch);
+    assertThat(snap.sequenceNumber()).isEqualTo(2);
+    assertThat(table.ops().current().lastSequenceNumber()).isEqualTo(2);
+
+    assertThat(snap.dataManifests(table.io())).hasSize(2);
+    // manifest with FILE_A2 added
+    validateManifest(
+        snap.dataManifests(table.io()).get(0),
+        dataSeqs(2L),
+        fileSeqs(2L),
+        ids(snap.snapshotId()),
+        files(FILE_A2),
+        statuses(Status.ADDED));
+
+    // manifest with FILE_A deleted
+    validateManifest(
+        snap.dataManifests(table.io()).get(1),
+        dataSeqs(1L, 1L),
+        fileSeqs(1L, 1L),
+        ids(initialCommit, snap.snapshotId()),
+        files(FILE_A, FILE_B),
+        statuses(Status.EXISTING, Status.DELETED));
+
+    assertThat(snap.deleteManifests(table.io())).hasSize(1);
+    validateDeleteManifest(
+        snap.deleteManifests(table.io()).get(0),
+        dataSeqs(2L),
+        fileSeqs(2L),
+        ids(snap.snapshotId()),
+        files(fileADeletes()),
+        statuses(Status.ADDED));
+  }
+
+  @TestTemplate
+  public void testValidateFileDeleteAndRowDelete() {
+    commit(table, table.newAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
+    long initialCommit = latestSnapshot(table, branch).snapshotId();
+
+    commit(
+        table,
+        table
+            .newRowDelta()
+            .addDeletes(fileBDeletes())
+            .validateFromSnapshot(initialCommit)
+            .validateDataFilesExist(ImmutableList.of(FILE_A.location())),
+        branch);
+
+    assertThatThrownBy(
+            () -> {
+              commit(
+                  table,
+                  table
+                      .newRowDelta()
+                      .addDeletes(fileADeletes())
+                      .addRows(FILE_A2)
+                      .removeRows(FILE_B)
+                      .validateFromSnapshot(initialCommit)
+                      .validateNoConflictingDeleteFiles()
+                      .validateDataFilesExist(ImmutableList.of(FILE_A.location())),
+                  branch);
+            })
+        .isInstanceOf(ValidationException.class)
+        .hasMessageContaining("found new delete for replaced data file: " + FILE_B);
+  }
+
+  @TestTemplate
+  public void testValidateFileDeleteAndRowDeleteSameFile() {
+    commit(table, table.newAppend().appendFile(FILE_A), branch);
+    long initialCommit = latestSnapshot(table, branch).snapshotId();
+
+    // test adding a delete vector to a deleted file
+    assertThatThrownBy(
+            () -> {
+              commit(
+                  table,
+                  table
+                      .newRowDelta()
+                      .addDeletes(fileADeletes())
+                      .removeRows(FILE_A)
+                      .validateFromSnapshot(initialCommit)
+                      .validateDeletedFiles()
+                      .validateDataFilesExist(ImmutableList.of(FILE_A.location())),
+                  branch);
+            })
+        .isInstanceOf(ValidationException.class)
+        .hasMessageContaining("Cannot delete data files")
+        .hasMessageContaining(FILE_A.location());
+  }
+
+  @TestTemplate
+  public void testValidateRemoveRows() {
+    commit(table, table.newAppend().appendFile(FILE_B), branch);
+    long initialCommit = latestSnapshot(table, branch).snapshotId();
+
+    // Remove a file which does not exist
+    assertThatThrownBy(
+            () -> {
+              commit(
+                  table,
+                  table
+                      .newRowDelta()
+                      .removeRows(FILE_A)
+                      .validateFromSnapshot(initialCommit)
+                      .validateDeletedFiles(),
+                  branch);
+            })
+        .isInstanceOf(ValidationException.class)
+        .hasMessageContaining("Missing required files to delete:")
+        .hasMessageContaining(FILE_A.location());
+
+    // Should succeed if validation is ignored
+    commit(
+        table, table.newRowDelta().removeRows(FILE_A).validateFromSnapshot(initialCommit), branch);
+
+    // Commit should be a no-op
+    Snapshot snap = latestSnapshot(table, branch);
+    validateManifest(
+        snap.dataManifests(table.io()).get(0),
+        dataSeqs(1L),
+        fileSeqs(1L),
+        ids(initialCommit),
+        files(FILE_B),
+        statuses(Status.ADDED));
+  }
+
   @TestTemplate
   public void testValidateDataFilesExistRewrite() {
     commit(table, table.newAppend().appendFile(FILE_A).appendFile(FILE_B), branch);
@@ -450,7 +591,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testOverwriteWithDeleteFile() {
+  public void testOverwriteWithRemoveRows() {
     commit(
         table,
         table.newRowDelta().addRows(FILE_A).addDeletes(fileADeletes()).addDeletes(fileBDeletes()),
@@ -493,7 +634,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testReplacePartitionsWithDeleteFile() {
+  public void testReplacePartitionsWithRemoveRows() {
     commit(
         table,
         table.newRowDelta().addRows(FILE_A).addDeletes(fileADeletes()).addDeletes(fileBDeletes()),
@@ -540,7 +681,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testDeleteByExpressionWithDeleteFile() {
+  public void testDeleteByExpressionWithRemoveRows() {
     commit(
         table,
         table.newRowDelta().addRows(FILE_A).addDeletes(fileADeletes()).addDeletes(fileBDeletes()),
@@ -577,7 +718,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testDeleteDataFileWithDeleteFile() {
+  public void testDeleteDataFileWithRemoveRows() {
     commit(
         table,
         table.newRowDelta().addRows(FILE_A).addDeletes(fileADeletes()).addDeletes(fileBDeletes()),
@@ -587,7 +728,7 @@ public class TestRowDelta extends TestBase {
     assertThat(latestSnapshot(table, branch).sequenceNumber()).isEqualTo(1);
     assertThat(table.ops().current().lastSequenceNumber()).isEqualTo(1);
 
-    // deleting a specific data file will not affect a delete file
+    // deleting a specific data file will not affect a delete file in v2 or less
     commit(table, table.newDelete().deleteFile(FILE_A), branch);
 
     Snapshot deleteSnap = latestSnapshot(table, branch);
@@ -603,21 +744,26 @@ public class TestRowDelta extends TestBase {
         files(FILE_A),
         statuses(Status.DELETED));
 
-    assertThat(deleteSnap.deleteManifests(table.io())).hasSize(1);
+    Iterator<Long> ids =
+        formatVersion >= 3
+            ? ids(deleteSnap.snapshotId(), deltaSnapshotId)
+            : ids(deltaSnapshotId, deltaSnapshotId);
+    Iterator<Status> statuses =
+        formatVersion >= 3
+            ? statuses(Status.DELETED, Status.EXISTING)
+            : statuses(Status.ADDED, Status.ADDED);
     validateDeleteManifest(
         deleteSnap.deleteManifests(table.io()).get(0),
         dataSeqs(1L, 1L),
         fileSeqs(1L, 1L),
-        ids(deltaSnapshotId, deltaSnapshotId),
+        ids,
         files(fileADeletes(), fileBDeletes()),
-        statuses(Status.ADDED, Status.ADDED));
+        statuses);
 
     // the manifest that removed FILE_A will be dropped next commit, causing the min sequence number
-    // of all data files
-    // to be 2, the largest known sequence number. this will cause FILE_A_DELETES to be removed
-    // because it is too old
-    // to apply to any data files.
-    commit(table, table.newRowDelta().removeDeletes(FILE_B_DELETES), branch);
+    // of all data files to be 2, the largest known sequence number. This will cause FILE_A_DELETES
+    // to be removed because it is too old to apply to any data files.
+    commit(table, table.newRowDelta().removeDeletes(fileBDeletes()), branch);
 
     Snapshot nextSnap = latestSnapshot(table, branch);
     assertThat(nextSnap.sequenceNumber()).isEqualTo(3);
@@ -630,7 +776,7 @@ public class TestRowDelta extends TestBase {
         dataSeqs(1L, 1L),
         fileSeqs(1L, 1L),
         ids(nextSnap.snapshotId(), nextSnap.snapshotId()),
-        files(fileADeletes(), fileBDeletes()),
+        formatVersion >= 3 ? files(fileBDeletes()) : files(fileADeletes(), fileBDeletes()),
         statuses(Status.DELETED, Status.DELETED));
   }
 
@@ -663,9 +809,9 @@ public class TestRowDelta extends TestBase {
         deleteSnap.deleteManifests(table.io()).get(0),
         dataSeqs(1L),
         fileSeqs(1L),
-        ids(deltaSnapshotId),
+        ids(formatVersion >= 3 ? deleteSnap.snapshotId() : deltaSnapshotId),
         files(fileADeletes()),
-        statuses(Status.ADDED));
+        statuses(formatVersion >= 3 ? Status.DELETED : Status.ADDED));
 
     // the manifest that removed FILE_A will be dropped next merging commit, but FastAppend will not
     // remove it
@@ -699,9 +845,9 @@ public class TestRowDelta extends TestBase {
         nextSnap.deleteManifests(table.io()).get(0),
         dataSeqs(1L),
         fileSeqs(1L),
-        ids(deltaSnapshotId),
+        ids(formatVersion >= 3 ? deleteSnap.snapshotId() : deltaSnapshotId),
         files(fileADeletes()),
-        statuses(Status.ADDED));
+        statuses(formatVersion >= 3 ? Status.DELETED : Status.ADDED));
   }
 
   @TestTemplate
@@ -1500,7 +1646,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testConcurrentDeletesRewriteSameDeleteFile() {
+  public void testConcurrentDeletesRewriteSameRemoveRows() {
     assumeThat(formatVersion).isEqualTo(2);
 
     DataFile dataFile = newDataFile("data_bucket=0");
@@ -1565,7 +1711,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testConcurrentManifestRewriteWithDeleteFileRemoval() throws IOException {
+  public void testConcurrentManifestRewriteWithRemoveRowsRemoval() throws IOException {
     assumeThat(formatVersion).isEqualTo(2);
     // Manifest rewrite isn't supported on branches currently
     assumeThat(branch).isEqualTo("main");
@@ -1629,7 +1775,7 @@ public class TestRowDelta extends TestBase {
   }
 
   @TestTemplate
-  public void testConcurrentMergeRewriteSameDeleteFile() {
+  public void testConcurrentMergeRewriteSameRemoveRows() {
     DataFile dataFile = newDataFile("data_bucket=0");
     DeleteFile deleteFile = newDeletes(dataFile);
     RowDelta baseRowDelta = table.newRowDelta().addRows(dataFile).addDeletes(deleteFile);
