@@ -779,6 +779,22 @@ public class TestSchemaUpdate {
         .hasMessage("Cannot add column, name already exists: ID");
   }
 
+  @Test
+  public void testAddMultipleRequiredColumnCaseInsensitive() {
+    Schema schema = new Schema(required(1, "id", Types.IntegerType.get()));
+
+    assertThatThrownBy(
+            () ->
+                new SchemaUpdate(schema, 1)
+                    .caseSensitive(false)
+                    .allowIncompatibleChanges()
+                    .addRequiredColumn("data", Types.StringType.get())
+                    .addRequiredColumn("DATA", Types.StringType.get())
+                    .apply())
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Cannot build lower case index: data and DATA collide");
+  }
+
   @Test
   public void testMakeColumnOptional() {
     Schema schema = new Schema(required(1, "id", Types.IntegerType.get()));
