@@ -116,6 +116,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     long currentSnapshotId = System.currentTimeMillis();
@@ -133,6 +134,7 @@ public class TestTableMetadata {
             7,
             manifestList,
             null,
+            null,
             null);
 
     List<HistoryEntry> snapshotLog =
@@ -198,6 +200,7 @@ public class TestTableMetadata {
             statisticsFiles,
             partitionStatisticsFiles,
             40,
+            ImmutableList.of(),
             ImmutableList.of());
 
     String asJson = TableMetadataParser.toJson(expected);
@@ -255,6 +258,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     long currentSnapshotId = System.currentTimeMillis();
@@ -272,6 +276,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     TableMetadata expected =
@@ -300,6 +305,7 @@ public class TestTableMetadata {
             ImmutableList.of(),
             ImmutableList.of(),
             0,
+            ImmutableList.of(),
             ImmutableList.of());
 
     String asJson = toJsonWithoutSpecAndSchemaList(expected);
@@ -359,6 +365,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     long currentSnapshotId = System.currentTimeMillis();
@@ -377,6 +384,7 @@ public class TestTableMetadata {
             7,
             manifestList,
             null,
+            null,
             null);
 
     List<HistoryEntry> snapshotLog =
@@ -421,6 +429,7 @@ public class TestTableMetadata {
                     ImmutableList.of(),
                     ImmutableList.of(),
                     0L,
+                    ImmutableList.of(),
                     ImmutableList.of()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageStartingWith("Current snapshot ID does not match main branch");
@@ -434,7 +443,7 @@ public class TestTableMetadata {
         createManifestListWithManifestFile(snapshotId, null, "file:/tmp/manifest1.avro");
     Snapshot snapshot =
         new BaseSnapshot(
-            0, snapshotId, null, snapshotId, null, null, null, manifestList, null, null);
+            0, snapshotId, null, snapshotId, null, null, null, manifestList, null, null, null);
 
     Schema schema = new Schema(6, Types.NestedField.required(10, "x", Types.StringType.get()));
 
@@ -468,6 +477,7 @@ public class TestTableMetadata {
                     ImmutableList.of(),
                     ImmutableList.of(),
                     0L,
+                    ImmutableList.of(),
                     ImmutableList.of()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageStartingWith("Current snapshot is not set, but main branch exists");
@@ -509,6 +519,7 @@ public class TestTableMetadata {
                     ImmutableList.of(),
                     ImmutableList.of(),
                     0L,
+                    ImmutableList.of(),
                     ImmutableList.of()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageEndingWith("does not exist in the existing snapshots list");
@@ -573,6 +584,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     long currentSnapshotId = System.currentTimeMillis();
@@ -590,6 +602,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     List<HistoryEntry> reversedSnapshotLog = Lists.newArrayList();
@@ -625,6 +638,7 @@ public class TestTableMetadata {
             ImmutableList.of(),
             ImmutableList.of(),
             0L,
+            ImmutableList.of(),
             ImmutableList.of());
 
     String asJson = TableMetadataParser.toJson(base);
@@ -650,6 +664,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
     long currentSnapshotId = System.currentTimeMillis();
 
@@ -667,6 +682,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     List<HistoryEntry> reversedSnapshotLog = Lists.newArrayList();
@@ -713,6 +729,7 @@ public class TestTableMetadata {
             ImmutableList.of(),
             ImmutableList.of(),
             0L,
+            ImmutableList.of(),
             ImmutableList.of());
 
     previousMetadataLog.add(latestPreviousMetadata);
@@ -744,6 +761,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     long currentSnapshotId = System.currentTimeMillis();
@@ -761,6 +779,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     List<HistoryEntry> reversedSnapshotLog = Lists.newArrayList();
@@ -816,6 +835,7 @@ public class TestTableMetadata {
             ImmutableList.of(),
             ImmutableList.of(),
             0L,
+            ImmutableList.of(),
             ImmutableList.of());
 
     previousMetadataLog.add(latestPreviousMetadata);
@@ -851,6 +871,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     long currentSnapshotId = System.currentTimeMillis();
@@ -868,6 +889,7 @@ public class TestTableMetadata {
             null,
             manifestList,
             null,
+            null,
             null);
 
     List<HistoryEntry> reversedSnapshotLog = Lists.newArrayList();
@@ -923,6 +945,7 @@ public class TestTableMetadata {
             ImmutableList.of(),
             ImmutableList.of(),
             0L,
+            ImmutableList.of(),
             ImmutableList.of());
 
     previousMetadataLog.add(latestPreviousMetadata);
@@ -970,6 +993,7 @@ public class TestTableMetadata {
                     ImmutableList.of(),
                     ImmutableList.of(),
                     0L,
+                    ImmutableList.of(),
                     ImmutableList.of()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("UUID is required in format v2");
@@ -1006,6 +1030,7 @@ public class TestTableMetadata {
                     ImmutableList.of(),
                     ImmutableList.of(),
                     0L,
+                    ImmutableList.of(),
                     ImmutableList.of()))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(
@@ -1053,6 +1078,7 @@ public class TestTableMetadata {
                 ImmutableList.of(),
                 ImmutableList.of(),
                 0L,
+                ImmutableList.of(),
                 ImmutableList.of()))
         .isNotNull();
 
@@ -1804,8 +1830,7 @@ public class TestTableMetadata {
 
   private String createManifestListWithManifestFile(
       long snapshotId, Long parentSnapshotId, String manifestFile) throws IOException {
-    File manifestList = File.createTempFile("manifests", null, temp.toFile());
-    manifestList.deleteOnExit();
+    File manifestList = temp.resolve("manifests-" + System.nanoTime()).toFile();
 
     try (ManifestListWriter writer =
         ManifestLists.write(
