@@ -49,7 +49,7 @@ public class TestJdbcUtil {
 
     Properties actual = JdbcUtil.filterAndRemovePrefix(input, "jdbc.");
 
-    assertThat(expected).isEqualTo(actual);
+    assertThat(actual).isEqualTo(expected);
   }
 
   @Test
@@ -143,4 +143,10 @@ public class TestJdbcUtil {
       assertThat(updated).isEqualTo(1);
     }
   }
+
+  @Test
+  public void emptyNamespaceInIdentifier() {
+    assertThat(JdbcUtil.stringToTableIdentifier("", "tblName"))
+        .isEqualTo(TableIdentifier.of(Namespace.empty(), "tblName"));
+  }
 }
