@@ -21,6 +21,7 @@ package org.apache.iceberg.rest;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatCode;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
@@ -48,17 +49,21 @@ import org.apache.hc.client5.http.io.HttpClientConnectionManager;
 import org.apache.hc.core5.http.HttpHost;
 import org.apache.hc.core5.http.HttpStatus;
 import org.apache.iceberg.IcebergBuild;
+import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.rest.auth.AuthSession;
+import org.apache.iceberg.rest.auth.TLSConfigurer;
 import org.apache.iceberg.rest.responses.ErrorResponse;
 import org.apache.iceberg.rest.responses.ErrorResponseParser;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.EnumSource;
 import org.junit.jupiter.params.provider.ValueSource;
 import org.mockserver.configuration.Configuration;
 import org.mockserver.integration.ClientAndServer;
+import org.mockserver.matchers.Times;
 import org.mockserver.model.HttpRequest;
 import org.mockserver.model.HttpResponse;
 import org.mockserver.verify.VerificationTimes;
@@ -71,6 +76,8 @@ public class TestHTTPClient {
 
   private static final int PORT = 1080;
   private static final String BEARER_AUTH_TOKEN = "auth_token";
+  private static final String USER_AGENT = "User-Agent";
+  private static final String TEST_USER_AGENT = "Test-User-Agent";
   private static final String URI = String.format("http://127.0.0.1:%d", PORT);
   private static final ObjectMapper MAPPER = RESTObjectMapper.mapper();
 
@@ -79,11 +86,26 @@ public class TestHTTPClient {
   private static ClientAndServer mockServer;
   private static RESTClient restClient;
 
+  public static class DefaultTLSConfigurer implements TLSConfigurer {
+    public static int count = 0;
+
+    public DefaultTLSConfigurer() {
+      count++;
+    }
+  }
+
+  public static class TLSConfigurerMissingNoArgCtor implements TLSConfigurer {
+    TLSConfigurerMissingNoArgCtor(String str) {}
+  }
+
   @BeforeAll
   public static void beforeClass() {
     mockServer = startClientAndServer(PORT);
     restClient =
-        HTTPClient.builder(ImmutableMap.of()).uri(URI).withAuthSession(AuthSession.EMPTY).build();
+        HTTPClient.builder(ImmutableMap.of(HTTPClient.REST_USER_AGENT, TEST_USER_AGENT))
+            .uri(URI)
+            .withAuthSession(AuthSession.EMPTY)
+            .build();
     icebergBuildGitCommitShort = IcebergBuild.gitCommitShortId();
     icebergBuildFullVersion = IcebergBuild.fullVersion();
   }
@@ -174,6 +196,65 @@ public class TestHTTPClient {
         .hasMessage("Invalid hostname for http client proxy: null");
   }
 
+  @Test
+  public void testClientWithProxyProps() throws IOException {
+    int proxyPort = 1070;
+    try (ClientAndServer proxyServer = startClientAndServer(proxyPort);
+        RESTClient clientWithProxy =
+            HTTPClient.builder(
+                    ImmutableMap.of(
+                        HTTPClient.REST_PROXY_HOSTNAME,
+                        "localhost",
+                        HTTPClient.REST_PROXY_PORT,
+                        String.valueOf(proxyPort)))
+                .uri(URI)
+                .withAuthSession(AuthSession.EMPTY)
+                .build()) {
+      String path = "v1/config";
+      HttpRequest mockRequest =
+          request("/" + path).withMethod(HttpMethod.HEAD.name().toUpperCase(Locale.ROOT));
+      HttpResponse mockResponse = response().withStatusCode(200);
+      proxyServer.when(mockRequest).respond(mockResponse);
+      clientWithProxy.head(path, ImmutableMap.of(), (onError) -> {});
+      proxyServer.verify(mockRequest, VerificationTimes.exactly(1));
+    }
+  }
+
+  @Test
+  public void testClientWithAuthProxyProps() throws IOException {
+    int proxyPort = 1070;
+    String authorizedUsername = "test-username";
+    String authorizedPassword = "test-password";
+    try (ClientAndServer proxyServer =
+            startClientAndServer(
+                new Configuration()
+                    .proxyAuthenticationUsername(authorizedUsername)
+                    .proxyAuthenticationPassword(authorizedPassword),
+                proxyPort);
+        RESTClient clientWithProxy =
+            HTTPClient.builder(
+                    ImmutableMap.of(
+                        HTTPClient.REST_PROXY_HOSTNAME,
+                        "localhost",
+                        HTTPClient.REST_PROXY_PORT,
+                        String.valueOf(proxyPort),
+                        HTTPClient.REST_PROXY_USERNAME,
+                        authorizedUsername,
+                        HTTPClient.REST_PROXY_PASSWORD,
+                        authorizedPassword))
+                .uri(URI)
+                .withAuthSession(AuthSession.EMPTY)
+                .build()) {
+      String path = "v1/config";
+      HttpRequest mockRequest =
+          request("/" + path).withMethod(HttpMethod.HEAD.name().toUpperCase(Locale.ROOT));
+      HttpResponse mockResponse = response().withStatusCode(200);
+      proxyServer.when(mockRequest).respond(mockResponse);
+      clientWithProxy.head(path, ImmutableMap.of(), (onError) -> {});
+      proxyServer.verify(mockRequest, VerificationTimes.exactly(1));
+    }
+  }
+
   @Test
   public void testProxyAuthenticationFailure() throws IOException {
     int proxyPort = 1050;
@@ -273,6 +354,48 @@ public class TestHTTPClient {
         .isEqualTo(HTTPClient.REST_MAX_CONNECTIONS_PER_ROUTE_DEFAULT);
   }
 
+  @Test
+  public void testLoadTLSConfigurer() {
+    Map<String, String> properties =
+        ImmutableMap.of(HTTPClient.REST_TLS_CONFIGURER, DefaultTLSConfigurer.class.getName());
+    HttpClientConnectionManager connectionManager =
+        HTTPClient.configureConnectionManager(properties);
+    assertThat(connectionManager).isInstanceOf(PoolingHttpClientConnectionManager.class);
+    assertThat(DefaultTLSConfigurer.count).isEqualTo(1);
+  }
+
+  @Test
+  public void testLoadTLSConfigurerNoArgConstructorNotFound() {
+    Map<String, String> properties =
+        ImmutableMap.of(
+            HTTPClient.REST_TLS_CONFIGURER, TLSConfigurerMissingNoArgCtor.class.getName());
+    assertThatThrownBy(() -> HTTPClient.configureConnectionManager(properties))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageStartingWith("Cannot initialize TLSConfigurer implementation")
+        .hasMessageContaining(
+            "NoSuchMethodException: org.apache.iceberg.rest.TestHTTPClient$TLSConfigurerMissingNoArgCtor.<init>()");
+  }
+
+  @Test
+  public void testLoadTLSConfigurerClassNotFound() {
+    Map<String, String> properties =
+        ImmutableMap.of(HTTPClient.REST_TLS_CONFIGURER, "TLSConfigurerDoesNotExist");
+    assertThatThrownBy(() -> HTTPClient.configureConnectionManager(properties))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageStartingWith("Cannot initialize TLSConfigurer implementation")
+        .hasMessageContaining("java.lang.ClassNotFoundException: TLSConfigurerDoesNotExist");
+  }
+
+  @Test
+  public void testLoadTLSConfigurerNotImplementTLSConfigurer() {
+    Map<String, String> properties =
+        ImmutableMap.of(HTTPClient.REST_TLS_CONFIGURER, Object.class.getName());
+    assertThatThrownBy(() -> HTTPClient.configureConnectionManager(properties))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageStartingWith("Cannot initialize TLSConfigurer")
+        .hasMessageContaining("does not implement TLSConfigurer");
+  }
+
   @Test
   public void testSocketTimeout() throws IOException {
     long socketTimeoutMs = 2000L;
@@ -337,6 +460,27 @@ public class TestHTTPClient {
         .doesNotThrowAnyException();
   }
 
+  @ParameterizedTest
+  @EnumSource(HttpMethod.class)
+  public void testRetryIdemmpotentMethods(HttpMethod method) throws JsonProcessingException {
+    assumeThat(method.name().equals("GET") || method.name().equals("HEAD"))
+        .as("Only GET and HEAD methods are idempotent")
+        .isTrue();
+    ResourcePaths paths = ResourcePaths.forCatalogProperties(Map.of());
+    ErrorHandler errorHandler = (ErrorHandler) ErrorHandlers.defaultErrorHandler();
+    String path = paths.table(TableIdentifier.of("ns", "table"));
+    Item loadTableRequestBody = new Item(0L, "load table");
+
+    // First request will respond with a 504 (Gateway Timeout)
+    addRequestTestCaseAndGetPath(path, method, loadTableRequestBody, HttpStatus.SC_GATEWAY_TIMEOUT);
+
+    // Second request will respond with a 200 (OK)
+    addRequestTestCaseAndGetPath(path, method, loadTableRequestBody, HttpStatus.SC_OK);
+
+    // No exception should be thrown, and the second request should succeed
+    doExecuteRequest(method, path, loadTableRequestBody, errorHandler, headers -> {});
+  }
+
   public static void testHttpMethodOnSuccess(HttpMethod method) throws JsonProcessingException {
     Item body = new Item(0L, "hank");
     int statusCode = 200;
@@ -382,10 +526,14 @@ public class TestHTTPClient {
     verify(onError).accept(any());
   }
 
-  // Adds a request that the mock-server can match against, based on the method, path, body, and
-  // headers.
-  // Return the path generated for the test case, so that the client can call that path to exercise
-  // it.
+  /**
+   * Adds a request that the mock server can match against, using the HTTP method, request body, and
+   * status code to define behavior. This method generates a unique path (based on the method and
+   * success/failure outcome) so the client can call it during tests.
+   *
+   * <p>Note: This will only add one exact request test case, i.e., the response will only be
+   * returned for the next matching invocation of the path.
+   */
   private static String addRequestTestCaseAndGetPath(HttpMethod method, Item body, int statusCode)
       throws JsonProcessingException {
 
@@ -395,6 +543,21 @@ public class TestHTTPClient {
     String pathName = isSuccess ? "success" : "failure";
     String path = String.format("%s_%s", method, pathName);
 
+    return addRequestTestCaseAndGetPath(path, method, body, statusCode);
+  }
+
+  /**
+   * Adds a request that the mock server can match against, using the provided path, method, body,
+   * and status code. This version allows custom control over the path used in the test, e.g., in
+   * the retry scenario, we need to return different responses for the same path and request.
+   *
+   * <p>Note: This will only add one exact request test case, i.e., the response will only be
+   * returned for the next matching invocation of the path.
+   */
+  private static String addRequestTestCaseAndGetPath(
+      String path, HttpMethod method, Item body, int statusCode) throws JsonProcessingException {
+    boolean isSuccess = statusCode == 200;
+
     // Build the expected request
     String asJson = body != null ? MAPPER.writeValueAsString(body) : null;
     HttpRequest mockRequest =
@@ -402,7 +565,8 @@ public class TestHTTPClient {
             .withMethod(method.name().toUpperCase(Locale.ROOT))
             .withHeader("Authorization", "Bearer " + BEARER_AUTH_TOKEN)
             .withHeader(HTTPClient.CLIENT_VERSION_HEADER, icebergBuildFullVersion)
-            .withHeader(HTTPClient.CLIENT_GIT_COMMIT_SHORT_HEADER, icebergBuildGitCommitShort);
+            .withHeader(HTTPClient.CLIENT_GIT_COMMIT_SHORT_HEADER, icebergBuildGitCommitShort)
+            .withHeader(USER_AGENT, TEST_USER_AGENT);
 
     if (method.usesRequestBody()) {
       mockRequest = mockRequest.withBody(asJson);
@@ -422,7 +586,7 @@ public class TestHTTPClient {
       }
     }
 
-    mockServer.when(mockRequest).respond(mockResponse);
+    mockServer.when(mockRequest, Times.exactly(1)).respond(mockResponse);
 
     return path;
   }
