@@ -18,11 +18,13 @@
  */
 package org.apache.iceberg.data;
 
+import static org.apache.iceberg.types.Types.NestedField.optional;
+import static org.apache.iceberg.types.Types.NestedField.required;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assumptions.assumeThat;
 
-import java.io.File;
 import java.io.IOException;
+import java.nio.ByteBuffer;
 import java.nio.file.Path;
 import java.time.LocalDate;
 import java.util.List;
@@ -37,6 +39,8 @@ import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TestHelpers.Row;
+import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Types;
@@ -55,14 +59,19 @@ public abstract class DeleteReadTests {
   // Schema passed to create tables
   public static final Schema SCHEMA =
       new Schema(
-          Types.NestedField.required(1, "id", Types.IntegerType.get()),
-          Types.NestedField.required(2, "data", Types.StringType.get()));
+          required(1, "id", Types.IntegerType.get()),
+          required(2, "data", Types.StringType.get()),
+          optional(3, "binaryData", Types.BinaryType.get()),
+          optional(
+              4,
+              "structData",
+              Types.StructType.of(optional(100, "structInnerData", Types.StringType.get()))));
 
   public static final Schema DATE_SCHEMA =
       new Schema(
-          Types.NestedField.required(1, "dt", Types.DateType.get()),
-          Types.NestedField.required(2, "data", Types.StringType.get()),
-          Types.NestedField.required(3, "id", Types.IntegerType.get()));
+          required(1, "dt", Types.DateType.get()),
+          required(2, "data", Types.StringType.get()),
+          required(3, "id", Types.IntegerType.get()));
 
   // Partition spec used to create tables
   public static final PartitionSpec SPEC =
@@ -115,7 +124,7 @@ public abstract class DeleteReadTests {
     this.dataFile =
         FileHelpers.writeDataFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             records);
 
@@ -146,31 +155,31 @@ public abstract class DeleteReadTests {
     DataFile dataFile1 =
         FileHelpers.writeDataFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-01"))),
             dateRecords.subList(0, 1));
     DataFile dataFile2 =
         FileHelpers.writeDataFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-02"))),
             dateRecords.subList(1, 2));
     DataFile dataFile3 =
         FileHelpers.writeDataFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-03"))),
             dateRecords.subList(2, 3));
     DataFile dataFile4 =
         FileHelpers.writeDataFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-04"))),
             dateRecords.subList(3, 4));
     DataFile dataFile5 =
         FileHelpers.writeDataFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-05"))),
             dateRecords.subList(4, 5));
 
@@ -231,7 +240,7 @@ public abstract class DeleteReadTests {
     DeleteFile eqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             dataDeletes,
             deleteRowSchema);
@@ -260,21 +269,21 @@ public abstract class DeleteReadTests {
     DeleteFile eqDeletes1 =
         FileHelpers.writeDeleteFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-01"))),
             dataDeletes.subList(0, 1),
             deleteRowSchema);
     DeleteFile eqDeletes2 =
         FileHelpers.writeDeleteFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-02"))),
             dataDeletes.subList(1, 2),
             deleteRowSchema);
     DeleteFile eqDeletes3 =
         FileHelpers.writeDeleteFile(
             dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(DateTimeUtil.daysFromDate(LocalDate.parse("2021-09-03"))),
             dataDeletes.subList(2, 3),
             deleteRowSchema);
@@ -308,7 +317,7 @@ public abstract class DeleteReadTests {
     DeleteFile eqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             dataDeletes,
             deleteRowSchema);
@@ -340,7 +349,7 @@ public abstract class DeleteReadTests {
     this.dataFile =
         FileHelpers.writeDataFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             records);
 
@@ -360,7 +369,7 @@ public abstract class DeleteReadTests {
     DeleteFile eqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             dataDeletes,
             deleteRowSchema);
@@ -387,7 +396,7 @@ public abstract class DeleteReadTests {
     Pair<DeleteFile, CharSequenceSet> posDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             deletes,
             formatVersion);
@@ -420,7 +429,7 @@ public abstract class DeleteReadTests {
     Pair<DeleteFile, CharSequenceSet> posDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             deletes,
             formatVersion);
@@ -436,7 +445,7 @@ public abstract class DeleteReadTests {
     posDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             deletes,
             formatVersion);
@@ -468,7 +477,7 @@ public abstract class DeleteReadTests {
     DeleteFile eqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             dataDeletes,
             dataSchema);
@@ -482,7 +491,7 @@ public abstract class DeleteReadTests {
     Pair<DeleteFile, CharSequenceSet> posDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             deletes,
             formatVersion);
@@ -515,7 +524,7 @@ public abstract class DeleteReadTests {
     DeleteFile dataEqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             dataDeletes,
             dataSchema);
@@ -531,7 +540,7 @@ public abstract class DeleteReadTests {
     DeleteFile idEqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             idDeletes,
             idSchema);
@@ -555,7 +564,7 @@ public abstract class DeleteReadTests {
     DataFile dataFileWithNull =
         FileHelpers.writeDataFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             Lists.newArrayList(record.copy("id", 131, "data", null)));
 
@@ -572,7 +581,7 @@ public abstract class DeleteReadTests {
     DeleteFile eqDeletes =
         FileHelpers.writeDeleteFile(
             table,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
             Row.of(0),
             dataDeletes,
             dataSchema);
@@ -586,6 +595,91 @@ public abstract class DeleteReadTests {
     checkDeleteCount(1L);
   }
 
+  @TestTemplate
+  public void testEqualityDeleteBinaryColumn() throws IOException {
+    writeOptionalTestDataFile();
+
+    Record binaryDataDelete = GenericRecord.create(table.schema().select("binaryData"));
+    List<Record> equalityDeletes =
+        Lists.newArrayList(
+            binaryDataDelete.copy("binaryData", ByteBuffer.wrap(("binaryData_0").getBytes())),
+            binaryDataDelete.copy("binaryData", ByteBuffer.wrap(("binaryData_1").getBytes())),
+            binaryDataDelete.copy("binaryData", ByteBuffer.wrap(("binaryData_2").getBytes())));
+    StructLikeSet expected = rowSetWithoutIds(table, records, 200, 201, 202);
+    testEqualityDeletes(equalityDeletes, expected);
+  }
+
+  @TestTemplate
+  public void testEqualityDeleteStructColumn() throws IOException {
+    writeOptionalTestDataFile();
+
+    Record structDataDelete = GenericRecord.create(table.schema().select("structData"));
+    Record structRecord0 =
+        GenericRecord.create(table.schema().findType("structData").asStructType());
+    Record structRecord1 =
+        GenericRecord.create(table.schema().findType("structData").asStructType());
+    Record structRecord2 =
+        GenericRecord.create(table.schema().findType("structData").asStructType());
+    structRecord0.setField("structInnerData", "structInnerData_0");
+    structRecord1.setField("structInnerData", "structInnerData_1");
+    structRecord2.setField("structInnerData", "structInnerData_2");
+    List<Record> equalityDeletes =
+        Lists.newArrayList(
+            structDataDelete.copy("structData", structRecord0),
+            structDataDelete.copy("structData", structRecord1),
+            structDataDelete.copy("structData", structRecord2));
+    StructLikeSet expected = rowSetWithoutIds(table, records, 200, 201, 202);
+    testEqualityDeletes(equalityDeletes, expected);
+  }
+
+  private void testEqualityDeletes(List<Record> equalityDeletes, StructLikeSet expected)
+      throws IOException {
+    Preconditions.checkArgument(
+        !equalityDeletes.isEmpty(), "Expected equality deletes in testEqualityDeletes");
+    DeleteFile eqDeletes =
+        FileHelpers.writeDeleteFile(
+            table,
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
+            Row.of(0),
+            equalityDeletes,
+            equalityDeletes.get(0).struct().asSchema());
+    table.newRowDelta().addDeletes(eqDeletes).commit();
+
+    StructLikeSet actual = rowSet(tableName, table, "*");
+    assertThat(actual).as("Table should contain expected rows").isEqualTo(expected);
+    checkDeleteCount(equalityDeletes.size());
+  }
+
+  private void writeOptionalTestDataFile() throws IOException {
+    Record record = GenericRecord.create(table.schema());
+    List<Record> recordsWithOptionalColumns = Lists.newArrayList();
+    for (int i = 0; i < 10; i++) {
+      Record structRecord =
+          GenericRecord.create(table.schema().findType("structData").asStructType());
+      structRecord.setField("structInnerData", "structInnerData_" + i);
+      recordsWithOptionalColumns.add(
+          record.copy(
+              ImmutableMap.of(
+                  "id",
+                  i + 200,
+                  "data",
+                  "testData",
+                  "binaryData",
+                  ByteBuffer.wrap(("binaryData_" + i).getBytes()),
+                  "structData",
+                  structRecord)));
+    }
+    DataFile binaryDataFile =
+        FileHelpers.writeDataFile(
+            table,
+            Files.localOutput(temp.resolve("junit" + System.nanoTime()).toFile()),
+            Row.of(0),
+            recordsWithOptionalColumns);
+
+    table.newAppend().appendFile(binaryDataFile).commit();
+    records.addAll(recordsWithOptionalColumns);
+  }
+
   private StructLikeSet selectColumns(StructLikeSet rows, String... columns) {
     Schema projection = table.schema().select(columns);
     StructLikeSet set = StructLikeSet.create(projection.asStruct());
