@@ -38,6 +38,8 @@ public interface TableLoader extends Closeable, Serializable, Cloneable {
 
   void open();
 
+  boolean isOpen();
+
   Table loadTable();
 
   /** Clone a TableLoader */
@@ -75,6 +77,11 @@ public interface TableLoader extends Closeable, Serializable, Cloneable {
       tables = new HadoopTables(hadoopConf.get());
     }
 
+    @Override
+    public boolean isOpen() {
+      return tables != null;
+    }
+
     @Override
     public Table loadTable() {
       FlinkEnvironmentContext.init();
@@ -115,6 +122,11 @@ public interface TableLoader extends Closeable, Serializable, Cloneable {
       catalog = catalogLoader.loadCatalog();
     }
 
+    @Override
+    public boolean isOpen() {
+      return catalog != null;
+    }
+
     @Override
     public Table loadTable() {
       FlinkEnvironmentContext.init();
@@ -126,6 +138,8 @@ public interface TableLoader extends Closeable, Serializable, Cloneable {
       if (catalog instanceof Closeable) {
         ((Closeable) catalog).close();
       }
+
+      catalog = null;
     }
 
     @Override
