@@ -30,10 +30,9 @@ import java.util.Set;
 import java.util.stream.Collectors;
 import java.util.stream.StreamSupport;
 import org.apache.flink.table.api.DataTypes;
+import org.apache.flink.table.api.Schema.UnresolvedPrimaryKey;
 import org.apache.flink.table.api.TableException;
-import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.api.ValidationException;
-import org.apache.flink.table.api.constraints.UniqueConstraint;
 import org.apache.flink.table.catalog.CatalogTable;
 import org.apache.flink.table.catalog.ObjectPath;
 import org.apache.flink.table.catalog.exceptions.TableNotExistException;
@@ -73,7 +72,7 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
   public void cleanNamespaces() {
     sql("DROP TABLE IF EXISTS %s.tl", flinkDatabase);
     sql("DROP TABLE IF EXISTS %s.tl2", flinkDatabase);
-    sql("DROP DATABASE IF EXISTS %s", flinkDatabase);
+    dropDatabase(flinkDatabase, true);
     super.clean();
   }
 
@@ -103,7 +102,7 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
         .isInstanceOf(ValidationException.class)
         .hasMessage("Table `tl` was not found.");
 
-    Schema actualSchema = FlinkSchemaUtil.convert(getTableEnv().from("tl2").getSchema());
+    Schema actualSchema = FlinkSchemaUtil.convert(getTableEnv().from("tl2").getResolvedSchema());
     assertThat(tableSchema.asStruct()).isEqualTo(actualSchema.asStruct());
   }
 
@@ -116,8 +115,11 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
         .isEqualTo(
             new Schema(Types.NestedField.optional(1, "id", Types.LongType.get())).asStruct());
     CatalogTable catalogTable = catalogTable("tl");
-    assertThat(catalogTable.getSchema())
-        .isEqualTo(TableSchema.builder().field("id", DataTypes.BIGINT()).build());
+    assertThat(catalogTable.getUnresolvedSchema())
+        .isEqualTo(
+            org.apache.flink.table.api.Schema.newBuilder()
+                .column("id", DataTypes.BIGINT())
+                .build());
   }
 
   @TestTemplate
@@ -129,9 +131,10 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
         .as("Should have the expected row key.")
         .isEqualTo(Sets.newHashSet(table.schema().findField("key").fieldId()));
     CatalogTable catalogTable = catalogTable("tl");
-    Optional<UniqueConstraint> uniqueConstraintOptional = catalogTable.getSchema().getPrimaryKey();
+    Optional<UnresolvedPrimaryKey> uniqueConstraintOptional =
+        catalogTable.getUnresolvedSchema().getPrimaryKey();
     assertThat(uniqueConstraintOptional).isPresent();
-    assertThat(uniqueConstraintOptional.get().getColumns()).containsExactly("key");
+    assertThat(uniqueConstraintOptional.get().getColumnNames()).containsExactly("key");
   }
 
   @TestTemplate
@@ -147,9 +150,10 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
                 table.schema().findField("id").fieldId(),
                 table.schema().findField("data").fieldId()));
     CatalogTable catalogTable = catalogTable("tl");
-    Optional<UniqueConstraint> uniqueConstraintOptional = catalogTable.getSchema().getPrimaryKey();
+    Optional<UnresolvedPrimaryKey> uniqueConstraintOptional =
+        catalogTable.getUnresolvedSchema().getPrimaryKey();
     assertThat(uniqueConstraintOptional).isPresent();
-    assertThat(uniqueConstraintOptional.get().getColumns()).containsExactly("id", "data");
+    assertThat(uniqueConstraintOptional.get().getColumnNames()).containsExactly("id", "data");
   }
 
   @TestTemplate
@@ -184,8 +188,11 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
         .isEqualTo(
             new Schema(Types.NestedField.optional(1, "id", Types.LongType.get())).asStruct());
     CatalogTable catalogTable = catalogTable("tl2");
-    assertThat(catalogTable.getSchema())
-        .isEqualTo(TableSchema.builder().field("id", DataTypes.BIGINT()).build());
+    assertThat(catalogTable.getUnresolvedSchema())
+        .isEqualTo(
+            org.apache.flink.table.api.Schema.newBuilder()
+                .column("id", DataTypes.BIGINT())
+                .build());
   }
 
   @TestTemplate
@@ -198,8 +205,11 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
     sql("CREATE TABLE %s LIKE tl", catalog2 + ".testdb.tl2");
 
     CatalogTable catalogTable = catalogTable(catalog2, "testdb", "tl2");
-    assertThat(catalogTable.getSchema())
-        .isEqualTo(TableSchema.builder().field("id", DataTypes.BIGINT()).build());
+    assertThat(catalogTable.getUnresolvedSchema())
+        .isEqualTo(
+            org.apache.flink.table.api.Schema.newBuilder()
+                .column("id", DataTypes.BIGINT())
+                .build());
 
     dropCatalog(catalog2, true);
   }
@@ -211,15 +221,19 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
     sql("CREATE TABLE `default_catalog`.`default_database`.tl2 LIKE tl");
 
     CatalogTable catalogTable = catalogTable("default_catalog", "default_database", "tl2");
-    assertThat(catalogTable.getSchema())
-        .isEqualTo(TableSchema.builder().field("id", DataTypes.BIGINT()).build());
+    assertThat(catalogTable.getUnresolvedSchema())
+        .isEqualTo(
+            org.apache.flink.table.api.Schema.newBuilder()
+                .column("id", DataTypes.BIGINT())
+                .build());
 
     String srcCatalogProps = FlinkCreateTableOptions.toJson(catalogName, DATABASE, "tl", config);
     Map<String, String> options = catalogTable.getOptions();
-    assertThat(options.get(FlinkCreateTableOptions.CONNECTOR_PROPS_KEY))
-        .isEqualTo(FlinkDynamicTableFactory.FACTORY_IDENTIFIER);
-    assertThat(options.get(FlinkCreateTableOptions.SRC_CATALOG_PROPS_KEY))
-        .isEqualTo(srcCatalogProps);
+    assertThat(options)
+        .containsEntry(
+            FlinkCreateTableOptions.CONNECTOR_PROPS_KEY,
+            FlinkDynamicTableFactory.FACTORY_IDENTIFIER)
+        .containsEntry(FlinkCreateTableOptions.SRC_CATALOG_PROPS_KEY, srcCatalogProps);
   }
 
   @TestTemplate
@@ -250,11 +264,11 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
     assertThat(table.spec())
         .isEqualTo(PartitionSpec.builderFor(table.schema()).identity("dt").build());
     CatalogTable catalogTable = catalogTable("tl");
-    assertThat(catalogTable.getSchema())
+    assertThat(catalogTable.getUnresolvedSchema())
         .isEqualTo(
-            TableSchema.builder()
-                .field("id", DataTypes.BIGINT())
-                .field("dt", DataTypes.STRING())
+            org.apache.flink.table.api.Schema.newBuilder()
+                .column("id", DataTypes.BIGINT())
+                .column("dt", DataTypes.STRING())
                 .build());
     assertThat(catalogTable.getPartitionKeys()).isEqualTo(Collections.singletonList("dt"));
   }
@@ -273,7 +287,7 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
   }
 
   @TestTemplate
-  public void testCreateTableWithFormatV2ThroughTableProperty() throws Exception {
+  public void testCreateTableWithFormatV2ThroughTableProperty() {
     sql("CREATE TABLE tl(id BIGINT) WITH ('format-version'='2')");
 
     Table table = table("tl");
@@ -281,7 +295,7 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
   }
 
   @TestTemplate
-  public void testUpgradeTableWithFormatV2ThroughTableProperty() throws Exception {
+  public void testUpgradeTableWithFormatV2ThroughTableProperty() {
     sql("CREATE TABLE tl(id BIGINT) WITH ('format-version'='1')");
 
     Table table = table("tl");
@@ -296,7 +310,7 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
   }
 
   @TestTemplate
-  public void testDowngradeTableToFormatV1ThroughTablePropertyFails() throws Exception {
+  public void testDowngradeTableToFormatV1ThroughTablePropertyFails() {
     sql("CREATE TABLE tl(id BIGINT) WITH ('format-version'='2')");
 
     Table table = table("tl");
@@ -319,13 +333,16 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
         PartitionSpec.builderFor(schema).bucket("id", 100).build());
 
     CatalogTable catalogTable = catalogTable("tl");
-    assertThat(catalogTable.getSchema())
-        .isEqualTo(TableSchema.builder().field("id", DataTypes.BIGINT()).build());
+    assertThat(catalogTable.getUnresolvedSchema())
+        .isEqualTo(
+            org.apache.flink.table.api.Schema.newBuilder()
+                .column("id", DataTypes.BIGINT())
+                .build());
     assertThat(catalogTable.getPartitionKeys()).isEmpty();
   }
 
   @TestTemplate
-  public void testAlterTableProperties() throws TableNotExistException {
+  public void testAlterTableProperties() {
     sql("CREATE TABLE tl(id BIGINT) WITH ('oldK'='oldV')");
     Map<String, String> properties = Maps.newHashMap();
     properties.put("oldK", "oldV");
@@ -673,11 +690,11 @@ public class TestFlinkCatalogTable extends CatalogTestBase {
   private void validateTableFiles(Table tbl, DataFile... expectedFiles) {
     tbl.refresh();
     Set<CharSequence> expectedFilePaths =
-        Arrays.stream(expectedFiles).map(DataFile::path).collect(Collectors.toSet());
+        Arrays.stream(expectedFiles).map(DataFile::location).collect(Collectors.toSet());
     Set<CharSequence> actualFilePaths =
         StreamSupport.stream(tbl.newScan().planFiles().spliterator(), false)
             .map(FileScanTask::file)
-            .map(ContentFile::path)
+            .map(ContentFile::location)
             .collect(Collectors.toSet());
     assertThat(actualFilePaths).as("Files should match").isEqualTo(expectedFilePaths);
   }
