@@ -52,21 +52,39 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
   @Parameter(index = 2)
   private boolean partitioned;
 
-  @Parameters(name = "format={0}, parallelism = {1}, partitioned = {2}")
+  @Parameter(index = 3)
+  private boolean isTableSchema;
+
+  @Parameters(name = "format={0}, parallelism = {1}, partitioned = {2}, isTableSchema = {3}")
   public static Object[][] parameters() {
     return new Object[][] {
-      {FileFormat.AVRO, 1, true},
-      {FileFormat.AVRO, 1, false},
-      {FileFormat.AVRO, 2, true},
-      {FileFormat.AVRO, 2, false},
-      {FileFormat.ORC, 1, true},
-      {FileFormat.ORC, 1, false},
-      {FileFormat.ORC, 2, true},
-      {FileFormat.ORC, 2, false},
-      {FileFormat.PARQUET, 1, true},
-      {FileFormat.PARQUET, 1, false},
-      {FileFormat.PARQUET, 2, true},
-      {FileFormat.PARQUET, 2, false}
+      // Remove after the deprecation of TableSchema - BEGIN
+      {FileFormat.AVRO, 1, true, true},
+      {FileFormat.AVRO, 1, false, true},
+      {FileFormat.AVRO, 2, true, true},
+      {FileFormat.AVRO, 2, false, true},
+      {FileFormat.ORC, 1, true, true},
+      {FileFormat.ORC, 1, false, true},
+      {FileFormat.ORC, 2, true, true},
+      {FileFormat.ORC, 2, false, true},
+      {FileFormat.PARQUET, 1, true, true},
+      {FileFormat.PARQUET, 1, false, true},
+      {FileFormat.PARQUET, 2, true, true},
+      {FileFormat.PARQUET, 2, false, true},
+      // Remove after the deprecation of TableSchema - END
+
+      {FileFormat.AVRO, 1, true, false},
+      {FileFormat.AVRO, 1, false, false},
+      {FileFormat.AVRO, 2, true, false},
+      {FileFormat.AVRO, 2, false, false},
+      {FileFormat.ORC, 1, true, false},
+      {FileFormat.ORC, 1, false, false},
+      {FileFormat.ORC, 2, true, false},
+      {FileFormat.ORC, 2, false, false},
+      {FileFormat.PARQUET, 1, true, false},
+      {FileFormat.PARQUET, 1, false, false},
+      {FileFormat.PARQUET, 2, true, false},
+      {FileFormat.PARQUET, 2, false, false},
     };
   }
 
@@ -115,11 +133,11 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
 
   @TestTemplate
   public void testWriteRow() throws Exception {
-    testWriteRow(parallelism, null, DistributionMode.NONE);
+    testWriteRow(parallelism, null, DistributionMode.NONE, isTableSchema);
   }
 
   @TestTemplate
-  public void testWriteRowWithTableSchema() throws Exception {
-    testWriteRow(parallelism, SimpleDataUtil.FLINK_SCHEMA, DistributionMode.NONE);
+  public void testWriteRowWithFlinkSchema() throws Exception {
+    testWriteRow(parallelism, SimpleDataUtil.FLINK_SCHEMA, DistributionMode.NONE, isTableSchema);
   }
 }
