@@ -21,6 +21,7 @@ package org.apache.iceberg.flink.sink;
 import static org.apache.iceberg.flink.TestFixtures.DATABASE;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.IOException;
 import java.util.Collections;
@@ -31,6 +32,7 @@ import org.apache.flink.configuration.Configuration;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.TableSchema;
+import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.types.Row;
 import org.apache.iceberg.DistributionMode;
@@ -55,7 +57,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.types.Types;
-import org.junit.Assume;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
 import org.junit.jupiter.api.extension.ExtendWith;
@@ -74,21 +75,39 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
   @Parameter(index = 2)
   private boolean partitioned;
 
-  @Parameters(name = "format={0}, parallelism={1}, partitioned={2}")
+  @Parameter(index = 3)
+  private boolean isTableSchema;
+
+  @Parameters(name = "format={0}, parallelism={1}, partitioned={2}, isTableSchema={3}")
   public static Object[][] parameters() {
     return new Object[][] {
-      {FileFormat.AVRO, 1, true},
-      {FileFormat.AVRO, 1, false},
-      {FileFormat.AVRO, 2, true},
-      {FileFormat.AVRO, 2, false},
-      {FileFormat.ORC, 1, true},
-      {FileFormat.ORC, 1, false},
-      {FileFormat.ORC, 2, true},
-      {FileFormat.ORC, 2, false},
-      {FileFormat.PARQUET, 1, true},
-      {FileFormat.PARQUET, 1, false},
-      {FileFormat.PARQUET, 2, true},
-      {FileFormat.PARQUET, 2, false}
+      // Remove after the deprecation of TableSchema - BEGIN
+      {FileFormat.AVRO, 1, true, true},
+      {FileFormat.AVRO, 1, false, true},
+      {FileFormat.AVRO, 2, true, true},
+      {FileFormat.AVRO, 2, false, true},
+      {FileFormat.ORC, 1, true, true},
+      {FileFormat.ORC, 1, false, true},
+      {FileFormat.ORC, 2, true, true},
+      {FileFormat.ORC, 2, false, true},
+      {FileFormat.PARQUET, 1, true, true},
+      {FileFormat.PARQUET, 1, false, true},
+      {FileFormat.PARQUET, 2, true, true},
+      {FileFormat.PARQUET, 2, false, true},
+      // Remove after the deprecation of TableSchema - END
+
+      {FileFormat.AVRO, 1, true, false},
+      {FileFormat.AVRO, 1, false, false},
+      {FileFormat.AVRO, 2, true, false},
+      {FileFormat.AVRO, 2, false, false},
+      {FileFormat.ORC, 1, true, false},
+      {FileFormat.ORC, 1, false, false},
+      {FileFormat.ORC, 2, true, false},
+      {FileFormat.ORC, 2, false, false},
+      {FileFormat.PARQUET, 1, true, false},
+      {FileFormat.PARQUET, 1, false, false},
+      {FileFormat.PARQUET, 2, true, false},
+      {FileFormat.PARQUET, 2, false, false},
     };
   }
 
@@ -145,57 +164,6 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
     testWriteRow(SimpleDataUtil.FLINK_SCHEMA, DistributionMode.NONE);
   }
 
-  @TestTemplate
-  void testJobNoneDistributeMode() throws Exception {
-    table
-        .updateProperties()
-        .set(TableProperties.WRITE_DISTRIBUTION_MODE, DistributionMode.HASH.modeName())
-        .commit();
-
-    testWriteRow(null, DistributionMode.NONE);
-
-    if (parallelism > 1) {
-      if (partitioned) {
-        int files = partitionFiles("aaa") + partitionFiles("bbb") + partitionFiles("ccc");
-        assertThat(files).as("Should have more than 3 files in iceberg table.").isGreaterThan(3);
-      }
-    }
-  }
-
-  @TestTemplate
-  void testJobHashDistributionMode() {
-    table
-        .updateProperties()
-        .set(TableProperties.WRITE_DISTRIBUTION_MODE, DistributionMode.HASH.modeName())
-        .commit();
-
-    assertThatThrownBy(() -> testWriteRow(null, DistributionMode.RANGE))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Flink does not support 'range' write distribution mode now.");
-  }
-
-  @TestTemplate
-  void testJobNullDistributionMode() throws Exception {
-    table
-        .updateProperties()
-        .set(TableProperties.WRITE_DISTRIBUTION_MODE, DistributionMode.HASH.modeName())
-        .commit();
-
-    testWriteRow(null, null);
-
-    if (partitioned) {
-      assertThat(partitionFiles("aaa"))
-          .as("There should be only 1 data file in partition 'aaa'")
-          .isEqualTo(1);
-      assertThat(partitionFiles("bbb"))
-          .as("There should be only 1 data file in partition 'bbb'")
-          .isEqualTo(1);
-      assertThat(partitionFiles("ccc"))
-          .as("There should be only 1 data file in partition 'ccc'")
-          .isEqualTo(1);
-    }
-  }
-
   @TestTemplate
   void testPartitionWriteMode() throws Exception {
     testWriteRow(null, DistributionMode.HASH);
@@ -271,29 +239,54 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
         env.fromCollection(leftRows, ROW_TYPE_INFO)
             .name("leftCustomSource")
             .uid("leftCustomSource");
-    IcebergSink.forRow(leftStream, SimpleDataUtil.FLINK_SCHEMA)
-        .table(leftTable)
-        .tableLoader(leftTableLoader)
-        .tableSchema(SimpleDataUtil.FLINK_SCHEMA)
-        .distributionMode(DistributionMode.NONE)
-        .uidSuffix("leftIcebergSink")
-        .append();
+
+    if (isTableSchema) {
+      IcebergSink.forRow(leftStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .table(leftTable)
+          .tableLoader(leftTableLoader)
+          .tableSchema(SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .distributionMode(DistributionMode.NONE)
+          .uidSuffix("leftIcebergSink")
+          .append();
+    } else {
+      IcebergSink.forRow(leftStream, SimpleDataUtil.FLINK_SCHEMA)
+          .table(leftTable)
+          .tableLoader(leftTableLoader)
+          .resolvedSchema(SimpleDataUtil.FLINK_SCHEMA)
+          .distributionMode(DistributionMode.NONE)
+          .uidSuffix("leftIcebergSink")
+          .append();
+    }
 
     List<Row> rightRows = createRows("right-");
     DataStream<Row> rightStream =
         env.fromCollection(rightRows, ROW_TYPE_INFO)
             .name("rightCustomSource")
             .uid("rightCustomSource");
-    IcebergSink.forRow(rightStream, SimpleDataUtil.FLINK_SCHEMA)
-        .table(rightTable)
-        .tableLoader(rightTableLoader)
-        .tableSchema(SimpleDataUtil.FLINK_SCHEMA)
-        .writeParallelism(parallelism)
-        .distributionMode(DistributionMode.HASH)
-        .uidSuffix("rightIcebergSink")
-        .setSnapshotProperty("flink.test", TestIcebergSink.class.getName())
-        .snapshotProperties(Collections.singletonMap("direction", "rightTable"))
-        .append();
+
+    if (isTableSchema) {
+      IcebergSink.forRow(rightStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .table(rightTable)
+          .tableLoader(rightTableLoader)
+          .tableSchema(SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .writeParallelism(parallelism)
+          .distributionMode(DistributionMode.HASH)
+          .uidSuffix("rightIcebergSink")
+          .setSnapshotProperty("flink.test", TestIcebergSink.class.getName())
+          .snapshotProperties(Collections.singletonMap("direction", "rightTable"))
+          .append();
+    } else {
+      IcebergSink.forRow(rightStream, SimpleDataUtil.FLINK_SCHEMA)
+          .table(rightTable)
+          .tableLoader(rightTableLoader)
+          .resolvedSchema(SimpleDataUtil.FLINK_SCHEMA)
+          .writeParallelism(parallelism)
+          .distributionMode(DistributionMode.HASH)
+          .uidSuffix("rightIcebergSink")
+          .setSnapshotProperty("flink.test", TestIcebergSink.class.getName())
+          .snapshotProperties(Collections.singletonMap("direction", "rightTable"))
+          .append();
+    }
 
     // Execute the program.
     env.execute("Test Iceberg DataStream.");
@@ -311,25 +304,6 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
     assertThat(rightTable.currentSnapshot().summary().get("direction")).isEqualTo("rightTable");
   }
 
-  @TestTemplate
-  void testOverrideWriteConfigWithUnknownDistributionMode() {
-    Map<String, String> newProps = Maps.newHashMap();
-    newProps.put(FlinkWriteOptions.DISTRIBUTION_MODE.key(), "UNRECOGNIZED");
-
-    List<Row> rows = createRows("");
-    DataStream<Row> dataStream = env.addSource(createBoundedSource(rows), ROW_TYPE_INFO);
-    IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
-        .table(table)
-        .tableLoader(tableLoader)
-        .writeParallelism(parallelism)
-        .setAll(newProps)
-        .append();
-
-    assertThatThrownBy(() -> env.execute("Test Iceberg DataStream"))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Invalid distribution mode: UNRECOGNIZED");
-  }
-
   @TestTemplate
   void testOverrideWriteConfigWithUnknownFileFormat() {
     Map<String, String> newProps = Maps.newHashMap();
@@ -339,12 +313,19 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
     DataStream<Row> dataStream = env.addSource(createBoundedSource(rows), ROW_TYPE_INFO);
 
     Builder builder =
-        IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
-            .table(table)
-            .tableLoader(tableLoader)
-            .writeParallelism(parallelism)
-            .setAll(newProps)
-            .uidSuffix("ingestion");
+        isTableSchema
+            ? IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+                .table(table)
+                .tableLoader(tableLoader)
+                .writeParallelism(parallelism)
+                .setAll(newProps)
+                .uidSuffix("ingestion")
+            : IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
+                .table(table)
+                .tableLoader(tableLoader)
+                .writeParallelism(parallelism)
+                .setAll(newProps)
+                .uidSuffix("ingestion");
     assertThatThrownBy(builder::append)
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Invalid file format: UNRECOGNIZED");
@@ -375,18 +356,28 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
   }
 
   @TestTemplate
-  void testOperatorsUidNameNoUidSuffix() throws Exception {
+  void testOperatorsUidNameNoUidSuffix() {
     List<Row> rows = createRows("");
     DataStream<Row> dataStream =
         env.addSource(createBoundedSource(rows), ROW_TYPE_INFO).uid("mySourceId");
 
-    IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
-        .table(table)
-        .tableLoader(tableLoader)
-        .tableSchema(SimpleDataUtil.FLINK_SCHEMA)
-        .writeParallelism(parallelism)
-        .distributionMode(DistributionMode.HASH)
-        .append();
+    if (isTableSchema) {
+      IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .table(table)
+          .tableLoader(tableLoader)
+          .tableSchema(SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .writeParallelism(parallelism)
+          .distributionMode(DistributionMode.HASH)
+          .append();
+    } else {
+      IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
+          .table(table)
+          .tableLoader(tableLoader)
+          .resolvedSchema(SimpleDataUtil.FLINK_SCHEMA)
+          .writeParallelism(parallelism)
+          .distributionMode(DistributionMode.HASH)
+          .append();
+    }
 
     Transformation firstTransformation = env.getTransformations().get(0);
     Transformation secondTransformation = env.getTransformations().get(1);
@@ -397,19 +388,30 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
   }
 
   @TestTemplate
-  void testOperatorsUidNameWitUidSuffix() throws Exception {
+  void testOperatorsUidNameWitUidSuffix() {
     List<Row> rows = createRows("");
     DataStream<Row> dataStream =
         env.addSource(createBoundedSource(rows), ROW_TYPE_INFO).uid("mySourceId");
 
-    IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
-        .table(table)
-        .tableLoader(tableLoader)
-        .tableSchema(SimpleDataUtil.FLINK_SCHEMA)
-        .writeParallelism(parallelism)
-        .distributionMode(DistributionMode.HASH)
-        .uidSuffix("data-ingestion")
-        .append();
+    if (isTableSchema) {
+      IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .table(table)
+          .tableLoader(tableLoader)
+          .tableSchema(SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .writeParallelism(parallelism)
+          .distributionMode(DistributionMode.HASH)
+          .uidSuffix("data-ingestion")
+          .append();
+    } else {
+      IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
+          .table(table)
+          .tableLoader(tableLoader)
+          .resolvedSchema(SimpleDataUtil.FLINK_SCHEMA)
+          .writeParallelism(parallelism)
+          .distributionMode(DistributionMode.HASH)
+          .uidSuffix("data-ingestion")
+          .append();
+    }
 
     Transformation firstTransformation = env.getTransformations().get(0);
     Transformation secondTransformation = env.getTransformations().get(1);
@@ -420,9 +422,10 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
   }
 
   @TestTemplate
-  void testErrorOnNullForRequiredField() throws Exception {
-    Assume.assumeFalse(
-        "ORC file format supports null values even for required fields.", format == FileFormat.ORC);
+  void testErrorOnNullForRequiredField() {
+    assumeThat(format)
+        .as("ORC file format supports null values even for required fields.")
+        .isNotEqualTo(FileFormat.ORC);
 
     Schema icebergSchema =
         new Schema(
@@ -446,30 +449,111 @@ public class TestIcebergSink extends TestFlinkIcebergSinkBase {
     DataStream<Row> dataStream =
         env.addSource(createBoundedSource(rows), ROW_TYPE_INFO).uid("mySourceId");
 
-    TableSchema flinkSchema = FlinkSchemaUtil.toSchema(icebergSchema);
-    IcebergSink.forRow(dataStream, flinkSchema)
-        .table(table2)
-        .tableLoader(TableLoader.fromCatalog(CATALOG_EXTENSION.catalogLoader(), tableIdentifier))
-        .tableSchema(flinkSchema)
-        .writeParallelism(parallelism)
-        .append();
+    if (isTableSchema) {
+      TableSchema flinkSchema = FlinkSchemaUtil.toSchema(icebergSchema);
+      IcebergSink.forRow(dataStream, flinkSchema)
+          .table(table2)
+          .tableLoader(TableLoader.fromCatalog(CATALOG_EXTENSION.catalogLoader(), tableIdentifier))
+          .tableSchema(flinkSchema)
+          .writeParallelism(parallelism)
+          .append();
+    } else {
+      ResolvedSchema flinkSchema = FlinkSchemaUtil.toResolvedSchema(icebergSchema);
+      IcebergSink.forRow(dataStream, flinkSchema)
+          .table(table2)
+          .tableLoader(TableLoader.fromCatalog(CATALOG_EXTENSION.catalogLoader(), tableIdentifier))
+          .resolvedSchema(flinkSchema)
+          .writeParallelism(parallelism)
+          .append();
+    }
 
     assertThatThrownBy(() -> env.execute()).hasRootCauseInstanceOf(NullPointerException.class);
   }
 
-  private void testWriteRow(TableSchema tableSchema, DistributionMode distributionMode)
+  @TestTemplate
+  void testDefaultWriteParallelism() {
+    List<Row> rows = createRows("");
+    DataStream<Row> dataStream =
+        env.addSource(createBoundedSource(rows), ROW_TYPE_INFO).uid("mySourceId");
+
+    var sink =
+        isTableSchema
+            ? IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+                .table(table)
+                .tableLoader(tableLoader)
+                .tableSchema(SimpleDataUtil.FLINK_TABLE_SCHEMA)
+                .distributionMode(DistributionMode.NONE)
+                .append()
+            : IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
+                .table(table)
+                .tableLoader(tableLoader)
+                .resolvedSchema(SimpleDataUtil.FLINK_SCHEMA)
+                .distributionMode(DistributionMode.NONE)
+                .append();
+
+    // since the sink write parallelism was null, it asserts that the default parallelism used was
+    // the input source parallelism.
+    // sink.getTransformation is referring to the SinkV2 Writer Operator associated to the
+    // IcebergSink
+    assertThat(sink.getTransformation().getParallelism()).isEqualTo(dataStream.getParallelism());
+  }
+
+  @TestTemplate
+  void testWriteParallelism() {
+    List<Row> rows = createRows("");
+
+    // the parallelism of this input source is always 1, as this is a non-parallel source.
+    DataStream<Row> dataStream =
+        env.addSource(createBoundedSource(rows), ROW_TYPE_INFO).uid("mySourceId");
+
+    var sink =
+        isTableSchema
+            ? IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+                .table(table)
+                .tableLoader(tableLoader)
+                .tableSchema(SimpleDataUtil.FLINK_TABLE_SCHEMA)
+                .distributionMode(DistributionMode.NONE)
+                .writeParallelism(parallelism)
+                .append()
+            : IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
+                .table(table)
+                .tableLoader(tableLoader)
+                .resolvedSchema(SimpleDataUtil.FLINK_SCHEMA)
+                .distributionMode(DistributionMode.NONE)
+                .writeParallelism(parallelism)
+                .append();
+
+    // The parallelism has been properly specified when creating the IcebergSink, so this asserts
+    // that its value is the same as the parallelism TestTemplate parameter
+    // sink.getTransformation is referring to the SinkV2 Writer Operator associated to the
+    // IcebergSink
+    assertThat(sink.getTransformation().getParallelism()).isEqualTo(parallelism);
+  }
+
+  private void testWriteRow(ResolvedSchema resolvedSchema, DistributionMode distributionMode)
       throws Exception {
     List<Row> rows = createRows("");
     DataStream<Row> dataStream =
         env.addSource(createBoundedSource(rows), ROW_TYPE_INFO).uid("mySourceId");
 
-    IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
-        .table(table)
-        .tableLoader(tableLoader)
-        .tableSchema(tableSchema)
-        .writeParallelism(parallelism)
-        .distributionMode(distributionMode)
-        .append();
+    if (isTableSchema) {
+      IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_TABLE_SCHEMA)
+          .table(table)
+          .tableLoader(tableLoader)
+          .tableSchema(
+              resolvedSchema == null ? null : TableSchema.fromResolvedSchema(resolvedSchema))
+          .writeParallelism(parallelism)
+          .distributionMode(distributionMode)
+          .append();
+    } else {
+      IcebergSink.forRow(dataStream, SimpleDataUtil.FLINK_SCHEMA)
+          .table(table)
+          .tableLoader(tableLoader)
+          .resolvedSchema(resolvedSchema)
+          .writeParallelism(parallelism)
+          .distributionMode(distributionMode)
+          .append();
+    }
 
     // Execute the program.
     env.execute("Test Iceberg DataStream.");
