@@ -27,6 +27,7 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.stream.Collectors;
 import org.apache.flink.api.common.RuntimeExecutionMode;
+import org.apache.flink.api.common.TaskInfo;
 import org.apache.flink.api.common.functions.RichMapFunction;
 import org.apache.flink.api.common.typeinfo.Types;
 import org.apache.flink.configuration.BatchExecutionOptions;
@@ -43,12 +44,16 @@ import org.apache.flink.table.api.TableEnvironment;
 import org.apache.flink.table.api.bridge.java.StreamTableEnvironment;
 import org.apache.flink.test.junit5.MiniClusterExtension;
 import org.apache.flink.types.Row;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.flink.FlinkConfigOptions;
 import org.apache.iceberg.flink.TestBase;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestTemplate;
 import org.junit.jupiter.api.Timeout;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.junit.jupiter.api.extension.RegisterExtension;
 
 /**
@@ -56,6 +61,7 @@ import org.junit.jupiter.api.extension.RegisterExtension;
  * anything goes wrong unexpectedly.
  */
 @Timeout(value = 60)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestIcebergSpeculativeExecutionSupport extends TestBase {
   private static final int NUM_TASK_MANAGERS = 1;
   private static final int NUM_TASK_SLOTS = 3;
@@ -89,6 +95,14 @@ public class TestIcebergSpeculativeExecutionSupport extends TestBase {
     return tEnv;
   }
 
+  @Parameter(index = 0)
+  private boolean useV2Sink;
+
+  @Parameters(name = "useV2Sink = {0}")
+  public static Object[][] parameters() {
+    return new Object[][] {{true}, {false}};
+  }
+
   @BeforeEach
   public void before() throws IOException {
     String warehouse =
@@ -113,8 +127,9 @@ public class TestIcebergSpeculativeExecutionSupport extends TestBase {
     dropCatalog(CATALOG_NAME, true);
   }
 
-  @Test
+  @TestTemplate
   public void testSpeculativeExecution() throws Exception {
+    tEnv.getConfig().set("table.exec.iceberg.use-v2-sink", String.valueOf(useV2Sink));
     Table table =
         tEnv.sqlQuery(String.format("SELECT * FROM %s.%s", DATABASE_NAME, INPUT_TABLE_NAME));
     DataStream<Row> slowStream =
@@ -151,8 +166,8 @@ public class TestIcebergSpeculativeExecutionSupport extends TestBase {
     @Override
     public Row map(Row row) throws Exception {
       // Simulate slow subtask 0 with attempt 0
-      if (getRuntimeContext().getIndexOfThisSubtask() == 0
-          && getRuntimeContext().getAttemptNumber() <= 0) {
+      TaskInfo taskInfo = getRuntimeContext().getTaskInfo();
+      if (taskInfo.getIndexOfThisSubtask() == 0 && taskInfo.getAttemptNumber() <= 0) {
         Thread.sleep(Integer.MAX_VALUE);
       }
 
@@ -160,8 +175,8 @@ public class TestIcebergSpeculativeExecutionSupport extends TestBase {
           Row.of(
               row.getField(0),
               row.getField(1),
-              getRuntimeContext().getIndexOfThisSubtask(),
-              getRuntimeContext().getAttemptNumber());
+              getRuntimeContext().getTaskInfo().getIndexOfThisSubtask(),
+              getRuntimeContext().getTaskInfo().getAttemptNumber());
 
       return output;
     }
