@@ -18,12 +18,19 @@
  */
 package org.apache.iceberg.flink;
 
+import java.util.Collections;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
+import java.util.UUID;
+import java.util.function.Function;
+import java.util.stream.Collectors;
 import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.api.TableSchema;
+import org.apache.flink.table.api.ValidationException;
 import org.apache.flink.table.catalog.Column;
 import org.apache.flink.table.catalog.ResolvedSchema;
+import org.apache.flink.table.catalog.UniqueConstraint;
 import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.table.types.logical.RowType;
 import org.apache.flink.table.types.utils.TypeConversions;
@@ -59,7 +66,7 @@ public class FlinkSchemaUtil {
   private FlinkSchemaUtil() {}
 
   /**
-   * @deprecated Use {@link #convert(ResolvedSchema)} instead.
+   * @deprecated will be removed in 2.0.0; use {@link #convert(ResolvedSchema)} instead.
    */
   @Deprecated
   public static Schema convert(TableSchema schema) {
@@ -102,11 +109,10 @@ public class FlinkSchemaUtil {
     RowType root = (RowType) schemaType;
     Type converted = root.accept(new FlinkTypeToType(root));
     Schema icebergSchema = new Schema(converted.asStructType().fields());
-    if (flinkSchema.getPrimaryKey().isPresent()) {
-      return freshIdentifierFieldIds(icebergSchema, flinkSchema.getPrimaryKey().get().getColumns());
-    } else {
-      return icebergSchema;
-    }
+    return flinkSchema
+        .getPrimaryKey()
+        .map(pk -> freshIdentifierFieldIds(icebergSchema, pk.getColumns()))
+        .orElse(icebergSchema);
   }
 
   private static Schema freshIdentifierFieldIds(Schema icebergSchema, List<String> primaryKeys) {
@@ -137,7 +143,10 @@ public class FlinkSchemaUtil {
    * @param flinkSchema a Flink TableSchema
    * @return the equivalent Schema
    * @throws IllegalArgumentException if the type cannot be converted or there are missing ids
+   * @deprecated since 1.10.0, will be removed in 2.0.0. Use {@link #convert(Schema,
+   *     ResolvedSchema)} instead.
    */
+  @Deprecated
   public static Schema convert(Schema baseSchema, TableSchema flinkSchema) {
     // convert to a type with fresh ids
     Types.StructType struct = convert(flinkSchema).asStruct();
@@ -155,6 +164,35 @@ public class FlinkSchemaUtil {
     }
   }
 
+  /**
+   * Convert a Flink {@link ResolvedSchema} to a {@link Schema} based on the given schema.
+   *
+   * <p>This conversion does not assign new ids; it uses ids from the base schema.
+   *
+   * <p>Data types, field order, and nullability will match the Flink type. This conversion may
+   * return a schema that is not compatible with base schema.
+   *
+   * @param baseSchema a Schema on which conversion is based
+   * @param flinkSchema a Flink ResolvedSchema
+   * @return the equivalent Schema
+   * @throws IllegalArgumentException if the type cannot be converted or there are missing ids
+   */
+  public static Schema convert(Schema baseSchema, ResolvedSchema flinkSchema) {
+    // convert to a type with fresh ids
+    Types.StructType struct = convert(flinkSchema).asStruct();
+    // reassign ids to match the base schema
+    Schema schema = TypeUtil.reassignIds(new Schema(struct.fields()), baseSchema);
+    // reassign doc to match the base schema
+    schema = TypeUtil.reassignDoc(schema, baseSchema);
+
+    // fix types that can't be represented in Flink (UUID)
+    Schema fixedSchema = FlinkFixupTypes.fixup(schema, baseSchema);
+    return flinkSchema
+        .getPrimaryKey()
+        .map(pk -> freshIdentifierFieldIds(fixedSchema, pk.getColumns()))
+        .orElse(fixedSchema);
+  }
+
   /**
    * Convert a {@link Schema} to a {@link RowType Flink type}.
    *
@@ -192,7 +230,10 @@ public class FlinkSchemaUtil {
    *
    * @param rowType a RowType
    * @return Flink TableSchema
+   * @deprecated since 1.10.0, will be removed in 2.0.0. Use {@link #toResolvedSchema(RowType)}
+   *     instead
    */
+  @Deprecated
   public static TableSchema toSchema(RowType rowType) {
     TableSchema.Builder builder = TableSchema.builder();
     for (RowType.RowField field : rowType.getFields()) {
@@ -201,12 +242,31 @@ public class FlinkSchemaUtil {
     return builder.build();
   }
 
+  /**
+   * Convert a {@link RowType} to a {@link ResolvedSchema}.
+   *
+   * @param rowType a RowType
+   * @return Flink ResolvedSchema
+   */
+  public static ResolvedSchema toResolvedSchema(RowType rowType) {
+    List<Column> columns = Lists.newArrayListWithExpectedSize(rowType.getFieldCount());
+    for (RowType.RowField field : rowType.getFields()) {
+      columns.add(
+          Column.physical(field.getName(), TypeConversions.fromLogicalToDataType(field.getType())));
+    }
+
+    return ResolvedSchema.of(columns);
+  }
+
   /**
    * Convert a {@link Schema} to a {@link TableSchema}.
    *
    * @param schema iceberg schema to convert.
    * @return Flink TableSchema.
+   * @deprecated since 1.10.0, will be removed in 2.0.0. Use {@link #toResolvedSchema(Schema)}
+   *     instead
    */
+  @Deprecated
   public static TableSchema toSchema(Schema schema) {
     TableSchema.Builder builder = TableSchema.builder();
 
@@ -231,4 +291,90 @@ public class FlinkSchemaUtil {
 
     return builder.build();
   }
+
+  /**
+   * Convert a {@link Schema} to a {@link ResolvedSchema}.
+   *
+   * @param schema iceberg schema to convert.
+   * @return Flink ResolvedSchema.
+   */
+  public static ResolvedSchema toResolvedSchema(Schema schema) {
+    RowType rowType = convert(schema);
+    List<Column> columns = Lists.newArrayListWithExpectedSize(rowType.getFieldCount());
+
+    // Add columns.
+    for (RowType.RowField field : rowType.getFields()) {
+      columns.add(
+          Column.physical(field.getName(), TypeConversions.fromLogicalToDataType(field.getType())));
+    }
+
+    // Add primary key.
+    Set<Integer> identifierFieldIds = schema.identifierFieldIds();
+    UniqueConstraint uniqueConstraint = null;
+    if (!identifierFieldIds.isEmpty()) {
+      List<String> primaryKeyColumns =
+          Lists.newArrayListWithExpectedSize(identifierFieldIds.size());
+      for (Integer identifierFieldId : identifierFieldIds) {
+        String columnName = schema.findColumnName(identifierFieldId);
+        Preconditions.checkNotNull(
+            columnName, "Cannot find field with id %s in schema %s", identifierFieldId, schema);
+
+        primaryKeyColumns.add(columnName);
+      }
+
+      uniqueConstraint =
+          UniqueConstraint.primaryKey(UUID.randomUUID().toString(), primaryKeyColumns);
+
+      validatePrimaryKey(uniqueConstraint, columns);
+    }
+
+    return new ResolvedSchema(columns, Collections.emptyList(), uniqueConstraint);
+  }
+
+  /**
+   * Copied from
+   * org.apache.flink.table.catalog.DefaultSchemaResolver#validatePrimaryKey(org.apache.flink.table.catalog.UniqueConstraint,
+   * java.util.List)
+   */
+  private static void validatePrimaryKey(UniqueConstraint primaryKey, List<Column> columns) {
+    final Map<String, Column> columnsByNameLookup =
+        columns.stream().collect(Collectors.toMap(Column::getName, Function.identity()));
+
+    final Set<String> duplicateColumns =
+        primaryKey.getColumns().stream()
+            .filter(name -> Collections.frequency(primaryKey.getColumns(), name) > 1)
+            .collect(Collectors.toSet());
+
+    if (!duplicateColumns.isEmpty()) {
+      throw new ValidationException(
+          String.format(
+              "Invalid primary key '%s'. A primary key must not contain duplicate columns. Found: %s",
+              primaryKey.getName(), duplicateColumns));
+    }
+
+    for (String columnName : primaryKey.getColumns()) {
+      Column column = columnsByNameLookup.get(columnName);
+      if (column == null) {
+        throw new ValidationException(
+            String.format(
+                "Invalid primary key '%s'. Column '%s' does not exist.",
+                primaryKey.getName(), columnName));
+      }
+
+      if (!column.isPhysical()) {
+        throw new ValidationException(
+            String.format(
+                "Invalid primary key '%s'. Column '%s' is not a physical column.",
+                primaryKey.getName(), columnName));
+      }
+
+      final LogicalType columnType = column.getDataType().getLogicalType();
+      if (columnType.isNullable()) {
+        throw new ValidationException(
+            String.format(
+                "Invalid primary key '%s'. Column '%s' is nullable.",
+                primaryKey.getName(), columnName));
+      }
+    }
+  }
 }
