@@ -22,11 +22,14 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.stream.Collectors;
 import org.apache.flink.annotation.Internal;
 import org.apache.flink.configuration.ReadableConfig;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.TableSchema;
+import org.apache.flink.table.catalog.Column;
+import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.connector.ChangelogMode;
 import org.apache.flink.table.connector.ProviderContext;
 import org.apache.flink.table.connector.source.DataStreamScanProvider;
@@ -38,7 +41,7 @@ import org.apache.flink.table.connector.source.abilities.SupportsProjectionPushD
 import org.apache.flink.table.connector.source.abilities.SupportsSourceWatermark;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.table.expressions.ResolvedExpression;
-import org.apache.flink.table.types.DataType;
+import org.apache.flink.table.factories.FactoryUtil;
 import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.flink.FlinkConfigOptions;
 import org.apache.iceberg.flink.FlinkFilters;
@@ -48,6 +51,7 @@ import org.apache.iceberg.flink.source.assigner.SplitAssignerType;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
+import org.apache.iceberg.util.PropertyUtil;
 
 /** Flink Iceberg table source. */
 @Internal
@@ -63,7 +67,7 @@ public class IcebergTableSource
   private List<Expression> filters;
 
   private final TableLoader loader;
-  private final TableSchema schema;
+  private final ResolvedSchema schema;
   private final Map<String, String> properties;
   private final boolean isLimitPushDown;
   private final ReadableConfig readableConfig;
@@ -81,7 +85,7 @@ public class IcebergTableSource
 
   public IcebergTableSource(
       TableLoader loader,
-      TableSchema schema,
+      ResolvedSchema schema,
       Map<String, String> properties,
       ReadableConfig readableConfig) {
     this(loader, schema, properties, null, false, null, ImmutableList.of(), readableConfig);
@@ -89,7 +93,7 @@ public class IcebergTableSource
 
   private IcebergTableSource(
       TableLoader loader,
-      TableSchema schema,
+      ResolvedSchema schema,
       Map<String, String> properties,
       int[] projectedFields,
       boolean isLimitPushDown,
@@ -120,8 +124,8 @@ public class IcebergTableSource
     return FlinkSource.forRowData()
         .env(execEnv)
         .tableLoader(loader)
-        .properties(properties)
-        .project(getProjectedSchema())
+        .setAll(properties)
+        .project(TableSchema.fromResolvedSchema(getProjectedSchema()))
         .limit(limit)
         .filters(filters)
         .flinkConf(readableConfig)
@@ -134,7 +138,7 @@ public class IcebergTableSource
     return IcebergSource.forRowData()
         .tableLoader(loader)
         .assignerFactory(assignerType.factory())
-        .properties(properties)
+        .setAll(properties)
         .project(getProjectedSchema())
         .limit(limit)
         .filters(filters)
@@ -142,17 +146,13 @@ public class IcebergTableSource
         .buildStream(env);
   }
 
-  private TableSchema getProjectedSchema() {
+  private ResolvedSchema getProjectedSchema() {
     if (projectedFields == null) {
       return schema;
     } else {
-      String[] fullNames = schema.getFieldNames();
-      DataType[] fullTypes = schema.getFieldDataTypes();
-      return TableSchema.builder()
-          .fields(
-              Arrays.stream(projectedFields).mapToObj(i -> fullNames[i]).toArray(String[]::new),
-              Arrays.stream(projectedFields).mapToObj(i -> fullTypes[i]).toArray(DataType[]::new))
-          .build();
+      List<Column> fullColumns = schema.getColumns();
+      return ResolvedSchema.of(
+          Arrays.stream(projectedFields).mapToObj(fullColumns::get).collect(Collectors.toList()));
     }
   }
 
@@ -217,6 +217,12 @@ public class IcebergTableSource
       public boolean isBounded() {
         return FlinkSource.isBounded(properties);
       }
+
+      @Override
+      public Optional<Integer> getParallelism() {
+        return Optional.ofNullable(
+            PropertyUtil.propertyAsNullableInt(properties, FactoryUtil.SOURCE_PARALLELISM.key()));
+      }
     };
   }
 
