@@ -61,7 +61,7 @@ public class TestChangeLogTable extends ChangeLogTableTestBase {
   private static final String CATALOG_NAME = "test_catalog";
   private static final String DATABASE_NAME = "test_db";
   private static final String TABLE_NAME = "test_table";
-  private static String warehouse;
+  private String warehouse;
 
   @Parameter private boolean partitioned;
 
@@ -92,7 +92,7 @@ public class TestChangeLogTable extends ChangeLogTableTestBase {
   @Override
   public void clean() {
     sql("DROP TABLE IF EXISTS %s", TABLE_NAME);
-    sql("DROP DATABASE IF EXISTS %s", DATABASE_NAME);
+    dropDatabase(DATABASE_NAME, true);
     dropCatalog(CATALOG_NAME, true);
     BoundedTableFactory.clearDataSets();
   }
