@@ -55,9 +55,9 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DeleteFile;
 import org.apache.iceberg.FileFormat;
-import org.apache.iceberg.GenericManifestFile;
-import org.apache.iceberg.ManifestContent;
 import org.apache.iceberg.ManifestFile;
+import org.apache.iceberg.ManifestFiles;
+import org.apache.iceberg.ManifestWriter;
 import org.apache.iceberg.Parameter;
 import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Parameters;
@@ -137,8 +137,7 @@ public class TestIcebergFilesCommitter extends TestBase {
       assertMaxCommittedCheckpointId(jobId, operatorId, -1L);
 
       // It's better to advance the max-committed-checkpoint-id in iceberg snapshot, so that the
-      // future flink job
-      // failover won't fail.
+      // future flink job failover won't fail.
       for (int i = 1; i <= 3; i++) {
         harness.snapshot(++checkpointId, ++timestamp);
         assertFlinkManifests(0);
@@ -764,7 +763,7 @@ public class TestIcebergFilesCommitter extends TestBase {
       // 2. Read the data files from manifests and assert.
       List<DataFile> dataFiles =
           FlinkManifestUtil.readDataFiles(
-              createTestingManifestFile(manifestPath), table.io(), table.specs());
+              createTestingManifestFile(manifestPath, dataFile1), table.io(), table.specs());
       assertThat(dataFiles).hasSize(1);
       TestHelpers.assertEquals(dataFile1, dataFiles.get(0));
 
@@ -814,7 +813,7 @@ public class TestIcebergFilesCommitter extends TestBase {
       // 2. Read the data files from manifests and assert.
       List<DataFile> dataFiles =
           FlinkManifestUtil.readDataFiles(
-              createTestingManifestFile(manifestPath), table.io(), table.specs());
+              createTestingManifestFile(manifestPath, dataFile1), table.io(), table.specs());
       assertThat(dataFiles).hasSize(1);
       TestHelpers.assertEquals(dataFile1, dataFiles.get(0));
 
@@ -1120,23 +1119,17 @@ public class TestIcebergFilesCommitter extends TestBase {
         null);
   }
 
-  private ManifestFile createTestingManifestFile(Path manifestPath) {
-    return new GenericManifestFile(
-        manifestPath.toAbsolutePath().toString(),
-        manifestPath.toFile().length(),
-        0,
-        ManifestContent.DATA,
-        0,
-        0,
-        0L,
-        0,
-        0,
-        0,
-        0,
-        0,
-        0,
-        null,
-        null);
+  private ManifestFile createTestingManifestFile(Path manifestPath, DataFile dataFile)
+      throws IOException {
+    ManifestWriter<DataFile> writer =
+        ManifestFiles.write(
+            formatVersion,
+            PartitionSpec.unpartitioned(),
+            table.io().newOutputFile(manifestPath.toString()),
+            0L);
+    writer.add(dataFile);
+    writer.close();
+    return writer.toManifestFile();
   }
 
   private List<Path> assertFlinkManifests(int expectedCount) throws IOException {
@@ -1176,8 +1169,8 @@ public class TestIcebergFilesCommitter extends TestBase {
   private void assertMaxCommittedCheckpointId(JobID jobID, OperatorID operatorID, long expectedId) {
     table.refresh();
     long actualId =
-        IcebergFilesCommitter.getMaxCommittedCheckpointId(
-            table, jobID.toString(), operatorID.toHexString(), branch);
+        SinkUtil.getMaxCommittedCheckpointId(
+            table, jobID.toString(), operatorID.toString(), branch);
     assertThat(actualId).isEqualTo(expectedId);
   }
 
