@@ -30,6 +30,7 @@ import org.apache.flink.runtime.state.StateInitializationContext;
 import org.apache.flink.runtime.state.StateSnapshotContext;
 import org.apache.flink.streaming.api.operators.AbstractStreamOperator;
 import org.apache.flink.streaming.api.operators.OneInputStreamOperator;
+import org.apache.flink.streaming.api.operators.StreamOperatorParameters;
 import org.apache.flink.streaming.runtime.streamrecord.StreamRecord;
 import org.apache.flink.table.data.RowData;
 import org.apache.iceberg.Schema;
@@ -72,12 +73,14 @@ public class DataStatisticsOperator extends AbstractStreamOperator<StatisticsOrR
   private transient volatile GlobalStatistics globalStatistics;
 
   DataStatisticsOperator(
+      StreamOperatorParameters<StatisticsOrRecord> parameters,
       String operatorName,
       Schema schema,
       SortOrder sortOrder,
       OperatorEventGateway operatorEventGateway,
       int downstreamParallelism,
       StatisticsType statisticsType) {
+    super(parameters);
     this.operatorName = operatorName;
     this.rowDataWrapper = new RowDataWrapper(FlinkSchemaUtil.convert(schema), schema.asStruct());
     this.sortKey = new SortKey(schema, sortOrder);
@@ -92,8 +95,8 @@ public class DataStatisticsOperator extends AbstractStreamOperator<StatisticsOrR
 
   @Override
   public void initializeState(StateInitializationContext context) throws Exception {
-    this.parallelism = getRuntimeContext().getNumberOfParallelSubtasks();
-    this.subtaskIndex = getRuntimeContext().getIndexOfThisSubtask();
+    this.parallelism = getRuntimeContext().getTaskInfo().getNumberOfParallelSubtasks();
+    this.subtaskIndex = getRuntimeContext().getTaskInfo().getIndexOfThisSubtask();
 
     // Use union state so that new subtasks can also restore global statistics during scale-up.
     this.globalStatisticsState =
@@ -204,7 +207,8 @@ public class DataStatisticsOperator extends AbstractStreamOperator<StatisticsOrR
 
     // Only subtask 0 saves the state so that globalStatisticsState(UnionListState) stores
     // an exact copy of globalStatistics
-    if (globalStatistics != null && getRuntimeContext().getIndexOfThisSubtask() == 0) {
+    if (globalStatistics != null
+        && getRuntimeContext().getTaskInfo().getIndexOfThisSubtask() == 0) {
       globalStatisticsState.clear();
       LOG.info(
           "Operator {} subtask {} saving global statistics to state", operatorName, subtaskIndex);
