@@ -27,10 +27,12 @@ import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 import org.apache.flink.table.api.DataTypes;
-import org.apache.flink.table.api.TableSchema;
+import org.apache.flink.table.catalog.Column;
+import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.data.GenericRowData;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.table.data.StringData;
+import org.apache.flink.table.legacy.api.TableSchema;
 import org.apache.flink.table.types.logical.RowType;
 import org.apache.flink.types.RowKind;
 import org.apache.hadoop.conf.Configuration;
@@ -82,12 +84,23 @@ public class SimpleDataUtil {
           Types.NestedField.optional(1, "id", Types.IntegerType.get()),
           Types.NestedField.optional(2, "data", Types.StringType.get()));
 
-  public static final TableSchema FLINK_SCHEMA =
-      TableSchema.builder().field("id", DataTypes.INT()).field("data", DataTypes.STRING()).build();
+  public static final Schema SCHEMA2 =
+      new Schema(
+          Types.NestedField.optional(1, "id", Types.IntegerType.get()),
+          Types.NestedField.optional(2, "data", Types.StringType.get()),
+          Types.NestedField.optional(3, "extra", Types.StringType.get()));
 
-  public static final RowType ROW_TYPE = (RowType) FLINK_SCHEMA.toRowDataType().getLogicalType();
+  public static final ResolvedSchema FLINK_SCHEMA =
+      ResolvedSchema.of(
+          Column.physical("id", DataTypes.INT()), Column.physical("data", DataTypes.STRING()));
+
+  public static final TableSchema FLINK_TABLE_SCHEMA = TableSchema.fromResolvedSchema(FLINK_SCHEMA);
+
+  public static final RowType ROW_TYPE =
+      (RowType) FLINK_SCHEMA.toSourceRowDataType().getLogicalType();
 
   public static final Record RECORD = GenericRecord.create(SCHEMA);
+  public static final Record RECORD2 = GenericRecord.create(SCHEMA2);
 
   public static Table createTable(
       String path, Map<String, String> properties, boolean partitioned) {
@@ -107,6 +120,14 @@ public class SimpleDataUtil {
     return record;
   }
 
+  public static Record createRecord(Integer id, String data, String extra) {
+    Record record = RECORD2.copy();
+    record.setField("id", id);
+    record.setField("data", data);
+    record.setField("extra", extra);
+    return record;
+  }
+
   public static RowData createRowData(Integer id, String data) {
     return GenericRowData.of(id, StringData.fromString(data));
   }
@@ -224,7 +245,12 @@ public class SimpleDataUtil {
     for (RowData row : rows) {
       Integer id = row.isNullAt(0) ? null : row.getInt(0);
       String data = row.isNullAt(1) ? null : row.getString(1).toString();
-      records.add(createRecord(id, data));
+      if (row.getArity() == 2) {
+        records.add(createRecord(id, data));
+      } else {
+        String extra = row.isNullAt(2) ? null : row.getString(2).toString();
+        records.add(createRecord(id, data, extra));
+      }
     }
     return records;
   }
