@@ -21,9 +21,14 @@ package org.apache.iceberg.flink;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
+import java.util.Collections;
+import java.util.List;
 import org.apache.flink.table.api.DataTypes;
-import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.api.ValidationException;
+import org.apache.flink.table.catalog.Column;
+import org.apache.flink.table.catalog.ResolvedSchema;
+import org.apache.flink.table.catalog.UniqueConstraint;
+import org.apache.flink.table.legacy.api.TableSchema;
 import org.apache.flink.table.types.logical.BinaryType;
 import org.apache.flink.table.types.logical.CharType;
 import org.apache.flink.table.types.logical.LocalZonedTimestampType;
@@ -33,48 +38,60 @@ import org.apache.flink.table.types.logical.TimeType;
 import org.apache.flink.table.types.logical.TimestampType;
 import org.apache.flink.table.types.logical.VarBinaryType;
 import org.apache.flink.table.types.logical.VarCharType;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestFlinkSchemaUtil {
 
-  @Test
+  @Parameter private boolean isTableSchema;
+
+  @Parameters(name = "isTableSchema={0}")
+  private static Object[][] parameters() {
+    return new Object[][] {{true}, {false}};
+  }
+
+  @TestTemplate
   public void testConvertFlinkSchemaToIcebergSchema() {
-    TableSchema flinkSchema =
-        TableSchema.builder()
-            .field("id", DataTypes.INT().notNull())
-            .field("name", DataTypes.STRING()) /* optional by default */
-            .field("salary", DataTypes.DOUBLE().notNull())
-            .field(
+    ResolvedSchema flinkSchema =
+        ResolvedSchema.of(
+            Column.physical("id", DataTypes.INT().notNull()),
+            Column.physical("name", DataTypes.STRING()) /* optional by default */,
+            Column.physical("salary", DataTypes.DOUBLE().notNull()),
+            Column.physical(
                 "locations",
                 DataTypes.MAP(
                     DataTypes.STRING(),
                     DataTypes.ROW(
                         DataTypes.FIELD("posX", DataTypes.DOUBLE().notNull(), "X field"),
-                        DataTypes.FIELD("posY", DataTypes.DOUBLE().notNull(), "Y field"))))
-            .field("strArray", DataTypes.ARRAY(DataTypes.STRING()).nullable())
-            .field("intArray", DataTypes.ARRAY(DataTypes.INT()).nullable())
-            .field("char", DataTypes.CHAR(10).notNull())
-            .field("varchar", DataTypes.VARCHAR(10).notNull())
-            .field("boolean", DataTypes.BOOLEAN().nullable())
-            .field("tinyint", DataTypes.TINYINT())
-            .field("smallint", DataTypes.SMALLINT())
-            .field("bigint", DataTypes.BIGINT())
-            .field("varbinary", DataTypes.VARBINARY(10))
-            .field("binary", DataTypes.BINARY(10))
-            .field("time", DataTypes.TIME())
-            .field("timestampWithoutZone", DataTypes.TIMESTAMP())
-            .field("timestampWithZone", DataTypes.TIMESTAMP_WITH_LOCAL_TIME_ZONE())
-            .field("date", DataTypes.DATE())
-            .field("decimal", DataTypes.DECIMAL(2, 2))
-            .field("decimal2", DataTypes.DECIMAL(38, 2))
-            .field("decimal3", DataTypes.DECIMAL(10, 1))
-            .field("multiset", DataTypes.MULTISET(DataTypes.STRING().notNull()))
-            .build();
+                        DataTypes.FIELD("posY", DataTypes.DOUBLE().notNull(), "Y field")))),
+            Column.physical("strArray", DataTypes.ARRAY(DataTypes.STRING()).nullable()),
+            Column.physical("intArray", DataTypes.ARRAY(DataTypes.INT()).nullable()),
+            Column.physical("char", DataTypes.CHAR(10).notNull()),
+            Column.physical("varchar", DataTypes.VARCHAR(10).notNull()),
+            Column.physical("boolean", DataTypes.BOOLEAN().nullable()),
+            Column.physical("tinyint", DataTypes.TINYINT()),
+            Column.physical("smallint", DataTypes.SMALLINT()),
+            Column.physical("bigint", DataTypes.BIGINT()),
+            Column.physical("varbinary", DataTypes.VARBINARY(10)),
+            Column.physical("binary", DataTypes.BINARY(10)),
+            Column.physical("time", DataTypes.TIME()),
+            Column.physical("timestampWithoutZone", DataTypes.TIMESTAMP()),
+            Column.physical("timestampWithZone", DataTypes.TIMESTAMP_WITH_LOCAL_TIME_ZONE()),
+            Column.physical("date", DataTypes.DATE()),
+            Column.physical("decimal", DataTypes.DECIMAL(2, 2)),
+            Column.physical("decimal2", DataTypes.DECIMAL(38, 2)),
+            Column.physical("decimal3", DataTypes.DECIMAL(10, 1)),
+            Column.physical("multiset", DataTypes.MULTISET(DataTypes.STRING().notNull())));
 
     Schema icebergSchema =
         new Schema(
@@ -120,19 +137,19 @@ public class TestFlinkSchemaUtil {
     checkSchema(flinkSchema, icebergSchema);
   }
 
-  @Test
+  @TestTemplate
   public void testMapField() {
-    TableSchema flinkSchema =
-        TableSchema.builder()
-            .field(
+    ResolvedSchema flinkSchema =
+        ResolvedSchema.of(
+            Column.physical(
                 "map_int_long",
-                DataTypes.MAP(DataTypes.INT(), DataTypes.BIGINT()).notNull()) /* Required */
-            .field(
+                DataTypes.MAP(DataTypes.INT(), DataTypes.BIGINT()).notNull()) /* Required */,
+            Column.physical(
                 "map_int_array_string",
-                DataTypes.MAP(DataTypes.ARRAY(DataTypes.INT()), DataTypes.STRING()))
-            .field(
-                "map_decimal_string", DataTypes.MAP(DataTypes.DECIMAL(10, 2), DataTypes.STRING()))
-            .field(
+                DataTypes.MAP(DataTypes.ARRAY(DataTypes.INT()), DataTypes.STRING())),
+            Column.physical(
+                "map_decimal_string", DataTypes.MAP(DataTypes.DECIMAL(10, 2), DataTypes.STRING())),
+            Column.physical(
                 "map_fields_fields",
                 DataTypes.MAP(
                         DataTypes.ROW(
@@ -145,8 +162,7 @@ public class TestFlinkSchemaUtil {
                                     DataTypes.ARRAY(DataTypes.STRING()),
                                     "doc - array"))
                             .notNull() /* Required */)
-                    .notNull() /* Required */)
-            .build();
+                    .notNull() /* Required */));
 
     Schema icebergSchema =
         new Schema(
@@ -190,11 +206,11 @@ public class TestFlinkSchemaUtil {
     checkSchema(flinkSchema, icebergSchema);
   }
 
-  @Test
+  @TestTemplate
   public void testStructField() {
-    TableSchema flinkSchema =
-        TableSchema.builder()
-            .field(
+    ResolvedSchema flinkSchema =
+        ResolvedSchema.of(
+            Column.physical(
                 "struct_int_string_decimal",
                 DataTypes.ROW(
                         DataTypes.FIELD("field_int", DataTypes.INT()),
@@ -208,14 +224,13 @@ public class TestFlinkSchemaUtil {
                                         "inner_struct_float_array",
                                         DataTypes.ARRAY(DataTypes.FLOAT())))
                                 .notNull()) /* Row is required */)
-                    .notNull()) /* Required */
-            .field(
+                    .notNull()) /* Required */,
+            Column.physical(
                 "struct_map_int_int",
                 DataTypes.ROW(
                         DataTypes.FIELD(
                             "field_map", DataTypes.MAP(DataTypes.INT(), DataTypes.INT())))
-                    .nullable()) /* Optional */
-            .build();
+                    .nullable()) /* Optional */);
 
     Schema icebergSchema =
         new Schema(
@@ -249,23 +264,23 @@ public class TestFlinkSchemaUtil {
     checkSchema(flinkSchema, icebergSchema);
   }
 
-  @Test
+  @TestTemplate
   public void testListField() {
-    TableSchema flinkSchema =
-        TableSchema.builder()
-            .field(
+    ResolvedSchema flinkSchema =
+        ResolvedSchema.of(
+            Column.physical(
                 "list_struct_fields",
                 DataTypes.ARRAY(DataTypes.ROW(DataTypes.FIELD("field_int", DataTypes.INT())))
-                    .notNull()) /* Required */
-            .field(
+                    .notNull()) /* Required */,
+            Column.physical(
                 "list_optional_struct_fields",
                 DataTypes.ARRAY(
                         DataTypes.ROW(
                             DataTypes.FIELD(
                                 "field_timestamp_with_local_time_zone",
                                 DataTypes.TIMESTAMP_WITH_LOCAL_TIME_ZONE())))
-                    .nullable()) /* Optional */
-            .field(
+                    .nullable()) /* Optional */,
+            Column.physical(
                 "list_map_fields",
                 DataTypes.ARRAY(
                         DataTypes.MAP(
@@ -274,8 +289,7 @@ public class TestFlinkSchemaUtil {
                                 DataTypes.ROW(
                                     DataTypes.FIELD("field_0", DataTypes.INT(), "doc - int")))
                             .notNull())
-                    .notNull()) /* Required */
-            .build();
+                    .notNull()) /* Required */);
 
     Schema icebergSchema =
         new Schema(
@@ -312,14 +326,26 @@ public class TestFlinkSchemaUtil {
     checkSchema(flinkSchema, icebergSchema);
   }
 
-  private void checkSchema(TableSchema flinkSchema, Schema icebergSchema) {
-    assertThat(FlinkSchemaUtil.convert(flinkSchema).asStruct()).isEqualTo(icebergSchema.asStruct());
-    // The conversion is not a 1:1 mapping, so we just check iceberg types.
-    assertThat(
-            FlinkSchemaUtil.convert(
-                    FlinkSchemaUtil.toSchema(FlinkSchemaUtil.convert(icebergSchema)))
-                .asStruct())
-        .isEqualTo(icebergSchema.asStruct());
+  private void checkSchema(ResolvedSchema flinkSchema, Schema icebergSchema) {
+    if (isTableSchema) {
+      assertThat(FlinkSchemaUtil.convert(TableSchema.fromResolvedSchema(flinkSchema)).asStruct())
+          .isEqualTo(icebergSchema.asStruct());
+      // The conversion is not a 1:1 mapping, so we just check iceberg types.
+      assertThat(
+              FlinkSchemaUtil.convert(
+                      FlinkSchemaUtil.toSchema(FlinkSchemaUtil.convert(icebergSchema)))
+                  .asStruct())
+          .isEqualTo(icebergSchema.asStruct());
+    } else {
+      assertThat(FlinkSchemaUtil.convert(flinkSchema).asStruct())
+          .isEqualTo(icebergSchema.asStruct());
+      // The conversion is not a 1:1 mapping, so we just check iceberg types.
+      assertThat(
+              FlinkSchemaUtil.convert(
+                      FlinkSchemaUtil.toResolvedSchema(FlinkSchemaUtil.convert(icebergSchema)))
+                  .asStruct())
+          .isEqualTo(icebergSchema.asStruct());
+    }
   }
 
   @Test
@@ -358,9 +384,13 @@ public class TestFlinkSchemaUtil {
     assertThat(FlinkSchemaUtil.convert(icebergType)).isEqualTo(flinkExpectedType);
     assertThat(FlinkSchemaUtil.convert(FlinkSchemaUtil.toSchema(RowType.of(flinkType))).asStruct())
         .isEqualTo(Types.StructType.of(Types.NestedField.optional(0, "f0", icebergExpectedType)));
+    assertThat(
+            FlinkSchemaUtil.convert(FlinkSchemaUtil.toResolvedSchema(RowType.of(flinkType)))
+                .asStruct())
+        .isEqualTo(Types.StructType.of(Types.NestedField.optional(0, "f0", icebergExpectedType)));
   }
 
-  @Test
+  @TestTemplate
   public void testConvertFlinkSchemaBaseOnIcebergSchema() {
     Schema baseSchema =
         new Schema(
@@ -369,18 +399,31 @@ public class TestFlinkSchemaUtil {
                 Types.NestedField.optional(102, "string", Types.StringType.get())),
             Sets.newHashSet(101));
 
-    TableSchema flinkSchema =
-        TableSchema.builder()
-            .field("int", DataTypes.INT().notNull())
-            .field("string", DataTypes.STRING().nullable())
-            .primaryKey("int")
-            .build();
-    Schema convertedSchema = FlinkSchemaUtil.convert(baseSchema, flinkSchema);
+    Schema convertedSchema;
+    if (isTableSchema) {
+      TableSchema flinkSchema =
+          TableSchema.builder()
+              .field("int", DataTypes.INT().notNull())
+              .field("string", DataTypes.STRING().nullable())
+              .primaryKey("int")
+              .build();
+      convertedSchema = FlinkSchemaUtil.convert(baseSchema, flinkSchema);
+    } else {
+      ResolvedSchema flinkSchema =
+          new ResolvedSchema(
+              List.of(
+                  Column.physical("int", DataTypes.INT().notNull()),
+                  Column.physical("string", DataTypes.STRING().nullable())),
+              Collections.emptyList(),
+              UniqueConstraint.primaryKey("pk", List.of("int")));
+      convertedSchema = FlinkSchemaUtil.convert(baseSchema, flinkSchema);
+    }
+
     assertThat(convertedSchema.asStruct()).isEqualTo(baseSchema.asStruct());
     assertThat(convertedSchema.identifierFieldIds()).containsExactly(101);
   }
 
-  @Test
+  @TestTemplate
   public void testConvertFlinkSchemaWithPrimaryKeys() {
     Schema icebergSchema =
         new Schema(
@@ -389,14 +432,22 @@ public class TestFlinkSchemaUtil {
                 Types.NestedField.required(2, "string", Types.StringType.get())),
             Sets.newHashSet(1, 2));
 
-    TableSchema tableSchema = FlinkSchemaUtil.toSchema(icebergSchema);
-    assertThat(tableSchema.getPrimaryKey())
-        .isPresent()
-        .get()
-        .satisfies(k -> assertThat(k.getColumns()).containsExactly("int", "string"));
+    if (isTableSchema) {
+      TableSchema tableSchema = FlinkSchemaUtil.toSchema(icebergSchema);
+      assertThat(tableSchema.getPrimaryKey())
+          .isPresent()
+          .get()
+          .satisfies(k -> assertThat(k.getColumns()).containsExactly("int", "string"));
+    } else {
+      ResolvedSchema resolvedSchema = FlinkSchemaUtil.toResolvedSchema(icebergSchema);
+      assertThat(resolvedSchema.getPrimaryKey())
+          .isPresent()
+          .get()
+          .satisfies(k -> assertThat(k.getColumns()).containsExactly("int", "string"));
+    }
   }
 
-  @Test
+  @TestTemplate
   public void testConvertFlinkSchemaWithNestedColumnInPrimaryKeys() {
     Schema icebergSchema =
         new Schema(
@@ -408,9 +459,16 @@ public class TestFlinkSchemaUtil {
                         Types.NestedField.required(2, "inner", Types.IntegerType.get())))),
             Sets.newHashSet(2));
 
-    assertThatThrownBy(() -> FlinkSchemaUtil.toSchema(icebergSchema))
-        .isInstanceOf(ValidationException.class)
-        .hasMessageStartingWith("Could not create a PRIMARY KEY")
-        .hasMessageContaining("Column 'struct.inner' does not exist.");
+    if (isTableSchema) {
+      assertThatThrownBy(() -> FlinkSchemaUtil.toSchema(icebergSchema))
+          .isInstanceOf(ValidationException.class)
+          .hasMessageStartingWith("Could not create a PRIMARY KEY")
+          .hasMessageContaining("Column 'struct.inner' does not exist.");
+    } else {
+      assertThatThrownBy(() -> FlinkSchemaUtil.toResolvedSchema(icebergSchema))
+          .isInstanceOf(ValidationException.class)
+          .hasMessageStartingWith("Invalid primary key")
+          .hasMessageContaining("Column 'struct.inner' does not exist.");
+    }
   }
 }
