@@ -22,17 +22,24 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.File;
+import java.io.IOException;
 import java.time.Duration;
 import java.util.List;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.atomic.AtomicReference;
+import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
 import org.apache.flink.api.connector.source.util.ratelimit.RateLimiterStrategy;
+import org.apache.flink.client.program.ClusterClient;
 import org.apache.flink.configuration.CheckpointingOptions;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.core.execution.JobClient;
 import org.apache.flink.runtime.client.JobExecutionException;
+import org.apache.flink.runtime.jobgraph.SavepointRestoreSettings;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
+import org.apache.flink.streaming.api.graph.StreamGraph;
+import org.apache.flink.test.junit5.InjectClusterClient;
 import org.apache.hadoop.fs.Path;
 import org.apache.iceberg.ContentFile;
 import org.apache.iceberg.DataFile;
@@ -60,40 +67,27 @@ class TestMonitorSource extends OperatorTestBase {
 
   @ParameterizedTest
   @ValueSource(booleans = {true, false})
-  void testChangeReaderIterator(boolean withDelete) {
-    if (withDelete) {
-      sql.exec(
-          "CREATE TABLE %s (id int, data varchar, PRIMARY KEY(`id`) NOT ENFORCED) WITH ('format-version'='2', 'write.upsert.enabled'='true')",
-          TABLE_NAME);
-    } else {
-      sql.exec("CREATE TABLE %s (id int, data varchar)", TABLE_NAME);
-    }
-
-    TableLoader tableLoader = sql.tableLoader(TABLE_NAME);
-    tableLoader.open();
-    Table table = tableLoader.loadTable();
+  void testChangeReaderIterator(boolean withDelete) throws IOException {
+    Table table = withDelete ? createTableWithDelete() : createTable();
 
     MonitorSource.TableChangeIterator iterator =
-        new MonitorSource.TableChangeIterator(tableLoader, null, Long.MAX_VALUE);
+        new MonitorSource.TableChangeIterator(tableLoader(), null, Long.MAX_VALUE);
 
     // For an empty table we get an empty result
     assertThat(iterator.next()).isEqualTo(EMPTY_EVENT);
 
     // Add a single commit and get back the commit data in the event
-    sql.exec("INSERT INTO %s VALUES (1, 'a')", TABLE_NAME);
-    table.refresh();
+    insert(table, 1, "a");
     TableChange expected = tableChangeWithLastSnapshot(table, TableChange.empty());
     assertThat(iterator.next()).isEqualTo(expected);
     // Make sure that consecutive calls do not return the data again
     assertThat(iterator.next()).isEqualTo(EMPTY_EVENT);
 
     // Add two more commits, but fetch the data in one loop
-    sql.exec("INSERT INTO %s VALUES (2, 'b')", TABLE_NAME);
-    table.refresh();
+    insert(table, 2, "b");
     expected = tableChangeWithLastSnapshot(table, TableChange.empty());
 
-    sql.exec("INSERT INTO %s VALUES (3, 'c')", TABLE_NAME);
-    table.refresh();
+    insert(table, 3, "c");
     expected = tableChangeWithLastSnapshot(table, expected);
 
     assertThat(iterator.next()).isEqualTo(expected);
@@ -106,17 +100,11 @@ class TestMonitorSource extends OperatorTestBase {
    */
   @Test
   void testSource() throws Exception {
-    sql.exec(
-        "CREATE TABLE %s (id int, data varchar) "
-            + "WITH ('flink.max-continuous-empty-commits'='100000')",
-        TABLE_NAME);
     StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-    TableLoader tableLoader = sql.tableLoader(TABLE_NAME);
-    tableLoader.open();
-    Table table = tableLoader.loadTable();
+    Table table = createTable();
     DataStream<TableChange> events =
         env.fromSource(
-                new MonitorSource(tableLoader, HIGH_RATE, Long.MAX_VALUE),
+                new MonitorSource(tableLoader(), HIGH_RATE, Long.MAX_VALUE),
                 WatermarkStrategy.noWatermarks(),
                 "TableChangeSource")
             .forceNonParallel();
@@ -175,9 +163,12 @@ class TestMonitorSource extends OperatorTestBase {
 
   /** Check that the {@link MonitorSource} operator state is restored correctly. */
   @Test
-  void testStateRestore(@TempDir File savepointDir) throws Exception {
-    sql.exec("CREATE TABLE %s (id int, data varchar)", TABLE_NAME);
-    sql.exec("INSERT INTO %s VALUES (1, 'a')", TABLE_NAME);
+  void testStateRestore(
+      @TempDir File savepointDir, @InjectClusterClient ClusterClient<?> clusterClient)
+      throws Exception {
+    Table table = createTable();
+    insert(table, 1, "a");
+    TableLoader tableLoader = tableLoader();
 
     Configuration config = new Configuration();
     config.set(CheckpointingOptions.CHECKPOINT_STORAGE, "filesystem");
@@ -185,8 +176,6 @@ class TestMonitorSource extends OperatorTestBase {
     StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment(config);
     env.enableCheckpointing(1000);
 
-    TableLoader tableLoader = sql.tableLoader(TABLE_NAME);
-    tableLoader.open();
     DataStream<TableChange> events =
         env.fromSource(
                 new MonitorSource(tableLoader, HIGH_RATE, Long.MAX_VALUE),
@@ -199,7 +188,7 @@ class TestMonitorSource extends OperatorTestBase {
     events.sinkTo(result);
 
     // Start the job
-    Configuration conf;
+    String savepointPath;
     JobClient jobClient = null;
     AtomicReference<TableChange> firstNonEmptyEvent = new AtomicReference<>();
     try {
@@ -220,11 +209,11 @@ class TestMonitorSource extends OperatorTestBase {
               });
     } finally {
       // Stop with savepoint
-      conf = closeJobClient(jobClient, savepointDir);
+      savepointPath = closeJobClient(jobClient, savepointDir);
     }
 
     // Restore from savepoint, create the same topology with a different env
-    env = StreamExecutionEnvironment.getExecutionEnvironment(conf);
+    env = StreamExecutionEnvironment.getExecutionEnvironment();
     events =
         env.fromSource(
                 new MonitorSource(tableLoader, LOW_RATE, Long.MAX_VALUE),
@@ -235,13 +224,13 @@ class TestMonitorSource extends OperatorTestBase {
     events.sinkTo(resultWithSavepoint);
 
     // Make sure that the job with restored source does not read new records from the table
-    JobClient clientWithSavepoint = null;
+    StreamGraph streamGraph = env.getStreamGraph();
+    streamGraph.setSavepointRestoreSettings(SavepointRestoreSettings.forPath(savepointPath));
+    CompletableFuture<JobID> jobIDCompletableFuture = clusterClient.submitJob(streamGraph);
     try {
-      clientWithSavepoint = env.executeAsync("Table Change Source test with savepoint");
-
       assertThat(resultWithSavepoint.poll(Duration.ofSeconds(5L))).isEqualTo(EMPTY_EVENT);
     } finally {
-      closeJobClient(clientWithSavepoint, null);
+      clusterClient.cancel(jobIDCompletableFuture.get());
     }
 
     // Restore without savepoint
@@ -268,14 +257,12 @@ class TestMonitorSource extends OperatorTestBase {
 
   @Test
   void testNotOneParallelismThrows() {
-    sql.exec("CREATE TABLE %s (id int, data varchar)", TABLE_NAME);
+    createTable();
 
     StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
-    TableLoader tableLoader = sql.tableLoader(TABLE_NAME);
-    tableLoader.open();
 
     env.fromSource(
-            new MonitorSource(tableLoader, HIGH_RATE, Long.MAX_VALUE),
+            new MonitorSource(tableLoader(), HIGH_RATE, Long.MAX_VALUE),
             WatermarkStrategy.noWatermarks(),
             "TableChangeSource")
         .setParallelism(2)
@@ -289,14 +276,13 @@ class TestMonitorSource extends OperatorTestBase {
   }
 
   @Test
-  void testMaxReadBack() {
-    sql.exec("CREATE TABLE %s (id int, data varchar)", TABLE_NAME);
-    sql.exec("INSERT INTO %s VALUES (1, 'a')", TABLE_NAME);
-    sql.exec("INSERT INTO %s VALUES (2, 'b')", TABLE_NAME);
-    sql.exec("INSERT INTO %s VALUES (3, 'c')", TABLE_NAME);
+  void testMaxReadBack() throws IOException {
+    Table table = createTable();
+    insert(table, 1, "a");
+    insert(table, 2, "b");
+    insert(table, 3, "c");
 
-    TableLoader tableLoader = sql.tableLoader(TABLE_NAME);
-    tableLoader.open();
+    TableLoader tableLoader = tableLoader();
 
     MonitorSource.TableChangeIterator iterator =
         new MonitorSource.TableChangeIterator(tableLoader, null, 1);
@@ -316,12 +302,11 @@ class TestMonitorSource extends OperatorTestBase {
   }
 
   @Test
-  void testSkipReplace() {
-    sql.exec("CREATE TABLE %s (id int, data varchar)", TABLE_NAME);
-    sql.exec("INSERT INTO %s VALUES (1, 'a')", TABLE_NAME);
+  void testSkipReplace() throws IOException {
+    Table table = createTable();
+    insert(table, 1, "a");
 
-    TableLoader tableLoader = sql.tableLoader(TABLE_NAME);
-    tableLoader.open();
+    TableLoader tableLoader = tableLoader();
 
     MonitorSource.TableChangeIterator iterator =
         new MonitorSource.TableChangeIterator(tableLoader, null, Long.MAX_VALUE);
@@ -330,7 +315,6 @@ class TestMonitorSource extends OperatorTestBase {
     assertThat(iterator.next().commitCount()).isEqualTo(1);
 
     // Create a DataOperations.REPLACE snapshot
-    Table table = tableLoader.loadTable();
     DataFile dataFile =
         table.snapshots().iterator().next().addedDataFiles(table.io()).iterator().next();
     RewriteFiles rewrite = tableLoader.loadTable().newRewrite();
