@@ -41,15 +41,13 @@ import org.apache.flink.runtime.execution.Environment;
 import org.apache.flink.runtime.operators.coordination.MockOperatorEventGateway;
 import org.apache.flink.runtime.operators.testutils.MockInputSplitProvider;
 import org.apache.flink.runtime.state.AbstractStateBackend;
+import org.apache.flink.runtime.state.OperatorStateBackendParametersImpl;
 import org.apache.flink.runtime.state.StateInitializationContext;
 import org.apache.flink.runtime.state.StateInitializationContextImpl;
 import org.apache.flink.runtime.state.TestTaskStateManager;
 import org.apache.flink.runtime.state.hashmap.HashMapStateBackend;
 import org.apache.flink.streaming.runtime.streamrecord.StreamRecord;
-import org.apache.flink.streaming.runtime.tasks.OneInputStreamTask;
 import org.apache.flink.streaming.runtime.tasks.StreamMockEnvironment;
-import org.apache.flink.streaming.util.MockOutput;
-import org.apache.flink.streaming.util.MockStreamConfig;
 import org.apache.flink.streaming.util.OneInputStreamOperatorTestHarness;
 import org.apache.flink.table.data.GenericRowData;
 import org.apache.flink.table.data.RowData;
@@ -57,7 +55,6 @@ import org.apache.flink.table.data.StringData;
 import org.apache.iceberg.SortKey;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
-import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.params.ParameterizedTest;
@@ -90,20 +87,16 @@ public class TestDataStatisticsOperator {
   }
 
   private DataStatisticsOperator createOperator(
-      StatisticsType type, int downstreamParallelism, MockOperatorEventGateway mockGateway)
-      throws Exception {
+      StatisticsType type, int downstreamParallelism, MockOperatorEventGateway mockGateway) {
     DataStatisticsOperator operator =
         new DataStatisticsOperator(
+            null,
             "testOperator",
             Fixtures.SCHEMA,
             Fixtures.SORT_ORDER,
             mockGateway,
             downstreamParallelism,
             type);
-    operator.setup(
-        new OneInputStreamTask<String, String>(env),
-        new MockStreamConfig(new Configuration(), 1),
-        new MockOutput<>(Lists.newArrayList()));
     return operator;
   }
 
@@ -362,7 +355,8 @@ public class TestDataStatisticsOperator {
     CloseableRegistry cancelStreamRegistry = new CloseableRegistry();
     OperatorStateStore operatorStateStore =
         abstractStateBackend.createOperatorStateBackend(
-            env, "test-operator", Collections.emptyList(), cancelStreamRegistry);
+            new OperatorStateBackendParametersImpl(
+                env, "test-operator", Collections.emptyList(), cancelStreamRegistry));
     return new StateInitializationContextImpl(null, operatorStateStore, null, null, null);
   }
 
