@@ -18,6 +18,10 @@
  */
 package org.apache.iceberg.flink.source.reader;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
+import java.io.File;
+import java.nio.file.Path;
 import java.util.Arrays;
 import java.util.List;
 import org.apache.flink.configuration.Configuration;
@@ -36,36 +40,33 @@ import org.apache.iceberg.flink.TestFixtures;
 import org.apache.iceberg.flink.TestHelpers;
 import org.apache.iceberg.flink.source.DataIterator;
 import org.apache.iceberg.io.CloseableIterator;
-import org.junit.Assert;
-import org.junit.ClassRule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestArrayPoolDataIteratorBatcherRowData {
 
-  @ClassRule public static final TemporaryFolder TEMPORARY_FOLDER = new TemporaryFolder();
-  private static final FileFormat fileFormat = FileFormat.PARQUET;
+  @TempDir protected Path temporaryFolder;
+  private static final FileFormat FILE_FORMAT = FileFormat.PARQUET;
+  private final Configuration config =
+      new Configuration()
+          .set(SourceReaderOptions.ELEMENT_QUEUE_CAPACITY, 1)
+          .set(FlinkConfigOptions.SOURCE_READER_FETCH_BATCH_RECORD_COUNT, 2);
 
-  private final GenericAppenderFactory appenderFactory;
-  private final DataIteratorBatcher<RowData> batcher;
-
-  public TestArrayPoolDataIteratorBatcherRowData() {
-    Configuration config = new Configuration();
-    // set array pool size to 1
-    config.set(SourceReaderOptions.ELEMENT_QUEUE_CAPACITY, 1);
-    // set batch array size to 2
-    config.set(FlinkConfigOptions.SOURCE_READER_FETCH_BATCH_RECORD_COUNT, 2);
-    this.batcher =
-        new ArrayPoolDataIteratorBatcher<>(config, new RowDataRecordFactory(TestFixtures.ROW_TYPE));
-    this.appenderFactory = new GenericAppenderFactory(TestFixtures.SCHEMA);
-  }
+  private final GenericAppenderFactory appenderFactory =
+      new GenericAppenderFactory(TestFixtures.SCHEMA);
+  private final DataIteratorBatcher<RowData> batcher =
+      new ArrayPoolDataIteratorBatcher<>(config, new RowDataRecordFactory(TestFixtures.ROW_TYPE));
 
   /** Read a CombinedScanTask that contains a single file with less than a full batch of records */
   @Test
   public void testSingleFileLessThanOneFullBatch() throws Exception {
     List<Record> records = RandomGenericData.generate(TestFixtures.SCHEMA, 1, 1);
     FileScanTask fileTask =
-        ReaderUtil.createFileTask(records, TEMPORARY_FOLDER.newFile(), fileFormat, appenderFactory);
+        ReaderUtil.createFileTask(
+            records,
+            File.createTempFile("junit", null, temporaryFolder.toFile()),
+            FILE_FORMAT,
+            appenderFactory);
     CombinedScanTask combinedTask = new BaseCombinedScanTask(fileTask);
     DataIterator<RowData> dataIterator = ReaderUtil.createDataIterator(combinedTask);
     String splitId = "someSplitId";
@@ -73,29 +74,27 @@ public class TestArrayPoolDataIteratorBatcherRowData {
         batcher.batch(splitId, dataIterator);
 
     ArrayBatchRecords<RowData> batch = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    Assert.assertTrue(batch.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(1, batch.numberOfRecords());
+    assertThat(batch.finishedSplits()).isEmpty();
+    assertThat(batch.nextSplit()).isEqualTo(splitId);
+    assertThat(batch.records()).hasSize(2);
+    assertThat(batch.numberOfRecords()).isEqualTo(1);
 
     RecordAndPosition<RowData> recordAndPosition = batch.nextRecordFromSplit();
 
     ///////////////////////////////
     // assert first record
 
-    Assert.assertEquals(0, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(1, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(0);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(1);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records.get(0), recordAndPosition.record());
 
-    Assert.assertNull(batch.nextRecordFromSplit());
-    Assert.assertNull(batch.nextSplit());
+    assertThat(batch.nextRecordFromSplit()).isNull();
+    assertThat(batch.nextSplit()).isNull();
     batch.recycle();
 
-    // assert end of input
-    Assert.assertFalse(recordBatchIterator.hasNext());
+    assertThat(recordBatchIterator).isExhausted();
   }
 
   /**
@@ -107,7 +106,11 @@ public class TestArrayPoolDataIteratorBatcherRowData {
   public void testSingleFileWithMultipleBatches() throws Exception {
     List<Record> records = RandomGenericData.generate(TestFixtures.SCHEMA, 5, 1);
     FileScanTask fileTask =
-        ReaderUtil.createFileTask(records, TEMPORARY_FOLDER.newFile(), fileFormat, appenderFactory);
+        ReaderUtil.createFileTask(
+            records,
+            File.createTempFile("junit", null, temporaryFolder.toFile()),
+            FILE_FORMAT,
+            appenderFactory);
     CombinedScanTask combinedTask = new BaseCombinedScanTask(fileTask);
     DataIterator<RowData> dataIterator = ReaderUtil.createDataIterator(combinedTask);
     String splitId = "someSplitId";
@@ -118,90 +121,86 @@ public class TestArrayPoolDataIteratorBatcherRowData {
     // assert first batch with full batch of 2 records
 
     ArrayBatchRecords<RowData> batch0 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    Assert.assertTrue(batch0.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch0.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch0.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(2, batch0.numberOfRecords());
+    assertThat(batch0.finishedSplits()).isEmpty();
+    assertThat(batch0.nextSplit()).isEqualTo(splitId);
+    assertThat(batch0.records()).hasSize(2);
+    assertThat(batch0.numberOfRecords()).isEqualTo(2);
 
     RecordAndPosition<RowData> recordAndPosition;
 
     // assert first record
     recordAndPosition = batch0.nextRecordFromSplit();
-    Assert.assertEquals(0, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(1, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(0);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(1);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records.get(0), recordAndPosition.record());
 
     // assert second record
     recordAndPosition = batch0.nextRecordFromSplit();
-    Assert.assertEquals(0, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(2, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(0);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(2);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records.get(1), recordAndPosition.record());
 
-    Assert.assertNull(batch0.nextRecordFromSplit());
-    Assert.assertNull(batch0.nextSplit());
+    assertThat(batch0.nextRecordFromSplit()).isNull();
+    assertThat(batch0.nextSplit()).isNull();
     batch0.recycle();
 
     ///////////////////////////////
     // assert second batch with full batch of 2 records
 
     ArrayBatchRecords<RowData> batch1 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    // assert array is reused
-    Assert.assertSame(batch0.records(), batch1.records());
-    Assert.assertTrue(batch1.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch1.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch1.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(2, batch1.numberOfRecords());
+    assertThat(batch1.records()).containsExactlyInAnyOrder(batch0.records());
+    assertThat(batch1.finishedSplits()).isEmpty();
+    assertThat(batch1.nextSplit()).isEqualTo(splitId);
+    assertThat(batch1.records()).hasSize(2);
+    assertThat(batch1.numberOfRecords()).isEqualTo(2);
 
     // assert third record
     recordAndPosition = batch1.nextRecordFromSplit();
-    Assert.assertEquals(0, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(3, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(0);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(3);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records.get(2), recordAndPosition.record());
 
     // assert fourth record
     recordAndPosition = batch1.nextRecordFromSplit();
-    Assert.assertEquals(0, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(4, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(0);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(4);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records.get(3), recordAndPosition.record());
 
-    Assert.assertNull(batch1.nextRecordFromSplit());
-    Assert.assertNull(batch1.nextSplit());
+    assertThat(batch1.nextRecordFromSplit()).isNull();
+    assertThat(batch1.nextSplit()).isNull();
     batch1.recycle();
 
     ///////////////////////////////
     // assert third batch with partial batch of 1 record
 
     ArrayBatchRecords<RowData> batch2 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    // assert array is reused
-    Assert.assertSame(batch0.records(), batch2.records());
-    Assert.assertTrue(batch2.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch2.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch2.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(1, batch2.numberOfRecords());
+    assertThat(batch2.records()).containsExactlyInAnyOrder(batch0.records());
+    assertThat(batch2.finishedSplits()).isEmpty();
+    assertThat(batch2.nextSplit()).isEqualTo(splitId);
+    assertThat(batch2.records()).hasSize(2);
+    assertThat(batch2.numberOfRecords()).isEqualTo(1);
 
     // assert fifth record
     recordAndPosition = batch2.nextRecordFromSplit();
-    Assert.assertEquals(0, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(5, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(0);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(5);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records.get(4), recordAndPosition.record());
 
-    Assert.assertNull(batch2.nextRecordFromSplit());
-    Assert.assertNull(batch2.nextSplit());
+    assertThat(batch2.nextRecordFromSplit()).isNull();
+    assertThat(batch2.nextSplit()).isNull();
     batch2.recycle();
 
-    // assert end of input
-    Assert.assertFalse(recordBatchIterator.hasNext());
+    assertThat(recordBatchIterator).isExhausted();
   }
 
   /**
@@ -214,20 +213,28 @@ public class TestArrayPoolDataIteratorBatcherRowData {
     List<Record> records0 = RandomGenericData.generate(TestFixtures.SCHEMA, 1, 1);
     FileScanTask fileTask0 =
         ReaderUtil.createFileTask(
-            records0, TEMPORARY_FOLDER.newFile(), fileFormat, appenderFactory);
+            records0,
+            File.createTempFile("junit", null, temporaryFolder.toFile()),
+            FILE_FORMAT,
+            appenderFactory);
     List<Record> records1 = RandomGenericData.generate(TestFixtures.SCHEMA, 4, 2);
     FileScanTask fileTask1 =
         ReaderUtil.createFileTask(
-            records1, TEMPORARY_FOLDER.newFile(), fileFormat, appenderFactory);
+            records1,
+            File.createTempFile("junit", null, temporaryFolder.toFile()),
+            FILE_FORMAT,
+            appenderFactory);
     List<Record> records2 = RandomGenericData.generate(TestFixtures.SCHEMA, 3, 3);
     FileScanTask fileTask2 =
         ReaderUtil.createFileTask(
-            records2, TEMPORARY_FOLDER.newFile(), fileFormat, appenderFactory);
+            records2,
+            File.createTempFile("junit", null, temporaryFolder.toFile()),
+            FILE_FORMAT,
+            appenderFactory);
     CombinedScanTask combinedTask =
         new BaseCombinedScanTask(Arrays.asList(fileTask0, fileTask1, fileTask2));
 
     DataIterator<RowData> dataIterator = ReaderUtil.createDataIterator(combinedTask);
-    // seek to file1 and after record 1
     dataIterator.seek(1, 1);
 
     String splitId = "someSplitId";
@@ -246,52 +253,50 @@ public class TestArrayPoolDataIteratorBatcherRowData {
 
     // variable naming convention: batch<fileOffset><batchId>
     ArrayBatchRecords<RowData> batch10 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    Assert.assertTrue(batch10.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch10.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch10.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(2, batch10.numberOfRecords());
+    assertThat(batch10.finishedSplits()).isEmpty();
+    assertThat(batch10.nextSplit()).isEqualTo(splitId);
+    assertThat(batch10.records()).hasSize(2);
+    assertThat(batch10.numberOfRecords()).isEqualTo(2);
 
     RecordAndPosition<RowData> recordAndPosition;
 
     recordAndPosition = batch10.nextRecordFromSplit();
-    Assert.assertEquals(1, recordAndPosition.fileOffset());
-    // seek should skip the first record in file1. starting from the second record
-    Assert.assertEquals(2, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(1);
+    assertThat(recordAndPosition.recordOffset())
+        .as("seek should skip the first record in file1. starting from the second record")
+        .isEqualTo(2);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records1.get(1), recordAndPosition.record());
 
     recordAndPosition = batch10.nextRecordFromSplit();
-    Assert.assertEquals(1, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(3, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(1);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(3);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records1.get(2), recordAndPosition.record());
 
-    Assert.assertNull(batch10.nextRecordFromSplit());
-    Assert.assertNull(batch10.nextSplit());
+    assertThat(batch10.nextRecordFromSplit()).isNull();
+    assertThat(batch10.nextSplit()).isNull();
     batch10.recycle();
 
     // assert second batch from file1 with partial batch of 1 record
 
     // variable naming convention: batch_<fileOffset>_<batchId>
     ArrayBatchRecords<RowData> batch11 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    // assert array is reused
-    Assert.assertSame(batch10.records(), batch11.records());
-    Assert.assertTrue(batch11.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch11.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch11.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(1, batch11.numberOfRecords());
+    assertThat(batch11.records()).containsExactlyInAnyOrder(batch10.records());
+    assertThat(batch11.finishedSplits()).isEmpty();
+    assertThat(batch11.nextSplit()).isEqualTo(splitId);
+    assertThat(batch11.records()).hasSize(2);
+    assertThat(batch11.numberOfRecords()).isEqualTo(1);
 
     recordAndPosition = batch11.nextRecordFromSplit();
-    Assert.assertEquals(1, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(4, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(1);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(4);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records1.get(3), recordAndPosition.record());
 
-    Assert.assertNull(batch11.nextRecordFromSplit());
-    Assert.assertNull(batch11.nextSplit());
+    assertThat(batch11.nextRecordFromSplit()).isNull();
+    assertThat(batch11.nextSplit()).isNull();
     batch11.recycle();
 
     ///////////////////////////////
@@ -303,29 +308,28 @@ public class TestArrayPoolDataIteratorBatcherRowData {
 
     // variable naming convention: batch_<fileOffset>_<batchId>
     ArrayBatchRecords<RowData> batch20 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    // assert array is reused
-    Assert.assertSame(batch10.records(), batch20.records());
-    Assert.assertTrue(batch20.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch20.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch20.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(2, batch20.numberOfRecords());
+    assertThat(batch20.records()).containsExactlyInAnyOrder(batch10.records());
+    assertThat(batch20.finishedSplits()).isEmpty();
+    assertThat(batch20.nextSplit()).isEqualTo(splitId);
+    assertThat(batch20.records()).hasSize(2);
+    assertThat(batch20.numberOfRecords()).isEqualTo(2);
 
     recordAndPosition = batch20.nextRecordFromSplit();
-    Assert.assertEquals(2, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(1, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(2);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(1);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records2.get(0), recordAndPosition.record());
 
     recordAndPosition = batch20.nextRecordFromSplit();
-    Assert.assertEquals(2, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(2, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(2);
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(2);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records2.get(1), recordAndPosition.record());
 
-    Assert.assertNull(batch20.nextRecordFromSplit());
-    Assert.assertNull(batch20.nextSplit());
+    assertThat(batch20.nextRecordFromSplit()).isNull();
+    assertThat(batch20.nextSplit()).isNull();
     batch20.recycle();
 
     ///////////////////////////////
@@ -333,26 +337,24 @@ public class TestArrayPoolDataIteratorBatcherRowData {
 
     // variable naming convention: batch_<fileOffset>_<batchId>
     ArrayBatchRecords<RowData> batch21 = (ArrayBatchRecords<RowData>) recordBatchIterator.next();
-    // assert array is reused
-    Assert.assertSame(batch10.records(), batch21.records());
-    Assert.assertTrue(batch21.finishedSplits().isEmpty());
-    Assert.assertEquals(splitId, batch21.nextSplit());
-    // reusable array size should be the configured value of 2
-    Assert.assertEquals(2, batch21.records().length);
-    // assert actual number of records in the array
-    Assert.assertEquals(1, batch21.numberOfRecords());
+    assertThat(batch21.records()).containsExactlyInAnyOrder(batch10.records());
+    assertThat(batch21.finishedSplits()).isEmpty();
+    assertThat(batch21.nextSplit()).isEqualTo(splitId);
+    assertThat(batch21.records()).hasSize(2);
+    assertThat(batch21.numberOfRecords()).isEqualTo(1);
 
     recordAndPosition = batch21.nextRecordFromSplit();
-    Assert.assertEquals(2, recordAndPosition.fileOffset());
-    // The position points to where the reader should resume after this record is processed.
-    Assert.assertEquals(3, recordAndPosition.recordOffset());
+    assertThat(recordAndPosition.fileOffset()).isEqualTo(2);
+
+    assertThat(recordAndPosition.recordOffset())
+        .as("The position points to where the reader should resume after this record is processed.")
+        .isEqualTo(3);
     TestHelpers.assertRowData(TestFixtures.SCHEMA, records2.get(2), recordAndPosition.record());
 
-    Assert.assertNull(batch21.nextRecordFromSplit());
-    Assert.assertNull(batch21.nextSplit());
+    assertThat(batch21.nextRecordFromSplit()).isNull();
+    assertThat(batch21.nextSplit()).isNull();
     batch21.recycle();
 
-    // assert end of input
-    Assert.assertFalse(recordBatchIterator.hasNext());
+    assertThat(recordBatchIterator).isExhausted();
   }
 }
