@@ -32,6 +32,8 @@ import org.apache.iceberg.ClientPool;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.exceptions.NoSuchIcebergTableException;
 import org.apache.iceberg.exceptions.NoSuchIcebergViewException;
+import org.apache.iceberg.exceptions.NoSuchTableException;
+import org.apache.iceberg.exceptions.NoSuchViewException;
 import org.apache.iceberg.io.FileIO;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
@@ -98,27 +100,45 @@ interface HiveOperationsBase {
             metadataLocation);
   }
 
+  private static boolean isValidIcebergView(Table table) {
+    String tableType = table.getParameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP);
+    return TableType.VIRTUAL_VIEW.name().equalsIgnoreCase(table.getTableType())
+        && ICEBERG_VIEW_TYPE_VALUE.equalsIgnoreCase(tableType);
+  }
+
+  private static boolean isValidIcebergTable(Table table) {
+    String tableType = table.getParameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP);
+    return BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE.equalsIgnoreCase(tableType);
+  }
+
   static void validateTableIsIceberg(Table table, String fullName) {
     String tableType = table.getParameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP);
     NoSuchIcebergTableException.check(
-        tableType != null
-            && tableType.equalsIgnoreCase(BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE),
-        "Not an iceberg table: %s (type=%s)",
-        fullName,
-        tableType);
+        isValidIcebergTable(table), "Not an iceberg table: %s (type=%s)", fullName, tableType);
   }
 
   static void validateTableIsIcebergView(Table table, String fullName) {
     String tableTypeProp = table.getParameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP);
     NoSuchIcebergViewException.check(
-        TableType.VIRTUAL_VIEW.name().equalsIgnoreCase(table.getTableType())
-            && ICEBERG_VIEW_TYPE_VALUE.equalsIgnoreCase(tableTypeProp),
+        isValidIcebergView(table),
         "Not an iceberg view: %s (type=%s) (tableType=%s)",
         fullName,
         tableTypeProp,
         table.getTableType());
   }
 
+  static void validateIcebergTableNotLoadedAsIcebergView(Table table, String fullName) {
+    if (!isValidIcebergView(table) && isValidIcebergTable(table)) {
+      throw new NoSuchViewException("View does not exist: %s", fullName);
+    }
+  }
+
+  static void validateIcebergViewNotLoadedAsIcebergTable(Table table, String fullName) {
+    if (!isValidIcebergTable(table) && isValidIcebergView(table)) {
+      throw new NoSuchTableException("Table does not exist: %s", fullName);
+    }
+  }
+
   default void persistTable(Table hmsTable, boolean updateHiveTable, String metadataLocation)
       throws TException, InterruptedException {
     if (updateHiveTable) {
