@@ -18,25 +18,16 @@
  */
 package org.apache.iceberg.nessie;
 
-import java.util.List;
-import java.util.Map;
 import org.apache.iceberg.BaseMetastoreTableOperations;
 import org.apache.iceberg.TableMetadata;
 import org.apache.iceberg.TableMetadataParser;
-import org.apache.iceberg.exceptions.AlreadyExistsException;
-import org.apache.iceberg.exceptions.CommitFailedException;
-import org.apache.iceberg.exceptions.CommitStateUnknownException;
-import org.apache.iceberg.exceptions.NamespaceNotEmptyException;
-import org.apache.iceberg.exceptions.NoSuchNamespaceException;
 import org.apache.iceberg.exceptions.NoSuchTableException;
 import org.apache.iceberg.io.FileIO;
 import org.projectnessie.client.http.HttpClientException;
+import org.projectnessie.error.NessieBadRequestException;
 import org.projectnessie.error.NessieConflictException;
+import org.projectnessie.error.NessieContentNotFoundException;
 import org.projectnessie.error.NessieNotFoundException;
-import org.projectnessie.error.NessieReferenceConflictException;
-import org.projectnessie.error.ReferenceConflicts;
-import org.projectnessie.model.Conflict;
-import org.projectnessie.model.Conflict.ConflictType;
 import org.projectnessie.model.Content;
 import org.projectnessie.model.ContentKey;
 import org.projectnessie.model.IcebergTable;
@@ -61,18 +52,12 @@ public class NessieTableOperations extends BaseMetastoreTableOperations {
   private final ContentKey key;
   private IcebergTable table;
   private final FileIO fileIO;
-  private final Map<String, String> catalogOptions;
 
   /** Create a nessie table operations given a table identifier. */
-  NessieTableOperations(
-      ContentKey key,
-      NessieIcebergClient client,
-      FileIO fileIO,
-      Map<String, String> catalogOptions) {
+  NessieTableOperations(ContentKey key, NessieIcebergClient client, FileIO fileIO) {
     this.key = key;
     this.client = client;
     this.fileIO = fileIO;
-    this.catalogOptions = catalogOptions;
   }
 
   @Override
@@ -87,7 +72,7 @@ public class NessieTableOperations extends BaseMetastoreTableOperations {
     } catch (NessieNotFoundException e) {
       throw new RuntimeException(
           String.format(
-              "Failed to refresh as ref '%s' " + "is no longer valid.", client.getRef().getName()),
+              "Failed to refresh as ref '%s' is no longer valid.", client.getRef().getName()),
           e);
     }
     String metadataLocation = null;
@@ -103,13 +88,7 @@ public class NessieTableOperations extends BaseMetastoreTableOperations {
         this.table =
             content
                 .unwrap(IcebergTable.class)
-                .orElseThrow(
-                    () ->
-                        new IllegalStateException(
-                            String.format(
-                                "Cannot refresh iceberg table: "
-                                    + "Nessie points to a non-Iceberg object for path: %s.",
-                                key)));
+                .orElseThrow(() -> new NessieContentNotFoundException(key, reference.getName()));
         metadataLocation = table.getMetadataLocation();
       }
     } catch (NessieNotFoundException ex) {
@@ -135,31 +114,23 @@ public class NessieTableOperations extends BaseMetastoreTableOperations {
     boolean newTable = base == null;
     String newMetadataLocation = writeNewMetadataIfRequired(newTable, metadata);
 
-    String refName = client.refName();
     boolean failure = false;
     try {
-      client.commitTable(base, metadata, newMetadataLocation, table, key);
-    } catch (NessieConflictException ex) {
-      failure = true;
-      if (ex instanceof NessieReferenceConflictException) {
-        // Throws a specialized exception, if possible
-        maybeThrowSpecializedException((NessieReferenceConflictException) ex);
+      String contentId = table == null ? null : table.getId();
+      client.commitTable(base, metadata, newMetadataLocation, contentId, key);
+    } catch (NessieConflictException | NessieNotFoundException | HttpClientException ex) {
+      if (ex instanceof NessieConflictException || ex instanceof NessieNotFoundException) {
+        failure = true;
       }
-      throw new CommitFailedException(
-          ex,
-          "Cannot commit: Reference hash is out of date. "
-              + "Update the reference '%s' and try again",
-          refName);
-    } catch (HttpClientException ex) {
-      // Intentionally catch all nessie-client-exceptions here and not just the "timeout" variant
-      // to catch all kinds of network errors (e.g. connection reset). Network code implementation
-      // details and all kinds of network devices can induce unexpected behavior. So better be
-      // safe than sorry.
-      throw new CommitStateUnknownException(ex);
-    } catch (NessieNotFoundException ex) {
+      NessieUtil.handleExceptionsForCommits(ex, client.refName(), Content.Type.ICEBERG_TABLE)
+          .ifPresent(
+              exception -> {
+                throw exception;
+              });
+    } catch (NessieBadRequestException ex) {
       failure = true;
-      throw new RuntimeException(
-          String.format("Cannot commit: Reference '%s' no longer exists", refName), ex);
+      throw NessieUtil.handleBadRequestForCommit(client, key, Content.Type.ICEBERG_TABLE)
+          .orElse(ex);
     } finally {
       if (failure) {
         io().deleteFile(newMetadataLocation);
@@ -167,38 +138,6 @@ public class NessieTableOperations extends BaseMetastoreTableOperations {
     }
   }
 
-  private static void maybeThrowSpecializedException(NessieReferenceConflictException ex) {
-    // Check if the server returned 'ReferenceConflicts' information
-    ReferenceConflicts referenceConflicts = ex.getErrorDetails();
-    if (referenceConflicts == null) {
-      return;
-    }
-
-    // Can only narrow down to a single exception, if there is only one conflict.
-    List<Conflict> conflicts = referenceConflicts.conflicts();
-    if (conflicts.size() != 1) {
-      return;
-    }
-
-    Conflict conflict = conflicts.get(0);
-    ConflictType conflictType = conflict.conflictType();
-    if (conflictType != null) {
-      switch (conflictType) {
-        case NAMESPACE_ABSENT:
-          throw new NoSuchNamespaceException(ex, "Namespace does not exist: %s", conflict.key());
-        case NAMESPACE_NOT_EMPTY:
-          throw new NamespaceNotEmptyException(ex, "Namespace not empty: %s", conflict.key());
-        case KEY_DOES_NOT_EXIST:
-          throw new NoSuchTableException(ex, "Table or view does not exist: %s", conflict.key());
-        case KEY_EXISTS:
-          throw new AlreadyExistsException(ex, "Table or view already exists: %s", conflict.key());
-        default:
-          // Explicit fall-through
-          break;
-      }
-    }
-  }
-
   @Override
   public FileIO io() {
     return fileIO;
