@@ -28,7 +28,9 @@ import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.jdbc.JdbcCatalog;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.util.PropertyUtil;
+import org.eclipse.jetty.server.Connector;
 import org.eclipse.jetty.server.Server;
+import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.server.handler.gzip.GzipHandler;
 import org.eclipse.jetty.servlet.ServletContextHandler;
 import org.eclipse.jetty.servlet.ServletHolder;
@@ -41,6 +43,9 @@ public class RESTCatalogServer {
   public static final String REST_PORT = "rest.port";
   static final int REST_PORT_DEFAULT = 8181;
 
+  public static final String CATALOG_NAME = "catalog.name";
+  static final String CATALOG_NAME_DEFAULT = "rest_backend";
+
   private Server httpServer;
   private final Map<String, String> config;
 
@@ -86,15 +91,18 @@ public class RESTCatalogServer {
     if (warehouseLocation == null) {
       File tmp = java.nio.file.Files.createTempDirectory("iceberg_warehouse").toFile();
       tmp.deleteOnExit();
-      warehouseLocation = tmp.toPath().resolve("iceberg_data").toFile().getAbsolutePath();
+      warehouseLocation = new File(tmp, "iceberg_data").getAbsolutePath();
       catalogProperties.put(CatalogProperties.WAREHOUSE_LOCATION, warehouseLocation);
 
       LOG.info("No warehouse location set. Defaulting to temp location: {}", warehouseLocation);
     }
 
-    LOG.info("Creating catalog with properties: {}", catalogProperties);
+    String catalogName =
+        PropertyUtil.propertyAsString(catalogProperties, CATALOG_NAME, CATALOG_NAME_DEFAULT);
+
+    LOG.info("Creating {} catalog with properties: {}", catalogName, catalogProperties);
     return new CatalogContext(
-        CatalogUtil.buildIcebergCatalog("rest_backend", catalogProperties, new Configuration()),
+        CatalogUtil.buildIcebergCatalog(catalogName, catalogProperties, new Configuration()),
         catalogProperties);
   }
 
@@ -113,6 +121,9 @@ public class RESTCatalogServer {
         new Server(
             PropertyUtil.propertyAsInt(catalogContext.configuration, REST_PORT, REST_PORT_DEFAULT));
     httpServer.setHandler(context);
+    for (Connector connector : httpServer.getConnectors()) {
+      ((ServerConnector) connector).setReusePort(true);
+    }
     httpServer.start();
 
     if (join) {
