@@ -94,8 +94,21 @@ public class GenericOrcReader implements OrcRowReader<Record> {
       return GenericOrcReaders.map(keyReader, valueReader);
     }
 
+    @Override
+    public OrcValueReader<?> variant(
+        Types.VariantType iVariant,
+        TypeDescription variant,
+        OrcValueReader<?> metadata,
+        OrcValueReader<?> value) {
+      return GenericOrcReaders.variants();
+    }
+
     @Override
     public OrcValueReader<?> primitive(Type.PrimitiveType iPrimitive, TypeDescription primitive) {
+      if (iPrimitive == null) {
+        return null;
+      }
+
       switch (primitive.getCategory()) {
         case BOOLEAN:
           return OrcValueReaders.booleans();
