@@ -60,7 +60,7 @@ public class GenericOrcWriter implements OrcRowWriter<Record> {
         TypeDescription record,
         List<String> names,
         List<OrcValueWriter<?>> fields) {
-      return new RecordWriter(fields);
+      return new RecordWriter(iStruct, fields);
     }
 
     @Override
@@ -75,8 +75,21 @@ public class GenericOrcWriter implements OrcRowWriter<Record> {
       return GenericOrcWriters.map(key, value);
     }
 
+    @Override
+    public OrcValueWriter<?> variant(
+        Types.VariantType iVariant,
+        TypeDescription variant,
+        OrcValueWriter<?> metadata,
+        OrcValueWriter<?> value) {
+      return GenericOrcWriters.variants();
+    }
+
     @Override
     public OrcValueWriter<?> primitive(Type.PrimitiveType iPrimitive, TypeDescription primitive) {
+      if (null == iPrimitive) {
+        return null;
+      }
+
       switch (iPrimitive.typeId()) {
         case BOOLEAN:
           return GenericOrcWriters.booleans();
@@ -99,6 +112,13 @@ public class GenericOrcWriter implements OrcRowWriter<Record> {
           } else {
             return GenericOrcWriters.timestamp();
           }
+        case TIMESTAMP_NANO:
+          Types.TimestampNanoType timestampNanoType = (Types.TimestampNanoType) iPrimitive;
+          if (timestampNanoType.shouldAdjustToUTC()) {
+            return GenericOrcWriters.timestampTzNanos();
+          } else {
+            return GenericOrcWriters.timestampNanos();
+          }
         case STRING:
           return GenericOrcWriters.strings();
         case UUID:
@@ -136,8 +156,8 @@ public class GenericOrcWriter implements OrcRowWriter<Record> {
 
   private static class RecordWriter extends GenericOrcWriters.StructWriter<Record> {
 
-    RecordWriter(List<OrcValueWriter<?>> writers) {
-      super(writers);
+    RecordWriter(Types.StructType struct, List<OrcValueWriter<?>> writers) {
+      super(struct, writers);
     }
 
     @Override
