@@ -95,7 +95,9 @@ import org.apache.orc.storage.ql.exec.vector.VectorizedRowBatch;
 @SuppressWarnings("checkstyle:AbbreviationAsWordInName")
 public class ORC {
 
-  /** @deprecated use {@link TableProperties#ORC_WRITE_BATCH_SIZE} instead */
+  /**
+   * @deprecated use {@link TableProperties#ORC_WRITE_BATCH_SIZE} instead
+   */
   @Deprecated private static final String VECTOR_ROW_BATCH_SIZE = "iceberg.orc.vectorbatch.size";
 
   private ORC() {}
@@ -115,7 +117,7 @@ public class ORC {
     private final Configuration conf;
     private Schema schema = null;
     private BiFunction<Schema, TypeDescription, OrcRowWriter<?>> createWriterFunc;
-    private Map<String, byte[]> metadata = Maps.newHashMap();
+    private final Map<String, byte[]> metadata = Maps.newHashMap();
     private MetricsConfig metricsConfig;
     private Function<Map<String, String>, Context> createContextFunc = Context::dataContext;
     private final Map<String, String> config = Maps.newLinkedHashMap();
