@@ -16,8 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.iceberg.parquet;
 
-public class ParquetAvroReader {
-}
+public class ParquetAvroReader {}
