@@ -25,12 +25,14 @@ import java.nio.ByteOrder;
 import java.util.Comparator;
 import java.util.Deque;
 import java.util.List;
+import java.util.Objects;
 import java.util.Optional;
 import org.apache.iceberg.expressions.PathUtil;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Comparators;
 import org.apache.iceberg.util.BinaryUtil;
+import org.apache.iceberg.util.UUIDUtil;
 import org.apache.iceberg.util.UnicodeUtil;
 import org.apache.iceberg.variants.PhysicalType;
 import org.apache.iceberg.variants.VariantArray;
@@ -89,6 +91,28 @@ class ParquetVariantUtil {
     }
   }
 
+  /**
+   * Convert a Parquet {@link TimestampLogicalTypeAnnotation} to the equivalent Variant {@link
+   * PhysicalType}.
+   *
+   * @param timestamp a Parquet {@link TimestampLogicalTypeAnnotation}
+   * @return a Variant {@link PhysicalType}
+   * @throws UnsupportedOperationException if the timestamp unit is not MICROS or NANOS
+   */
+  static PhysicalType convert(TimestampLogicalTypeAnnotation timestamp) {
+    switch (timestamp.getUnit()) {
+      case MICROS:
+        return timestamp.isAdjustedToUTC() ? PhysicalType.TIMESTAMPTZ : PhysicalType.TIMESTAMPNTZ;
+      case NANOS:
+        return timestamp.isAdjustedToUTC()
+            ? PhysicalType.TIMESTAMPTZ_NANOS
+            : PhysicalType.TIMESTAMPNTZ_NANOS;
+      default:
+        throw new UnsupportedOperationException(
+            "Invalid unit for shredded timestamp: " + timestamp.getUnit());
+    }
+  }
+
   /**
    * Serialize Variant metadata and value in a single concatenated buffer.
    *
@@ -125,6 +149,9 @@ class ParquetVariantUtil {
       case DATE:
       case TIMESTAMPTZ:
       case TIMESTAMPNTZ:
+      case TIMESTAMPTZ_NANOS:
+      case TIMESTAMPNTZ_NANOS:
+      case TIME:
       case FLOAT:
       case DOUBLE:
         return (T) value;
@@ -141,6 +168,8 @@ class ParquetVariantUtil {
         return (T) ((Binary) value).toByteBuffer();
       case STRING:
         return (T) ((Binary) value).toStringUsingUTF8();
+      case UUID:
+        return (T) UUIDUtil.convert(((Binary) value).getBytes());
       default:
         throw new IllegalStateException("Invalid bound type: " + primitive);
     }
@@ -213,7 +242,7 @@ class ParquetVariantUtil {
 
     @Override
     public Optional<PhysicalType> visit(TimeLogicalTypeAnnotation ignored) {
-      return Optional.empty();
+      return Optional.of(PhysicalType.TIME);
     }
 
     @Override
@@ -226,6 +255,11 @@ class ParquetVariantUtil {
             return Optional.of(PhysicalType.TIMESTAMPNTZ);
           }
         case NANOS:
+          if (timestamps.isAdjustedToUTC()) {
+            return Optional.of(PhysicalType.TIMESTAMPTZ_NANOS);
+          } else {
+            return Optional.of(PhysicalType.TIMESTAMPNTZ_NANOS);
+          }
         default:
           return Optional.empty();
       }
@@ -253,7 +287,7 @@ class ParquetVariantUtil {
 
     @Override
     public Optional<PhysicalType> visit(UUIDLogicalTypeAnnotation uuidLogicalType) {
-      return Optional.empty();
+      return Optional.of(PhysicalType.UUID);
     }
   }
 
@@ -362,9 +396,27 @@ class ParquetVariantUtil {
 
     @Override
     public Type array(VariantArray array, List<Type> elementResults) {
+      if (elementResults.isEmpty()) {
+        return null;
+      }
+
+      // Shred if all the elements are of a uniform type and build 3-level list
+      Type shredType = elementResults.get(0);
+      if (shredType != null
+          && elementResults.stream().allMatch(type -> Objects.equals(type, shredType))) {
+        return list(shredType);
+      }
+
       return null;
     }
 
+    private static GroupType list(Type shreddedType) {
+      GroupType elementType = field("element", shreddedType);
+      checkField(elementType);
+
+      return Types.optionalList().element(elementType).named("typed_value");
+    }
+
     @Override
     public Type primitive(VariantPrimitive<?> primitive) {
       switch (primitive.type()) {
@@ -418,6 +470,23 @@ class ParquetVariantUtil {
         case STRING:
           return shreddedPrimitive(
               PrimitiveType.PrimitiveTypeName.BINARY, LogicalTypeAnnotation.stringType());
+        case TIME:
+          return shreddedPrimitive(
+              PrimitiveType.PrimitiveTypeName.INT64,
+              LogicalTypeAnnotation.timeType(false, LogicalTypeAnnotation.TimeUnit.MICROS));
+        case TIMESTAMPTZ_NANOS:
+          return shreddedPrimitive(
+              PrimitiveType.PrimitiveTypeName.INT64,
+              LogicalTypeAnnotation.timestampType(true, LogicalTypeAnnotation.TimeUnit.NANOS));
+        case TIMESTAMPNTZ_NANOS:
+          return shreddedPrimitive(
+              PrimitiveType.PrimitiveTypeName.INT64,
+              LogicalTypeAnnotation.timestampType(false, LogicalTypeAnnotation.TimeUnit.NANOS));
+        case UUID:
+          return shreddedPrimitive(
+              PrimitiveType.PrimitiveTypeName.FIXED_LEN_BYTE_ARRAY,
+              LogicalTypeAnnotation.uuidType(),
+              16);
       }
 
       throw new UnsupportedOperationException("Unsupported shredding type: " + primitive.type());
@@ -473,5 +542,10 @@ class ParquetVariantUtil {
         PrimitiveType.PrimitiveTypeName primitive, LogicalTypeAnnotation annotation) {
       return Types.optional(primitive).as(annotation).named("typed_value");
     }
+
+    private static Type shreddedPrimitive(
+        PrimitiveType.PrimitiveTypeName primitive, LogicalTypeAnnotation annotation, int length) {
+      return Types.optional(primitive).as(annotation).length(length).named("typed_value");
+    }
   }
 }
