@@ -141,7 +141,6 @@ public class TestMigrateTableProcedure extends ExtensionsTestBase {
   @TestTemplate
   public void testMigrateWithInvalidMetricsConfig() throws IOException {
     assumeThat(catalogName).isEqualToIgnoringCase("spark_catalog");
-
     String location = Files.createTempDirectory(temp, "junit").toFile().toString();
     sql(
         "CREATE TABLE %s (id bigint NOT NULL, data string) USING parquet LOCATION '%s'",
@@ -159,7 +158,6 @@ public class TestMigrateTableProcedure extends ExtensionsTestBase {
   @TestTemplate
   public void testMigrateWithConflictingProps() throws IOException {
     assumeThat(catalogName).isEqualToIgnoringCase("spark_catalog");
-
     String location = Files.createTempDirectory(temp, "junit").toFile().toString();
     sql(
         "CREATE TABLE %s (id bigint NOT NULL, data string) USING parquet LOCATION '%s'",
@@ -236,7 +234,6 @@ public class TestMigrateTableProcedure extends ExtensionsTestBase {
   @TestTemplate
   public void testMigrateWithParallelism() throws IOException {
     assumeThat(catalogName).isEqualToIgnoringCase("spark_catalog");
-
     String location = Files.createTempDirectory(temp, "junit").toFile().toString();
     sql(
         "CREATE TABLE %s (id bigint NOT NULL, data string) USING parquet LOCATION '%s'",
@@ -257,7 +254,6 @@ public class TestMigrateTableProcedure extends ExtensionsTestBase {
   @TestTemplate
   public void testMigrateWithInvalidParallelism() throws IOException {
     assumeThat(catalogName).isEqualToIgnoringCase("spark_catalog");
-
     String location = Files.createTempDirectory(temp, "junit").toFile().toString();
     sql(
         "CREATE TABLE %s (id bigint NOT NULL, data string) USING parquet LOCATION '%s'",
@@ -277,15 +273,16 @@ public class TestMigrateTableProcedure extends ExtensionsTestBase {
   @TestTemplate
   public void testMigratePartitionedWithParallelism() throws IOException {
     assumeThat(catalogName).isEqualToIgnoringCase("spark_catalog");
-
     String location = Files.createTempDirectory(temp, "junit").toFile().toString();
     sql(
         "CREATE TABLE %s (id bigint NOT NULL, data string) USING parquet PARTITIONED BY (id) LOCATION '%s'",
         tableName, location);
     sql("INSERT INTO TABLE %s (id, data) VALUES (1, 'a'), (2, 'b')", tableName);
-    List<Object[]> result =
-        sql("CALL %s.system.migrate(table => '%s', parallelism => %d)", catalogName, tableName, 2);
-    assertEquals("Procedure output must match", ImmutableList.of(row(2L)), result);
+
+    assertEquals(
+        "Procedure output must match",
+        ImmutableList.of(row(2L)),
+        sql("CALL %s.system.migrate(table => '%s', parallelism => %d)", catalogName, tableName, 2));
     assertEquals(
         "Should have expected rows",
         ImmutableList.of(row("a", 1L), row("b", 2L)),
