@@ -20,26 +20,26 @@ package org.apache.iceberg.spark.extensions;
 
 import static org.apache.iceberg.SnapshotSummary.ADDED_FILE_SIZE_PROP;
 import static org.apache.iceberg.SnapshotSummary.REMOVED_FILE_SIZE_PROP;
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
 import java.util.Map;
+import org.apache.iceberg.CatalogProperties;
+import org.apache.iceberg.EnvironmentContext;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.data.TestHelpers;
 import org.apache.iceberg.spark.source.SimpleRecord;
 import org.apache.spark.sql.Encoders;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTestBase {
-
-  public TestRewritePositionDeleteFilesProcedure(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-  }
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestRewritePositionDeleteFilesProcedure extends ExtensionsTestBase {
 
   private void createTable() throws Exception {
     createTable(false);
@@ -79,12 +79,12 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
         .append();
   }
 
-  @After
+  @AfterEach
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testExpireDeleteFilesAll() throws Exception {
     createTable();
 
@@ -92,7 +92,7 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
     sql("DELETE FROM %s WHERE id=2", tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertEquals(2, TestHelpers.deleteFiles(table).size());
+    assertThat(TestHelpers.deleteFiles(table)).hasSize(2);
 
     List<Object[]> output =
         sql(
@@ -114,10 +114,10 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
                 Long.valueOf(snapshotSummary.get(ADDED_FILE_SIZE_PROP)))),
         output);
 
-    Assert.assertEquals(1, TestHelpers.deleteFiles(table).size());
+    assertThat(TestHelpers.deleteFiles(table)).hasSize(1);
   }
 
-  @Test
+  @TestTemplate
   public void testExpireDeleteFilesNoOption() throws Exception {
     createTable();
 
@@ -128,7 +128,7 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
     sql("DELETE FROM %s WHERE id=5", tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertEquals(5, TestHelpers.deleteFiles(table).size());
+    assertThat(TestHelpers.deleteFiles(table)).hasSize(5);
 
     List<Object[]> output =
         sql(
@@ -148,7 +148,7 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
         output);
   }
 
-  @Test
+  @TestTemplate
   public void testExpireDeleteFilesFilter() throws Exception {
     createTable(true);
 
@@ -160,7 +160,7 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
     sql("DELETE FROM %s WHERE id = 3 and data='h'", tableName);
 
     Table table = validationCatalog.loadTable(tableIdent);
-    Assert.assertEquals(6, TestHelpers.deleteFiles(table).size());
+    assertThat(TestHelpers.deleteFiles(table)).hasSize(6);
 
     List<Object[]> output =
         sql(
@@ -184,26 +184,27 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
                 Long.valueOf(snapshotSummary.get(ADDED_FILE_SIZE_PROP)))),
         output);
 
-    Assert.assertEquals(4, TestHelpers.deleteFiles(table).size());
+    assertThat(TestHelpers.deleteFiles(table)).hasSize(4);
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidOption() throws Exception {
     createTable();
 
-    Assert.assertThrows(
-        "Cannot use options [foo], they are not supported by the action or the rewriter BIN-PACK",
-        IllegalArgumentException.class,
-        () ->
-            sql(
-                "CALL %s.system.rewrite_position_delete_files("
-                    + "table => '%s',"
-                    + "options => map("
-                    + "'foo', 'bar'))",
-                catalogName, tableIdent));
+    assertThatThrownBy(
+            () ->
+                sql(
+                    "CALL %s.system.rewrite_position_delete_files("
+                        + "table => '%s',"
+                        + "options => map("
+                        + "'foo', 'bar'))",
+                    catalogName, tableIdent))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessageContaining(
+            "Cannot use options [foo], they are not supported by the action or the rewriter BIN-PACK");
   }
 
-  @Test
+  @TestTemplate
   public void testRewriteWithUntranslatedOrUnconvertedFilter() throws Exception {
     createTable();
     assertThatThrownBy(
@@ -223,6 +224,26 @@ public class TestRewritePositionDeleteFilesProcedure extends SparkExtensionsTest
         .hasMessageContaining("Cannot convert Spark filter");
   }
 
+  @TestTemplate
+  public void testRewriteSummary() throws Exception {
+    createTable();
+    sql("DELETE FROM %s WHERE id=1", tableName);
+
+    sql(
+        "CALL %s.system.rewrite_position_delete_files("
+            + "table => '%s',"
+            + "options => map("
+            + "'rewrite-all','true'))",
+        catalogName, tableIdent);
+
+    Map<String, String> summary = snapshotSummary();
+    assertThat(summary)
+        .containsKey(CatalogProperties.APP_ID)
+        .containsEntry(EnvironmentContext.ENGINE_NAME, "spark")
+        .hasEntrySatisfying(
+            EnvironmentContext.ENGINE_VERSION, v -> assertThat(v).startsWith("3.4"));
+  }
+
   private Map<String, String> snapshotSummary() {
     return validationCatalog.loadTable(tableIdent).currentSnapshot().summary();
   }
