@@ -33,16 +33,17 @@ import static org.apache.iceberg.TableProperties.ORC_COMPRESSION;
 import static org.apache.iceberg.TableProperties.ORC_COMPRESSION_STRATEGY;
 import static org.apache.iceberg.TableProperties.PARQUET_COMPRESSION;
 import static org.apache.iceberg.TableProperties.PARQUET_COMPRESSION_LEVEL;
-import static org.apache.spark.sql.connector.write.RowLevelOperation.Command.DELETE;
 
 import java.util.Locale;
 import java.util.Map;
+import org.apache.iceberg.BaseMetadataTable;
 import org.apache.iceberg.DistributionMode;
 import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.IsolationLevel;
 import org.apache.iceberg.SnapshotSummary;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
+import org.apache.iceberg.TableUtil;
 import org.apache.iceberg.deletes.DeleteGranularity;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.relocated.com.google.common.annotations.VisibleForTesting;
@@ -77,10 +78,6 @@ public class SparkWriteConf {
 
   private static final Logger LOG = LoggerFactory.getLogger(SparkWriteConf.class);
 
-  private static final long DATA_FILE_SIZE = 128 * 1024 * 1024; // 128 MB
-  private static final long DELETE_FILE_SIZE = 32 * 1024 * 1024; // 32 MB
-
-  private final SparkSession spark;
   private final Table table;
   private final String branch;
   private final RuntimeConfig sessionConf;
@@ -93,12 +90,13 @@ public class SparkWriteConf {
 
   public SparkWriteConf(
       SparkSession spark, Table table, String branch, Map<String, String> writeOptions) {
-    this.spark = spark;
     this.table = table;
     this.branch = branch;
     this.sessionConf = spark.conf();
     this.writeOptions = writeOptions;
     this.confParser = new SparkConfParser(spark, table, writeOptions);
+
+    SparkUtil.validateTimestampWithoutTimezoneConfig(spark.conf(), writeOptions);
   }
 
   public boolean checkNullability() {
@@ -141,8 +139,7 @@ public class SparkWriteConf {
         .booleanConf()
         .option(SparkWriteOptions.MERGE_SCHEMA)
         .option(SparkWriteOptions.SPARK_MERGE_SCHEMA)
-        .sessionConf(SparkSQLProperties.MERGE_SCHEMA)
-        .defaultValue(SparkSQLProperties.MERGE_SCHEMA_DEFAULT)
+        .defaultValue(SparkWriteOptions.MERGE_SCHEMA_DEFAULT)
         .parse();
   }
 
@@ -171,19 +168,6 @@ public class SparkWriteConf {
     return FileFormat.fromString(valueAsString);
   }
 
-  private String dataCompressionCodec() {
-    switch (dataFileFormat()) {
-      case PARQUET:
-        return parquetCompressionCodec();
-      case AVRO:
-        return avroCompressionCodec();
-      case ORC:
-        return orcCompressionCodec();
-      default:
-        return null;
-    }
-  }
-
   public long targetDataFileSize() {
     return confParser
         .longConf()
@@ -193,25 +177,20 @@ public class SparkWriteConf {
         .parse();
   }
 
-  public boolean useFanoutWriter(SparkWriteRequirements writeRequirements) {
-    boolean defaultValue = !writeRequirements.hasOrdering();
-    return fanoutWriterEnabled(defaultValue);
-  }
-
-  private boolean fanoutWriterEnabled() {
-    return fanoutWriterEnabled(true /* enabled by default */);
-  }
-
-  private boolean fanoutWriterEnabled(boolean defaultValue) {
+  public boolean fanoutWriterEnabled() {
     return confParser
         .booleanConf()
         .option(SparkWriteOptions.FANOUT_ENABLED)
         .tableProperty(TableProperties.SPARK_WRITE_PARTITIONED_FANOUT_ENABLED)
-        .defaultValue(defaultValue)
+        .defaultValue(TableProperties.SPARK_WRITE_PARTITIONED_FANOUT_ENABLED_DEFAULT)
         .parse();
   }
 
   public FileFormat deleteFileFormat() {
+    if (!(table instanceof BaseMetadataTable) && TableUtil.formatVersion(table) >= 3) {
+      return FileFormat.PUFFIN;
+    }
+
     String valueAsString =
         confParser
             .stringConf()
@@ -221,19 +200,6 @@ public class SparkWriteConf {
     return valueAsString != null ? FileFormat.fromString(valueAsString) : dataFileFormat();
   }
 
-  private String deleteCompressionCodec() {
-    switch (deleteFileFormat()) {
-      case PARQUET:
-        return deleteParquetCompressionCodec();
-      case AVRO:
-        return deleteAvroCompressionCodec();
-      case ORC:
-        return deleteOrcCompressionCodec();
-      default:
-        return null;
-    }
-  }
-
   public long targetDeleteFileSize() {
     return confParser
         .longConf()
@@ -270,8 +236,7 @@ public class SparkWriteConf {
       return SparkWriteRequirements.EMPTY;
     }
 
-    return SparkWriteUtil.writeRequirements(
-        table, distributionMode(), fanoutWriterEnabled(), dataAdvisoryPartitionSize());
+    return SparkWriteUtil.writeRequirements(table, distributionMode(), fanoutWriterEnabled());
   }
 
   @VisibleForTesting
@@ -319,11 +284,7 @@ public class SparkWriteConf {
     }
 
     return SparkWriteUtil.copyOnWriteRequirements(
-        table,
-        command,
-        copyOnWriteDistributionMode(command),
-        fanoutWriterEnabled(),
-        dataAdvisoryPartitionSize());
+        table, command, copyOnWriteDistributionMode(command), fanoutWriterEnabled());
   }
 
   @VisibleForTesting
@@ -347,11 +308,7 @@ public class SparkWriteConf {
     }
 
     return SparkWriteUtil.positionDeltaRequirements(
-        table,
-        command,
-        positionDeltaDistributionMode(command),
-        fanoutWriterEnabled(),
-        command == DELETE ? deleteAdvisoryPartitionSize() : dataAdvisoryPartitionSize());
+        table, command, positionDeltaDistributionMode(command), fanoutWriterEnabled());
   }
 
   @VisibleForTesting
@@ -527,24 +484,42 @@ public class SparkWriteConf {
 
     switch (deleteFormat) {
       case PARQUET:
-        writeProperties.put(DELETE_PARQUET_COMPRESSION, deleteParquetCompressionCodec());
-        String deleteParquetCompressionLevel = deleteParquetCompressionLevel();
-        if (deleteParquetCompressionLevel != null) {
-          writeProperties.put(DELETE_PARQUET_COMPRESSION_LEVEL, deleteParquetCompressionLevel);
-        }
+        setWritePropertyWithFallback(
+            writeProperties,
+            DELETE_PARQUET_COMPRESSION,
+            deleteParquetCompressionCodec(),
+            parquetCompressionCodec());
+        setWritePropertyWithFallback(
+            writeProperties,
+            DELETE_PARQUET_COMPRESSION_LEVEL,
+            deleteParquetCompressionLevel(),
+            parquetCompressionLevel());
         break;
 
       case AVRO:
-        writeProperties.put(DELETE_AVRO_COMPRESSION, deleteAvroCompressionCodec());
-        String deleteAvroCompressionLevel = deleteAvroCompressionLevel();
-        if (deleteAvroCompressionLevel != null) {
-          writeProperties.put(DELETE_AVRO_COMPRESSION_LEVEL, deleteAvroCompressionLevel);
-        }
+        setWritePropertyWithFallback(
+            writeProperties,
+            DELETE_AVRO_COMPRESSION,
+            deleteAvroCompressionCodec(),
+            avroCompressionCodec());
+        setWritePropertyWithFallback(
+            writeProperties,
+            DELETE_AVRO_COMPRESSION_LEVEL,
+            deleteAvroCompressionLevel(),
+            avroCompressionLevel());
         break;
 
       case ORC:
-        writeProperties.put(DELETE_ORC_COMPRESSION, deleteOrcCompressionCodec());
-        writeProperties.put(DELETE_ORC_COMPRESSION_STRATEGY, deleteOrcCompressionStrategy());
+        setWritePropertyWithFallback(
+            writeProperties,
+            DELETE_ORC_COMPRESSION,
+            deleteOrcCompressionCodec(),
+            orcCompressionCodec());
+        setWritePropertyWithFallback(
+            writeProperties,
+            DELETE_ORC_COMPRESSION_STRATEGY,
+            deleteOrcCompressionStrategy(),
+            orcCompressionStrategy());
         break;
 
       default:
@@ -554,6 +529,15 @@ public class SparkWriteConf {
     return writeProperties;
   }
 
+  private void setWritePropertyWithFallback(
+      Map<String, String> writeProperties, String key, String value, String fallbackValue) {
+    if (value != null) {
+      writeProperties.put(key, value);
+    } else if (fallbackValue != null) {
+      writeProperties.put(key, fallbackValue);
+    }
+  }
+
   private String parquetCompressionCodec() {
     return confParser
         .stringConf()
@@ -570,8 +554,7 @@ public class SparkWriteConf {
         .option(SparkWriteOptions.COMPRESSION_CODEC)
         .sessionConf(SparkSQLProperties.COMPRESSION_CODEC)
         .tableProperty(DELETE_PARQUET_COMPRESSION)
-        .defaultValue(parquetCompressionCodec())
-        .parse();
+        .parseOptional();
   }
 
   private String parquetCompressionLevel() {
@@ -590,7 +573,6 @@ public class SparkWriteConf {
         .option(SparkWriteOptions.COMPRESSION_LEVEL)
         .sessionConf(SparkSQLProperties.COMPRESSION_LEVEL)
         .tableProperty(DELETE_PARQUET_COMPRESSION_LEVEL)
-        .defaultValue(parquetCompressionLevel())
         .parseOptional();
   }
 
@@ -610,8 +592,7 @@ public class SparkWriteConf {
         .option(SparkWriteOptions.COMPRESSION_CODEC)
         .sessionConf(SparkSQLProperties.COMPRESSION_CODEC)
         .tableProperty(DELETE_AVRO_COMPRESSION)
-        .defaultValue(avroCompressionCodec())
-        .parse();
+        .parseOptional();
   }
 
   private String avroCompressionLevel() {
@@ -630,7 +611,6 @@ public class SparkWriteConf {
         .option(SparkWriteOptions.COMPRESSION_LEVEL)
         .sessionConf(SparkSQLProperties.COMPRESSION_LEVEL)
         .tableProperty(DELETE_AVRO_COMPRESSION_LEVEL)
-        .defaultValue(avroCompressionLevel())
         .parseOptional();
   }
 
@@ -650,8 +630,7 @@ public class SparkWriteConf {
         .option(SparkWriteOptions.COMPRESSION_CODEC)
         .sessionConf(SparkSQLProperties.COMPRESSION_CODEC)
         .tableProperty(DELETE_ORC_COMPRESSION)
-        .defaultValue(orcCompressionCodec())
-        .parse();
+        .parseOptional();
   }
 
   private String orcCompressionStrategy() {
@@ -670,45 +649,7 @@ public class SparkWriteConf {
         .option(SparkWriteOptions.COMPRESSION_STRATEGY)
         .sessionConf(SparkSQLProperties.COMPRESSION_STRATEGY)
         .tableProperty(DELETE_ORC_COMPRESSION_STRATEGY)
-        .defaultValue(orcCompressionStrategy())
-        .parse();
-  }
-
-  private long dataAdvisoryPartitionSize() {
-    long defaultValue =
-        advisoryPartitionSize(DATA_FILE_SIZE, dataFileFormat(), dataCompressionCodec());
-    return advisoryPartitionSize(defaultValue);
-  }
-
-  private long deleteAdvisoryPartitionSize() {
-    long defaultValue =
-        advisoryPartitionSize(DELETE_FILE_SIZE, deleteFileFormat(), deleteCompressionCodec());
-    return advisoryPartitionSize(defaultValue);
-  }
-
-  private long advisoryPartitionSize(long defaultValue) {
-    return confParser
-        .longConf()
-        .option(SparkWriteOptions.ADVISORY_PARTITION_SIZE)
-        .sessionConf(SparkSQLProperties.ADVISORY_PARTITION_SIZE)
-        .tableProperty(TableProperties.SPARK_WRITE_ADVISORY_PARTITION_SIZE_BYTES)
-        .defaultValue(defaultValue)
-        .parse();
-  }
-
-  private long advisoryPartitionSize(
-      long expectedFileSize, FileFormat outputFileFormat, String outputCodec) {
-    double shuffleCompressionRatio = shuffleCompressionRatio(outputFileFormat, outputCodec);
-    long suggestedAdvisoryPartitionSize = (long) (expectedFileSize * shuffleCompressionRatio);
-    return Math.max(suggestedAdvisoryPartitionSize, sparkAdvisoryPartitionSize());
-  }
-
-  private long sparkAdvisoryPartitionSize() {
-    return (long) spark.sessionState().conf().getConf(SQLConf.ADVISORY_PARTITION_SIZE_IN_BYTES());
-  }
-
-  private double shuffleCompressionRatio(FileFormat outputFileFormat, String outputCodec) {
-    return SparkCompressionUtil.shuffleCompressionRatio(spark, outputFileFormat, outputCodec);
+        .parseOptional();
   }
 
   public DeleteGranularity deleteGranularity() {
