@@ -51,21 +51,24 @@ import java.time.Duration;
 import java.util.List;
 import java.util.Map;
 import org.apache.iceberg.DistributionMode;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.UpdateProperties;
 import org.apache.iceberg.deletes.DeleteGranularity;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestSparkWriteConf extends TestBaseWithCatalog {
 
-  @Before
+  @BeforeEach
   public void before() {
+    super.before();
     sql(
         "CREATE TABLE %s (id BIGINT, data STRING, date DATE, ts TIMESTAMP) "
             + "USING iceberg "
@@ -73,12 +76,12 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         tableName);
   }
 
-  @After
+  @AfterEach
   public void after() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testDurationConf() {
     Table table = validationCatalog.loadTable(tableIdent);
     String confName = "spark.sql.iceberg.some-duration-conf";
@@ -100,7 +103,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteGranularityDefault() {
     Table table = validationCatalog.loadTable(tableIdent);
     SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
@@ -109,7 +112,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     assertThat(value).isEqualTo(DeleteGranularity.PARTITION);
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteGranularityTableProperty() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -124,7 +127,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     assertThat(value).isEqualTo(DeleteGranularity.FILE);
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteGranularityWriteOption() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -142,7 +145,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     assertThat(value).isEqualTo(DeleteGranularity.FILE);
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteGranularityInvalidValue() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -155,7 +158,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         .hasMessageContaining("Unknown delete granularity");
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionDefault() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -164,7 +167,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     checkMode(DistributionMode.HASH, writeConf);
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionModeWithWriteOption() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -175,7 +178,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     checkMode(DistributionMode.NONE, writeConf);
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionModeWithSessionConfig() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.NONE.modeName()),
@@ -186,7 +189,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionModeWithTableProperties() {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -202,7 +205,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     checkMode(DistributionMode.NONE, writeConf);
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionModeWithTblPropAndSessionConfig() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.NONE.modeName()),
@@ -223,7 +226,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionModeWithWriteOptionAndSessionConfig() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.RANGE.modeName()),
@@ -240,7 +243,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testSparkWriteConfDistributionModeWithEverything() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.DISTRIBUTION_MODE, DistributionMode.RANGE.modeName()),
@@ -265,7 +268,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testSparkConfOverride() {
     List<List<Map<String, String>>> propertiesSuites =
         Lists.newArrayList(
@@ -338,7 +341,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testDataPropsDefaultsAsDeleteProps() {
     List<List<Map<String, String>>> propertiesSuites =
         Lists.newArrayList(
@@ -407,7 +410,7 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteFileWriteConf() {
     List<List<Map<String, String>>> propertiesSuites =
         Lists.newArrayList(
@@ -502,9 +505,9 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
           SparkWriteConf writeConf = new SparkWriteConf(spark, table, ImmutableMap.of());
           Map<String, String> writeProperties = writeConf.writeProperties();
           Map<String, String> expectedProperties = propertiesSuite.get(2);
-          Assert.assertEquals(expectedProperties.size(), writeConf.writeProperties().size());
+          assertThat(writeConf.writeProperties()).hasSameSizeAs(expectedProperties);
           for (Map.Entry<String, String> entry : writeProperties.entrySet()) {
-            Assert.assertEquals(entry.getValue(), expectedProperties.get(entry.getKey()));
+            assertThat(expectedProperties).containsEntry(entry.getKey(), entry.getValue());
           }
 
           table.refresh();
@@ -518,12 +521,12 @@ public class TestSparkWriteConf extends SparkTestBaseWithCatalog {
   }
 
   private void checkMode(DistributionMode expectedMode, SparkWriteConf writeConf) {
-    Assert.assertEquals(expectedMode, writeConf.distributionMode());
-    Assert.assertEquals(expectedMode, writeConf.copyOnWriteDistributionMode(DELETE));
-    Assert.assertEquals(expectedMode, writeConf.positionDeltaDistributionMode(DELETE));
-    Assert.assertEquals(expectedMode, writeConf.copyOnWriteDistributionMode(UPDATE));
-    Assert.assertEquals(expectedMode, writeConf.positionDeltaDistributionMode(UPDATE));
-    Assert.assertEquals(expectedMode, writeConf.copyOnWriteDistributionMode(MERGE));
-    Assert.assertEquals(expectedMode, writeConf.positionDeltaDistributionMode(MERGE));
+    assertThat(writeConf.distributionMode()).isEqualTo(expectedMode);
+    assertThat(writeConf.copyOnWriteDistributionMode(DELETE)).isEqualTo(expectedMode);
+    assertThat(writeConf.positionDeltaDistributionMode(DELETE)).isEqualTo(expectedMode);
+    assertThat(writeConf.copyOnWriteDistributionMode(UPDATE)).isEqualTo(expectedMode);
+    assertThat(writeConf.positionDeltaDistributionMode(UPDATE)).isEqualTo(expectedMode);
+    assertThat(writeConf.copyOnWriteDistributionMode(MERGE)).isEqualTo(expectedMode);
+    assertThat(writeConf.positionDeltaDistributionMode(MERGE)).isEqualTo(expectedMode);
   }
 }
