@@ -22,7 +22,7 @@ import static org.apache.iceberg.spark.actions.NDVSketchUtil.APACHE_DATASKETCHES
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.assertThatNoException;
+import static org.assertj.core.api.Assertions.assertThatCode;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.IOException;
@@ -61,6 +61,7 @@ import org.junit.jupiter.api.extension.ExtendWith;
 
 @ExtendWith(ParameterizedTestExtension.class)
 public class TestComputeTableStatsAction extends CatalogTestBase {
+
   private static final Types.StructType LEAF_STRUCT_TYPE =
       Types.StructType.of(
           optional(1, "leafLongCol", Types.LongType.get()),
@@ -187,7 +188,7 @@ public class TestComputeTableStatsAction extends CatalogTestBase {
     SparkActions actions = SparkActions.get();
     assertThatThrownBy(() -> actions.computeTableStats(table).columns("id1").execute())
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageStartingWith("Can't find column id1 in table");
+        .hasMessageContaining("Can't find column id1 in table");
   }
 
   @TestTemplate
@@ -245,8 +246,8 @@ public class TestComputeTableStatsAction extends CatalogTestBase {
     // Snapshot id not specified
     Table table = Spark3Util.loadIcebergTable(spark, tableName);
 
-    assertThatNoException()
-        .isThrownBy(() -> actions.computeTableStats(table).columns("data").execute());
+    assertThatCode(() -> actions.computeTableStats(table).columns("data").execute())
+        .doesNotThrowAnyException();
 
     sql("ALTER TABLE %s DROP COLUMN %s", tableName, "data");
     // Append data to create snapshot
@@ -255,14 +256,14 @@ public class TestComputeTableStatsAction extends CatalogTestBase {
     long snapshotId2 = Spark3Util.loadIcebergTable(spark, tableName).currentSnapshot().snapshotId();
 
     // Snapshot id specified
-    assertThatNoException()
-        .isThrownBy(
-            () -> actions.computeTableStats(table).snapshot(snapshotId1).columns("data").execute());
+    assertThatCode(
+            () -> actions.computeTableStats(table).snapshot(snapshotId1).columns("data").execute())
+        .doesNotThrowAnyException();
 
     assertThatThrownBy(
             () -> actions.computeTableStats(table).snapshot(snapshotId2).columns("data").execute())
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageStartingWith("Can't find column data in table");
+        .hasMessageContaining("Can't find column data in table");
   }
 
   @TestTemplate
@@ -332,7 +333,7 @@ public class TestComputeTableStatsAction extends CatalogTestBase {
     SparkActions actions = SparkActions.get();
     assertThatThrownBy(() -> actions.computeTableStats(table).execute())
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("No columns found to compute stats");
+        .hasMessageContaining("No columns found to compute stats");
   }
 
   @TestTemplate
