@@ -18,6 +18,9 @@
  */
 package org.apache.iceberg.spark.source;
 
+import static org.apache.iceberg.FileFormat.AVRO;
+import static org.apache.iceberg.FileFormat.ORC;
+import static org.apache.iceberg.FileFormat.PARQUET;
 import static org.apache.iceberg.RowLevelOperationMode.MERGE_ON_READ;
 import static org.apache.iceberg.TableProperties.AVRO_COMPRESSION;
 import static org.apache.iceberg.TableProperties.DEFAULT_FILE_FORMAT;
@@ -50,16 +53,19 @@ import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.ManifestFile;
 import org.apache.iceberg.ManifestFiles;
 import org.apache.iceberg.ManifestReader;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Table;
-import org.apache.iceberg.actions.SizeBasedFileRewriter;
+import org.apache.iceberg.actions.SizeBasedFileRewritePlanner;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.io.InputFile;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
+import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.SparkCatalogConfig;
-import org.apache.iceberg.spark.SparkCatalogTestBase;
 import org.apache.iceberg.spark.SparkWriteOptions;
 import org.apache.iceberg.spark.actions.SparkActions;
 import org.apache.orc.OrcFile;
@@ -69,73 +75,98 @@ import org.apache.parquet.hadoop.metadata.ParquetMetadata;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SparkSession;
-import org.junit.AfterClass;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
-@RunWith(Parameterized.class)
-public class TestCompressionSettings extends SparkCatalogTestBase {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestCompressionSettings extends CatalogTestBase {
 
   private static final Configuration CONF = new Configuration();
   private static final String TABLE_NAME = "testWriteData";
 
   private static SparkSession spark = null;
 
-  private final FileFormat format;
-  private final ImmutableMap<String, String> properties;
+  @Parameter(index = 3)
+  private FileFormat format;
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @Parameter(index = 4)
+  private Map<String, String> properties;
 
-  @Parameterized.Parameters(name = "format = {0}, properties = {1}")
+  @TempDir private java.nio.file.Path temp;
+
+  @Parameters(
+      name =
+          "catalogName = {0}, implementation = {1}, config = {2}, format = {3}, properties = {4}")
   public static Object[][] parameters() {
     return new Object[][] {
-      {"parquet", ImmutableMap.of(COMPRESSION_CODEC, "zstd", COMPRESSION_LEVEL, "1")},
-      {"parquet", ImmutableMap.of(COMPRESSION_CODEC, "gzip")},
-      {"orc", ImmutableMap.of(COMPRESSION_CODEC, "zstd", COMPRESSION_STRATEGY, "speed")},
-      {"orc", ImmutableMap.of(COMPRESSION_CODEC, "zstd", COMPRESSION_STRATEGY, "compression")},
-      {"avro", ImmutableMap.of(COMPRESSION_CODEC, "snappy", COMPRESSION_LEVEL, "3")}
+      {
+        SparkCatalogConfig.SPARK.catalogName(),
+        SparkCatalogConfig.SPARK.implementation(),
+        SparkCatalogConfig.SPARK.properties(),
+        PARQUET,
+        ImmutableMap.of(COMPRESSION_CODEC, "zstd", COMPRESSION_LEVEL, "1")
+      },
+      {
+        SparkCatalogConfig.SPARK.catalogName(),
+        SparkCatalogConfig.SPARK.implementation(),
+        SparkCatalogConfig.SPARK.properties(),
+        PARQUET,
+        ImmutableMap.of(COMPRESSION_CODEC, "gzip")
+      },
+      {
+        SparkCatalogConfig.SPARK.catalogName(),
+        SparkCatalogConfig.SPARK.implementation(),
+        SparkCatalogConfig.SPARK.properties(),
+        ORC,
+        ImmutableMap.of(COMPRESSION_CODEC, "zstd", COMPRESSION_STRATEGY, "speed")
+      },
+      {
+        SparkCatalogConfig.SPARK.catalogName(),
+        SparkCatalogConfig.SPARK.implementation(),
+        SparkCatalogConfig.SPARK.properties(),
+        ORC,
+        ImmutableMap.of(COMPRESSION_CODEC, "zstd", COMPRESSION_STRATEGY, "compression")
+      },
+      {
+        SparkCatalogConfig.SPARK.catalogName(),
+        SparkCatalogConfig.SPARK.implementation(),
+        SparkCatalogConfig.SPARK.properties(),
+        AVRO,
+        ImmutableMap.of(COMPRESSION_CODEC, "snappy", COMPRESSION_LEVEL, "3")
+      }
     };
   }
 
-  @BeforeClass
+  @BeforeAll
   public static void startSpark() {
     TestCompressionSettings.spark = SparkSession.builder().master("local[2]").getOrCreate();
   }
 
-  @Before
+  @BeforeEach
   public void resetSpecificConfigurations() {
     spark.conf().unset(COMPRESSION_CODEC);
     spark.conf().unset(COMPRESSION_LEVEL);
     spark.conf().unset(COMPRESSION_STRATEGY);
   }
 
-  @Parameterized.AfterParam
-  public static void clearSourceCache() {
+  @AfterEach
+  public void afterEach() {
     spark.sql(String.format("DROP TABLE IF EXISTS %s", TABLE_NAME));
   }
 
-  @AfterClass
+  @AfterAll
   public static void stopSpark() {
     SparkSession currentSpark = TestCompressionSettings.spark;
     TestCompressionSettings.spark = null;
     currentSpark.stop();
   }
 
-  public TestCompressionSettings(String format, ImmutableMap properties) {
-    super(
-        SparkCatalogConfig.SPARK.catalogName(),
-        SparkCatalogConfig.SPARK.implementation(),
-        SparkCatalogConfig.SPARK.properties());
-    this.format = FileFormat.fromString(format);
-    this.properties = properties;
-  }
-
-  @Test
+  @TestTemplate
   public void testWriteDataWithDifferentSetting() throws Exception {
     sql("CREATE TABLE %s (id int, data string) USING iceberg", TABLE_NAME);
     Map<String, String> tableProperties = Maps.newHashMap();
@@ -168,6 +199,8 @@ public class TestCompressionSettings extends SparkCatalogTestBase {
       spark.conf().set(entry.getKey(), entry.getValue());
     }
 
+    assertSparkConf();
+
     df.select("id", "data")
         .writeTo(TABLE_NAME)
         .option(SparkWriteOptions.WRITE_FORMAT, format.toString())
@@ -197,7 +230,7 @@ public class TestCompressionSettings extends SparkCatalogTestBase {
 
     SparkActions.get(spark)
         .rewritePositionDeletes(table)
-        .option(SizeBasedFileRewriter.REWRITE_ALL, "true")
+        .option(SizeBasedFileRewritePlanner.REWRITE_ALL, "true")
         .execute();
     table.refresh();
     deleteManifestFiles = table.currentSnapshot().deleteManifests(table.io());
@@ -230,4 +263,13 @@ public class TestCompressionSettings extends SparkCatalogTestBase {
         return fileReader.getMetaString(DataFileConstants.CODEC);
     }
   }
+
+  private void assertSparkConf() {
+    String[] propertiesToCheck = {COMPRESSION_CODEC, COMPRESSION_LEVEL, COMPRESSION_STRATEGY};
+    for (String prop : propertiesToCheck) {
+      String expected = properties.getOrDefault(prop, null);
+      String actual = spark.conf().get(prop, null);
+      assertThat(actual).isEqualToIgnoringCase(expected);
+    }
+  }
 }
