@@ -58,11 +58,11 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.spark.TestBase;
 import org.apache.iceberg.types.Types;
-import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.Dataset;
-import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
+import org.apache.spark.sql.RowFactory;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
+import org.apache.spark.sql.types.DataTypes;
 import org.apache.spark.sql.types.StructType;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeAll;
@@ -77,7 +77,7 @@ public class TestSparkMetadataColumns extends TestBase {
   private static final String TABLE_NAME = "test_table";
   private static final Schema SCHEMA =
       new Schema(
-          Types.NestedField.optional(1, "id", Types.LongType.get()),
+          Types.NestedField.required(1, "id", Types.LongType.get()),
           Types.NestedField.optional(2, "category", Types.StringType.get()),
           Types.NestedField.optional(3, "data", Types.StringType.get()));
   private static final PartitionSpec SPEC = PartitionSpec.unpartitioned();
@@ -90,23 +90,15 @@ public class TestSparkMetadataColumns extends TestBase {
 
   @Parameters(name = "fileFormat = {0}, vectorized = {1}, formatVersion = {2}")
   public static Object[][] parameters() {
-    return new Object[][] {
-      {FileFormat.PARQUET, false, 1},
-      {FileFormat.PARQUET, true, 1},
-      {FileFormat.PARQUET, false, 2},
-      {FileFormat.PARQUET, true, 2},
-      {FileFormat.PARQUET, false, 3},
-      {FileFormat.PARQUET, true, 3},
-      {FileFormat.AVRO, false, 1},
-      {FileFormat.AVRO, false, 2},
-      {FileFormat.AVRO, false, 3},
-      {FileFormat.ORC, false, 1},
-      {FileFormat.ORC, true, 1},
-      {FileFormat.ORC, false, 2},
-      {FileFormat.ORC, true, 2},
-      {FileFormat.ORC, false, 3},
-      {FileFormat.ORC, true, 3},
-    };
+    List<Object[]> parameters = Lists.newArrayList();
+    for (int version : TestHelpers.ALL_VERSIONS) {
+      parameters.add(new Object[] {FileFormat.PARQUET, false, version});
+      parameters.add(new Object[] {FileFormat.PARQUET, true, version});
+      parameters.add(new Object[] {FileFormat.AVRO, false, version});
+      parameters.add(new Object[] {FileFormat.ORC, false, version});
+      parameters.add(new Object[] {FileFormat.ORC, true, version});
+    }
+    return parameters.toArray(new Object[0][]);
   }
 
   @TempDir private Path temp;
@@ -228,21 +220,21 @@ public class TestSparkMetadataColumns extends TestBase {
 
     table.updateProperties().set(PARQUET_ROW_GROUP_SIZE_BYTES, "100").commit();
 
-    List<Long> ids = Lists.newArrayList();
+    List<Row> rows = Lists.newArrayList();
     for (long id = 0L; id < 200L; id++) {
-      ids.add(id);
+      rows.add(RowFactory.create(id));
     }
     Dataset<Row> df =
         spark
-            .createDataset(ids, Encoders.LONG())
-            .withColumnRenamed("value", "id")
+            .createDataFrame(rows, new StructType().add("id", DataTypes.LongType, false))
             .withColumn("category", lit("hr"))
             .withColumn("data", lit("ABCDEF"));
     df.coalesce(1).writeTo(TABLE_NAME).append();
 
     assertThat(spark.table(TABLE_NAME).count()).isEqualTo(200);
 
-    List<Object[]> expectedRows = ids.stream().map(this::row).collect(Collectors.toList());
+    List<Object[]> expectedRows =
+        rows.stream().map(r -> row(r.get(0))).collect(Collectors.toList());
     assertEquals("Rows must match", expectedRows, sql("SELECT _pos FROM %s", TABLE_NAME));
   }
 
@@ -252,21 +244,21 @@ public class TestSparkMetadataColumns extends TestBase {
 
     table.updateProperties().set(PARQUET_BATCH_SIZE, "1000").commit();
 
-    List<Long> ids = Lists.newArrayList();
+    List<Row> rows = Lists.newArrayList();
     for (long id = 0L; id < 7500L; id++) {
-      ids.add(id);
+      rows.add(RowFactory.create(id));
     }
     Dataset<Row> df =
         spark
-            .createDataset(ids, Encoders.LONG())
-            .withColumnRenamed("value", "id")
+            .createDataFrame(rows, new StructType().add("id", DataTypes.LongType, false))
             .withColumn("category", lit("hr"))
             .withColumn("data", lit("ABCDEF"));
     df.coalesce(1).writeTo(TABLE_NAME).append();
 
     assertThat(spark.table(TABLE_NAME).count()).isEqualTo(7500);
 
-    List<Object[]> expectedRows = ids.stream().map(this::row).collect(Collectors.toList());
+    List<Object[]> expectedRows =
+        rows.stream().map(r -> row(r.get(0))).collect(Collectors.toList());
     assertEquals("Rows must match", expectedRows, sql("SELECT _pos FROM %s", TABLE_NAME));
   }
 
@@ -318,25 +310,15 @@ public class TestSparkMetadataColumns extends TestBase {
   }
 
   @TestTemplate
-  public void testRowLineageColumnsResolvedInV3OrHigher() {
-    if (formatVersion >= 3) {
-      // Test against an empty table to ensure column resolution in formats supporting row lineage
-      // and so that the test doesn't have to change with inheritance
-      assertEquals(
-          "Rows must match",
-          ImmutableList.of(),
-          sql("SELECT _row_id, _last_updated_sequence_number, id FROM %s", TABLE_NAME));
-    } else {
-      // Should fail to resolve row lineage metadata columns in V1/V2 tables
-      assertThatThrownBy(() -> sql("SELECT _row_id FROM %s", TABLE_NAME))
-          .isInstanceOf(AnalysisException.class)
-          .hasMessageContaining(
-              "A column or function parameter with name `_row_id` cannot be resolved");
-      assertThatThrownBy(() -> sql("SELECT _last_updated_sequence_number FROM %s", TABLE_NAME))
-          .isInstanceOf(AnalysisException.class)
-          .hasMessageContaining(
-              "A column or function parameter with name `_last_updated_sequence_number` cannot be resolved");
-    }
+  public void testIdentifierFields() {
+    table.updateSchema().setIdentifierFields("id").commit();
+
+    sql("INSERT INTO TABLE %s VALUES (1, 'a1', 'b1')", TABLE_NAME);
+
+    assertEquals(
+        "Rows must match",
+        ImmutableList.of(row(1L, 0, null)),
+        sql("SELECT id, _spec_id, _partition FROM %s", TABLE_NAME));
   }
 
   private void createAndInitTable() throws IOException {
