@@ -21,13 +21,11 @@ package org.apache.iceberg.spark.source;
 import static org.apache.hadoop.hive.conf.HiveConf.ConfVars.METASTOREURIS;
 import static org.apache.iceberg.spark.source.SparkSQLExecutionHelper.lastExecutedMetricValue;
 import static org.apache.iceberg.types.Types.NestedField.required;
-import static org.apache.spark.sql.types.DataTypes.IntegerType;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.io.File;
 import java.io.IOException;
-import java.time.LocalDate;
 import java.util.List;
 import java.util.Set;
 import org.apache.hadoop.conf.Configuration;
@@ -70,9 +68,6 @@ import org.apache.iceberg.parquet.ParquetSchemaUtil;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
-import org.apache.iceberg.spark.ImmutableParquetBatchReadConf;
-import org.apache.iceberg.spark.ParquetBatchReadConf;
-import org.apache.iceberg.spark.ParquetReaderType;
 import org.apache.iceberg.spark.SparkSchemaUtil;
 import org.apache.iceberg.spark.SparkStructLike;
 import org.apache.iceberg.spark.data.RandomData;
@@ -91,7 +86,6 @@ import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.internal.SQLConf;
 import org.apache.spark.sql.types.StructType;
-import org.apache.spark.sql.vectorized.ColumnarBatch;
 import org.jetbrains.annotations.NotNull;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.AfterEach;
@@ -113,14 +107,16 @@ public class TestSparkReaderDeletes extends DeleteReadTests {
 
   @Parameters(name = "fileFormat = {0}, formatVersion = {1}, vectorized = {2}, planningMode = {3}")
   public static Object[][] parameters() {
-    return new Object[][] {
-      new Object[] {FileFormat.PARQUET, 2, false, PlanningMode.DISTRIBUTED},
-      new Object[] {FileFormat.PARQUET, 2, true, PlanningMode.LOCAL},
-      new Object[] {FileFormat.ORC, 2, false, PlanningMode.DISTRIBUTED},
-      new Object[] {FileFormat.AVRO, 2, false, PlanningMode.LOCAL},
-      new Object[] {FileFormat.PARQUET, 3, false, PlanningMode.DISTRIBUTED},
-      new Object[] {FileFormat.PARQUET, 3, true, PlanningMode.LOCAL},
-    };
+    List<Object[]> parameters = Lists.newArrayList();
+    for (int version : TestHelpers.V2_AND_ABOVE) {
+      parameters.add(new Object[] {FileFormat.PARQUET, version, false, PlanningMode.DISTRIBUTED});
+      parameters.add(new Object[] {FileFormat.PARQUET, version, true, PlanningMode.LOCAL});
+      if (version == 2) {
+        parameters.add(new Object[] {FileFormat.ORC, version, false, PlanningMode.DISTRIBUTED});
+        parameters.add(new Object[] {FileFormat.AVRO, version, false, PlanningMode.LOCAL});
+      }
+    }
+    return parameters.toArray(new Object[0][]);
   }
 
   @BeforeAll
@@ -172,7 +168,7 @@ public class TestSparkReaderDeletes extends DeleteReadTests {
     Table table = catalog.createTable(TableIdentifier.of("default", name), schema);
     TableOperations ops = ((BaseTable) table).operations();
     TableMetadata meta = ops.current();
-    ops.commit(meta, meta.upgradeToFormatVersion(formatVersion));
+    ops.commit(meta, meta.upgradeToFormatVersion(2));
     table
         .updateProperties()
         .set(TableProperties.DEFAULT_FILE_FORMAT, format.name())
@@ -328,7 +324,7 @@ public class TestSparkReaderDeletes extends DeleteReadTests {
 
     for (CombinedScanTask task : tasks) {
       try (EqualityDeleteRowReader reader =
-          new EqualityDeleteRowReader(task, table, null, table.schema(), false)) {
+          new EqualityDeleteRowReader(task, table, null, table.schema(), false, true)) {
         while (reader.next()) {
           actualRowSet.add(
               new InternalRowWrapper(
@@ -637,63 +633,6 @@ public class TestSparkReaderDeletes extends DeleteReadTests {
     assertThat(rowSet(tblName, tbl, "*")).hasSize(193);
   }
 
-  @TestTemplate
-  public void testEqualityDeleteWithDifferentScanAndDeleteColumns() throws IOException {
-    assumeThat(format).isEqualTo(FileFormat.PARQUET);
-    initDateTable();
-
-    Schema deleteRowSchema = dateTable.schema().select("dt");
-    Record dataDelete = GenericRecord.create(deleteRowSchema);
-    List<Record> dataDeletes =
-        Lists.newArrayList(
-            dataDelete.copy("dt", LocalDate.parse("2021-09-01")),
-            dataDelete.copy("dt", LocalDate.parse("2021-09-02")),
-            dataDelete.copy("dt", LocalDate.parse("2021-09-03")));
-
-    DeleteFile eqDeletes =
-        FileHelpers.writeDeleteFile(
-            dateTable,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-            TestHelpers.Row.of(0),
-            dataDeletes.subList(0, 3),
-            deleteRowSchema);
-
-    dateTable.newRowDelta().addDeletes(eqDeletes).commit();
-
-    CloseableIterable<CombinedScanTask> tasks =
-        TableScanUtil.planTasks(
-            dateTable.newScan().planFiles(),
-            TableProperties.METADATA_SPLIT_SIZE_DEFAULT,
-            TableProperties.SPLIT_LOOKBACK_DEFAULT,
-            TableProperties.SPLIT_OPEN_FILE_COST_DEFAULT);
-
-    ParquetBatchReadConf conf =
-        ImmutableParquetBatchReadConf.builder()
-            .batchSize(7)
-            .readerType(ParquetReaderType.ICEBERG)
-            .build();
-
-    for (CombinedScanTask task : tasks) {
-      try (BatchDataReader reader =
-          new BatchDataReader(
-              // expected column is id, while the equality filter column is dt
-              dateTable,
-              task,
-              dateTable.schema(),
-              dateTable.schema().select("id"),
-              false,
-              conf,
-              null)) {
-        while (reader.next()) {
-          ColumnarBatch columnarBatch = reader.get();
-          int numOfCols = columnarBatch.numCols();
-          assertThat(numOfCols).as("Number of columns").isEqualTo(1);
-          assertThat(columnarBatch.column(0).dataType()).as("Column type").isEqualTo(IntegerType);
-        }
-      }
-    }
-  }
-
   private static final Schema PROJECTION_SCHEMA =
       new Schema(
           required(1, "id", Types.IntegerType.get()),
