@@ -22,8 +22,10 @@ import static org.apache.spark.sql.functions.col;
 import static org.apache.spark.sql.functions.lit;
 import static org.apache.spark.sql.functions.when;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
@@ -31,10 +33,13 @@ import org.apache.iceberg.Table;
 import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.SparkCatalogConfig;
 import org.apache.iceberg.types.Types;
+import org.apache.spark.SparkException;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestCreateTableAsSelect extends CatalogTestBase {
 
   @Parameter(index = 3)
@@ -92,8 +97,7 @@ public class TestCreateTableAsSelect extends CatalogTestBase {
     assertThat(ctasTable.schema().asStruct())
         .as("Should have expected nullable schema")
         .isEqualTo(expectedSchema.asStruct());
-
-    assertThat(ctasTable.spec().fields()).as("Should be an unpartitioned table").hasSize(0);
+    assertThat(ctasTable.spec().fields()).as("Should be an unpartitioned table").isEmpty();
     assertEquals(
         "Should have rows matching the source table",
         sql("SELECT * FROM %s ORDER BY id", sourceName),
@@ -126,28 +130,15 @@ public class TestCreateTableAsSelect extends CatalogTestBase {
   }
 
   @TestTemplate
-  public void testCTASWriteDistributionModeRespected() {
-    sql(
-        "CREATE TABLE %s USING iceberg PARTITIONED BY (bucket(2, id)) AS SELECT * FROM %s",
-        tableName, sourceName);
-
-    Schema expectedSchema =
-        new Schema(
-            Types.NestedField.optional(1, "id", Types.LongType.get()),
-            Types.NestedField.optional(2, "data", Types.StringType.get()));
-
-    PartitionSpec expectedSpec = PartitionSpec.builderFor(expectedSchema).bucket("id", 2).build();
-
-    Table ctasTable = validationCatalog.loadTable(tableIdent);
-
-    assertThat(ctasTable.schema().asStruct())
-        .as("Should have expected nullable schema")
-        .isEqualTo(expectedSchema.asStruct());
-    assertThat(ctasTable.spec()).as("Should be partitioned by id").isEqualTo(expectedSpec);
-    assertEquals(
-        "Should have rows matching the source table",
-        sql("SELECT * FROM %s ORDER BY id", sourceName),
-        sql("SELECT * FROM %s ORDER BY id", tableName));
+  public void testCTASWriteDistributionModeNotRespected() {
+    assertThatThrownBy(
+            () ->
+                sql(
+                    "CREATE TABLE %s USING iceberg PARTITIONED BY (bucket(2, id)) AS SELECT * FROM %s",
+                    tableName, sourceName))
+        .isInstanceOf(SparkException.class)
+        .hasMessageContaining(
+            "Incoming records violate the writer assumption that records are clustered by spec and by partition within each spec");
   }
 
   @TestTemplate
@@ -194,15 +185,10 @@ public class TestCreateTableAsSelect extends CatalogTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
 
     assertThat(rtasTable.snapshots()).as("Table should have expected snapshots").hasSize(2);
-    assertThat(rtasTable.properties().get("prop1"))
-        .as("Should have updated table property")
-        .isEqualTo("newval1");
-    assertThat(rtasTable.properties().get("prop2"))
-        .as("Should have preserved table property")
-        .isEqualTo("val2");
-    assertThat(rtasTable.properties().get("prop3"))
-        .as("Should have new table property")
-        .isEqualTo("val3");
+    assertThat(rtasTable.properties())
+        .containsEntry("prop1", "newval1")
+        .containsEntry("prop2", "val2")
+        .containsEntry("prop3", "val3");
   }
 
   @TestTemplate
@@ -272,7 +258,7 @@ public class TestCreateTableAsSelect extends CatalogTestBase {
     assertThat(ctasTable.schema().asStruct())
         .as("Should have expected nullable schema")
         .isEqualTo(expectedSchema.asStruct());
-    assertThat(ctasTable.spec().fields()).as("Should be an unpartitioned table").hasSize(0);
+    assertThat(ctasTable.spec().fields()).as("Should be an unpartitioned table").isEmpty();
     assertEquals(
         "Should have rows matching the source table",
         sql("SELECT * FROM %s ORDER BY id", sourceName),
@@ -421,6 +407,8 @@ public class TestCreateTableAsSelect extends CatalogTestBase {
             + "FROM %s ORDER BY 3, 1",
         tableName, sourceName);
 
+    rtasTable.refresh();
+
     Schema expectedSchema =
         new Schema(
             Types.NestedField.optional(1, "id", Types.LongType.get()),
