@@ -28,6 +28,7 @@ import java.util.Date;
 import java.util.List;
 import java.util.concurrent.TimeUnit;
 import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.events.Listeners;
@@ -44,7 +45,9 @@ import org.apache.spark.sql.Row;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestSelect extends CatalogTestBase {
   private int scanEventCount = 0;
   private ScanEvent lastScanEvent = null;
@@ -326,42 +329,6 @@ public class TestSelect extends CatalogTestBase {
     assertEquals("Snapshot at specific tag reference name", actual, travelWithLongResult);
   }
 
-  @TestTemplate
-  public void testBranchReference() {
-    Table table = validationCatalog.loadTable(tableIdent);
-    long snapshotId = table.currentSnapshot().snapshotId();
-    table.manageSnapshots().createBranch("test_branch", snapshotId).commit();
-    List<Object[]> expected = sql("SELECT * FROM %s", tableName);
-
-    // create a second snapshot, read the table at the branch
-    sql("INSERT INTO %s VALUES (4, 'd', 4.0), (5, 'e', 5.0)", tableName);
-    List<Object[]> actual1 = sql("SELECT * FROM %s VERSION AS OF 'test_branch'", tableName);
-    assertEquals("Snapshot at specific branch reference name", expected, actual1);
-
-    // read the table at the branch
-    // HIVE time travel syntax
-    List<Object[]> actual2 =
-        sql("SELECT * FROM %s FOR SYSTEM_VERSION AS OF 'test_branch'", tableName);
-    assertEquals("Snapshot at specific branch reference name", expected, actual2);
-
-    // Spark session catalog does not support extended table names
-    if (!"spark_catalog".equals(catalogName)) {
-      // read the table using the "branch_" prefix in the table name
-      List<Object[]> actual3 = sql("SELECT * FROM %s.branch_test_branch", tableName);
-      assertEquals("Snapshot at specific branch reference name, prefix", expected, actual3);
-    }
-
-    // read the table using DataFrameReader option: branch
-    Dataset<Row> df =
-        spark
-            .read()
-            .format("iceberg")
-            .option(SparkReadOptions.BRANCH, "test_branch")
-            .load(tableName);
-    List<Object[]> fromDF = rowsToJava(df.collectAsList());
-    assertEquals("Snapshot at specific branch reference name", expected, fromDF);
-  }
-
   @TestTemplate
   public void readAndWriteWithBranchAfterSchemaChange() {
     Table table = validationCatalog.loadTable(tableIdent);
@@ -420,6 +387,42 @@ public class TestSelect extends CatalogTestBase {
             row(7L, "g", java.sql.Date.valueOf("2023-07-07")));
   }
 
+  @TestTemplate
+  public void testBranchReference() {
+    Table table = validationCatalog.loadTable(tableIdent);
+    long snapshotId = table.currentSnapshot().snapshotId();
+    table.manageSnapshots().createBranch("test_branch", snapshotId).commit();
+    List<Object[]> expected = sql("SELECT * FROM %s", tableName);
+
+    // create a second snapshot, read the table at the branch
+    sql("INSERT INTO %s VALUES (4, 'd', 4.0), (5, 'e', 5.0)", tableName);
+    List<Object[]> actual1 = sql("SELECT * FROM %s VERSION AS OF 'test_branch'", tableName);
+    assertEquals("Snapshot at specific branch reference name", expected, actual1);
+
+    // read the table at the branch
+    // HIVE time travel syntax
+    List<Object[]> actual2 =
+        sql("SELECT * FROM %s FOR SYSTEM_VERSION AS OF 'test_branch'", tableName);
+    assertEquals("Snapshot at specific branch reference name", expected, actual2);
+
+    // Spark session catalog does not support extended table names
+    if (!"spark_catalog".equals(catalogName)) {
+      // read the table using the "branch_" prefix in the table name
+      List<Object[]> actual3 = sql("SELECT * FROM %s.branch_test_branch", tableName);
+      assertEquals("Snapshot at specific branch reference name, prefix", expected, actual3);
+    }
+
+    // read the table using DataFrameReader option: branch
+    Dataset<Row> df =
+        spark
+            .read()
+            .format("iceberg")
+            .option(SparkReadOptions.BRANCH, "test_branch")
+            .load(tableName);
+    List<Object[]> fromDF = rowsToJava(df.collectAsList());
+    assertEquals("Snapshot at specific branch reference name", expected, fromDF);
+  }
+
   @TestTemplate
   public void testUnknownReferenceAsOf() {
     assertThatThrownBy(() -> sql("SELECT * FROM %s VERSION AS OF 'test_unknown'", tableName))
