@@ -21,72 +21,62 @@ package org.apache.iceberg.spark.sql;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
-import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
+import org.apache.iceberg.spark.TestBaseWithCatalog;
 import org.apache.iceberg.spark.functions.YearsFunction;
 import org.apache.spark.sql.AnalysisException;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
 
-public class TestSparkYearsFunction extends SparkTestBaseWithCatalog {
+public class TestSparkYearsFunction extends TestBaseWithCatalog {
 
-  @Before
+  @BeforeEach
   public void useCatalog() {
     sql("USE %s", catalogName);
   }
 
-  @Test
+  @TestTemplate
   public void testDates() {
-    Assert.assertEquals(
-        "Expected to produce 2017 - 1970 = 47",
-        47,
-        scalarSql("SELECT system.years(date('2017-12-01'))"));
-    Assert.assertEquals(
-        "Expected to produce 1970 - 1970 = 0",
-        0,
-        scalarSql("SELECT system.years(date('1970-01-01'))"));
-    Assert.assertEquals(
-        "Expected to produce 1969 - 1970 = -1",
-        -1,
-        scalarSql("SELECT system.years(date('1969-12-31'))"));
-    Assert.assertNull(scalarSql("SELECT system.years(CAST(null AS DATE))"));
+    assertThat(scalarSql("SELECT system.years(date('2017-12-01'))"))
+        .as("Expected to produce 2017 - 1970 = 47")
+        .isEqualTo(47);
+    assertThat(scalarSql("SELECT system.years(date('1970-01-01'))"))
+        .as("Expected to produce 1970 - 1970 = 0")
+        .isEqualTo(0);
+    assertThat(scalarSql("SELECT system.years(date('1969-12-31'))"))
+        .as("Expected to produce 1969 - 1970 = -1")
+        .isEqualTo(-1);
+    assertThat(scalarSql("SELECT system.years(CAST(null AS DATE))")).isNull();
   }
 
-  @Test
+  @TestTemplate
   public void testTimestamps() {
-    Assert.assertEquals(
-        "Expected to produce 2017 - 1970 = 47",
-        47,
-        scalarSql("SELECT system.years(TIMESTAMP '2017-12-01 10:12:55.038194 UTC+00:00')"));
-    Assert.assertEquals(
-        "Expected to produce 1970 - 1970 = 0",
-        0,
-        scalarSql("SELECT system.years(TIMESTAMP '1970-01-01 00:00:01.000001 UTC+00:00')"));
-    Assert.assertEquals(
-        "Expected to produce 1969 - 1970 = -1",
-        -1,
-        scalarSql("SELECT system.years(TIMESTAMP '1969-12-31 23:59:58.999999 UTC+00:00')"));
-    Assert.assertNull(scalarSql("SELECT system.years(CAST(null AS TIMESTAMP))"));
+    assertThat(scalarSql("SELECT system.years(TIMESTAMP '2017-12-01 10:12:55.038194 UTC+00:00')"))
+        .as("Expected to produce 2017 - 1970 = 47")
+        .isEqualTo(47);
+    assertThat(scalarSql("SELECT system.years(TIMESTAMP '1970-01-01 00:00:01.000001 UTC+00:00')"))
+        .as("Expected to produce 1970 - 1970 = 0")
+        .isEqualTo(0);
+    assertThat(scalarSql("SELECT system.years(TIMESTAMP '1969-12-31 23:59:58.999999 UTC+00:00')"))
+        .as("Expected to produce 1969 - 1970 = -1")
+        .isEqualTo(-1);
+    assertThat(scalarSql("SELECT system.years(CAST(null AS TIMESTAMP))")).isNull();
   }
 
-  @Test
+  @TestTemplate
   public void testTimestampNtz() {
-    Assert.assertEquals(
-        "Expected to produce 2017 - 1970 = 47",
-        47,
-        scalarSql("SELECT system.years(TIMESTAMP_NTZ '2017-12-01 10:12:55.038194 UTC')"));
-    Assert.assertEquals(
-        "Expected to produce 1970 - 1970 = 0",
-        0,
-        scalarSql("SELECT system.years(TIMESTAMP_NTZ '1970-01-01 00:00:01.000001 UTC')"));
-    Assert.assertEquals(
-        "Expected to produce 1969 - 1970 = -1",
-        -1,
-        scalarSql("SELECT system.years(TIMESTAMP_NTZ '1969-12-31 23:59:58.999999 UTC')"));
-    Assert.assertNull(scalarSql("SELECT system.years(CAST(null AS TIMESTAMP_NTZ))"));
+    assertThat(scalarSql("SELECT system.years(TIMESTAMP_NTZ '2017-12-01 10:12:55.038194 UTC')"))
+        .as("Expected to produce 2017 - 1970 = 47")
+        .isEqualTo(47);
+    assertThat(scalarSql("SELECT system.years(TIMESTAMP_NTZ '1970-01-01 00:00:01.000001 UTC')"))
+        .as("Expected to produce 1970 - 1970 = 0")
+        .isEqualTo(0);
+    assertThat(scalarSql("SELECT system.years(TIMESTAMP_NTZ '1969-12-31 23:59:58.999999 UTC')"))
+        .as("Expected to produce 1969 - 1970 = -1")
+        .isEqualTo(-1);
+    assertThat(scalarSql("SELECT system.years(CAST(null AS TIMESTAMP_NTZ))")).isNull();
   }
 
-  @Test
+  @TestTemplate
   public void testWrongNumberOfArguments() {
     assertThatThrownBy(() -> scalarSql("SELECT system.years()"))
         .isInstanceOf(AnalysisException.class)
@@ -100,7 +90,7 @@ public class TestSparkYearsFunction extends SparkTestBaseWithCatalog {
             "Function 'years' cannot process input: (date, date): Wrong number of inputs");
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidInputTypes() {
     assertThatThrownBy(() -> scalarSql("SELECT system.years(1)"))
         .isInstanceOf(AnalysisException.class)
@@ -113,7 +103,7 @@ public class TestSparkYearsFunction extends SparkTestBaseWithCatalog {
             "Function 'years' cannot process input: (bigint): Expected value to be date or timestamp");
   }
 
-  @Test
+  @TestTemplate
   public void testThatMagicFunctionsAreInvoked() {
     String dateValue = "date('2017-12-01')";
     String dateTransformClass = YearsFunction.DateToYearsFunction.class.getName();
