@@ -18,21 +18,23 @@
  */
 package org.apache.iceberg.spark.sql;
 
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.sql.Timestamp;
 import java.time.LocalDateTime;
 import java.util.Arrays;
 import java.util.List;
-import java.util.Map;
 import java.util.stream.Collectors;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.relocated.com.google.common.base.Joiner;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
-import org.apache.iceberg.spark.SparkCatalogTestBase;
+import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.iceberg.spark.SparkSQLProperties;
 import org.apache.iceberg.spark.SparkSessionCatalog;
@@ -41,17 +43,15 @@ import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.util.CaseInsensitiveStringMap;
 import org.joda.time.DateTime;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestTimestampWithoutZone extends SparkCatalogTestBase {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestTimestampWithoutZone extends CatalogTestBase {
 
   private static final String NEW_TABLE_NAME = "created_table";
-  private final Map<String, String> config;
-
   private static final Schema SCHEMA =
       new Schema(
           Types.NestedField.required(1, "id", Types.LongType.get()),
@@ -64,7 +64,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
           row(2L, toLocalDateTime("2021-01-01T00:00:00.0"), toTimestamp("2021-02-01T00:00:00.0")),
           row(3L, toLocalDateTime("2021-01-01T00:00:00.0"), toTimestamp("2021-02-01T00:00:00.0")));
 
-  @Parameterized.Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
+  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
   public static Object[][] parameters() {
     return new Object[][] {
       {
@@ -79,24 +79,18 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
     };
   }
 
-  public TestTimestampWithoutZone(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-    this.config = config;
-  }
-
-  @Before
+  @BeforeEach
   public void createTables() {
     validationCatalog.createTable(tableIdent, SCHEMA);
   }
 
-  @After
+  @AfterEach
   public void removeTables() {
     validationCatalog.dropTable(tableIdent, true);
     sql("DROP TABLE IF EXISTS %s", NEW_TABLE_NAME);
   }
 
-  @Test
+  @TestTemplate
   public void testDeprecatedTimezoneProperty() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.USE_TIMESTAMP_WITHOUT_TIME_ZONE_IN_NEW_TABLES, "true"),
@@ -107,7 +101,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
                         .sessionState()
                         .catalogManager()
                         .currentCatalog()
-                        .initialize(catalog.name(), new CaseInsensitiveStringMap(config));
+                        .initialize(catalog.name(), new CaseInsensitiveStringMap(catalogConfig));
                   })
               .isInstanceOf(UnsupportedOperationException.class)
               .hasMessage(
@@ -115,7 +109,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testReadWithDeprecatedTimezoneProperty() {
     withSQLConf(
         ImmutableMap.of(SparkSQLProperties.HANDLE_TIMESTAMP_WITHOUT_TIMEZONE, "true"),
@@ -130,7 +124,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testReadWithDeprecatedTimezonePropertyReadOption() {
     assertThatThrownBy(
             () -> {
@@ -145,7 +139,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
             "Option handle-timestamp-without-timezone is not supported in Spark 3.4 due to the introduction of native support for timestamp without timezone.");
   }
 
-  @Test
+  @TestTemplate
   public void testWriteWithDeprecatedTimezoneProperty() {
     withSQLConf(
         ImmutableMap.of(
@@ -166,7 +160,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
         });
   }
 
-  @Test
+  @TestTemplate
   public void testWriteWithDeprecatedTimezonePropertyReadOption() {
     assertThatThrownBy(
             () -> {
@@ -213,7 +207,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
   8
    */
 
-  @Test
+  @TestTemplate
   public void testAppendTimestampWithoutZone() {
     // Both NTZ
     sql(
@@ -227,7 +221,7 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
                     toLocalDateTime("2021-02-01T00:00:00.0")))));
   }
 
-  @Test
+  @TestTemplate
   public void testAppendTimestampWithZone() {
     // Both TZ
     sql(
@@ -241,16 +235,15 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
                     toTimestamp("2021-02-01T00:00:00.0")))));
   }
 
-  @Test
+  @TestTemplate
   public void testCreateAsSelectWithTimestampWithoutZone() {
     sql("INSERT INTO %s VALUES %s", tableName, rowToSqlValues(values));
 
     sql("CREATE TABLE %s USING iceberg AS SELECT * FROM %s", NEW_TABLE_NAME, tableName);
 
-    Assert.assertEquals(
-        "Should have " + values.size() + " row",
-        (long) values.size(),
-        scalarSql("SELECT count(*) FROM %s", NEW_TABLE_NAME));
+    assertThat(scalarSql("SELECT count(*) FROM %s", NEW_TABLE_NAME))
+        .as("Should have " + values.size() + " row")
+        .isEqualTo((long) values.size());
 
     assertEquals(
         "Row data should match expected",
@@ -258,16 +251,15 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
         sql("SELECT * FROM %s ORDER BY id", NEW_TABLE_NAME));
   }
 
-  @Test
+  @TestTemplate
   public void testCreateNewTableShouldHaveTimestampWithZoneIcebergType() {
     sql("INSERT INTO %s VALUES %s", tableName, rowToSqlValues(values));
 
     sql("CREATE TABLE %s USING iceberg AS SELECT * FROM %s", NEW_TABLE_NAME, tableName);
 
-    Assert.assertEquals(
-        "Should have " + values.size() + " row",
-        (long) values.size(),
-        scalarSql("SELECT count(*) FROM %s", NEW_TABLE_NAME));
+    assertThat(scalarSql("SELECT count(*) FROM %s", NEW_TABLE_NAME))
+        .as("Should have " + values.size() + " row")
+        .isEqualTo((long) values.size());
 
     assertEquals(
         "Data from created table should match data from base table",
@@ -279,21 +271,20 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
     assertFieldsType(createdTable.schema(), Types.TimestampType.withZone(), "tsz");
   }
 
-  @Test
+  @TestTemplate
   public void testCreateNewTableShouldHaveTimestampWithoutZoneIcebergType() {
     spark
         .sessionState()
         .catalogManager()
         .currentCatalog()
-        .initialize(catalog.name(), new CaseInsensitiveStringMap(config));
+        .initialize(catalog.name(), new CaseInsensitiveStringMap(catalogConfig));
     sql("INSERT INTO %s VALUES %s", tableName, rowToSqlValues(values));
 
     sql("CREATE TABLE %s USING iceberg AS SELECT * FROM %s", NEW_TABLE_NAME, tableName);
 
-    Assert.assertEquals(
-        "Should have " + values.size() + " row",
-        (long) values.size(),
-        scalarSql("SELECT count(*) FROM %s", NEW_TABLE_NAME));
+    assertThat(scalarSql("SELECT count(*) FROM %s", NEW_TABLE_NAME))
+        .as("Should have " + values.size() + " row")
+        .isEqualTo((long) values.size());
 
     assertEquals(
         "Row data should match expected",
@@ -342,6 +333,6 @@ public class TestTimestampWithoutZone extends SparkCatalogTestBase {
         .select(fields)
         .asStruct()
         .fields()
-        .forEach(field -> Assert.assertEquals(expected, field.type()));
+        .forEach(field -> assertThat(field.type()).isEqualTo(expected));
   }
 }
