@@ -100,8 +100,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("range");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "range");
 
     SortOrder expected =
         SortOrder.builderFor(table.schema())
@@ -124,8 +123,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("range");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "range");
 
     SortOrder expected =
         SortOrder.builderFor(table.schema())
@@ -148,8 +146,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("range");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "range");
 
     SortOrder expected =
         SortOrder.builderFor(table.schema())
@@ -173,8 +170,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("range");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "range");
 
     assertThat(table.sortOrder()).as("Table must be sorted").isNotEqualTo(SortOrder.unsorted());
 
@@ -182,8 +178,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String newDistributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(newDistributionMode).as("New distribution mode must match").isEqualTo("none");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "none");
 
     assertThat(table.sortOrder()).as("New sort order must match").isEqualTo(SortOrder.unsorted());
   }
@@ -200,7 +195,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    assertThat(table.properties().containsKey(TableProperties.WRITE_DISTRIBUTION_MODE)).isFalse();
+    assertThat(table.properties()).doesNotContainKey(TableProperties.WRITE_DISTRIBUTION_MODE);
 
     SortOrder expected =
         SortOrder.builderFor(table.schema())
@@ -224,7 +219,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    assertThat(table.properties().containsKey(TableProperties.WRITE_DISTRIBUTION_MODE)).isFalse();
+    assertThat(table.properties()).doesNotContainKey(TableProperties.WRITE_DISTRIBUTION_MODE);
 
     SortOrder expected =
         SortOrder.builderFor(table.schema()).withOrderId(1).desc("category").build();
@@ -243,8 +238,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("hash");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
 
     SortOrder expected = SortOrder.builderFor(table.schema()).withOrderId(1).asc("id").build();
     assertThat(table.sortOrder()).as("Sort order must match").isEqualTo(expected);
@@ -262,8 +256,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("hash");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
 
     SortOrder expected = SortOrder.builderFor(table.schema()).withOrderId(1).asc("id").build();
     assertThat(table.sortOrder()).as("Sort order must match").isEqualTo(expected);
@@ -272,8 +265,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String newDistributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(newDistributionMode).as("Distribution mode must match").isEqualTo(distributionMode);
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
   }
 
   @TestTemplate
@@ -288,8 +280,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("hash");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
 
     assertThat(table.sortOrder()).as("Sort order must match").isEqualTo(SortOrder.unsorted());
   }
@@ -306,8 +297,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("hash");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
 
     assertThat(table.sortOrder()).as("Sort order must match").isEqualTo(SortOrder.unsorted());
   }
@@ -324,8 +314,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("hash");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
 
     assertThat(table.sortOrder()).as("Sort order must match").isEqualTo(SortOrder.unsorted());
   }
@@ -342,8 +331,7 @@ public class TestSetWriteDistributionAndOrdering extends ExtensionsTestBase {
 
     table.refresh();
 
-    String distributionMode = table.properties().get(TableProperties.WRITE_DISTRIBUTION_MODE);
-    assertThat(distributionMode).as("Distribution mode must match").isEqualTo("hash");
+    assertThat(table.properties()).containsEntry(TableProperties.WRITE_DISTRIBUTION_MODE, "hash");
 
     SortOrder expected = SortOrder.builderFor(table.schema()).withOrderId(1).asc("id").build();
     assertThat(table.sortOrder()).as("Sort order must match").isEqualTo(expected);
