@@ -53,10 +53,6 @@ public class SparkWriteOptions {
   // File scan task set ID that indicates which files must be replaced
   public static final String REWRITTEN_FILE_SCAN_TASK_SET_ID = "rewritten-file-scan-task-set-id";
 
-  // Controls whether to allow writing timestamps without zone info
-  public static final String HANDLE_TIMESTAMP_WITHOUT_TIMEZONE =
-      "handle-timestamp-without-timezone";
-
   public static final String OUTPUT_SPEC_ID = "output-spec-id";
 
   public static final String OVERWRITE_MODE = "overwrite-mode";
@@ -72,11 +68,21 @@ public class SparkWriteOptions {
 
   public static final String MERGE_SCHEMA = "merge-schema";
   public static final String SPARK_MERGE_SCHEMA = "mergeSchema";
-  public static final boolean MERGE_SCHEMA_DEFAULT = false;
 
   // Identifies snapshot from which to start validating conflicting changes
   public static final String VALIDATE_FROM_SNAPSHOT_ID = "validate-from-snapshot-id";
 
   // Isolation Level for DataFrame calls. Currently supported by overwritePartitions
   public static final String ISOLATION_LEVEL = "isolation-level";
+
+  // Controls write compress options
+  public static final String COMPRESSION_CODEC = "compression-codec";
+  public static final String COMPRESSION_LEVEL = "compression-level";
+  public static final String COMPRESSION_STRATEGY = "compression-strategy";
+
+  // Overrides the advisory partition size
+  public static final String ADVISORY_PARTITION_SIZE = "advisory-partition-size";
+
+  // Overrides the delete granularity
+  public static final String DELETE_GRANULARITY = "delete-granularity";
 }
