@@ -57,8 +57,8 @@ public class MigrateTableSparkAction extends BaseTableCreationSparkAction<Migrat
 
   private final StagingTableCatalog destCatalog;
   private final Identifier destTableIdent;
-  private final Identifier backupIdent;
 
+  private Identifier backupIdent;
   private boolean dropBackup = false;
   private ExecutorService executorService;
 
@@ -104,6 +104,12 @@ public class MigrateTableSparkAction extends BaseTableCreationSparkAction<Migrat
     return this;
   }
 
+  @Override
+  public MigrateTableSparkAction backupTableName(String tableName) {
+    this.backupIdent = Identifier.of(sourceTableIdent().namespace(), tableName);
+    return this;
+  }
+
   @Override
   public MigrateTableSparkAction executeWith(ExecutorService service) {
     this.executorService = service;
