@@ -53,7 +53,8 @@ public class ExpireSnapshotsProcedure extends BaseProcedure {
         ProcedureParameter.optional("retain_last", DataTypes.IntegerType),
         ProcedureParameter.optional("max_concurrent_deletes", DataTypes.IntegerType),
         ProcedureParameter.optional("stream_results", DataTypes.BooleanType),
-        ProcedureParameter.optional("snapshot_ids", DataTypes.createArrayType(DataTypes.LongType))
+        ProcedureParameter.optional("snapshot_ids", DataTypes.createArrayType(DataTypes.LongType)),
+        ProcedureParameter.optional("clean_expired_metadata", DataTypes.BooleanType)
       };
 
   private static final StructType OUTPUT_TYPE =
@@ -104,6 +105,7 @@ public class ExpireSnapshotsProcedure extends BaseProcedure {
     Integer maxConcurrentDeletes = args.isNullAt(3) ? null : args.getInt(3);
     Boolean streamResult = args.isNullAt(4) ? null : args.getBoolean(4);
     long[] snapshotIds = args.isNullAt(5) ? null : args.getArray(5).toLongArray();
+    Boolean cleanExpiredMetadata = args.isNullAt(6) ? null : args.getBoolean(6);
 
     Preconditions.checkArgument(
         maxConcurrentDeletes == null || maxConcurrentDeletes > 0,
@@ -148,6 +150,10 @@ public class ExpireSnapshotsProcedure extends BaseProcedure {
                 ExpireSnapshotsSparkAction.STREAM_RESULTS, Boolean.toString(streamResult));
           }
 
+          if (cleanExpiredMetadata != null) {
+            action.cleanExpiredMetadata(cleanExpiredMetadata);
+          }
+
           ExpireSnapshots.Result result = action.execute();
 
           return toOutputRows(result);
