@@ -63,6 +63,8 @@ public class RemoveOrphanFilesProcedure extends BaseProcedure {
         ProcedureParameter.optional("equal_schemes", STRING_MAP),
         ProcedureParameter.optional("equal_authorities", STRING_MAP),
         ProcedureParameter.optional("prefix_mismatch_mode", DataTypes.StringType),
+        // List files with prefix operations. Default is false.
+        ProcedureParameter.optional("prefix_listing", DataTypes.BooleanType)
       };
 
   private static final StructType OUTPUT_TYPE =
@@ -136,6 +138,8 @@ public class RemoveOrphanFilesProcedure extends BaseProcedure {
     PrefixMismatchMode prefixMismatchMode =
         args.isNullAt(8) ? null : PrefixMismatchMode.fromString(args.getString(8));
 
+    boolean prefixListing = args.isNullAt(9) ? false : args.getBoolean(9);
+
     return withIcebergTable(
         tableIdent,
         table -> {
@@ -182,6 +186,8 @@ public class RemoveOrphanFilesProcedure extends BaseProcedure {
             action.prefixMismatchMode(prefixMismatchMode);
           }
 
+          action.usePrefixListing(prefixListing);
+
           DeleteOrphanFiles.Result result = action.execute();
 
           return toOutputRows(result);
