@@ -73,6 +73,7 @@ abstract class BaseReader<T, TaskT extends ScanTask> implements Closeable {
   private final ScanTaskGroup<TaskT> taskGroup;
   private final Iterator<TaskT> tasks;
   private final DeleteCounter counter;
+  private final boolean cacheDeleteFilesOnExecutors;
 
   private Map<String, InputFile> lazyInputFiles;
   private CloseableIterator<T> currentIterator;
@@ -84,7 +85,8 @@ abstract class BaseReader<T, TaskT extends ScanTask> implements Closeable {
       ScanTaskGroup<TaskT> taskGroup,
       Schema tableSchema,
       Schema expectedSchema,
-      boolean caseSensitive) {
+      boolean caseSensitive,
+      boolean cacheDeleteFilesOnExecutors) {
     this.table = table;
     this.taskGroup = taskGroup;
     this.tasks = taskGroup.tasks().iterator();
@@ -96,6 +98,7 @@ abstract class BaseReader<T, TaskT extends ScanTask> implements Closeable {
     this.nameMapping =
         nameMappingString != null ? NameMappingParser.fromJson(nameMappingString) : null;
     this.counter = new DeleteCounter();
+    this.cacheDeleteFilesOnExecutors = cacheDeleteFilesOnExecutors;
   }
 
   protected abstract CloseableIterator<T> open(TaskT task);
@@ -110,6 +113,10 @@ abstract class BaseReader<T, TaskT extends ScanTask> implements Closeable {
     return caseSensitive;
   }
 
+  protected boolean cacheDeleteFilesOnExecutors() {
+    return cacheDeleteFilesOnExecutors;
+  }
+
   protected NameMapping nameMapping() {
     return nameMapping;
   }
@@ -221,7 +228,10 @@ abstract class BaseReader<T, TaskT extends ScanTask> implements Closeable {
 
     @Override
     protected DeleteLoader newDeleteLoader() {
-      return new CachingDeleteLoader(this::loadInputFile);
+      if (cacheDeleteFilesOnExecutors) {
+        return new CachingDeleteLoader(this::loadInputFile);
+      }
+      return new BaseDeleteLoader(this::loadInputFile);
     }
 
     private class CachingDeleteLoader extends BaseDeleteLoader {
