@@ -19,6 +19,7 @@
 package org.apache.iceberg.spark.source.metrics;
 
 import java.text.NumberFormat;
+import java.util.Locale;
 import org.apache.spark.sql.connector.metric.CustomMetric;
 
 public class NumDeletes implements CustomMetric {
@@ -42,6 +43,6 @@ public class NumDeletes implements CustomMetric {
       sum += taskMetric;
     }
 
-    return NumberFormat.getIntegerInstance().format(sum);
+    return NumberFormat.getIntegerInstance(Locale.ROOT).format(sum);
   }
 }
