@@ -79,11 +79,8 @@ import org.apache.spark.sql.types.Decimal;
 import org.apache.spark.sql.types.MapType;
 import org.apache.spark.sql.types.StructField;
 import org.apache.spark.sql.types.StructType;
-import org.apache.spark.sql.types.TimestampNTZType;
-import org.apache.spark.sql.types.TimestampType$;
 import org.apache.spark.sql.vectorized.ColumnarBatch;
 import org.apache.spark.unsafe.types.UTF8String;
-import org.junit.Assert;
 import scala.collection.Seq;
 
 public class TestHelpers {
@@ -116,28 +113,16 @@ public class TestHelpers {
     }
   }
 
-  public static void assertEqualsBatch(
-      Types.StructType struct, Iterator<Record> expected, ColumnarBatch batch) {
+  public static void assertEqualsBatchWithRows(
+      Types.StructType struct, Iterator<Row> expected, ColumnarBatch batch) {
     for (int rowId = 0; rowId < batch.numRows(); rowId++) {
-      InternalRow row = batch.getRow(rowId);
-      Record rec = expected.next();
-
       List<Types.NestedField> fields = struct.fields();
-      for (int readPos = 0; readPos < fields.size(); readPos += 1) {
-        Types.NestedField field = fields.get(readPos);
-        Field writeField = rec.getSchema().getField(field.name());
-
-        Type fieldType = field.type();
-        Object actualValue = row.isNullAt(readPos) ? null : row.get(readPos, convert(fieldType));
-
-        Object expectedValue;
-        if (writeField != null) {
-          int writePos = writeField.pos();
-          expectedValue = rec.get(writePos);
-        } else {
-          expectedValue = field.initialDefault();
-        }
-
+      InternalRow row = batch.getRow(rowId);
+      Row expectedRow = expected.next();
+      for (int i = 0; i < fields.size(); i += 1) {
+        Type fieldType = fields.get(i).type();
+        Object expectedValue = expectedRow.get(i);
+        Object actualValue = row.isNullAt(i) ? null : row.get(i, convert(fieldType));
         assertEqualsUnsafe(fieldType, expectedValue, actualValue);
       }
     }
@@ -169,7 +154,7 @@ public class TestHelpers {
         }
       }
 
-      Assert.assertNotNull("Should have a matching key", matchingKey);
+      assertThat(matchingKey).as("Should have a matching key").isNotNull();
       assertEqualsSafe(valueType, expected.get(expectedKey), actual.get(matchingKey));
     }
   }
@@ -189,14 +174,16 @@ public class TestHelpers {
       case LONG:
       case FLOAT:
       case DOUBLE:
-        Assert.assertEquals("Primitive value should be equal to expected", expected, actual);
+        assertThat(actual).as("Primitive value should be equal to expected").isEqualTo(expected);
         break;
       case DATE:
         assertThat(expected).as("Should be an int").isInstanceOf(Integer.class);
         assertThat(actual).as("Should be a Date").isInstanceOf(Date.class);
-        int daysFromEpoch = (Integer) expected;
-        LocalDate date = ChronoUnit.DAYS.addTo(EPOCH_DAY, daysFromEpoch);
-        Assert.assertEquals("ISO-8601 date should be equal", date.toString(), actual.toString());
+        LocalDate date = ChronoUnit.DAYS.addTo(EPOCH_DAY, (Integer) expected);
+        assertThat(actual)
+            .as("ISO-8601 date should be equal")
+            .asString()
+            .isEqualTo(String.valueOf(date));
         break;
       case TIMESTAMP:
         Types.TimestampType timestampType = (Types.TimestampType) type;
@@ -208,7 +195,7 @@ public class TestHelpers {
           Timestamp ts = (Timestamp) actual;
           // milliseconds from nanos has already been added by getTime
           long tsMicros = (ts.getTime() * 1000) + ((ts.getNanos() / 1000) % 1000);
-          Assert.assertEquals("Timestamp micros should be equal", expected, tsMicros);
+          assertThat(tsMicros).as("Timestamp micros should be equal").isEqualTo(expected);
         } else {
           assertThat(actual).as("Should be a LocalDateTime").isInstanceOf(LocalDateTime.class);
 
@@ -216,17 +203,18 @@ public class TestHelpers {
           Instant instant = ts.toInstant(ZoneOffset.UTC);
           // milliseconds from nanos has already been added by getTime
           long tsMicros = (instant.toEpochMilli() * 1000) + ((ts.getNano() / 1000) % 1000);
-          Assert.assertEquals("Timestamp micros should be equal", expected, tsMicros);
+          assertThat(tsMicros).as("Timestamp micros should be equal").isEqualTo(expected);
         }
         break;
       case STRING:
-        assertThat(actual).as("Should be a String").isInstanceOf(String.class);
-        Assert.assertEquals("Strings should be equal", String.valueOf(expected), actual);
+        assertThat(actual).isInstanceOf(String.class).isEqualTo(String.valueOf(expected));
         break;
       case UUID:
         assertThat(expected).as("Should expect a UUID").isInstanceOf(UUID.class);
-        assertThat(actual).as("Should be a String").isInstanceOf(String.class);
-        Assert.assertEquals("UUID string representation should match", expected.toString(), actual);
+        assertThat(actual)
+            .isInstanceOf(String.class)
+            .asString()
+            .isEqualTo(String.valueOf(expected));
         break;
       case FIXED:
         // generated data is written using Avro or Parquet/Avro so generated rows use
@@ -242,19 +230,15 @@ public class TestHelpers {
               "Invalid expected value, not byte[] or Fixed: " + expected);
         }
 
-        assertThat(actual).as("Should be a byte[]").isInstanceOf(byte[].class);
-        assertThat(actual).as("Bytes should match").isEqualTo(expectedBytes);
+        assertThat(actual).isInstanceOf(byte[].class).isEqualTo(expectedBytes);
         break;
       case BINARY:
         assertThat(expected).as("Should expect a ByteBuffer").isInstanceOf(ByteBuffer.class);
-        assertThat(actual).as("Should be a byte[]").isInstanceOf(byte[].class);
-        Assert.assertArrayEquals(
-            "Bytes should match", ((ByteBuffer) expected).array(), (byte[]) actual);
+        assertThat(actual).isInstanceOf(byte[].class).isEqualTo(((ByteBuffer) expected).array());
         break;
       case DECIMAL:
         assertThat(expected).as("Should expect a BigDecimal").isInstanceOf(BigDecimal.class);
-        assertThat(actual).as("Should be a BigDecimal").isInstanceOf(BigDecimal.class);
-        Assert.assertEquals("BigDecimals should be equal", expected, actual);
+        assertThat(actual).isInstanceOf(BigDecimal.class).isEqualTo(expected);
         break;
       case STRUCT:
         assertThat(expected).as("Should expect a Record").isInstanceOf(Record.class);
@@ -340,20 +324,19 @@ public class TestHelpers {
       case LONG:
         assertThat(actual).as("Should be a long").isInstanceOf(Long.class);
         if (expected instanceof Integer) {
-          Assert.assertEquals("Values didn't match", ((Number) expected).longValue(), actual);
+          assertThat(actual).as("Values didn't match").isEqualTo(((Number) expected).longValue());
         } else {
-          Assert.assertEquals("Primitive value should be equal to expected", expected, actual);
+          assertThat(actual).as("Primitive value should be equal to expected").isEqualTo(expected);
         }
         break;
       case DOUBLE:
         assertThat(actual).as("Should be a double").isInstanceOf(Double.class);
         if (expected instanceof Float) {
-          Assert.assertEquals(
-              "Values didn't match",
-              Double.doubleToLongBits(((Number) expected).doubleValue()),
-              Double.doubleToLongBits((double) actual));
+          assertThat(Double.doubleToLongBits((double) actual))
+              .as("Values didn't match")
+              .isEqualTo(Double.doubleToLongBits(((Number) expected).doubleValue()));
         } else {
-          Assert.assertEquals("Primitive value should be equal to expected", expected, actual);
+          assertThat(actual).as("Primitive value should be equal to expected").isEqualTo(expected);
         }
         break;
       case INTEGER:
@@ -361,17 +344,17 @@ public class TestHelpers {
       case BOOLEAN:
       case DATE:
       case TIMESTAMP:
-        Assert.assertEquals("Primitive value should be equal to expected", expected, actual);
+        assertThat(actual).as("Primitive value should be equal to expected").isEqualTo(expected);
         break;
       case STRING:
-        assertThat(actual).as("Should be a UTF8String").isInstanceOf(UTF8String.class);
-        Assert.assertEquals("Strings should be equal", expected, actual.toString());
+        assertThat(actual).isInstanceOf(UTF8String.class).asString().isEqualTo(expected);
         break;
       case UUID:
         assertThat(expected).as("Should expect a UUID").isInstanceOf(UUID.class);
-        assertThat(actual).as("Should be a UTF8String").isInstanceOf(UTF8String.class);
-        Assert.assertEquals(
-            "UUID string representation should match", expected.toString(), actual.toString());
+        assertThat(actual)
+            .isInstanceOf(UTF8String.class)
+            .asString()
+            .isEqualTo(String.valueOf(expected));
         break;
       case FIXED:
         // generated data is written using Avro or Parquet/Avro so generated rows use
@@ -392,15 +375,14 @@ public class TestHelpers {
         break;
       case BINARY:
         assertThat(expected).as("Should expect a ByteBuffer").isInstanceOf(ByteBuffer.class);
-        assertThat(actual).as("Should be a byte[]").isInstanceOf(byte[].class);
-        Assert.assertArrayEquals(
-            "Bytes should match", ((ByteBuffer) expected).array(), (byte[]) actual);
+        assertThat(actual).isInstanceOf(byte[].class).isEqualTo(((ByteBuffer) expected).array());
         break;
       case DECIMAL:
         assertThat(expected).as("Should expect a BigDecimal").isInstanceOf(BigDecimal.class);
         assertThat(actual).as("Should be a Decimal").isInstanceOf(Decimal.class);
-        Assert.assertEquals(
-            "BigDecimals should be equal", expected, ((Decimal) actual).toJavaBigDecimal());
+        assertThat(((Decimal) actual).toJavaBigDecimal())
+            .as("BigDecimals should be equal")
+            .isEqualTo(expected);
         break;
       case STRUCT:
         assertThat(expected).as("Should expect a Record").isInstanceOf(Record.class);
@@ -436,7 +418,7 @@ public class TestHelpers {
   public static void assertEquals(
       String prefix, Types.StructType type, InternalRow expected, Row actual) {
     if (expected == null || actual == null) {
-      Assert.assertEquals(prefix, expected, actual);
+      assertThat(actual).as(prefix).isEqualTo(expected);
     } else {
       List<Types.NestedField> fields = type.fields();
       for (int c = 0; c < fields.size(); ++c) {
@@ -452,10 +434,9 @@ public class TestHelpers {
           case DECIMAL:
           case DATE:
           case TIMESTAMP:
-            Assert.assertEquals(
-                prefix + "." + fieldName + " - " + childType,
-                getValue(expected, c, childType),
-                getPrimitiveValue(actual, c, childType));
+            assertThat(getPrimitiveValue(actual, c, childType))
+                .as(prefix + "." + fieldName + " - " + childType)
+                .isEqualTo(getValue(expected, c, childType));
             break;
           case UUID:
           case FIXED:
@@ -499,9 +480,9 @@ public class TestHelpers {
   private static void assertEqualsLists(
       String prefix, Types.ListType type, ArrayData expected, List actual) {
     if (expected == null || actual == null) {
-      Assert.assertEquals(prefix, expected, actual);
+      assertThat(actual).as(prefix).isEqualTo(expected);
     } else {
-      Assert.assertEquals(prefix + " length", expected.numElements(), actual.size());
+      assertThat(actual).as(prefix + "length").hasSize(expected.numElements());
       Type childType = type.elementType();
       for (int e = 0; e < expected.numElements(); ++e) {
         switch (childType.typeId()) {
@@ -514,10 +495,10 @@ public class TestHelpers {
           case DECIMAL:
           case DATE:
           case TIMESTAMP:
-            Assert.assertEquals(
-                prefix + ".elem " + e + " - " + childType,
-                getValue(expected, e, childType),
-                actual.get(e));
+            assertThat(actual)
+                .as(prefix + ".elem " + e + " - " + childType)
+                .element(e)
+                .isEqualTo(getValue(expected, e, childType));
             break;
           case UUID:
           case FIXED:
@@ -561,21 +542,20 @@ public class TestHelpers {
   private static void assertEqualsMaps(
       String prefix, Types.MapType type, MapData expected, Map<?, ?> actual) {
     if (expected == null || actual == null) {
-      Assert.assertEquals(prefix, expected, actual);
+      assertThat(actual).as(prefix).isEqualTo(expected);
     } else {
       Type keyType = type.keyType();
       Type valueType = type.valueType();
       ArrayData expectedKeyArray = expected.keyArray();
       ArrayData expectedValueArray = expected.valueArray();
-      Assert.assertEquals(prefix + " length", expected.numElements(), actual.size());
+      assertThat(actual).as(prefix + " length").hasSize(expectedKeyArray.numElements());
       for (int e = 0; e < expected.numElements(); ++e) {
         Object expectedKey = getValue(expectedKeyArray, e, keyType);
         Object actualValue = actual.get(expectedKey);
         if (actualValue == null) {
-          Assert.assertEquals(
-              prefix + ".key=" + expectedKey + " has null",
-              true,
-              expected.valueArray().isNullAt(e));
+          assertThat(expected.valueArray().isNullAt(e))
+              .as(prefix + ".key=" + expectedKey + " has null")
+              .isTrue();
         } else {
           switch (valueType.typeId()) {
             case BOOLEAN:
@@ -587,10 +567,9 @@ public class TestHelpers {
             case DECIMAL:
             case DATE:
             case TIMESTAMP:
-              Assert.assertEquals(
-                  prefix + ".key=" + expectedKey + " - " + valueType,
-                  getValue(expectedValueArray, e, valueType),
-                  actual.get(expectedKey));
+              assertThat(actual.get(expectedKey))
+                  .as(prefix + ".key=" + expectedKey + " - " + valueType)
+                  .isEqualTo(getValue(expectedValueArray, e, valueType));
               break;
             case UUID:
             case FIXED:
@@ -720,11 +699,7 @@ public class TestHelpers {
   }
 
   private static void assertEqualBytes(String context, byte[] expected, byte[] actual) {
-    if (expected == null || actual == null) {
-      Assert.assertEquals(context, expected, actual);
-    } else {
-      Assert.assertArrayEquals(context, expected, actual);
-    }
+    assertThat(actual).as(context).isEqualTo(expected);
   }
 
   static void assertEquals(Schema schema, Object expected, Object actual) {
@@ -764,21 +739,18 @@ public class TestHelpers {
     } else if (type instanceof BinaryType) {
       assertEqualBytes(context, (byte[]) expected, (byte[]) actual);
     } else {
-      Assert.assertEquals("Value should match expected: " + context, expected, actual);
+      assertThat(actual).as("Value should match expected: " + context).isEqualTo(expected);
     }
   }
 
   private static void assertEquals(
       String context, StructType struct, InternalRow expected, InternalRow actual) {
-    Assert.assertEquals("Should have correct number of fields", struct.size(), actual.numFields());
+    assertThat(actual.numFields())
+        .as("Should have correct number of fields")
+        .isEqualTo(struct.size());
     for (int i = 0; i < actual.numFields(); i += 1) {
       StructField field = struct.fields()[i];
       DataType type = field.dataType();
-      // ColumnarRow.get doesn't support TimestampNTZType, causing tests to fail. the representation
-      // is identical to TimestampType so this uses that type to validate.
-      if (type instanceof TimestampNTZType) {
-        type = TimestampType$.MODULE$;
-      }
 
       assertEquals(
           context + "." + field.name(),
@@ -790,8 +762,9 @@ public class TestHelpers {
 
   private static void assertEquals(
       String context, ArrayType array, ArrayData expected, ArrayData actual) {
-    Assert.assertEquals(
-        "Should have the same number of elements", expected.numElements(), actual.numElements());
+    assertThat(actual.numElements())
+        .as("Should have the same number of elements")
+        .isEqualTo(expected.numElements());
     DataType type = array.elementType();
     for (int i = 0; i < actual.numElements(); i += 1) {
       assertEquals(
@@ -803,8 +776,9 @@ public class TestHelpers {
   }
 
   private static void assertEquals(String context, MapType map, MapData expected, MapData actual) {
-    Assert.assertEquals(
-        "Should have the same number of elements", expected.numElements(), actual.numElements());
+    assertThat(actual.numElements())
+        .as("Should have the same number of elements")
+        .isEqualTo(expected.numElements());
 
     DataType keyType = map.keyType();
     ArrayData expectedKeys = expected.keyArray();
