@@ -22,12 +22,14 @@ import static org.apache.iceberg.TableProperties.SPARK_WRITE_PARTITIONED_FANOUT_
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
 
 import java.io.File;
-import java.io.IOException;
+import java.net.InetAddress;
+import java.nio.file.Path;
 import java.util.List;
 import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
@@ -36,6 +38,9 @@ import org.apache.iceberg.DataFile;
 import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.ManifestFile;
 import org.apache.iceberg.ManifestFiles;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.SnapshotRef;
@@ -54,64 +59,65 @@ import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SaveMode;
 import org.apache.spark.sql.SparkSession;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestSparkDataWrite {
   private static final Configuration CONF = new Configuration();
-  private final FileFormat format;
-  private final String branch;
+
+  @Parameter(index = 0)
+  private FileFormat format;
+
+  @Parameter(index = 1)
+  private String branch;
+
   private static SparkSession spark = null;
   private static final Schema SCHEMA =
       new Schema(
           optional(1, "id", Types.IntegerType.get()), optional(2, "data", Types.StringType.get()));
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir private Path temp;
 
-  @Parameterized.Parameters(name = "format = {0}, branch = {1}")
-  public static Object[] parameters() {
-    return new Object[] {
-      new Object[] {"parquet", null},
-      new Object[] {"parquet", "main"},
-      new Object[] {"parquet", "testBranch"},
-      new Object[] {"avro", null},
-      new Object[] {"orc", "testBranch"}
+  @Parameters(name = "format = {0}, branch = {1}")
+  public static Object[][] parameters() {
+    return new Object[][] {
+      new Object[] {FileFormat.PARQUET, null},
+      new Object[] {FileFormat.PARQUET, "main"},
+      new Object[] {FileFormat.PARQUET, "testBranch"},
+      new Object[] {FileFormat.AVRO, null},
+      new Object[] {FileFormat.ORC, "testBranch"}
     };
   }
 
-  @BeforeClass
+  @BeforeAll
   public static void startSpark() {
-    TestSparkDataWrite.spark = SparkSession.builder().master("local[2]").getOrCreate();
+    TestSparkDataWrite.spark =
+        SparkSession.builder()
+            .master("local[2]")
+            .config("spark.driver.host", InetAddress.getLoopbackAddress().getHostAddress())
+            .getOrCreate();
   }
 
-  @Parameterized.AfterParam
-  public static void clearSourceCache() {
+  @AfterEach
+  public void clearSourceCache() {
     ManualSource.clearTables();
   }
 
-  @AfterClass
+  @AfterAll
   public static void stopSpark() {
     SparkSession currentSpark = TestSparkDataWrite.spark;
     TestSparkDataWrite.spark = null;
     currentSpark.stop();
   }
 
-  public TestSparkDataWrite(String format, String branch) {
-    this.format = FileFormat.fromString(format);
-    this.branch = branch;
-  }
-
-  @Test
-  public void testBasicWrite() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testBasicWrite() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -139,31 +145,30 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
     for (ManifestFile manifest :
         SnapshotUtil.latestSnapshot(table, branch).allManifests(table.io())) {
       for (DataFile file : ManifestFiles.read(manifest, table.io())) {
         // TODO: avro not support split
         if (!format.equals(FileFormat.AVRO)) {
-          Assert.assertNotNull("Split offsets not present", file.splitOffsets());
+          assertThat(file.splitOffsets()).as("Split offsets not present").isNotNull();
         }
-        Assert.assertEquals("Should have reported record count as 1", 1, file.recordCount());
+        assertThat(file.recordCount()).as("Should have reported record count as 1").isEqualTo(1);
         // TODO: append more metric info
         if (format.equals(FileFormat.PARQUET)) {
-          Assert.assertNotNull("Column sizes metric not present", file.columnSizes());
-          Assert.assertNotNull("Counts metric not present", file.valueCounts());
-          Assert.assertNotNull("Null value counts metric not present", file.nullValueCounts());
-          Assert.assertNotNull("Lower bounds metric not present", file.lowerBounds());
-          Assert.assertNotNull("Upper bounds metric not present", file.upperBounds());
+          assertThat(file.columnSizes()).as("Column sizes metric not present").isNotNull();
+          assertThat(file.valueCounts()).as("Counts metric not present").isNotNull();
+          assertThat(file.nullValueCounts()).as("Null value counts metric not present").isNotNull();
+          assertThat(file.lowerBounds()).as("Lower bounds metric not present").isNotNull();
+          assertThat(file.upperBounds()).as("Upper bounds metric not present").isNotNull();
         }
       }
     }
   }
 
-  @Test
-  public void testAppend() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testAppend() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -209,13 +214,12 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
   }
 
-  @Test
-  public void testEmptyOverwrite() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testEmptyOverwrite() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -255,13 +259,12 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
   }
 
-  @Test
-  public void testOverwrite() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testOverwrite() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -308,13 +311,12 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
   }
 
-  @Test
-  public void testUnpartitionedOverwrite() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testUnpartitionedOverwrite() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -351,13 +353,12 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
   }
 
-  @Test
-  public void testUnpartitionedCreateWithTargetFileSizeViaTableProperties() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testUnpartitionedCreateWithTargetFileSizeViaTableProperties() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -391,8 +392,7 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
 
     List<DataFile> files = Lists.newArrayList();
     for (ManifestFile manifest :
@@ -402,33 +402,37 @@ public class TestSparkDataWrite {
       }
     }
 
-    Assert.assertEquals("Should have 4 DataFiles", 4, files.size());
-    Assert.assertTrue(
-        "All DataFiles contain 1000 rows", files.stream().allMatch(d -> d.recordCount() == 1000));
+    assertThat(files)
+        .hasSize(4)
+        .allSatisfy(
+            dataFile ->
+                assertThat(dataFile.recordCount())
+                    .as("All DataFiles contain 1000 rows")
+                    .isEqualTo(1000));
   }
 
-  @Test
-  public void testPartitionedCreateWithTargetFileSizeViaOption() throws IOException {
+  @TestTemplate
+  public void testPartitionedCreateWithTargetFileSizeViaOption() {
     partitionedCreateWithTargetFileSizeViaOption(IcebergOptionsType.NONE);
   }
 
-  @Test
-  public void testPartitionedFanoutCreateWithTargetFileSizeViaOption() throws IOException {
+  @TestTemplate
+  public void testPartitionedFanoutCreateWithTargetFileSizeViaOption() {
     partitionedCreateWithTargetFileSizeViaOption(IcebergOptionsType.TABLE);
   }
 
-  @Test
-  public void testPartitionedFanoutCreateWithTargetFileSizeViaOption2() throws IOException {
+  @TestTemplate
+  public void testPartitionedFanoutCreateWithTargetFileSizeViaOption2() {
     partitionedCreateWithTargetFileSizeViaOption(IcebergOptionsType.JOB);
   }
 
-  @Test
-  public void testWriteProjection() throws IOException {
-    Assume.assumeTrue(
-        "Not supported in Spark 3; analysis requires all columns are present",
-        spark.version().startsWith("2"));
+  @TestTemplate
+  public void testWriteProjection() {
+    assumeThat(spark.version())
+        .as("Not supported in Spark 3; analysis requires all columns are present")
+        .startsWith("2");
 
-    File parent = temp.newFolder(format.toString());
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -456,17 +460,16 @@ public class TestSparkDataWrite {
 
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
   }
 
-  @Test
-  public void testWriteProjectionWithMiddle() throws IOException {
-    Assume.assumeTrue(
-        "Not supported in Spark 3; analysis requires all columns are present",
-        spark.version().startsWith("2"));
+  @TestTemplate
+  public void testWriteProjectionWithMiddle() {
+    assumeThat(spark.version())
+        .as("Not supported in Spark 3; analysis requires all columns are present")
+        .startsWith("2");
 
-    File parent = temp.newFolder(format.toString());
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -501,13 +504,12 @@ public class TestSparkDataWrite {
 
     List<ThreeColumnRecord> actual =
         result.orderBy("c1").as(Encoders.bean(ThreeColumnRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
   }
 
-  @Test
-  public void testViewsReturnRecentResults() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testViewsReturnRecentResults() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -537,8 +539,7 @@ public class TestSparkDataWrite {
     List<SimpleRecord> actual1 =
         spark.table("tmp").as(Encoders.bean(SimpleRecord.class)).collectAsList();
     List<SimpleRecord> expected1 = Lists.newArrayList(new SimpleRecord(1, "a"));
-    Assert.assertEquals("Number of rows should match", expected1.size(), actual1.size());
-    Assert.assertEquals("Result rows should match", expected1, actual1);
+    assertThat(actual1).hasSameSizeAs(expected1).isEqualTo(expected1);
 
     df.select("id", "data")
         .write()
@@ -551,13 +552,11 @@ public class TestSparkDataWrite {
         spark.table("tmp").as(Encoders.bean(SimpleRecord.class)).collectAsList();
     List<SimpleRecord> expected2 =
         Lists.newArrayList(new SimpleRecord(1, "a"), new SimpleRecord(1, "a"));
-    Assert.assertEquals("Number of rows should match", expected2.size(), actual2.size());
-    Assert.assertEquals("Result rows should match", expected2, actual2);
+    assertThat(actual2).hasSameSizeAs(expected2).isEqualTo(expected2);
   }
 
-  public void partitionedCreateWithTargetFileSizeViaOption(IcebergOptionsType option)
-      throws IOException {
-    File parent = temp.newFolder(format.toString());
+  public void partitionedCreateWithTargetFileSizeViaOption(IcebergOptionsType option) {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "test");
     String targetLocation = locationWithBranch(location);
 
@@ -619,9 +618,8 @@ public class TestSparkDataWrite {
     Dataset<Row> result = spark.read().format("iceberg").load(targetLocation);
 
     List<SimpleRecord> actual =
-        result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Number of rows should match", expected.size(), actual.size());
-    Assert.assertEquals("Result rows should match", expected, actual);
+        result.orderBy("id", "data").as(Encoders.bean(SimpleRecord.class)).collectAsList();
+    assertThat(actual).hasSameSizeAs(expected).isEqualTo(expected);
 
     List<DataFile> files = Lists.newArrayList();
     for (ManifestFile manifest :
@@ -630,15 +628,18 @@ public class TestSparkDataWrite {
         files.add(file);
       }
     }
-
-    Assert.assertEquals("Should have 8 DataFiles", 8, files.size());
-    Assert.assertTrue(
-        "All DataFiles contain 1000 rows", files.stream().allMatch(d -> d.recordCount() == 1000));
+    assertThat(files)
+        .hasSize(8)
+        .allSatisfy(
+            dataFile ->
+                assertThat(dataFile.recordCount())
+                    .as("All DataFiles contain 1000 rows")
+                    .isEqualTo(1000));
   }
 
-  @Test
-  public void testCommitUnknownException() throws IOException {
-    File parent = temp.newFolder(format.toString());
+  @TestTemplate
+  public void testCommitUnknownException() {
+    File parent = temp.resolve(format.toString()).toFile();
     File location = new File(parent, "commitunknown");
     String targetLocation = locationWithBranch(location);
 
@@ -706,10 +707,8 @@ public class TestSparkDataWrite {
     Dataset<Row> result = spark.read().format("iceberg").load(targetLocation);
     List<SimpleRecord> actual =
         result.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals(
-        "Number of rows should match", records.size() + records2.size(), actual.size());
     assertThat(actual)
-        .describedAs("Result rows should match")
+        .hasSize(records.size() + records2.size())
         .containsExactlyInAnyOrder(
             ImmutableList.<SimpleRecord>builder()
                 .addAll(records)
