@@ -19,7 +19,6 @@
 package org.apache.iceberg.spark.source;
 
 import java.util.List;
-import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.io.FileWriterFactory;
 import org.apache.iceberg.io.TestRollingFileWriters;
@@ -30,10 +29,6 @@ import org.apache.spark.unsafe.types.UTF8String;
 
 public class TestSparkRollingFileWriters extends TestRollingFileWriters<InternalRow> {
 
-  public TestSparkRollingFileWriters(FileFormat fileFormat, boolean partitioned) {
-    super(fileFormat, partitioned);
-  }
-
   @Override
   protected FileWriterFactory<InternalRow> newWriterFactory(
       Schema dataSchema,
