@@ -24,7 +24,7 @@ import static org.apache.iceberg.types.Types.NestedField.required;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
-import java.io.IOException;
+import java.net.InetAddress;
 import java.nio.ByteBuffer;
 import java.nio.file.Path;
 import java.util.List;
@@ -80,7 +80,11 @@ public class TestWriteMetricsConfig {
 
   @BeforeAll
   public static void startSpark() {
-    TestWriteMetricsConfig.spark = SparkSession.builder().master("local[2]").getOrCreate();
+    TestWriteMetricsConfig.spark =
+        SparkSession.builder()
+            .master("local[2]")
+            .config("spark.driver.host", InetAddress.getLoopbackAddress().getHostAddress())
+            .getOrCreate();
     TestWriteMetricsConfig.sc = JavaSparkContext.fromSparkContext(spark.sparkContext());
   }
 
@@ -93,7 +97,7 @@ public class TestWriteMetricsConfig {
   }
 
   @Test
-  public void testFullMetricsCollectionForParquet() throws IOException {
+  public void testFullMetricsCollectionForParquet() {
     String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
@@ -116,7 +120,6 @@ public class TestWriteMetricsConfig {
 
     for (FileScanTask task : table.newScan().includeColumnStats().planFiles()) {
       DataFile file = task.file();
-
       assertThat(file.nullValueCounts()).hasSize(2);
       assertThat(file.valueCounts()).hasSize(2);
       assertThat(file.lowerBounds()).hasSize(2);
@@ -125,7 +128,7 @@ public class TestWriteMetricsConfig {
   }
 
   @Test
-  public void testCountMetricsCollectionForParquet() throws IOException {
+  public void testCountMetricsCollectionForParquet() {
     String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
@@ -156,7 +159,7 @@ public class TestWriteMetricsConfig {
   }
 
   @Test
-  public void testNoMetricsCollectionForParquet() throws IOException {
+  public void testNoMetricsCollectionForParquet() {
     String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
@@ -187,7 +190,7 @@ public class TestWriteMetricsConfig {
   }
 
   @Test
-  public void testCustomMetricCollectionForParquet() throws IOException {
+  public void testCustomMetricCollectionForParquet() {
     String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
@@ -221,7 +224,7 @@ public class TestWriteMetricsConfig {
   }
 
   @Test
-  public void testBadCustomMetricCollectionForParquet() throws IOException {
+  public void testBadCustomMetricCollectionForParquet() {
     String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
@@ -237,7 +240,7 @@ public class TestWriteMetricsConfig {
   }
 
   @Test
-  public void testCustomMetricCollectionForNestedParquet() throws IOException {
+  public void testCustomMetricCollectionForNestedParquet() {
     String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
@@ -271,16 +274,12 @@ public class TestWriteMetricsConfig {
       Map<Integer, Long> nullValueCounts = file.nullValueCounts();
       assertThat(nullValueCounts)
           .hasSize(3)
-          .containsKey(longCol.fieldId())
-          .containsKey(recordId.fieldId())
-          .containsKey(recordData.fieldId());
+          .containsKeys(longCol.fieldId(), recordId.fieldId(), recordData.fieldId());
 
       Map<Integer, Long> valueCounts = file.valueCounts();
       assertThat(valueCounts)
           .hasSize(3)
-          .containsKey(longCol.fieldId())
-          .containsKey(recordId.fieldId())
-          .containsKey(recordData.fieldId());
+          .containsKeys(longCol.fieldId(), recordId.fieldId(), recordData.fieldId());
 
       Map<Integer, ByteBuffer> lowerBounds = file.lowerBounds();
       assertThat(lowerBounds).hasSize(2).containsKey(recordId.fieldId());
