@@ -398,7 +398,7 @@ public abstract class SparkRowLevelOperationsTestBase extends ExtensionsTestBase
       DataWriter<GenericRecord> dataWriter =
           Parquet.writeData(file)
               .forTable(table)
-              .createWriterFunc(GenericParquetWriter::buildWriter)
+              .createWriterFunc(GenericParquetWriter::create)
               .overwrite()
               .build();
 
