@@ -21,8 +21,8 @@ package org.apache.iceberg.spark.extensions;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
-import java.util.Map;
 import org.apache.iceberg.IsolationLevel;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
@@ -31,18 +31,15 @@ import org.apache.iceberg.spark.source.SimpleRecord;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.functions;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestConflictValidation extends SparkExtensionsTestBase {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestConflictValidation extends ExtensionsTestBase {
 
-  public TestConflictValidation(
-      String catalogName, String implementation, Map<String, String> config) {
-    super(catalogName, implementation, config);
-  }
-
-  @Before
+  @BeforeEach
   public void createTables() {
     sql(
         "CREATE TABLE %s (id int, data string) USING iceberg "
@@ -54,12 +51,12 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
     sql("INSERT INTO %s VALUES (1, 'a'), (2, 'b'), (3, 'c')", tableName);
   }
 
-  @After
+  @AfterEach
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testOverwriteFilterSerializableIsolation() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
     long snapshotId = table.currentSnapshot().snapshotId();
@@ -91,7 +88,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwrite(functions.col("id").equalTo(1));
   }
 
-  @Test
+  @TestTemplate
   public void testOverwriteFilterSerializableIsolation2() throws Exception {
     List<SimpleRecord> records =
         Lists.newArrayList(new SimpleRecord(1, "a"), new SimpleRecord(1, "b"));
@@ -128,7 +125,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwrite(functions.col("id").equalTo(1));
   }
 
-  @Test
+  @TestTemplate
   public void testOverwriteFilterSerializableIsolation3() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
     long snapshotId = table.currentSnapshot().snapshotId();
@@ -162,7 +159,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwrite(functions.col("id").equalTo(1));
   }
 
-  @Test
+  @TestTemplate
   public void testOverwriteFilterNoSnapshotIdValidation() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
 
@@ -193,7 +190,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwrite(functions.col("id").equalTo(1));
   }
 
-  @Test
+  @TestTemplate
   public void testOverwriteFilterSnapshotIsolation() throws Exception {
     List<SimpleRecord> records =
         Lists.newArrayList(new SimpleRecord(1, "a"), new SimpleRecord(1, "b"));
@@ -230,7 +227,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwrite(functions.col("id").equalTo(1));
   }
 
-  @Test
+  @TestTemplate
   public void testOverwriteFilterSnapshotIsolation2() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
     long snapshotId = table.currentSnapshot().snapshotId();
@@ -247,7 +244,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwrite(functions.col("id").equalTo(1));
   }
 
-  @Test
+  @TestTemplate
   public void testOverwritePartitionSerializableIsolation() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
     final long snapshotId = table.currentSnapshot().snapshotId();
@@ -279,7 +276,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwritePartitions();
   }
 
-  @Test
+  @TestTemplate
   public void testOverwritePartitionSnapshotIsolation() throws Exception {
     List<SimpleRecord> records =
         Lists.newArrayList(new SimpleRecord(1, "a"), new SimpleRecord(1, "b"));
@@ -314,7 +311,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwritePartitions();
   }
 
-  @Test
+  @TestTemplate
   public void testOverwritePartitionSnapshotIsolation2() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
     final long snapshotId = table.currentSnapshot().snapshotId();
@@ -348,7 +345,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwritePartitions();
   }
 
-  @Test
+  @TestTemplate
   public void testOverwritePartitionSnapshotIsolation3() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
     final long snapshotId = table.currentSnapshot().snapshotId();
@@ -365,7 +362,7 @@ public class TestConflictValidation extends SparkExtensionsTestBase {
         .overwritePartitions();
   }
 
-  @Test
+  @TestTemplate
   public void testOverwritePartitionNoSnapshotIdValidation() throws Exception {
     Table table = validationCatalog.loadTable(tableIdent);
 
