@@ -131,11 +131,16 @@ public class TestStoragePartitionedJoinsInRowLevelOperations extends ExtensionsT
           SparkPlan plan =
               executeAndKeepPlan(
                   "DELETE FROM %s t WHERE "
-                      + "EXISTS (SELECT 1 FROM %s s WHERE t.id = s.id AND t.dep = s.dep) AND "
-                      + "dep = 'hr'",
+                      + "EXISTS (SELECT 1 FROM %s s WHERE t.id = s.id AND t.dep = s.dep)",
                   tableName, tableName(OTHER_TABLE_NAME));
           String planAsString = plan.toString();
-          assertThat(planAsString).doesNotContain("Exchange");
+          if (mode == COPY_ON_WRITE) {
+            int actualNumShuffles = StringUtils.countMatches(planAsString, "Exchange");
+            assertThat(actualNumShuffles).as("Should be 1 shuffle with SPJ").isEqualTo(1);
+            assertThat(planAsString).contains("Exchange hashpartitioning(_file");
+          } else {
+            assertThat(planAsString).doesNotContain("Exchange");
+          }
         });
 
     ImmutableList<Object[]> expectedRows =
@@ -194,11 +199,16 @@ public class TestStoragePartitionedJoinsInRowLevelOperations extends ExtensionsT
           SparkPlan plan =
               executeAndKeepPlan(
                   "UPDATE %s t SET salary = -1 WHERE "
-                      + "EXISTS (SELECT 1 FROM %s s WHERE t.id = s.id AND t.dep = s.dep) AND "
-                      + "dep = 'hr'",
+                      + "EXISTS (SELECT 1 FROM %s s WHERE t.id = s.id AND t.dep = s.dep)",
                   tableName, tableName(OTHER_TABLE_NAME));
           String planAsString = plan.toString();
-          assertThat(planAsString).doesNotContain("Exchange");
+          if (mode == COPY_ON_WRITE) {
+            int actualNumShuffles = StringUtils.countMatches(planAsString, "Exchange");
+            assertThat(actualNumShuffles).as("Should be 1 shuffle with SPJ").isEqualTo(1);
+            assertThat(planAsString).contains("Exchange hashpartitioning(_file");
+          } else {
+            assertThat(planAsString).doesNotContain("Exchange");
+          }
         });
 
     ImmutableList<Object[]> expectedRows =
