@@ -101,6 +101,7 @@ public class Spark3Util {
   private static final Set<String> RESERVED_PROPERTIES =
       ImmutableSet.of(TableCatalog.PROP_LOCATION, TableCatalog.PROP_PROVIDER);
   private static final Joiner DOT = Joiner.on(".");
+  private static final String HIVE_NULL = "__HIVE_DEFAULT_PARTITION__";
 
   private Spark3Util() {}
 
@@ -233,6 +234,13 @@ public class Spark3Util {
         add.isNullable(),
         "Incompatible change: cannot add required column: %s",
         leafName(add.fieldNames()));
+    if (add.defaultValue() != null) {
+      throw new UnsupportedOperationException(
+          String.format(
+              "Cannot add column %s since setting default values in Spark is currently unsupported",
+              leafName(add.fieldNames())));
+    }
+
     Type type = SparkSchemaUtil.convert(add.dataType());
     pendingUpdate.addColumn(
         parentName(add.fieldNames()), leafName(add.fieldNames()), type, add.comment());
@@ -946,7 +954,7 @@ public class Spark3Util {
                         Object catalystValue = partition.values().get(fieldIndex, field.dataType());
                         Object value =
                             CatalystTypeConverters.convertToScala(catalystValue, field.dataType());
-                        values.put(field.name(), String.valueOf(value));
+                        values.put(field.name(), (value == null) ? HIVE_NULL : value.toString());
                       });
 
               FileStatusWithMetadata fileStatus =
