@@ -24,7 +24,6 @@ import org.apache.spark.sql.catalyst.analysis.NoSuchNamespaceException;
 import org.apache.spark.sql.connector.catalog.FunctionCatalog;
 import org.apache.spark.sql.connector.catalog.Identifier;
 import org.apache.spark.sql.connector.catalog.functions.UnboundFunction;
-import scala.Option;
 
 interface SupportsFunctions extends FunctionCatalog {
 
@@ -36,6 +35,7 @@ interface SupportsFunctions extends FunctionCatalog {
     return namespace.length == 0;
   }
 
+  @Override
   default Identifier[] listFunctions(String[] namespace) throws NoSuchNamespaceException {
     if (isFunctionNamespace(namespace)) {
       return SparkFunctions.list().stream()
@@ -48,6 +48,7 @@ interface SupportsFunctions extends FunctionCatalog {
     throw new NoSuchNamespaceException(namespace);
   }
 
+  @Override
   default UnboundFunction loadFunction(Identifier ident) throws NoSuchFunctionException {
     String[] namespace = ident.namespace();
     String name = ident.name();
@@ -59,7 +60,6 @@ interface SupportsFunctions extends FunctionCatalog {
       }
     }
 
-    throw new NoSuchFunctionException(
-        String.format("Cannot load function: %s.%s", name(), ident), Option.empty());
+    throw new NoSuchFunctionException(ident);
   }
 }
