@@ -19,10 +19,12 @@
 package org.apache.iceberg.spark.actions;
 
 import static org.apache.iceberg.MetadataTableType.ENTRIES;
+import static org.apache.spark.sql.functions.col;
 
 import java.io.Serializable;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Set;
 import java.util.UUID;
 import java.util.function.Function;
 import java.util.function.Predicate;
@@ -37,6 +39,7 @@ import org.apache.iceberg.ManifestContent;
 import org.apache.iceberg.ManifestFile;
 import org.apache.iceberg.ManifestFiles;
 import org.apache.iceberg.ManifestWriter;
+import org.apache.iceberg.PartitionField;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Partitioning;
 import org.apache.iceberg.RollingManifestWriter;
@@ -71,6 +74,7 @@ import org.apache.spark.sql.Encoder;
 import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SparkSession;
+import org.apache.spark.sql.functions;
 import org.apache.spark.sql.types.StructType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -98,6 +102,8 @@ public class RewriteManifestsSparkAction
           .addedManifests(ImmutableList.of())
           .build();
 
+  private static final String DATA_FILE_PARTITION_COLUMN_NAME = "data_file.partition";
+
   private final Table table;
   private final int formatVersion;
   private final long targetManifestSizeBytes;
@@ -107,6 +113,8 @@ public class RewriteManifestsSparkAction
   private Predicate<ManifestFile> predicate = manifest -> true;
   private String outputLocation;
 
+  private List<String> partitionFieldClustering = null;
+
   RewriteManifestsSparkAction(SparkSession spark, Table table) {
     super(spark);
     this.table = table;
@@ -168,6 +176,30 @@ public class RewriteManifestsSparkAction
     return withJobGroupInfo(info, this::doExecute);
   }
 
+  @Override
+  public RewriteManifestsSparkAction sortBy(List<String> partitionFields) {
+    // Collect set of available partition columns to cluster on
+    Set<String> availablePartitionNames =
+        spec.fields().stream().map(PartitionField::name).collect(Collectors.toSet());
+
+    // Identify specified partition fields that are not available in the spec
+    List<String> missingFields =
+        partitionFields.stream()
+            .filter(field -> !availablePartitionNames.contains(field))
+            .collect(Collectors.toList());
+
+    // Check if these partition fields are included in the spec
+    Preconditions.checkArgument(
+        missingFields.isEmpty(),
+        "Cannot set manifest sorting because specified field(s) %s were not found in current partition spec %s. Spec ID %s",
+        missingFields,
+        this.spec,
+        this.spec.specId());
+
+    this.partitionFieldClustering = partitionFields;
+    return this;
+  }
+
   private RewriteManifests.Result doExecute() {
     List<ManifestFile> rewrittenManifests = Lists.newArrayList();
     List<ManifestFile> addedManifests = Lists.newArrayList();
@@ -255,8 +287,7 @@ public class RewriteManifestsSparkAction
         manifestEntryDF,
         df -> {
           WriteManifests<?> writeFunc = newWriteManifestsFunc(content, df.schema());
-          Column partitionColumn = df.col("data_file.partition");
-          Dataset<Row> transformedDF = repartitionAndSort(df, partitionColumn, numManifests);
+          Dataset<Row> transformedDF = repartitionAndSort(df, sortColumn(), numManifests);
           return writeFunc.apply(transformedDF).collectAsList();
         });
   }
@@ -275,6 +306,28 @@ public class RewriteManifestsSparkAction
     }
   }
 
+  private Column sortColumn() {
+    if (partitionFieldClustering != null) {
+      LOG.info(
+          "Clustering manifests for specId {} by partition columns by {} ",
+          spec.specId(),
+          partitionFieldClustering);
+
+      // Map the top level partition column names to the column name referenced within the manifest
+      // entry dataframe
+      Column[] partitionColumns =
+          partitionFieldClustering.stream()
+              .map(p -> col(DATA_FILE_PARTITION_COLUMN_NAME + "." + p))
+              .toArray(Column[]::new);
+
+      // Form a new temporary column to cluster manifests on, based on the custom clustering columns
+      // order provided
+      return functions.struct(partitionColumns);
+    } else {
+      return new Column(DATA_FILE_PARTITION_COLUMN_NAME);
+    }
+  }
+
   private Dataset<Row> repartitionAndSort(Dataset<Row> df, Column col, int numPartitions) {
     return df.repartitionByRange(numPartitions, col).sortWithinPartitions(col);
   }
