@@ -18,6 +18,7 @@
  */
 package org.apache.iceberg.spark.procedures;
 
+import java.util.Iterator;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.actions.RewriteManifests;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
@@ -27,7 +28,9 @@ import org.apache.iceberg.spark.procedures.SparkProcedures.ProcedureBuilder;
 import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.connector.catalog.Identifier;
 import org.apache.spark.sql.connector.catalog.TableCatalog;
-import org.apache.spark.sql.connector.iceberg.catalog.ProcedureParameter;
+import org.apache.spark.sql.connector.catalog.procedures.BoundProcedure;
+import org.apache.spark.sql.connector.catalog.procedures.ProcedureParameter;
+import org.apache.spark.sql.connector.read.Scan;
 import org.apache.spark.sql.types.DataTypes;
 import org.apache.spark.sql.types.Metadata;
 import org.apache.spark.sql.types.StructField;
@@ -43,11 +46,13 @@ import org.apache.spark.sql.types.StructType;
  */
 class RewriteManifestsProcedure extends BaseProcedure {
 
+  static final String NAME = "rewrite_manifests";
+
   private static final ProcedureParameter[] PARAMETERS =
       new ProcedureParameter[] {
-        ProcedureParameter.required("table", DataTypes.StringType),
-        ProcedureParameter.optional("use_caching", DataTypes.BooleanType),
-        ProcedureParameter.optional("spec_id", DataTypes.IntegerType)
+        requiredInParameter("table", DataTypes.StringType),
+        optionalInParameter("use_caching", DataTypes.BooleanType),
+        optionalInParameter("spec_id", DataTypes.IntegerType)
       };
 
   // counts are not nullable since the action result is never null
@@ -72,18 +77,18 @@ class RewriteManifestsProcedure extends BaseProcedure {
     super(tableCatalog);
   }
 
+  @Override
+  public BoundProcedure bind(StructType inputType) {
+    return this;
+  }
+
   @Override
   public ProcedureParameter[] parameters() {
     return PARAMETERS;
   }
 
   @Override
-  public StructType outputType() {
-    return OUTPUT_TYPE;
-  }
-
-  @Override
-  public InternalRow[] call(InternalRow args) {
+  public Iterator<Scan> call(InternalRow args) {
     Identifier tableIdent = toIdentifier(args.getString(0), PARAMETERS[0].name());
     Boolean useCaching = args.isNullAt(1) ? null : args.getBoolean(1);
     Integer specId = args.isNullAt(2) ? null : args.getInt(2);
@@ -103,7 +108,7 @@ class RewriteManifestsProcedure extends BaseProcedure {
 
           RewriteManifests.Result result = action.execute();
 
-          return toOutputRows(result);
+          return asScanIterator(OUTPUT_TYPE, toOutputRows(result));
         });
   }
 
@@ -114,6 +119,11 @@ class RewriteManifestsProcedure extends BaseProcedure {
     return new InternalRow[] {row};
   }
 
+  @Override
+  public String name() {
+    return NAME;
+  }
+
   @Override
   public String description() {
     return "RewriteManifestsProcedure";
