@@ -18,12 +18,15 @@
  */
 package org.apache.iceberg.spark.procedures;
 
+import java.util.Iterator;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.spark.procedures.SparkProcedures.ProcedureBuilder;
 import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.connector.catalog.Identifier;
 import org.apache.spark.sql.connector.catalog.TableCatalog;
-import org.apache.spark.sql.connector.iceberg.catalog.ProcedureParameter;
+import org.apache.spark.sql.connector.catalog.procedures.BoundProcedure;
+import org.apache.spark.sql.connector.catalog.procedures.ProcedureParameter;
+import org.apache.spark.sql.connector.read.Scan;
 import org.apache.spark.sql.types.DataTypes;
 import org.apache.spark.sql.types.Metadata;
 import org.apache.spark.sql.types.StructField;
@@ -39,10 +42,12 @@ import org.apache.spark.sql.types.StructType;
  */
 class RollbackToSnapshotProcedure extends BaseProcedure {
 
+  static final String NAME = "rollback_to_snapshot";
+
   private static final ProcedureParameter[] PARAMETERS =
       new ProcedureParameter[] {
-        ProcedureParameter.required("table", DataTypes.StringType),
-        ProcedureParameter.required("snapshot_id", DataTypes.LongType)
+        requiredInParameter("table", DataTypes.StringType),
+        requiredInParameter("snapshot_id", DataTypes.LongType)
       };
 
   private static final StructType OUTPUT_TYPE =
@@ -65,18 +70,18 @@ class RollbackToSnapshotProcedure extends BaseProcedure {
     super(tableCatalog);
   }
 
+  @Override
+  public BoundProcedure bind(StructType inputType) {
+    return this;
+  }
+
   @Override
   public ProcedureParameter[] parameters() {
     return PARAMETERS;
   }
 
   @Override
-  public StructType outputType() {
-    return OUTPUT_TYPE;
-  }
-
-  @Override
-  public InternalRow[] call(InternalRow args) {
+  public Iterator<Scan> call(InternalRow args) {
     Identifier tableIdent = toIdentifier(args.getString(0), PARAMETERS[0].name());
     long snapshotId = args.getLong(1);
 
@@ -88,10 +93,15 @@ class RollbackToSnapshotProcedure extends BaseProcedure {
           table.manageSnapshots().rollbackTo(snapshotId).commit();
 
           InternalRow outputRow = newInternalRow(previousSnapshot.snapshotId(), snapshotId);
-          return new InternalRow[] {outputRow};
+          return asScanIterator(OUTPUT_TYPE, outputRow);
         });
   }
 
+  @Override
+  public String name() {
+    return NAME;
+  }
+
   @Override
   public String description() {
     return "RollbackToSnapshotProcedure";
