@@ -19,6 +19,7 @@
 package org.apache.iceberg.spark.source.metrics;
 
 import java.text.NumberFormat;
+import java.util.Locale;
 import org.apache.spark.sql.connector.metric.CustomMetric;
 
 public class NumSplits implements CustomMetric {
@@ -36,10 +37,10 @@ public class NumSplits implements CustomMetric {
   @Override
   public String aggregateTaskMetrics(long[] taskMetrics) {
     long sum = initialValue;
-    for (int i = 0; i < taskMetrics.length; i++) {
-      sum += taskMetrics[i];
+    for (long taskMetric : taskMetrics) {
+      sum += taskMetric;
     }
 
-    return NumberFormat.getIntegerInstance().format(sum);
+    return NumberFormat.getIntegerInstance(Locale.ROOT).format(sum);
   }
 }
