@@ -19,6 +19,8 @@
 package org.apache.iceberg.spark.data;
 
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assumptions.assumeThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -31,6 +33,9 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.Path;
 import org.apache.iceberg.Files;
 import org.apache.iceberg.MetadataColumns;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.data.DeleteFilter;
 import org.apache.iceberg.deletes.PositionDeleteIndex;
@@ -57,16 +62,12 @@ import org.apache.spark.sql.catalyst.expressions.GenericInternalRow;
 import org.apache.spark.sql.types.StructType;
 import org.apache.spark.sql.vectorized.ColumnarBatch;
 import org.apache.spark.unsafe.types.UTF8String;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestSparkParquetReadMetadataColumns {
   private static final Schema DATA_SCHEMA =
       new Schema(
@@ -114,28 +115,24 @@ public class TestSparkParquetReadMetadataColumns {
     }
   }
 
-  @Parameterized.Parameters(name = "vectorized = {0}")
+  @Parameters(name = "vectorized = {0}")
   public static Object[][] parameters() {
     return new Object[][] {new Object[] {false}, new Object[] {true}};
   }
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir protected java.nio.file.Path temp;
 
-  private final boolean vectorized;
+  @Parameter private boolean vectorized;
   private File testFile;
 
-  public TestSparkParquetReadMetadataColumns(boolean vectorized) {
-    this.vectorized = vectorized;
-  }
-
-  @Before
+  @BeforeEach
   public void writeFile() throws IOException {
     List<Path> fileSplits = Lists.newArrayList();
     StructType struct = SparkSchemaUtil.convert(DATA_SCHEMA);
     Configuration conf = new Configuration();
 
-    testFile = temp.newFile();
-    Assert.assertTrue("Delete should succeed", testFile.delete());
+    testFile = File.createTempFile("junit", null, temp.toFile());
+    assertThat(testFile.delete()).as("Delete should succeed").isTrue();
     ParquetFileWriter parquetFileWriter =
         new ParquetFileWriter(
             conf,
@@ -144,8 +141,8 @@ public class TestSparkParquetReadMetadataColumns {
 
     parquetFileWriter.start();
     for (int i = 0; i < NUM_ROW_GROUPS; i += 1) {
-      File split = temp.newFile();
-      Assert.assertTrue("Delete should succeed", split.delete());
+      File split = File.createTempFile("junit", null, temp.toFile());
+      assertThat(split.delete()).as("Delete should succeed").isTrue();
       fileSplits.add(new Path(split.getAbsolutePath()));
       try (FileAppender<InternalRow> writer =
           Parquet.write(Files.localOutput(split))
@@ -164,14 +161,14 @@ public class TestSparkParquetReadMetadataColumns {
             .getKeyValueMetaData());
   }
 
-  @Test
+  @TestTemplate
   public void testReadRowNumbers() throws IOException {
     readAndValidate(null, null, null, EXPECTED_ROWS);
   }
 
-  @Test
+  @TestTemplate
   public void testReadRowNumbersWithDelete() throws IOException {
-    Assume.assumeTrue(vectorized);
+    assumeThat(vectorized).isTrue();
 
     List<InternalRow> expectedRowsAfterDelete = Lists.newArrayList();
     EXPECTED_ROWS.forEach(row -> expectedRowsAfterDelete.add(row.copy()));
@@ -229,7 +226,7 @@ public class TestSparkParquetReadMetadataColumns {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testReadRowNumbersWithFilter() throws IOException {
     // current iceberg supports row group filter.
     for (int i = 1; i < 5; i += 1) {
@@ -243,7 +240,7 @@ public class TestSparkParquetReadMetadataColumns {
     }
   }
 
-  @Test
+  @TestTemplate
   public void testReadRowNumbersWithSplits() throws IOException {
     ParquetFileReader fileReader =
         new ParquetFileReader(
@@ -295,11 +292,11 @@ public class TestSparkParquetReadMetadataColumns {
       final Iterator<InternalRow> actualRows = reader.iterator();
 
       for (InternalRow internalRow : expected) {
-        Assert.assertTrue("Should have expected number of rows", actualRows.hasNext());
+        assertThat(actualRows).as("Should have expected number of rows").hasNext();
         TestHelpers.assertEquals(PROJECTION_SCHEMA, internalRow, actualRows.next());
       }
 
-      Assert.assertFalse("Should not have extra rows", actualRows.hasNext());
+      assertThat(actualRows).as("Should not have extra rows").isExhausted();
     }
   }
 
