@@ -23,6 +23,11 @@ import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 
 public class TestAvroDataFrameWrite extends DataFrameWriteTestBase {
+  @Override
+  protected boolean supportsVariant() {
+    return true;
+  }
+
   @Override
   protected void configureTable(Table table) {
     table
