@@ -24,10 +24,12 @@ import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.math.BigDecimal;
 import java.util.List;
+import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.TableProperties;
+import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.spark.Spark3Util;
-import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
+import org.apache.iceberg.spark.TestBaseWithCatalog;
 import org.apache.iceberg.types.Type;
 import org.apache.iceberg.types.Types;
 import org.apache.spark.sql.AnalysisException;
@@ -38,23 +40,24 @@ import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.sql.catalyst.parser.ParseException;
 import org.apache.spark.sql.internal.SQLConf;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
-  @Before
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestDataFrameWriterV2 extends TestBaseWithCatalog {
+  @BeforeEach
   public void createTable() {
     sql("CREATE TABLE %s (id bigint, data string) USING iceberg", tableName);
   }
 
-  @After
+  @AfterEach
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Test
+  @TestTemplate
   public void testMergeSchemaFailsWithoutWriterOption() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -86,7 +89,7 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
         .hasMessage("Field new_col not found in source schema");
   }
 
-  @Test
+  @TestTemplate
   public void testMergeSchemaWithoutAcceptAnySchema() throws Exception {
     Dataset<Row> twoColDF =
         jsonToDF(
@@ -109,11 +112,11 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
 
     assertThatThrownBy(() -> threeColDF.writeTo(tableName).option("merge-schema", "true").append())
         .isInstanceOf(AnalysisException.class)
-        .hasMessageStartingWith(
-            "Cannot write to 'testhadoop.default.table', too many data columns");
+        .hasMessageContaining(
+            "Cannot write to `testhadoop`.`default`.`table`, the reason is too many data columns");
   }
 
-  @Test
+  @TestTemplate
   public void testMergeSchemaSparkProperty() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -147,7 +150,7 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
         sql("select * from %s order by id", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testMergeSchemaIcebergProperty() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -181,9 +184,14 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
         sql("select * from %s order by id", tableName));
   }
 
-  @Test
+  @TestTemplate
   public void testWriteWithCaseSensitiveOption() throws NoSuchTableException, ParseException {
-    SparkSession sparkSession = spark.cloneSession();
+    Preconditions.checkArgument(
+        spark instanceof org.apache.spark.sql.classic.SparkSession,
+        "Expected instance of org.apache.spark.sql.classic.SparkSession, but got: %s",
+        spark.getClass().getName());
+
+    SparkSession sparkSession = ((org.apache.spark.sql.classic.SparkSession) spark).cloneSession();
     sparkSession
         .sql(
             String.format(
@@ -205,16 +213,51 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
     List<Types.NestedField> fields =
         Spark3Util.loadIcebergTable(sparkSession, tableName).schema().asStruct().fields();
     // Additional columns should not be created
-    Assert.assertEquals(2, fields.size());
+    assertThat(fields).hasSize(2);
 
     // enable spark.sql.caseSensitive
     sparkSession.sql(String.format("SET %s=true", SQLConf.CASE_SENSITIVE().key()));
     ds.writeTo(tableName).option("merge-schema", "true").option("check-ordering", "false").append();
     fields = Spark3Util.loadIcebergTable(sparkSession, tableName).schema().asStruct().fields();
-    Assert.assertEquals(4, fields.size());
+    assertThat(fields).hasSize(4);
   }
 
-  @Test
+  @TestTemplate
+  public void testMergeSchemaSparkConfiguration() throws Exception {
+    sql(
+        "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
+        tableName, TableProperties.SPARK_WRITE_ACCEPT_ANY_SCHEMA);
+    Dataset<Row> twoColDF =
+        jsonToDF(
+            "id bigint, data string",
+            "{ \"id\": 1, \"data\": \"a\" }",
+            "{ \"id\": 2, \"data\": \"b\" }");
+
+    twoColDF.writeTo(tableName).append();
+
+    assertEquals(
+        "Should have initial 2-column rows",
+        ImmutableList.of(row(1L, "a"), row(2L, "b")),
+        sql("select * from %s order by id", tableName));
+    spark.conf().set("spark.sql.iceberg.merge-schema", "true");
+    Dataset<Row> threeColDF =
+        jsonToDF(
+            "id bigint, data string, salary float",
+            "{ \"id\": 3, \"data\": \"c\", \"salary\": 120000.34 }",
+            "{ \"id\": 4, \"data\": \"d\", \"salary\": 140000.56 }");
+
+    threeColDF.writeTo(tableName).append();
+    assertEquals(
+        "Should have 3-column rows",
+        ImmutableList.of(
+            row(1L, "a", null),
+            row(2L, "b", null),
+            row(3L, "c", 120000.34F),
+            row(4L, "d", 140000.56F)),
+        sql("select * from %s order by id", tableName));
+  }
+
+  @TestTemplate
   public void testMergeSchemaIgnoreCastingLongToInt() throws Exception {
     sql(
         "ALTER TABLE %s SET TBLPROPERTIES ('%s'='true')",
@@ -254,7 +297,7 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
     assertThat(idField.type().typeId()).isEqualTo(Type.TypeID.LONG);
   }
 
-  @Test
+  @TestTemplate
   public void testMergeSchemaIgnoreCastingDoubleToFloat() throws Exception {
     removeTables();
     sql("CREATE TABLE %s (id double, data string) USING iceberg", tableName);
@@ -296,7 +339,7 @@ public class TestDataFrameWriterV2 extends SparkTestBaseWithCatalog {
     assertThat(idField.type().typeId()).isEqualTo(Type.TypeID.DOUBLE);
   }
 
-  @Test
+  @TestTemplate
   public void testMergeSchemaIgnoreCastingDecimalToDecimalWithNarrowerPrecision() throws Exception {
     removeTables();
     sql("CREATE TABLE %s (id decimal(6,2), data string) USING iceberg", tableName);
