@@ -24,6 +24,7 @@ import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.IOException;
+import java.net.InetAddress;
 import java.net.URI;
 import java.nio.file.Files;
 import java.sql.Timestamp;
@@ -41,6 +42,7 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.RawLocalFileSystem;
+import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.Parameter;
 import org.apache.iceberg.ParameterizedTestExtension;
 import org.apache.iceberg.Parameters;
@@ -51,6 +53,7 @@ import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.expressions.Literal;
 import org.apache.iceberg.hadoop.HadoopTables;
+import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
@@ -83,16 +86,16 @@ public class TestPartitionPruning {
   @Parameters(name = "format = {0}, vectorized = {1}, planningMode = {2}")
   public static Object[][] parameters() {
     return new Object[][] {
-      {"parquet", false, DISTRIBUTED},
-      {"parquet", true, LOCAL},
-      {"avro", false, DISTRIBUTED},
-      {"orc", false, LOCAL},
-      {"orc", true, DISTRIBUTED}
+      {FileFormat.PARQUET, false, DISTRIBUTED},
+      {FileFormat.PARQUET, true, LOCAL},
+      {FileFormat.AVRO, false, DISTRIBUTED},
+      {FileFormat.ORC, false, LOCAL},
+      {FileFormat.ORC, true, DISTRIBUTED}
     };
   }
 
   @Parameter(index = 0)
-  private String format;
+  private FileFormat format;
 
   @Parameter(index = 1)
   private boolean vectorized;
@@ -112,7 +115,11 @@ public class TestPartitionPruning {
 
   @BeforeAll
   public static void startSpark() {
-    TestPartitionPruning.spark = SparkSession.builder().master("local[2]").getOrCreate();
+    TestPartitionPruning.spark =
+        SparkSession.builder()
+            .master("local[2]")
+            .config("spark.driver.host", InetAddress.getLoopbackAddress().getHostAddress())
+            .getOrCreate();
     TestPartitionPruning.sparkContext = JavaSparkContext.fromSparkContext(spark.sparkContext());
 
     String optionKey = String.format("fs.%s.impl", CountOpenLocalFileSystem.scheme);
@@ -283,9 +290,7 @@ public class TestPartitionPruning {
             .filter(filterCond)
             .orderBy("id")
             .collectAsList();
-    assertThat(actual).as("Actual rows should not be empty").isNotEmpty();
-
-    assertThat(actual).as("Rows should match").isEqualTo(expected);
+    assertThat(actual).isNotEmpty().isEqualTo(expected);
 
     assertAccessOnDataFiles(originTableLocation, table, partCondition);
   }
@@ -302,7 +307,7 @@ public class TestPartitionPruning {
     String trackedTableLocation = CountOpenLocalFileSystem.convertPath(originTableLocation);
     Map<String, String> properties =
         ImmutableMap.of(
-            TableProperties.DEFAULT_FILE_FORMAT, format,
+            TableProperties.DEFAULT_FILE_FORMAT, format.toString(),
             TableProperties.DATA_PLANNING_MODE, planningMode.modeName(),
             TableProperties.DELETE_PLANNING_MODE, planningMode.modeName());
     return TABLES.create(LOG_SCHEMA, spec, properties, trackedTableLocation);
@@ -327,9 +332,15 @@ public class TestPartitionPruning {
             .collect(Collectors.toList());
 
     JavaRDD<InternalRow> rdd = sparkContext.parallelize(rows);
+    Preconditions.checkArgument(
+        spark instanceof org.apache.spark.sql.classic.SparkSession,
+        "Expected instance of org.apache.spark.sql.classic.SparkSession, but got: %s",
+        spark.getClass().getName());
+
     Dataset<Row> df =
-        spark.internalCreateDataFrame(
-            JavaRDD.toRDD(rdd), SparkSchemaUtil.convert(LOG_SCHEMA), false);
+        ((org.apache.spark.sql.classic.SparkSession) spark)
+            .internalCreateDataFrame(
+                JavaRDD.toRDD(rdd), SparkSchemaUtil.convert(LOG_SCHEMA), false);
 
     return df.selectExpr("id", "date", "level", "message", "timestamp")
         .selectExpr(
