@@ -24,19 +24,21 @@ import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
-import java.io.IOException;
+import java.net.InetAddress;
+import java.nio.file.Path;
 import java.util.List;
 import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
-import org.apache.iceberg.PlanningMode;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.hadoop.HadoopTables;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
-import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.iceberg.spark.SparkSchemaUtil;
@@ -46,21 +48,29 @@ import org.apache.spark.sql.Encoders;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.RowFactory;
 import org.apache.spark.sql.SparkSession;
-import org.junit.AfterClass;
-import org.junit.Assert;
-import org.junit.BeforeClass;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestSnapshotSelection {
 
-  @Parameterized.Parameters(name = "planningMode = {0}")
+  @Parameters(name = "properties = {0}")
   public static Object[] parameters() {
-    return new Object[] {LOCAL, DISTRIBUTED};
+    return new Object[][] {
+      {
+        ImmutableMap.of(
+            TableProperties.DATA_PLANNING_MODE, LOCAL.modeName(),
+            TableProperties.DELETE_PLANNING_MODE, LOCAL.modeName())
+      },
+      {
+        ImmutableMap.of(
+            TableProperties.DATA_PLANNING_MODE, DISTRIBUTED.modeName(),
+            TableProperties.DELETE_PLANNING_MODE, DISTRIBUTED.modeName())
+      }
+    };
   }
 
   private static final Configuration CONF = new Configuration();
@@ -68,34 +78,32 @@ public class TestSnapshotSelection {
       new Schema(
           optional(1, "id", Types.IntegerType.get()), optional(2, "data", Types.StringType.get()));
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir private Path temp;
 
   private static SparkSession spark = null;
 
-  private final Map<String, String> properties;
+  @Parameter(index = 0)
+  private Map<String, String> properties;
 
-  public TestSnapshotSelection(PlanningMode planningMode) {
-    this.properties =
-        ImmutableMap.of(
-            TableProperties.DATA_PLANNING_MODE, planningMode.modeName(),
-            TableProperties.DELETE_PLANNING_MODE, planningMode.modeName());
-  }
-
-  @BeforeClass
+  @BeforeAll
   public static void startSpark() {
-    TestSnapshotSelection.spark = SparkSession.builder().master("local[2]").getOrCreate();
+    TestSnapshotSelection.spark =
+        SparkSession.builder()
+            .master("local[2]")
+            .config("spark.driver.host", InetAddress.getLoopbackAddress().getHostAddress())
+            .getOrCreate();
   }
 
-  @AfterClass
+  @AfterAll
   public static void stopSpark() {
     SparkSession currentSpark = TestSnapshotSelection.spark;
     TestSnapshotSelection.spark = null;
     currentSpark.stop();
   }
 
-  @Test
-  public void testSnapshotSelectionById() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionById() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -115,7 +123,7 @@ public class TestSnapshotSelection {
     Dataset<Row> secondDf = spark.createDataFrame(secondBatchRecords, SimpleRecord.class);
     secondDf.select("id", "data").write().format("iceberg").mode("append").save(tableLocation);
 
-    Assert.assertEquals("Expected 2 snapshots", 2, Iterables.size(table.snapshots()));
+    assertThat(table.snapshots()).as("Expected 2 snapshots").hasSize(2);
 
     // verify records in the current snapshot
     Dataset<Row> currentSnapshotResult = spark.read().format("iceberg").load(tableLocation);
@@ -124,8 +132,9 @@ public class TestSnapshotSelection {
     List<SimpleRecord> expectedRecords = Lists.newArrayList();
     expectedRecords.addAll(firstBatchRecords);
     expectedRecords.addAll(secondBatchRecords);
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, currentSnapshotRecords);
+    assertThat(currentSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
 
     // verify records in the previous snapshot
     Snapshot currentSnapshot = table.currentSnapshot();
@@ -134,13 +143,14 @@ public class TestSnapshotSelection {
         spark.read().format("iceberg").option("snapshot-id", parentSnapshotId).load(tableLocation);
     List<SimpleRecord> previousSnapshotRecords =
         previousSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals(
-        "Previous snapshot rows should match", firstBatchRecords, previousSnapshotRecords);
+    assertThat(previousSnapshotRecords)
+        .as("Previous snapshot rows should match")
+        .isEqualTo(firstBatchRecords);
   }
 
-  @Test
-  public void testSnapshotSelectionByTimestamp() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByTimestamp() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -163,7 +173,7 @@ public class TestSnapshotSelection {
     Dataset<Row> secondDf = spark.createDataFrame(secondBatchRecords, SimpleRecord.class);
     secondDf.select("id", "data").write().format("iceberg").mode("append").save(tableLocation);
 
-    Assert.assertEquals("Expected 2 snapshots", 2, Iterables.size(table.snapshots()));
+    assertThat(table.snapshots()).as("Expected 2 snapshots").hasSize(2);
 
     // verify records in the current snapshot
     Dataset<Row> currentSnapshotResult = spark.read().format("iceberg").load(tableLocation);
@@ -172,8 +182,9 @@ public class TestSnapshotSelection {
     List<SimpleRecord> expectedRecords = Lists.newArrayList();
     expectedRecords.addAll(firstBatchRecords);
     expectedRecords.addAll(secondBatchRecords);
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, currentSnapshotRecords);
+    assertThat(currentSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
 
     // verify records in the previous snapshot
     Dataset<Row> previousSnapshotResult =
@@ -184,13 +195,14 @@ public class TestSnapshotSelection {
             .load(tableLocation);
     List<SimpleRecord> previousSnapshotRecords =
         previousSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals(
-        "Previous snapshot rows should match", firstBatchRecords, previousSnapshotRecords);
+    assertThat(previousSnapshotRecords)
+        .as("Previous snapshot rows should match")
+        .isEqualTo(firstBatchRecords);
   }
 
-  @Test
-  public void testSnapshotSelectionByInvalidSnapshotId() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByInvalidSnapshotId() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -203,11 +215,11 @@ public class TestSnapshotSelection {
         .hasMessage("Cannot find snapshot with ID -10");
   }
 
-  @Test
-  public void testSnapshotSelectionByInvalidTimestamp() throws IOException {
+  @TestTemplate
+  public void testSnapshotSelectionByInvalidTimestamp() {
     long timestamp = System.currentTimeMillis();
 
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
     tables.create(SCHEMA, spec, properties, tableLocation);
@@ -223,9 +235,9 @@ public class TestSnapshotSelection {
         .hasMessageContaining("Cannot find a snapshot older than");
   }
 
-  @Test
-  public void testSnapshotSelectionBySnapshotIdAndTimestamp() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionBySnapshotIdAndTimestamp() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -255,9 +267,9 @@ public class TestSnapshotSelection {
         .hasMessageContaining("tag");
   }
 
-  @Test
-  public void testSnapshotSelectionByTag() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByTag() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -286,13 +298,14 @@ public class TestSnapshotSelection {
         currentSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
     List<SimpleRecord> expectedRecords = Lists.newArrayList();
     expectedRecords.addAll(firstBatchRecords);
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, currentSnapshotRecords);
+    assertThat(currentSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
   }
 
-  @Test
-  public void testSnapshotSelectionByBranch() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByBranch() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -321,13 +334,14 @@ public class TestSnapshotSelection {
         currentSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
     List<SimpleRecord> expectedRecords = Lists.newArrayList();
     expectedRecords.addAll(firstBatchRecords);
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, currentSnapshotRecords);
+    assertThat(currentSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
   }
 
-  @Test
-  public void testSnapshotSelectionByBranchAndTagFails() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByBranchAndTagFails() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -356,9 +370,9 @@ public class TestSnapshotSelection {
         .hasMessageStartingWith("Can specify only one of snapshot-id");
   }
 
-  @Test
-  public void testSnapshotSelectionByTimestampAndBranchOrTagFails() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByTimestampAndBranchOrTagFails() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -399,9 +413,9 @@ public class TestSnapshotSelection {
         .hasMessageStartingWith("Can specify only one of snapshot-id");
   }
 
-  @Test
-  public void testSnapshotSelectionByBranchWithSchemaChange() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByBranchWithSchemaChange() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -422,8 +436,9 @@ public class TestSnapshotSelection {
         branchSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
     List<SimpleRecord> expectedRecords = Lists.newArrayList();
     expectedRecords.addAll(firstBatchRecords);
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, branchSnapshotRecords);
+    assertThat(branchSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
 
     // Deleting a column to indicate schema change
     table.updateSchema().deleteColumn("data").commit();
@@ -455,9 +470,9 @@ public class TestSnapshotSelection {
             new SimpleRecord(1, null), new SimpleRecord(2, null), new SimpleRecord(3, null));
   }
 
-  @Test
-  public void testWritingToBranchAfterSchemaChange() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testWritingToBranchAfterSchemaChange() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -478,8 +493,9 @@ public class TestSnapshotSelection {
         branchSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
     List<SimpleRecord> expectedRecords = Lists.newArrayList();
     expectedRecords.addAll(firstBatchRecords);
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, branchSnapshotRecords);
+    assertThat(branchSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
 
     // Deleting and add a new column of the same type to indicate schema change
     table.updateSchema().deleteColumn("data").addColumn("zip", Types.IntegerType.get()).commit();
@@ -528,9 +544,9 @@ public class TestSnapshotSelection {
         .containsAll(records);
   }
 
-  @Test
-  public void testSnapshotSelectionByTagWithSchemaChange() throws IOException {
-    String tableLocation = temp.newFolder("iceberg-table").toString();
+  @TestTemplate
+  public void testSnapshotSelectionByTagWithSchemaChange() {
+    String tableLocation = temp.resolve("iceberg-table").toFile().toString();
 
     HadoopTables tables = new HadoopTables(CONF);
     PartitionSpec spec = PartitionSpec.unpartitioned();
@@ -552,7 +568,9 @@ public class TestSnapshotSelection {
         spark.read().format("iceberg").option("tag", "tag").load(tableLocation);
     List<SimpleRecord> tagSnapshotRecords =
         tagSnapshotResult.orderBy("id").as(Encoders.bean(SimpleRecord.class)).collectAsList();
-    Assert.assertEquals("Current snapshot rows should match", expectedRecords, tagSnapshotRecords);
+    assertThat(tagSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
 
     // Deleting a column to indicate schema change
     table.updateSchema().deleteColumn("data").commit();
@@ -565,7 +583,8 @@ public class TestSnapshotSelection {
             .orderBy("id")
             .as(Encoders.bean(SimpleRecord.class))
             .collectAsList();
-    Assert.assertEquals(
-        "Current snapshot rows should match", expectedRecords, deletedColumnTagSnapshotRecords);
+    assertThat(deletedColumnTagSnapshotRecords)
+        .as("Current snapshot rows should match")
+        .isEqualTo(expectedRecords);
   }
 }
